@@ -30,8 +30,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IEXTENSIONFACTORY_H
 
 
-class iAnimator;
-class iAnimatorScript;
 class iRenderTool;
 class iViewModule;
 
@@ -41,7 +39,6 @@ class iExtensionFactory
 	
 public:
 		
-	static iAnimatorScript*		CreateAnimatorScript(iAnimator *animator);
 	static iRenderTool*			CreateRenderTool(iViewModule *vm);
 };
 
