@@ -33,12 +33,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  IFrIT version
 //
-#define IVERSION_BASE			"3.2.8"
+#define IVERSION_BASE			"3.3.2"
 
-#define IVERSION_EXT_ART		"2.2.0"
-#define IVERSION_EXT_MV			"1.1.0"
-#define IVERSION_EXT_VTK		"1.0.0"
-#define IVERSION_EXT_GADGET		"1.0.0"
+#define IVERSION_EXT_ART		"2.3.1"
+#define IVERSION_EXT_MV			"1.2.1"
+#define IVERSION_EXT_VTK		"1.1.0"
+#define IVERSION_EXT_GADGET		"1.1.0"
 
 //
 //  History
@@ -125,8 +125,24 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //			MultiView extension redone, port to VTK 5.2, fixed overlays
 //
 //  090822  Base-3.2.8    ART-2.2.0    MV-1.1.0    VTK-1.0.0     GADGET-1.0.0
-//          Fixed isosurface making for left/right coordinate systems in ART extension (not quite)
-//			Renamed HART extension into ART extension and DID NOT add support for CART
+//          Fixed isosurface making for left/right coordinate systems in ART extension
+//			Renamed HART extension into ART extension and added support for CART
+//
+//  091210  Base-3.2.9    ART-2.2.1    MV-1.1.0    VTK-1.0.0     GADGET-1.0.0
+//          Added double precision particle positions reading for CART
+//			Fixed a few minor bugs
+//
+//  100222  Base-3.3.0    ART-2.3.0    MV-1.2.0    VTK-1.1.0     GADGET-1.1.0
+//          Removed last vestiges of Qt3 when using Qt4 - Qt3Support is not needed any more
+//			Ported to 64-bin windows
+//
+//  100315  Base-3.3.1    ART-2.3.0    MV-1.2.0    VTK-1.1.0     GADGET-1.1.0
+//          Emergency release: removed support for VTK 5.4 due to its performance bug
+//
+//  100503  Base-3.3.2    ART-2.3.1    MV-1.2.1    VTK-1.1.0     GADGET-1.1.0
+//          Fixed bug with ART streamlines, fixed anti-aliasiang bug in docking, blocked
+//			all extraneous functions in iggRenderWindow, re-factored the stereo mode to
+//			fix the flicker reported by Doug and stereo non-recongnition reported by Patrick.
 //
 
 //
@@ -134,11 +150,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  1. Point sprats for particles
 //  2. Multiple images in Composer (do we need this???)
-//  3. CART support
 //
 
 #if ISHELL_INCLUDED(ISHELL_QT)
-#include <qglobal.h>
+#include "iqt.h"
 #endif
 
 
