@@ -36,16 +36,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkConfigure.h>
 
 
-#if (VTK_MAJOR_VERSION<4 || (VTK_MAJOR_VERSION==4 && VTK_MINOR_VERSION<4))
+#if (VTK_MAJOR_VERSION < 5)
 #error "This version of VTK is too old and is no longer supported."
 #endif
 
 
-
-#if (VTK_MAJOR_VERSION==4 && VTK_MINOR_VERSION==4)
-#define IVTK_44
-#endif
-
 #if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION==0)
 #define IVTK_50
 #if (VTK_BUILD_VERSION < 2)
@@ -56,30 +51,26 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION==2)
 #define IVTK_52
 #endif
+#if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION<2)
+#define IVTK_PRE52
+#endif
+
 
 #if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION==4)
 #define IVTK_54
-#if (VTK_BUILD_VERSION < 1)
-#define IVTK_540
+#error "VTK 5.4 is not supported at present due to a severe performance bug."
 #endif
+#if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION<4)
+#define IVTK_PRE54
 #endif
 
+#if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION==6)
+#define IVTK_56
+#endif
+#if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION<6)
+#define IVTK_PRE56
+#endif
 
-#ifdef IVTK_44
-
-class vtkSource;
-typedef vtkSource ivtkFilter;
-class vtkDataSetToPolyDataFilter;
-typedef vtkDataSetToPolyDataFilter ivtkPolyDataFilter;
-
-#define IVTK_QUAD_ORDER 0
-
-#else
-
-class vtkAlgorithm;
-typedef vtkAlgorithm ivtkFilter;
-class vtkPolyDataAlgorithm;
-typedef vtkPolyDataAlgorithm ivtkPolyDataFilter;
 
 #define IVTK_QUAD_ORDER 3
 
@@ -91,24 +82,12 @@ typedef vtkPolyDataAlgorithm ivtkPolyDataFilter;
 #define IVTK_SUPPORTS_MPEG
 #endif
 
+
+#ifdef VTK_PRE56
+#define vtkSwitch(s) ((s)?1:0)
+#else
+#define vtkSwitch(s) (s)
 #endif
 
 
-#if defined(IVTK_44) || defined(IVTK_50)
-#define IVTK_PRE52
-#endif
-
-
-#if defined(IVTK_PRE52) || defined(IVTK_52)
-#define IVTK_PRE54
-#endif
-
-#if defined(IVTK_540)
-//
-//  A bug workaround - hopefully, temporary!!!
-//
-#include <vtkOpenGLPolyDataMapper.h>
-#define vtkPolyDataMapper vtkOpenGLPolyDataMapper
-#endif
-
 #endif // IVTK_H
