@@ -34,8 +34,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "ilookuptable.h"
 #include "ipalette.h"
-#include "iparameter.h"
-#include "ivtk.h"
 
 #include <vtkCamera.h>
 #include <vtkLookupTable.h>
@@ -110,36 +108,9 @@ void iActor::InstallArtifactCorrector(iArtifactCorrector *c)
 {
 	if(c == mCorrector) return;
 
-	if(mCorrector == 0)
-	{
-		c->SetInput(mDefaultMapper->GetInput());
-		mDefaultMapper->SetInput(c->GetOutput());
-	}
-	else
-	{
-		if(c == 0)
-		{
-#ifdef IVTK_44
-			mDefaultMapper->SetInput(mCorrector->GetInput());
-#else
-			mDefaultMapper->SetInput(mCorrector->GetPolyDataInput(0));
-#endif
-		}
-		else
-		{
-			c->SetInput(mCorrector->GetInput());
-#ifdef IVTK_44
-			mDefaultMapper->SetInput(c->GetInput());
-#else
-			mDefaultMapper->SetInput(c->GetPolyDataInput(0));
-#endif
-		}
-		mCorrector->UnRegister(this);
-	}
-
+	if(mCorrector != 0) mCorrector->UnRegister(this);
 	mCorrector = c;
 	mCorrector->Register(this);
-	this->Modified();
 }
 
 
@@ -222,7 +193,12 @@ void iActor::Render(vtkRenderer *ren, vtkMapper * /*m*/)
 		this->SetScale(mAxisScale[0],mAxisScale[1],mAxisScale[2]);
 	}
 	
-	if(mCorrector != 0) mCorrector->CorrectArtifacts(ren,this->GetProperty());
+
+	if(mCorrector != 0)
+	{
+		vtkPolyDataMapper *m = vtkPolyDataMapper::SafeDownCast(this->Mapper);
+		if(m != 0) mCorrector->CorrectArtifacts(ren,this->GetProperty(),m,this->AllocatedRenderTime);
+	}
 
 	//
 	//  Fix VTK bug
@@ -272,20 +248,15 @@ void iActor::SetAxisScale(double sx, double sy, double sz)
 //
 void iActor::SetInput(vtkPolyData *data)
 {
-	if(mCorrector == 0)
-	{
-		mDefaultMapper->SetInput(data);
-	}
-	else
-	{
-		mCorrector->SetInput(data);
-		mDefaultMapper->SetInput(mCorrector->GetOutput());
-	}
+	mDefaultMapper->SetInput(data);
 
 	vtkMapper *save = this->Mapper;
 	this->Mapper = mDefaultMapper;
 	this->UpdateOwnLODs();
 	this->Mapper = save;
+
+	vtkPolyDataMapper *m = vtkPolyDataMapper::SafeDownCast(this->Mapper);
+	if(m != 0) m->SetInput(data);
 }
 	
 
@@ -314,7 +285,7 @@ void iActor::SyncWithLimits(iDataLimits *l, int v, float scale)
 {
 	if(l!=0 && scale>0.0f && v>=0 && v<l->GetNumVars())
 	{
-		mLookupTable->SetStretch(iParameter::_StretchLin);
+		mLookupTable->SetStretch(iDataStretch::Linear);
 		this->SetScalarRange(l->GetLowerLimit(v)/scale,l->GetUpperLimit(v)/scale);
 		mLookupTable->SetStretch(l->GetStretch(v));
 	}
@@ -422,14 +393,3 @@ bool iActorSubjectPointer::operator==(const iActorSubjectPointer &p) const
 	}
 	else return (mPointer == p.mPointer);
 }
-
-
-bool iActorSubjectPointer::operator<(const iActorSubjectPointer &p) const
-{
-	if(mPointer!=0 && p.mPointer!=0)
-	{
-		return ((unsigned long)mPointer->mWindow < (unsigned long)p.mPointer->mWindow); 
-	}
-	else return ((unsigned long)mPointer < (unsigned long)p.mPointer);
-}
-
