@@ -85,7 +85,6 @@ public:
 	void operator=(iActorSubject *p);
 	void operator=(const iActorSubjectPointer &p);
 	bool operator==(const iActorSubjectPointer &p) const;
-	bool operator<(const iActorSubjectPointer &p) const;
 
 private:
 
@@ -143,7 +142,7 @@ private:
 
 	double mBasicScale, mAxisScale[3];
 	bool mScaled;
-	iOrderedArray<iActorSubjectPointer> mSubjects;
+	iSearchableArray<iActorSubjectPointer> mSubjects;
 	iActorSubject *mDummySubject, *mCurrentSubject;
 	iActorSubjectPointer mDummySubjectPointer;
 	vtkPolyDataMapper *mDefaultMapper;
