@@ -502,7 +502,7 @@ bool iAnimator::SetTitlePageFile(const iString &s)
 bool iAnimator::LoadScriptFile(const iString &name)
 {
 	iString fname(name);
-	iDirectory::ExpandFileName(fname,this->GetViewModule()->GetControlModule()->GetShell()->GetEnvironment(_EnvironmentScript));
+	iDirectory::ExpandFileName(fname,this->GetViewModule()->GetControlModule()->GetShell()->GetEnvironment(Environment::Script));
 
 	iFile f(fname);
 	if(!f.Open(iFile::_Read,iFile::_Text))
@@ -1000,7 +1000,7 @@ bool iAnimator::RenderImages(bool dumpImage)
 	if(mDebugFlag==0 && dumpImage)
 	{
 		this->GetErrorStatus()->Monitor(this->GetViewModule()->GetErrorStatus(),true);
-		this->GetViewModule()->DumpImages(images,_ImageTypeAnimationFrame);
+		this->GetViewModule()->DumpImages(images,ImageType::AnimationFrame);
 	}
 
 	return this->GetErrorStatus()->NoError();
