@@ -268,7 +268,7 @@ private:
 	void RestoreState();
 
 	bool mStarted, mStartedRender, mUseScript, mRestoreCamera, mInheritSettings, mIsPlayingDemo;
-	long mSeed;
+	unsigned long mSeed;
 	int mDebugFlag;
 
 	iString mScriptFileName, mScriptText;
