@@ -482,7 +482,7 @@ bool iAnimatorScript::ExecuteControlScript(iScript *self, const iString& filenam
 	}
 
 	iString fname(filename);
-	iDirectory::ExpandFileName(fname,curControl->GetShell()->GetEnvironment(_EnvironmentBase));
+	iDirectory::ExpandFileName(fname,curControl->GetShell()->GetEnvironment(Environment::Base));
 
 	iFile f(fname);
 	if(!f.Open(iFile::_Read,iFile::_Text))
