@@ -41,7 +41,8 @@ class iBoundedPlaneSource : public iBoundedPolyDataSource
 
 public:
 	
-	static iBoundedPlaneSource* New(iViewSubject *vo);
+	vtkTypeMacro(iBoundedPlaneSource,iBoundedPolyDataSource);
+	static iBoundedPlaneSource* New(iViewSubject *vo = 0);
 
 protected:
 	
@@ -53,6 +54,8 @@ protected:
 	virtual void AddObserverToSource(unsigned long e, vtkCommand *c, float priority);
 	virtual float GetSourceMemorySize() const;
 
+private:
+
 	//
 	//  VTK stuff
 	//
