@@ -42,7 +42,8 @@ class iBoundedSphereSource : public iBoundedPolyDataSource
 
 public:
 	
-	static iBoundedSphereSource* New(iViewSubject *vo);
+	vtkTypeMacro(iBoundedSphereSource,iBoundedPolyDataSource);
+	static iBoundedSphereSource* New(iViewSubject *vo = 0);
 
 protected:
 	
@@ -54,6 +55,8 @@ protected:
 	virtual void AddObserverToSource(unsigned long e, vtkCommand *c, float priority);
 	virtual float GetSourceMemorySize() const;
 
+private:
+
 	//
 	//  VTK stuff
 	//
