@@ -47,6 +47,16 @@ iBuffer<T>::~iBuffer()
 }
 
 
+template<class T>
+void iBuffer<T>::Reset(bool fill0)
+{
+	delete [] this->mArr;
+	this->mLen = 100;
+	this->mArr = new T[this->mLen]; IERROR_ASSERT(this->mArr);
+	if(fill0) memset(this->mArr,0,this->mLen*sizeof(T));
+}
+
+
 template<class T>
 T& iBuffer<T>::operator[](int i)
 {
