@@ -140,7 +140,7 @@ iCameraPath::~iCameraPath()
 
 void iCameraPath::SetEnabled(bool s)
 {
-	if(s && mCamPathWidget->GetEnabled()==0)
+	if(s && !this->GetEnabled())
 	{
 		mCamPathWidget->SetEnabled(1);
 		mFocPathWidget->SetEnabled(mIsFocalPath?1:0);
@@ -150,7 +150,7 @@ void iCameraPath::SetEnabled(bool s)
 		mCamPathWidget->InvokeEvent(vtkCommand::InteractionEvent);
 		if(mIsFocalPath) mFocPathWidget->InvokeEvent(vtkCommand::InteractionEvent);
 	}
-	if(!s && mCamPathWidget->GetEnabled()!=0)
+	if(!s && this->GetEnabled())
 	{
 		mCamPathWidget->SetEnabled(0);
 		mFocPathWidget->SetEnabled(0);
