@@ -81,6 +81,14 @@ public:
 	void SetFocalPathHandlePosition(int n, double x[3]);
 	void GetFocalPathHandlePosition(int n, double x[3]) const;
 
+	//
+	//  Special forms for Animator packing/unpacking
+	//
+	void SetCameraPathHandlePositions(int dir, const float *x);
+	void GetCameraPathHandlePositions(float *x1, float *x2, float *x3) const;
+	void SetFocalPathHandlePositions(int dir, const float *x);
+	void GetFocalPathHandlePositions(float *x1, float *x2, float *x3) const;
+
 	vtkPoints* GetCameraPathPoints();
 	vtkPoints* GetFocalPathPoints();
 
