@@ -32,12 +32,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icaption.h"
 #include "imarker.h"
 #include "imarkerfamily.h"
+#include "irendertool.h"
 #include "iviewmodule.h"
 #include "iviewobjectfamily.h"
 
 #include <vtkActor2D.h>
 #include <vtkCamera.h>
+#include <vtkCellArray.h>
 #include <vtkMath.h>
+#include <vtkPolyData.h>
+#include <vtkPolyDataMapper2D.h>
+#include <vtkProperty2D.h>
 #include <vtkRenderer.h>
 #include <vtkRenderWindowInteractor.h>
 
@@ -56,33 +61,90 @@ iCaptionInteractorStyle* iCaptionInteractorStyle::New(iViewModule *vm)
 
 iCaptionInteractorStyle::iCaptionInteractorStyle(iViewModule *vm) : mViewModule(vm)
 {
-	mInteractionCaption = 0;
+	mInteractionMarker = 0;
+
+	//
+	//  Experimental: gray screen for moving captions
+	//
+	vtkPolyData *data = vtkPolyData::New(); IERROR_ASSERT(data);
+
+	vtkPoints *pts = vtkPoints::New(VTK_FLOAT); IERROR_ASSERT(pts);
+	pts->SetNumberOfPoints(4);
+	pts->SetPoint(0,0.0,0.0,0.0);
+	pts->SetPoint(1,1.0,0.0,0.0);
+	pts->SetPoint(2,1.0,1.0,0.0);
+	pts->SetPoint(3,0.0,1.0,0.0);
+	data->SetPoints(pts);
+	pts->Delete();
+
+	vtkCellArray *cells = vtkCellArray::New(); IERROR_ASSERT(cells);
+	cells->InsertNextCell(4);
+	cells->InsertCellPoint(0);
+	cells->InsertCellPoint(1);
+	cells->InsertCellPoint(2);
+	cells->InsertCellPoint(3);
+	data->SetPolys(cells);
+	cells->Delete();
+	
+	vtkPolyDataMapper2D *mapper = vtkPolyDataMapper2D::New(); IERROR_ASSERT(mapper);
+	mapper->SetInput(data);
+	data->Delete();
+	vtkCoordinate *c = vtkCoordinate::New(); IERROR_ASSERT(c);
+	c->SetCoordinateSystemToNormalizedViewport();
+	mapper->SetTransformCoordinate(c);
+	c->Delete();
+
+	mScreen = vtkActor2D::New(); IERROR_ASSERT(mScreen);
+	mScreen->SetMapper(mapper);
+	mapper->Delete();
+
+	mScreen->GetPositionCoordinate()->SetCoordinateSystemToNormalizedViewport();
+	mScreen->SetPosition(0.0,0.0);
+	mScreen->SetLayerNumber(10);
+	mScreen->GetProperty()->SetOpacity(0.7);
+	mScreen->GetProperty()->SetColor(0.5,0.5,0.5);
+	this->GetViewModule()->GetRenderTool()->AddObject(mScreen);
+	mScreen->SetVisibility(0);
+
+	wNextStyle = 0;
+	wTransparentCaptions = true;
 }
 
 
 iCaptionInteractorStyle::~iCaptionInteractorStyle()
 {
+	this->GetViewModule()->GetRenderTool()->RemoveObject(mScreen);
+	mScreen->Delete();
+}
+
+
+void iCaptionInteractorStyle::Launch(vtkInteractorStyle *next)
+{
+	mScreen->SetVisibility(1);
+	wNextStyle = next;
+	wTransparentCaptions = iCaption::Transparent;
+	iCaption::Transparent = false;
 }
 
 
 void iCaptionInteractorStyle::FindPickedActor(int x, int y)
 {
 	int i;
-	int *x1, *x2;
 
-	if(CurrentRenderer == 0) return;
+	if(this->CurrentRenderer == 0) return;
 	
 	for(i=0; i<=this->GetViewModule()->GetMarkerFamily()->GetMaxMemberIndex(); i++) if(this->GetViewModule()->GetMarkerFamily()->GetMember(i)->GetMarkerCaption()->GetVisibility() == 1)
 	{
-		x1 = this->GetViewModule()->GetMarkerFamily()->GetMember(i)->GetMarkerCaption()->GetPositionCoordinate()->GetComputedDisplayValue(this->CurrentRenderer);
-		x2 = this->GetViewModule()->GetMarkerFamily()->GetMember(i)->GetMarkerCaption()->GetPosition2Coordinate()->GetComputedDisplayValue(this->CurrentRenderer);
-		if(x>x1[0] && y>x1[1] && x<x2[0] && y<x2[1])
+		int *s = this->CurrentRenderer->GetSize();
+		float b[4];
+		this->GetViewModule()->GetMarkerFamily()->GetMember(i)->GetMarkerCaption()->GetBounds(this->CurrentRenderer,b);
+		if(x>b[0]*s[0] && y>b[2]*s[1] && x<b[1]*s[0] && y<b[3]*s[1])
 		{
-			mInteractionCaption = this->GetViewModule()->GetMarkerFamily()->GetMember(i)->GetMarkerCaption();
+			mInteractionMarker = this->GetViewModule()->GetMarkerFamily()->GetMember(i);
 			return;
 		}
 	}
-	mInteractionCaption = 0;
+	mInteractionMarker = 0;
 }
 
 //
@@ -91,7 +153,7 @@ void iCaptionInteractorStyle::FindPickedActor(int x, int y)
 //
 void iCaptionInteractorStyle::Rotate()
 {
-	if(CurrentRenderer==0 || mInteractionCaption==0)
+	if(CurrentRenderer==0 || mInteractionMarker==0)
     {
 		return;
     }
@@ -102,8 +164,8 @@ void iCaptionInteractorStyle::Rotate()
 	float dx = rwi->GetEventPosition()[0] - rwi->GetLastEventPosition()[0];
 	float dy = rwi->GetEventPosition()[1] - rwi->GetLastEventPosition()[1];
 	
-	double *x = mInteractionCaption->GetPosition();
-	mInteractionCaption->SetPosition(x[0]+dx/size[0],x[1]+dy/size[1]);
+	const float *x = mInteractionMarker->GetCaptionPosition();
+	mInteractionMarker->SetCaptionPosition(x[0]+dx/size[0],x[1]+dy/size[1]);
 	
     rwi->Render();
 }
@@ -118,31 +180,46 @@ void iCaptionInteractorStyle::OnLeftButtonDown()
 	
 	this->FindPokedRenderer(x, y);
 	this->FindPickedActor(x, y);
-	if(CurrentRenderer==0 || mInteractionCaption==0)
+	if(CurrentRenderer!=0 && mInteractionMarker!=0)
     {
-		return;
+	    this->StartRotate();
+	}
+	else
+	{
+		this->Finish();
     }
 	
-    this->StartRotate();
 }
 
 
 void iCaptionInteractorStyle::OnLeftButtonUp()
 {
-	vtkInteractorStyleTrackballActor::OnLeftButtonUp();
 	//
 	//  Quantize the position
 	//
-	double *x0, x[2];
-	if(mInteractionCaption != 0)
+	if(mInteractionMarker != 0)
 	{
 		int *size = CurrentRenderer->GetSize();
-		x0 = mInteractionCaption->GetPosition();
+		const float *x0 = mInteractionMarker->GetCaptionPosition();
+		float x[2];
 		x[0] = 10.0*floor(0.1*x0[0]*size[0])/size[0];
 		x[1] = 10.0*floor(0.1*x0[1]*size[1])/size[1];
-		mInteractionCaption->SetPosition(x[0],x[1]);
-
+		mInteractionMarker->SetCaptionPosition(x[0],x[1]);
 		Interactor->Render();
 	}
 }
 
+void iCaptionInteractorStyle::Finish()
+{
+	if(mScreen->GetVisibility() != 0)
+	{
+		mScreen->SetVisibility(0);
+		iCaption::Transparent = wTransparentCaptions;
+		Interactor->Render();
+
+		if(wNextStyle != 0)
+		{
+			this->GetInteractor()->SetInteractorStyle(wNextStyle);
+		}
+	}
+}
