@@ -35,9 +35,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ipointermacro.h"
 
-class iCaption;
+class iMarker;
 class iViewModule;
 
+class vtkActor2D;
+
 
 class iCaptionInteractorStyle: public vtkInteractorStyleTrackballActor
 {
@@ -49,24 +51,28 @@ public:
 	vtkTypeMacro(iCaptionInteractorStyle,vtkInteractorStyleTrackballActor);
 	static iCaptionInteractorStyle* New(iViewModule *vm = 0);
 	
+	void Launch(vtkInteractorStyle *next);
+
 	void FindPickedActor(int x, int y);
 	
-	void Rotate(); 
-	void OnLeftButtonUp();
-	void OnLeftButtonDown();
+	virtual void Rotate(); 
+	virtual void OnLeftButtonUp();
+	virtual void OnLeftButtonDown();
+	
 	//
 	//  Disable all interactions except left mouse moving the caption around
 	//
-	void Spin(){} 
-	void Pan(){}
-	void Dolly(){} 
-	void UniformScale(){}
+	virtual void Spin(){} 
+	virtual void Pan(){}
+	virtual void Dolly(){} 
+	virtual void UniformScale(){}
 	
-	void OnChar(){}
-	void OnMiddleButtonDown(){}
-	void OnMiddleButtonUp(){}
-	void OnRightButtonDown(){}
-	void OnRightButtonUp(){}
+	virtual void OnLeave(){ this->Finish(); }
+	virtual void OnChar(){ this->Finish(); }
+	virtual void OnMiddleButtonDown(){ this->Finish(); }
+	virtual void OnMiddleButtonUp(){}
+	virtual void OnRightButtonDown(){ this->Finish(); }
+	virtual void OnRightButtonUp(){}
 
 protected:
 	
@@ -76,7 +82,13 @@ private:
 
 	iCaptionInteractorStyle(iViewModule *vm);
 
-	iCaption *mInteractionCaption;
+	void Finish();
+
+	iMarker *mInteractionMarker;
+	vtkActor2D *mScreen;
+
+	vtkInteractorStyle *wNextStyle;
+	bool wTransparentCaptions;
 };
 
 #endif // ICAPTIONINTERACTORSTYLE_H
