@@ -45,6 +45,20 @@ class iControlScript;
 class iShell;
 
 
+namespace iParameter
+{
+	namespace CommandInterpreterType
+	{
+		//
+		// CommandInterpreter parameters
+		//
+		const int Code = 0;
+		const int Result = 1;
+		const int Error = 2;
+	};
+};
+
+
 class iCommandInterpreter : public vtkObjectBase
 {
 
