@@ -47,7 +47,8 @@ public:
 		_Warning,
 		_LowError,
 		_HighError,
-		_FatalError
+		_FatalError,
+		_Notification
 	};
 
 	//
