@@ -35,11 +35,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkPolyDataNormals.h>
 #include <vtkToolkits.h>
 
-#if defined(IVTK_44) && !defined(VTK_USE_PATENTED)
-#define vtkMarchingContourFilter vtkContourFilter
-#else
 #include <vtkMarchingContourFilter.h>
-#endif
 
 
 //
@@ -54,9 +50,7 @@ iContourFilter::iContourFilter(iViewSubject *vo) : iGenericFilter<vtkDataSetToPo
 	mCurVar = 0;
 
 	vtkContourFilter *w0 = vtkContourFilter::New(); IERROR_ASSERT(w0);
-#ifndef IVTK_44
 	w0->UseScalarTreeOn();
-#endif
 	w0->ComputeNormalsOn();
 	w0->ComputeScalarsOff();
 	w0->ComputeGradientsOff();
@@ -70,9 +64,7 @@ iContourFilter::iContourFilter(iViewSubject *vo) : iGenericFilter<vtkDataSetToPo
 	}
 
 	vtkMarchingContourFilter *w1 = vtkMarchingContourFilter::New(); IERROR_ASSERT(w1);
-#if !defined(IVTK_44) || defined(VTK_USE_PATENTED)
 	w1->UseScalarTreeOn();
-#endif
 	w1->ComputeNormalsOn();
 	w1->ComputeScalarsOff();
 	w1->ComputeGradientsOff();
