@@ -34,7 +34,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkDataSetToPolyDataFilter.h>
 
 
-#include "ivtk.h"
+class vtkPolyDataAlgorithm;
 
 
 class iContourFilter : public iGenericFilter<vtkDataSetToPolyDataFilter,vtkDataSet,vtkPolyData>
@@ -62,7 +62,7 @@ protected:
 private:
 
 	int mCurVar, mMethod;
-	ivtkPolyDataFilter *mWorkers[2];
+	vtkPolyDataAlgorithm *mWorkers[2];
 };
 
 #endif // ICONTOURFILTER_H
