@@ -46,7 +46,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iimagecomposer.h"
 #include "imarker.h"
 #include "imarkerfamily.h"
-#include "ipalette.h"
+#include "ipaletteset.h"
 #include "iparallel.h"
 #include "iparallelmanager.h"
 #include "iparticlegroup.h"
@@ -101,19 +101,6 @@ IOBJECT_DEFINE_KEY(iControlModule,SynchronizeInteractors,si,Bool,1);
 //
 namespace iControlModule_Private
 {
-	iPalette* Palette_Rainbow();
-	iPalette* Palette_Temperature();
-	iPalette* Palette_Greyscale();
-	iPalette* Palette_Bluewhite();
-	iPalette* Palette_Prizm();
-	iPalette* Palette_Greenwhite();
-	iPalette* Palette_Bluered();
-	iPalette* Palette_Stern();
-	iPalette* Palette_Haze();
-	iPalette* Palette_Starlight();
-	iPalette* Palette_3color();
-	iPalette* Palette_4color();
-
 	template<class Family>
 	bool SetCurrentObject(Family *fam, int obj)
 	{
@@ -130,13 +117,13 @@ namespace iControlModule_Private
 	{
 		switch(objOption)
 		{
-		case _ObjectOptionOne:
+		case ObjectOption::One:
 			{
 				fam->GetCurrentMember()->UnPackState(command);
 				executeOk = fam->GetCurrentMember()->UnPackedSomething();
 				break;
 			}
-		case _ObjectOptionAll:
+		case ObjectOption::All:
 			{
 				int j;
 				for(j=0; j<=fam->GetMaxMemberIndex(); j++)
@@ -308,11 +295,6 @@ iControlModule::iControlModule(iShell *s) : iObject("ControlModule"), mShell(s)
 	mBlockBroadcasts = true;
 	mAutoRender = mSyncInteractors = mExecuteOk = false;
 
-	//
-	//  Palettes must be created before the ViewModule family is created, since they are used then
-	//
-	this->CreateDefaultPalettes();
-
 	//
 	//  Parallel performance - this must be first, since many components are parallel workers as well
 	//
@@ -371,8 +353,6 @@ iControlModule::~iControlModule()
 
 	mParallelObserver->Delete();
 	mParallelManager->Delete();
-
-	for(i=0; i<mPalList.Size(); i++) delete mPalList[i];
 }
 
 
@@ -411,25 +391,25 @@ bool iControlModule::Execute(const iString &command, bool render, int option, in
 	//
 	//  Set modes
 	//
-	int objOption = option & _ObjectOptionMask;
-	int modOption = option & _ModuleOptionMask;
-	int renOption = option & _RenderOptionMask;
+	int objOption = option & ObjectOption::Mask;
+	int modOption = option & ModuleOption::Mask;
+	int renOption = option & RenderOption::Mask;
 
 	//
 	//  Check that modes are valid
 	//
 	if(
-		(objOption!=_ObjectOptionOne && objOption!=_ObjectOptionAll) ||
-		(modOption!=_ModuleOptionOne && modOption!=_ModuleOptionAll && modOption!=_ModuleOptionClones) || 
-		(renOption!=_RenderOptionOne && renOption!=_RenderOptionAll && renOption!=_RenderOptionClones && renOption!=_RenderOptionAuto))
+		(objOption!=ObjectOption::One && objOption!=ObjectOption::All) ||
+		(modOption!=ModuleOption::One && modOption!=ModuleOption::All && modOption!=ModuleOption::Clones) || 
+		(renOption!=RenderOption::One && renOption!=RenderOption::All && renOption!=RenderOption::Clones && renOption!=RenderOption::Auto))
 	{
 		IERROR_LOW("Invalid option.");
 		//
 		//  Continue after an error with default ones
 		//
-		objOption = _ObjectOptionOne;
-		modOption = _ModuleOptionOne;
-		renOption = _RenderOptionAuto;
+		objOption = ObjectOption::One;
+		modOption = ModuleOption::One;
+		renOption = RenderOption::Auto;
 	}
 
 	//
@@ -446,20 +426,20 @@ bool iControlModule::Execute(const iString &command, bool render, int option, in
 	{
 		switch(modOption)
 		{
-		case _ModuleOptionOne:
+		case ModuleOption::One:
 			{
 				if(j == mod) this->ExecuteForViewModule(mViewModules->GetMember(j),command,render,objOption,renOption);
 				break;
 			}
-		case _ModuleOptionAll:
+		case ModuleOption::All:
 			{
-				if(renOption == _RenderOptionAuto) renOption = _RenderOptionAll;
+				if(renOption == RenderOption::Auto) renOption = RenderOption::All;
 				this->ExecuteForViewModule(mViewModules->GetMember(j),command,render,objOption,renOption);
 				break;
 			}
-		case _ModuleOptionClones:
+		case ModuleOption::Clones:
 			{
-				if(renOption == _RenderOptionAuto) renOption = _RenderOptionClones;
+				if(renOption == RenderOption::Auto) renOption = RenderOption::Clones;
 				if(r == mViewModules->GetMember(j)->GetReader()) this->ExecuteForViewModule(mViewModules->GetMember(j),command,render,objOption,renOption);
 				break;
 			}
@@ -468,7 +448,7 @@ bool iControlModule::Execute(const iString &command, bool render, int option, in
 
 	iObject::ReportMissingKeys(true);
 #ifdef I_CHECK1
-	if(renOption == _RenderOptionAuto) IERROR_LOW("Improper RenderOption.");
+	if(renOption == RenderOption::Auto) IERROR_LOW("Improper RenderOption.");
 #endif
 
 	//
@@ -496,17 +476,17 @@ bool iControlModule::Execute(const iString &command, bool render, int option, in
 	{
 		switch(renOption)
 		{
-		case _RenderOptionOne:
+		case RenderOption::One:
 			{
 				if(j == mod) mViewModules->GetMember(j)->Render();
 				break;
 			}
-		case _RenderOptionAll:
+		case RenderOption::All:
 			{
 				mViewModules->GetMember(j)->Render();
 				break;
 			}
-		case _RenderOptionClones:
+		case RenderOption::Clones:
 			{
 				if(r == mViewModules->GetMember(j)->GetReader()) mViewModules->GetMember(j)->Render();
 				break;
@@ -620,7 +600,7 @@ void iControlModule::ExecuteForViewModule(iViewModule *module, const iString &co
 	const iObjectType *ptype = iObjectTypeRegistry::FindType(command.Section(iObjectKey::PrefixSeparator(),0,0));
 	if(ptype == 0)
 	{
-		if(renOption == _RenderOptionAuto) renOption = _RenderOptionOne;
+		if(renOption == RenderOption::Auto) renOption = RenderOption::One;
 		return;
 	}
 
@@ -630,11 +610,11 @@ void iControlModule::ExecuteForViewModule(iViewModule *module, const iString &co
 		this->GetErrorStatus()->Monitor(object->GetErrorStatus());
 		object->UnPackState(command);
 		mExecuteOk = object->UnPackedSomething();
-		if(renOption == _RenderOptionAuto) renOption = _RenderOptionOne;
+		if(renOption == RenderOption::Auto) renOption = RenderOption::One;
 
 		if(ptype->IsMatch(iDataReader::Type()) || ptype->IsMatch(iDataSubject::Type()))
 		{
-			if(renOption == _RenderOptionAuto) renOption = _RenderOptionClones;
+			if(renOption == RenderOption::Auto) renOption = RenderOption::Clones;
 		}
 
 		return;
@@ -645,7 +625,7 @@ void iControlModule::ExecuteForViewModule(iViewModule *module, const iString &co
 		iMarkerFamily *fam = module->GetMarkerFamily();
 		ExecuteForObject(fam,command,objOption,mExecuteOk);
 		if(mExecuteOk) module->GetMarkerFamily()->UpdateLegend();
-		if(renOption == _RenderOptionAuto) renOption = _RenderOptionOne;
+		if(renOption == RenderOption::Auto) renOption = RenderOption::One;
 		return;
 	}
 
@@ -653,7 +633,7 @@ void iControlModule::ExecuteForViewModule(iViewModule *module, const iString &co
 	{
 		iParticlesViewSubject *fam = module->GetParticlesViewSubject();
 		ExecuteForObject(fam,command,objOption,mExecuteOk);
-		if(renOption == _RenderOptionAuto) renOption = _RenderOptionOne;
+		if(renOption == RenderOption::Auto) renOption = RenderOption::One;
 		return;
 	}
 
@@ -663,7 +643,7 @@ void iControlModule::ExecuteForViewModule(iViewModule *module, const iString &co
 		ExecuteForObject(fam,command,objOption,mExecuteOk);
 	}
 
-	if(renOption == _RenderOptionAuto) renOption = _RenderOptionOne;
+	if(renOption == RenderOption::Auto) renOption = RenderOption::One;
 }
 
 
@@ -683,7 +663,7 @@ bool iControlModule::CreateObject(const iObjectType &type, bool render, int mod,
 			//
 			//  Set the type of the instance created
 			//
-			if(vmtype==_ModuleTypeClone || vmtype==_ModuleTypeCopy)
+			if(vmtype==ModuleType::Clone || vmtype==ModuleType::Copy)
 			{
 				mViewModules->GetMember(i)->CopyState(module);
 				mViewModules->GetMember(i)->BecomeClone(module);
@@ -691,7 +671,7 @@ bool iControlModule::CreateObject(const iObjectType &type, bool render, int mod,
 			//
 			//  If a copy, unclone
 			//
-			if(vmtype == _ModuleTypeCopy) mViewModules->GetMember(i)->BecomeClone(0);
+			if(vmtype == ModuleType::Copy) mViewModules->GetMember(i)->BecomeClone(0);
 			//
 			//  Update composer
 			//
@@ -1018,7 +998,7 @@ bool iControlModule::QueryValue(const iObjectKey &key, iFunctionMapping* &f, int
 	
 	if(key.Type().IsMatch(iVolumeViewSubject::Type()))
 	{
-		if(obj == -1) obj = module->GetViewObjectFamily(_ObjectTypeVolume)->GetCurrentMemberIndex();
+		if(obj == -1) obj = module->GetViewObjectFamily(ViewSubject::Id::Volume)->GetCurrentMemberIndex();
 		if(key == iVolumeViewSubject::KeyOpacityFunction())
 		{
 			f = module->GetVolumeViewSubject(obj)->GetOpacityFunction();
@@ -1182,54 +1162,12 @@ ICONTROLMODULE_PACKCOMMAND_DEFINITION(iColor,iColor);
 ICONTROLMODULE_PACKCOMMAND_DEFINITION(iString,const iString&);
 
 
-//
-// Palette manipulation
-//
-void iControlModule::CreateDefaultPalettes()
-{
-	if(mPalList.Size() > 0) return;
-
-	mPalList.Add(Palette_Rainbow());
-	mPalList.Add(Palette_Temperature());
-	mPalList.Add(Palette_Bluewhite());
-	mPalList.Add(Palette_Prizm());
-	mPalList.Add(Palette_Starlight());
-	mPalList.Add(Palette_Greenwhite());
-	mPalList.Add(Palette_Bluered());
-	mPalList.Add(Palette_Haze());
-	mPalList.Add(Palette_Stern());
-	mPalList.Add(Palette_Greyscale());
-	mPalList.Add(Palette_3color());
-	mPalList.Add(Palette_4color());
-}
-
-
-iPalette* iControlModule::GetPalette(int n) const
-{
-	return mPalList[n];
-}
-
-
-int iControlModule::GetNumberOfPalettes() const
-{ 
-	return mPalList.Size(); 
-}
-
-
-bool iControlModule::AddEmptyPalette()
-{
-	iPalette *tmp = new iPalette; if(tmp == 0) return false;
-	mPalList.Add(tmp);
-	return true;
-}
-
-
 //
 //  Saving and restoring the state
 //
 bool iControlModule::SaveStateToFile(const iString &filename) const
 {
-    int i, j, k;
+    int j, k;
 	iViewObjectFamily *fam;
 	iString prefix = "";
 	iString state, ws;
@@ -1331,20 +1269,14 @@ bool iControlModule::SaveStateToFile(const iString &filename) const
 	mComposer->PackCompleteState(state);
 	ws = prefix + iImageComposer::Type().FullName() + " " + state;
 	if(!F.WriteLine(ws)) return Error(F);
-	this->GetShell()->OnLoadStateFileAtom(85);
+	this->GetShell()->OnLoadStateFileAtom(82);
+
 	//
 	//  Save the palettes
 	//
-	for(i=0; i<mPalList.Size(); i++)
-	{
-		this->PackValuePalette(ws,mPalList[i]);
-		ws = prefix + "Palette " + iString::FromNumber(i) + " " + ws;
-		if(!F.WriteLine(ws)) 
-		{
-			F.Close();
-			return false;
-		}
-	}
+	iPaletteSet::Default()->PackCompleteState(state);
+	ws = prefix + iPaletteSet::Type().FullName() + " " + state;
+	this->GetShell()->OnLoadStateFileAtom(85);
 	
 	this->GetShell()->OnLoadStateFileAtom(90);
 
@@ -1564,6 +1496,21 @@ bool iControlModule::LoadStateFromFile(const iString &filename)
 
 		LOAD_OBJECT(GetMarkerFamily(),iMarker::Type(),true);
 		
+		if(ws == iImageComposer::Type().FullName()) 
+		{
+			mComposer->UnPackCompleteState(line.Section(" ",1));
+			this->GetShell()->OnInitAtom();
+		}
+
+		if(ws == iPaletteSet::Type().FullName()) 
+		{
+			iPaletteSet::Default()->UnPackCompleteState(line.Section(" ",1));
+			this->GetShell()->OnInitAtom();
+		}
+
+		//
+		//  Deprecated format
+		//
 		if(ws == "Palette") 
 		{
 			k = line.Section(" ",1,1).ToInt(ok);
@@ -1576,22 +1523,16 @@ bool iControlModule::LoadStateFromFile(const iString &filename)
 			//
 			if(CompatibilityMode==11 && line.Section(" ",2,2).Section("/",0,0).Find("*reversed")>-1) ok = false;
 
-			while(k>=mPalList.Size() && ok)
+			while(k>=iPaletteSet::Default()->GetNumberOfPalettes() && ok)
 			{
-				ok = this->AddEmptyPalette();
+				ok = iPaletteSet::Default()->AddEmptyPalette();
 			}
 			if(ok)
 			{
 				ws = line.Section(" ",2);
-				if(!this->UnPackValuePalette(ws,mPalList[k])) return Error(F);
+				if(!iPaletteSet::Default()->UnPackValuePalette(ws,iPaletteSet::Default()->GetPalette(k))) return Error(F);
 			}
 		}		
-
-		if(ws == iImageComposer::Type().FullName()) 
-		{
-			mComposer->UnPackCompleteState(line.Section(" ",1));
-			this->GetShell()->OnInitAtom();
-		}
 	}
 
 	this->GetShell()->OnLoadStateFileAtom(80);
@@ -1616,63 +1557,6 @@ bool iControlModule::LoadStateFromFile(const iString &filename)
 }
 
 
-void iControlModule::PackValuePalette(iString &s, const iPalette *p) const
-{
-	iViewSubject *tmpObject = mViewModules->GetMember(0)->GetMarkerFamily()->GetMember(0);
-	const iObjectKey& keyRed = iObjectKeyRegistry::GetTempKey(Type(),"Red");
-	const iObjectKey& keyGreen = iObjectKeyRegistry::GetTempKey(Type(),"Green");
-	const iObjectKey& keyBlue = iObjectKeyRegistry::GetTempKey(Type(),"Blue");
-
-	s = p->GetName().Substitute(" ","*") + iObjectKey::FieldSeparator();
-	tmpObject->PackValuePiecewiseFunction(s,keyRed,p->GetRedComponent());
-	tmpObject->PackValuePiecewiseFunction(s,keyGreen,p->GetGreenComponent());
-	tmpObject->PackValuePiecewiseFunction(s,keyBlue,p->GetBlueComponent());
-
-	iObjectKeyRegistry::ReleaseTempKey(keyRed);
-	iObjectKeyRegistry::ReleaseTempKey(keyGreen);
-	iObjectKeyRegistry::ReleaseTempKey(keyBlue);
-}
-
-
-bool iControlModule::UnPackValuePalette(const iString &s, iPalette *p)
-{
-	bool ok = true;
-
-	iViewSubject *tmpObject = mViewModules->GetMember(0)->GetMarkerFamily()->GetMember(0);
-	const iObjectKey& keyRed = iObjectKeyRegistry::GetTempKey(Type(),"Red");
-	const iObjectKey& keyGreen = iObjectKeyRegistry::GetTempKey(Type(),"Green");
-	const iObjectKey& keyBlue = iObjectKeyRegistry::GetTempKey(Type(),"Blue");
-
-	iString ws;
-	ws = s.Section(iObjectKey::FieldSeparator(),0,0);
-	ws.Replace("*"," ");
-	if(!ws.IsEmpty()) p->SetName(ws); else ok = false;
-
-	if(ok)
-	{
-		//
-		//  Loop over 3 color functions
-		//
-		ws = s.Section(iObjectKey::FieldSeparator(),1);
-		iPiecewiseFunction *r = p->GetRedComponent();
-		iPiecewiseFunction *g = p->GetGreenComponent();
-		iPiecewiseFunction *b = p->GetBlueComponent();
-
-		ok = tmpObject->UnPackValuePiecewiseFunction(ws,keyRed,r) && 
-		 	tmpObject->UnPackValuePiecewiseFunction(ws,keyGreen,g) &&
-			tmpObject->UnPackValuePiecewiseFunction(ws,keyBlue,b);
-
-		if(ok) p->Update();
-	}
-
-	iObjectKeyRegistry::ReleaseTempKey(keyRed);
-	iObjectKeyRegistry::ReleaseTempKey(keyGreen);
-	iObjectKeyRegistry::ReleaseTempKey(keyBlue);
-
-	return ok;
-}
-
-
 iEventObserver* iControlModule::GetInteractorObserver() const
 {
 	return mInteractorObserver;
@@ -1749,8 +1633,8 @@ void iControlModule::SetSynchronizeInteractors(bool s)
 void iControlModule::SetOptimizationMode(int m)
 {
 	iDataConsumer::SetGlobalOptimizationMode(m);
-	vtkMapper::SetGlobalImmediateModeRendering((m==_DataConsumerOptimizeForMemory)?1:0);
-	vtkDataObject::SetGlobalReleaseDataFlag((m==_DataConsumerOptimizeForMemory)?1:0);
+	vtkMapper::SetGlobalImmediateModeRendering((m==DataConsumerOptimizationMode::OptimizeForMemory)?1:0);
+	vtkDataObject::SetGlobalReleaseDataFlag((m==DataConsumerOptimizationMode::OptimizeForMemory)?1:0);
 
 	this->ClearCache();
 	//
@@ -1766,376 +1650,3 @@ int iControlModule::GetOptimizationMode() const
 	return iDataConsumer::GetGlobalOptimizationMode();
 }
 
-
-//
-//  Helper functions hidden in a private namespace
-//
-namespace iControlModule_Private
-{
-	iPalette* Palette_Rainbow()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("Rainbow");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,0.0);
-		g->MovePoint(0,0.0,0.0);
-		b->MovePoint(0,0.0,0.1);
-
-		r->MovePoint(1,1.0,1.0);
-		g->MovePoint(1,1.0,0.9);
-		b->MovePoint(1,1.0,0.9);
-
-		r->AddPoint(1.0/6.0,0.0);
-		g->AddPoint(1.0/6.0,0.0);
-		b->AddPoint(1.0/6.0,1.0);
-
-		r->AddPoint(2.0/6.0,0.0);
-		g->AddPoint(2.0/6.0,1.0);
-		b->AddPoint(2.0/6.0,1.0);
-
-		r->AddPoint(3.0/6.0,0.0);
-		g->AddPoint(3.0/6.0,1.0);
-		b->AddPoint(3.0/6.0,0.0);
-
-		r->AddPoint(4.0/6.0,1.0);
-		g->AddPoint(4.0/6.0,1.0);
-		b->AddPoint(4.0/6.0,0.0);
-
-		r->AddPoint(5.0/6.0,1.0);
-		g->AddPoint(5.0/6.0,0.0);
-		b->AddPoint(5.0/6.0,0.0);
-
-		tmp->Update();
-		return tmp;
-	}
-
-
-	iPalette* Palette_Temperature()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("Temperature");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,0.3);
-		g->MovePoint(0,0.0,0.0);
-		b->MovePoint(0,0.0,0.0);
-
-		r->MovePoint(1,1.0,1.0);
-		g->MovePoint(1,1.0,0.8);
-		b->MovePoint(1,1.0,0.8);
-
-		r->AddPoint(0.7,1.0);
-		g->AddPoint(0.6,0.0);
-		b->AddPoint(0.8,0.0);
-
-		tmp->Update();
-		return tmp;
-	}
-
-
-	iPalette* Palette_Greyscale()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("Greyscale");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,0.0);
-		g->MovePoint(0,0.0,0.0);
-		b->MovePoint(0,0.0,0.0);
-
-		r->MovePoint(1,1.0,1.0);
-		g->MovePoint(1,1.0,1.0);
-		b->MovePoint(1,1.0,1.0);
-
-		tmp->Update();
-		return tmp;
-	}
-
-
-	iPalette* Palette_Bluewhite()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("Blue-white");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,0.0);
-		g->MovePoint(0,0.0,0.0);
-		b->MovePoint(0,0.0,0.1);
-
-		r->MovePoint(1,1.0,0.9);
-		g->MovePoint(1,1.0,0.9);
-		b->MovePoint(1,1.0,1.0);
-
-		r->AddPoint(0.75,0.0);
-		g->AddPoint(0.38,0.0);
-		b->AddPoint(0.78,1.0);
-
-		tmp->Update();
-		return tmp;
-	}
-
-
-	iPalette* Palette_Prizm()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("Prizm");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,0.0);
-		g->MovePoint(0,0.0,0.0);
-		b->MovePoint(0,0.0,0.0);
-
-		r->MovePoint(1,1.0,0.0);
-		g->MovePoint(1,1.0,0.0);
-		b->MovePoint(1,1.0,0.0);
-
-		r->AddPoint(0.25,1.0);
-		g->AddPoint(0.25,0.0);
-		b->AddPoint(0.25,0.0);
-
-		r->AddPoint(0.50,0.0);
-		g->AddPoint(0.50,1.0);
-		b->AddPoint(0.50,0.0);
-
-		r->AddPoint(0.75,0.0);
-		g->AddPoint(0.75,0.0);
-		b->AddPoint(0.75,1.0);
-
-		tmp->Update();
-		return tmp;
-	}
-
-
-	iPalette* Palette_Greenwhite()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("Green-white");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,0.0);
-		g->MovePoint(0,0.0,0.1);
-		b->MovePoint(0,0.0,0.0);
-
-		r->MovePoint(1,1.0,1.0);
-		g->MovePoint(1,1.0,1.0);
-		b->MovePoint(1,1.0,1.0);
-
-		r->AddPoint(0.375,0.0);
-		b->AddPoint(0.750,0.0);
-
-		tmp->Update();
-		return tmp;
-	}
-
-
-	iPalette* Palette_Bluered()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("Blue-red");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,0.0);
-		g->MovePoint(0,0.0,0.0);
-		b->MovePoint(0,0.0,0.0);
-
-		r->MovePoint(1,1.0,1.0);
-		g->MovePoint(1,1.0,0.0);
-		b->MovePoint(1,1.0,0.0);
-
-		r->AddPoint(0.25,0.0);
-		g->AddPoint(0.25,1.0);
-		b->AddPoint(0.25,1.0);
-
-		r->AddPoint(0.5,0.0);
-		g->AddPoint(0.5,0.0);
-		b->AddPoint(0.5,1.0);
-
-		r->AddPoint(0.75,1.0);
-		g->AddPoint(0.75,0.0);
-		b->AddPoint(0.75,1.0);
-
-		tmp->Update();
-		return tmp;
-	}
-
-
-	iPalette* Palette_Stern()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("Stern");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,0.0);
-		g->MovePoint(0,0.0,0.0);
-		b->MovePoint(0,0.0,0.0);
-
-		r->MovePoint(1,1.0,1.0);
-		g->MovePoint(1,1.0,1.0);
-		b->MovePoint(1,1.0,1.0);
-
-		r->AddPoint(0.05,1.0);
-		r->AddPoint(0.25,0.0);
-		b->AddPoint(0.50,1.0);
-		b->AddPoint(0.75,0.0);
-
-		tmp->Update();
-		return tmp;
-	}
-
-
-	iPalette* Palette_Haze()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("Haze");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,1.0);
-		g->MovePoint(0,0.0,0.8);
-		b->MovePoint(0,0.0,1.0);
-
-		r->MovePoint(1,1.0,1.0);
-		g->MovePoint(1,1.0,0.8);
-		b->MovePoint(1,1.0,0.0);
-
-		r->AddPoint(0.5,0.0);
-		g->AddPoint(0.5,0.1);
-		b->AddPoint(0.5,0.5);
-
-		tmp->Update();
-		return tmp;
-	}
-
-
-	iPalette* Palette_Starlight()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("Starlight");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,0.5);
-		g->MovePoint(0,0.0,0.0);
-		b->MovePoint(0,0.0,0.0);
-
-		r->MovePoint(1,1.0,1.0);
-		g->MovePoint(1,1.0,1.0);
-		b->MovePoint(1,1.0,0.7);
-
-		r->AddPoint(0.5,0.9);
-		g->AddPoint(0.5,0.7);
-		b->AddPoint(0.5,0.2);
-
-		tmp->Update();
-		return tmp;
-	}
-
-
-	iPalette* Palette_3color()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("3 color");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,1.0);
-		g->MovePoint(0,0.0,0.0);
-		b->MovePoint(0,0.0,0.0);
-
-		r->MovePoint(1,1.0,0.0);
-		g->MovePoint(1,1.0,0.0);
-		b->MovePoint(1,1.0,1.0);
-
-		r->AddPoint(0.3333,1.0);
-		g->AddPoint(0.3333,0.0);
-		b->AddPoint(0.3333,0.0);
-		r->AddPoint(0.3334,0.0);
-		g->AddPoint(0.3334,1.0);
-		b->AddPoint(0.3334,0.0);
-
-		r->AddPoint(0.6666,0.0);
-		g->AddPoint(0.6666,1.0);
-		b->AddPoint(0.6666,0.0);
-		r->AddPoint(0.6667,0.0);
-		g->AddPoint(0.6667,0.0);
-		b->AddPoint(0.6667,1.0);
-
-		tmp->Update();
-		return tmp;
-	}
-
-
-	iPalette* Palette_4color()
-	{
-		iPalette* tmp = new iPalette; IERROR_ASSERT(tmp);
-		tmp->SetName("4 color");
-
-		iPiecewiseFunction *r = tmp->GetRedComponent();
-		iPiecewiseFunction *g = tmp->GetGreenComponent();
-		iPiecewiseFunction *b = tmp->GetBlueComponent();
-
-		r->MovePoint(0,0.0,1.0);
-		g->MovePoint(0,0.0,0.0);
-		b->MovePoint(0,0.0,0.0);
-
-		r->MovePoint(1,1.0,0.0);
-		g->MovePoint(1,1.0,0.0);
-		b->MovePoint(1,1.0,1.0);
-
-		r->AddPoint(0.24,1.0);
-		g->AddPoint(0.24,0.0);
-		b->AddPoint(0.24,0.0);
-		r->AddPoint(0.25,1.0);
-		g->AddPoint(0.25,1.0);
-		b->AddPoint(0.25,0.0);
-
-		r->AddPoint(0.49,1.0);
-		g->AddPoint(0.49,1.0);
-		b->AddPoint(0.49,0.0);
-		r->AddPoint(0.50,0.0);
-		g->AddPoint(0.50,1.0);
-		b->AddPoint(0.50,0.0);
-
-		r->AddPoint(0.74,0.0);
-		g->AddPoint(0.74,1.0);
-		b->AddPoint(0.74,0.0);
-		r->AddPoint(0.75,0.0);
-		g->AddPoint(0.75,0.0);
-		b->AddPoint(0.75,1.0);
-
-		tmp->Update();
-		return tmp;
-	}
-};
-
