@@ -180,14 +180,14 @@ namespace iControlScript_Private
 		const iObjectType *tmp = iObjectTypeRegistry::FindType(arg.Section(" ",0,0));
 		if(tmp != 0)
 		{
-			int vmtype = _ModuleTypeNew;
+			int vmtype = ModuleType::New;
 
 			if(*tmp == iViewModule::Type())
 			{
 				iString v = arg.Section(" ",1);
 				v.ReduceWhiteSpace();
-				if(v == "/copy") vmtype = _ModuleTypeCopy;
-				if(v == "/clone") vmtype = _ModuleTypeClone;
+				if(v == "/copy") vmtype = ModuleType::Copy;
+				if(v == "/clone") vmtype = ModuleType::Clone;
 			}
 
 			if(!curControl->CreateObject(*tmp,curRender,-1,vmtype))
@@ -613,19 +613,19 @@ bool iControlScript::ExecBody(iScript *self, const iString &request, int mode)
 //
 bool iControlScript::Exec(iScript *self, const iString &request)
 {
-	return ExecBody(self,request,_ObjectOptionOne|_ModuleOptionOne|_RenderOptionAuto);
+	return ExecBody(self,request,ObjectOption::One|ModuleOption::One|RenderOption::Auto);
 }
 
 
 bool iControlScript::ExecAllObjects(iScript *self, const iString &request)
 {
-	return ExecBody(self,request,_ObjectOptionAll|_ModuleOptionOne|_RenderOptionAuto);
+	return ExecBody(self,request,ObjectOption::All|ModuleOption::One|RenderOption::Auto);
 }
 
 
 bool iControlScript::ExecAllWindows(iScript *self, const iString &request)
 {
-	return ExecBody(self,request,_ObjectOptionAll|_ModuleOptionAll|_RenderOptionAuto);
+	return ExecBody(self,request,ObjectOption::All|ModuleOption::All|RenderOption::Auto);
 }
 
 
@@ -784,7 +784,7 @@ bool iControlScript::Animate(iScript *self, const iString &arg)
 	{
 		iString fname(arg);
 
-		iDirectory::ExpandFileName(fname,curControl->GetShell()->GetEnvironment(_EnvironmentBase));
+		iDirectory::ExpandFileName(fname,curControl->GetShell()->GetEnvironment(Environment::Base));
 
 		iFile f(fname);
 		if(!f.Open(iFile::_Read,iFile::_Text))
