@@ -84,9 +84,9 @@ IVIEWSUBJECT_DEFINE_INHERITED_KEYS_PALETTE(iCrossSectionViewSubject,1);
 //
 // iCrossSectionViewSubject class
 //
-iCrossSectionViewSubject::iCrossSectionViewSubject(iViewModule *vm, const iDataType &type, const iString &name) : iSolidViewSubject(vm,type,name,1,_ViewSubjectNoColor|_ViewSubjectNoOpacity|_ViewSubjectNoReplicating|_ViewSubjectHasPosition)
+iCrossSectionViewSubject::iCrossSectionViewSubject(iViewModule *vm, const iDataType &type, const iString &name) : iSolidViewSubject(vm,type,name,1,ViewSubject::Flag::NoColor|ViewSubject::Flag::NoOpacity|ViewSubject::Flag::NoReplicating|ViewSubject::Flag::HasPosition)
 {
-	mObjectType = _ObjectTypeCrossSection;
+	mSubjectId = ViewSubject::Id::CrossSection;
 
 	mVar = 0;
 	mDir = 2;
@@ -184,7 +184,7 @@ void iCrossSectionViewSubject::ForcePolygonalMethod(bool s)
 
 void iCrossSectionViewSubject::ShowColorBarsBody(bool show)
 {
-	this->GetViewModule()->GetColorBars()->ShowBar(_ColorBarsPriorityCrossSection,this->GetVar(),this->GetDataType(),mPalettes[0],show);
+	this->GetViewModule()->GetColorBars()->ShowBar(ColorBarsPriority::CrossSection,this->GetVar(),this->GetDataType(),mPalettes[0],show);
 }
 
 
