@@ -34,7 +34,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "idatareader.h"
 #include "ierror.h"
 #include "iviewmodule.h"
-#include "ivtk.h"
 
 
 //
@@ -46,7 +45,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iParameter;
 
 
-int iDataConsumer::mModeGlobal = _DataConsumerOptimizeForSpeed;
+int iDataConsumer::mModeGlobal = DataConsumerOptimizationMode::OptimizeForSpeed;
 
 
 //
@@ -99,9 +98,6 @@ iDataConsumer::~iDataConsumer()
 	//
 	if(mDataHandlers.Size() > 0)
 	{
-#if defined(I_DEBUG) && defined(IVTK_44)
-		IERROR_LOW("Not all DataHandlers have been deleted.");
-#endif
 		int i;
 		for(i=0; i<mDataHandlers.Size(); i++) mDataHandlers[i]->mConsumer = 0;
 	}
@@ -146,7 +142,7 @@ vtkDataSet* iDataConsumer::GetData() const
 
 void iDataConsumer::SetGlobalOptimizationMode(int mode)
 {
-	if(mode>=0 && mode<__NumDataConsumerOptimizationModes)
+	if(DataConsumerOptimizationMode::IsValid(mode))
 	{
 		mModeGlobal = mode;
 	}
@@ -158,12 +154,12 @@ void iDataConsumer::SetOptimizationMode(int mode)
 	//
 	//  Reset the global mode;
 	//
-	if(mode>=0 && mode<__NumDataConsumerOptimizationModes)
+	if(DataConsumerOptimizationMode::IsValid(mode))
 	{
 		mModeLocal = mode;
 		mOverrideGlobal = true;
 	}
-	else if(mode==_DataConsumerResetToGlobal)
+	else if(mode==DataConsumerOptimizationMode::ResetToGlobal)
 	{
 		mModeLocal = mModeGlobal;
 		mOverrideGlobal = false;
