@@ -30,38 +30,45 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IDATAFORMATTER_H
 
 
-#include "iviewmodulecomponent.h"
+#include <vtkObjectBase.h>
 
 
 #include "iarray.h"
 #include "istring.h"
 
+#include "ipointermacro.h"
+
 class iDataLimits;
+class iViewModule;
 
 
-class iDataFormatter : public iViewModuleComponent
+class iDataFormatter : public vtkObjectBase
 {
 
+	IPOINTER_AS_PART(ViewModule);
+
 public:
 
+	static iDataFormatter* New(iViewModule *vm = 0);
+
 	inline int GetNumReportLines() const { return mVarNameLines.Size(); }
 	void GetReport(int i, iString& varName, iString &varData, iString &varUnit) const;
 
 	void AddOneLine(const iString &name, const iString &data, const iString &unit);
 
-protected:
-
-	iDataFormatter(iViewModule *vm);
-	virtual ~iDataFormatter();
-
 	void ClearReport();
-
 	void FormatScalarData(iDataLimits *lim, int n, float *v, bool useClass = false);
 	void FormatVectorData(iDataLimits *lim, int ivar, float *v, float *div = 0, float *vort = 0);
 	void FormatTensorData(iDataLimits *lim, int ivar, float *v, bool compressed = false);
 
+protected:
+
+	virtual ~iDataFormatter();
+
 private:
 
+	iDataFormatter(iViewModule *vm);
+
 	iArray<iString> mVarNameLines, mVarDataLines, mVarUnitLines;
 	iString mFormatHelper;
 };
