@@ -30,18 +30,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IDATAHANDLER_H
 
 
-#include "iviewmodulecomponent.h"
-
+#include "ipointermacro.h"
 
 class iDataConsumer;
 class iDataSyncRequest;
+class iViewModule;
 
 
-class iDataHandler : public iViewModuleComponent
+class iDataHandler
 {
 
 	friend class iDataConsumer;
 
+	IPOINTER_AS_PART(ViewModule);
+
 public:
 
 	bool IsOptimizedForSpeed() const;
@@ -55,6 +57,8 @@ protected:
 
 	virtual void SyncWithData(const iDataSyncRequest &r) = 0;
 
+private:
+
 	iDataConsumer *mConsumer;
 };
 
