@@ -235,7 +235,10 @@ void iDataLimits::AdjustMinMax(Var &v)
 			v.Max =  0.01f;
 		}
 	}
-		
+	
+	if(v.IsAtMax) v.UpperLimit = v.Max;
+	if(v.IsAtMin) v.LowerLimit = v.Min;
+
 	if(v.UpperLimit > v.Max) v.UpperLimit = v.Max;
 	if(v.UpperLimit < v.Min) v.UpperLimit = v.Min;
 	if(v.LowerLimit < v.Min) v.LowerLimit = v.Min;
@@ -255,6 +258,19 @@ void iDataLimits::SetMax(int n, float v)
 }
 
 
+void iDataLimits::SetMinMax(int n, float vMin, float vMax)
+{
+	if(n>=0 && n<mVars.Size())
+	{
+		mVars[n]->Min = vMin;
+		mVars[n]->Max = vMax;
+		this->AdjustMinMax(*mVars[n]);
+		this->NotifyDependencies(n);
+	}
+	else this->Invalid(0);
+}
+
+
 void iDataLimits::SetMin(int n, float v)
 {
 	if(n>=0 && n<mVars.Size())
@@ -310,7 +326,16 @@ void iDataLimits::UpdateUpperLimit(float v, int n, float &ll, float &ul)
 {
 	if(n>=0 && n<mVars.Size())
     {
-		if(v > mVars[n]->Max) v = mVars[n]->Max;
+		if(v < mVars[n]->Min) v = mVars[n]->Min;
+		if(v < mVars[n]->Max)
+		{
+			mVars[n]->IsAtMax = false;
+		}
+		else
+		{
+			v = mVars[n]->Max;
+			mVars[n]->IsAtMax = true;
+		}
 		ul = v;
 		if(v < ll) ll = v;
 		this->NotifyDependencies(n);
@@ -323,7 +348,16 @@ void iDataLimits::UpdateLowerLimit(float v, int n, float &ll, float &ul)
 {
 	if(n>=0 && n<mVars.Size())
     {
-		if(v < mVars[n]->Min) v = mVars[n]->Min;
+		if(v > mVars[n]->Max) v = mVars[n]->Max;
+		if(v > mVars[n]->Min)
+		{
+			mVars[n]->IsAtMin = false;
+		}
+		else
+		{
+			v = mVars[n]->Min;
+			mVars[n]->IsAtMin = true;
+		}
 		ll = v;
 		if(v > ul) ul = v;
 		this->NotifyDependencies(n);
@@ -336,6 +370,7 @@ void iDataLimits::Initialize(Var &v)
 {
 	v.LowerLimit = v.Min;
 	v.UpperLimit = v.Max;
+	v.IsAtMin = v.IsAtMax = true;
 }
 
 
