@@ -46,6 +46,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iobjectfactory.h"
 #include "iparallelmanager.h"
 #include "iparallelworker.h"
+#include "iuniformgriddata.h"
 #include "iuniformgridfileloader.h"
 #include "iviewmodule.h"
 
@@ -114,8 +115,8 @@ iDataReader::iDataReader(iViewModule *vm) : iExtendableObject("Data Reader"), mV
 	mTwoCopies = mInExtensionUpdate = false;
 
 	mCellToPointMode = 2;
-	mVoxelLocation = _VoxelLocationVertex;
-	mBoundaryConditions = _BoundaryConditionsWall;
+	mVoxelLocation = VoxelLocation::Vertex;
+	mBoundaryConditions = BoundaryConditions::Wall;
 
     mUniformVectorsLoader = new iUniformVectorsFileLoader(this); IERROR_ASSERT(mUniformVectorsLoader);
     mUniformScalarsLoader = new iUniformScalarsFileLoader(this,mUniformVectorsLoader); IERROR_ASSERT(mUniformScalarsLoader);
@@ -813,7 +814,7 @@ void iDataReader::SetBoundaryConditions(int v)
 {
 	int i;
 
-	if(v>=0 && v<__NumBoundaryConditions)
+	if(BoundaryConditions::IsValid(v))
 	{
 		mBoundaryConditions = v;
 		for(i=0; i<mLoaders.Size(); i++)
