@@ -31,13 +31,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "imath.h"
-#include "iparameter.h"
 
 class iString;
 
 
 namespace iDataStretch
 {
+	const int Linear =	0;
+	const int Log =		1;
+
 	template<class T> T ApplyStretch(T f, int mode, bool up);
 	template<class T> T ResetStretch(T f, int mode);
 
@@ -110,7 +112,7 @@ namespace iDataStretch
 
 		switch(mode)
 		{
-		case iParameter::_StretchLog:
+		case Log:
 			{
 				if(f > zero) 
 				{
@@ -132,7 +134,7 @@ namespace iDataStretch
 	{
 		switch(mode)
 		{
-		case iParameter::_StretchLog: 
+		case Log: 
 			{
 				return pow10(f);
 				break;
