@@ -265,7 +265,7 @@ void iDataSubject::PackStateBody(iString &s) const
 void iDataSubject::UnPackStateBody(const iString &s)
 {
 	static iBuffer<int> itmp;
-	static iBuffer<float> ftmp;
+	static iBuffer<float> ftmp, ftmp2;
 	static iBuffer<iString> stmp;
 	int i, n; bool b;
 	
@@ -299,15 +299,26 @@ void iDataSubject::UnPackStateBody(const iString &s)
 		for(i=0; i<n; i++) ftmp[i] = limits->GetMin(i);
 		if(this->UnPackValue(s,KeyMin(),ftmp,n))
 		{
-			for(i=0; i<n; i++) limits->SetMin(i,ftmp[i]);
-			this->ClearCache();
+			for(i=0; i<n; i++) ftmp2[i] = limits->GetMax(i);
+			if(this->UnPackValue(s,KeyMax(),ftmp2,n))
+			{
+				for(i=0; i<n; i++) limits->SetMinMax(i,ftmp[i],ftmp2[i]);
+				this->ClearCache();
+			}
+			else
+			{
+				for(i=0; i<n; i++) limits->SetMin(i,ftmp[i]);
+				this->ClearCache();
+			}
 		}
-
-		for(i=0; i<n; i++) ftmp[i] = limits->GetMax(i);
-		if(this->UnPackValue(s,KeyMax(),ftmp,n))
+		else
 		{
-			for(i=0; i<n; i++) limits->SetMax(i,ftmp[i]);
-			this->ClearCache();
+			for(i=0; i<n; i++) ftmp[i] = limits->GetMax(i);
+			if(this->UnPackValue(s,KeyMax(),ftmp,n))
+			{
+				for(i=0; i<n; i++) limits->SetMax(i,ftmp[i]);
+				this->ClearCache();
+			}
 		}
 
 		for(i=0; i<n; i++) ftmp[i] = limits->GetLowerLimit(i);
