@@ -30,7 +30,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
-#include "ivtk.h"
 
 #include <vtkDirectory.h>
 
@@ -116,11 +115,7 @@ const iString iDirectory::GetFile(const iString &name, int skip) const
 
 bool iDirectory::Make(const iString &name)
 {
-#ifdef IVTK_44
-	return (vtkDirectory::CreateDirectory(name.ToCharPointer()) != 0);
-#else
 	return (vtkDirectory::MakeDirectory(name.ToCharPointer()) != 0);
-#endif
 }
 
 
