@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #define IERROR_LOW(_m_)			{ iConsole::Display(iConsole::_LowError,_m_,__FILE__,__LINE__); }
-#define IERROR_HIGH(_m_)		{ iConsole::Display(iConsole::_LowError,_m_,__FILE__,__LINE__); }
+#define IERROR_HIGH(_m_)		{ iConsole::Display(iConsole::_HighError,_m_,__FILE__,__LINE__); }
 #define IERROR_FATAL(_m_)		{ iConsole::Display(iConsole::_FatalError,_m_,__FILE__,__LINE__); }
 #define IERROR_ASSERT(_p_)		{ if((_p_) == 0) iConsole::Display(iConsole::_FatalError,"Invalid use of a null pointer.",__FILE__,__LINE__); }
 
