@@ -38,7 +38,7 @@ iFamily<Object,Parent>* iFamily<Object,Parent>::New(Parent *p)
 
 
 template<class Object, class Parent>
-iFamily<Object,Parent>::iFamily(Parent *p) : mMemlist(0)
+iFamily<Object,Parent>::iFamily(Parent *p)
 {
 	this->mParent = p;
 	this->mCur = 0;
