@@ -126,7 +126,7 @@ void iFieldViewSubject::SetGlyphSampleRate(int v)
 
 void iFieldViewSubject::ShowColorBarsBody(bool show)
 {
-	if(this->IsColoredByScalars()) this->GetViewModule()->GetColorBars()->ShowBar(_ColorBarsPriorityField,mColorBy,mScalarDataType,mPalettes[0],show);
+	if(this->IsColoredByScalars()) this->GetViewModule()->GetColorBars()->ShowBar(ColorBarsPriority::Field,mColorBy,mScalarDataType,mPalettes[0],show);
 }
 
 
@@ -177,6 +177,7 @@ void iFieldViewSubject::ViewSubjectSyncWithData(const iDataSyncRequest &r)
 	{
 		mMergeDataFilter->SetDataInput(0,this->GetViewModule()->GetReader()->GetData(mScalarDataType));
 		mMergeDataFilter->SetInput(this->GetData());
+		mMergeDataFilter->Update();
 		this->ResetPipelineInput(mMergeDataFilter->GetOutput());
 	}
 
