@@ -137,6 +137,7 @@ bool iFile::ReadLine(iString &s, int max)
 	const int nbuf = 256;
 	char buf[nbuf];
 	int n, r = 0;
+	bool cont;
 	
 	mStream->clear();
 	s.Clear();
@@ -147,18 +148,33 @@ bool iFile::ReadLine(iString &s, int max)
 		n = nbuf;
 		if(n > max-r+1) n = max - r + 1;
 		mStream->getline(buf,n);
-		if(mStream->fail()!=0 && mStream->gcount()==n-1) mStream->clear();
+		if(mStream->gcount() < n-1) 
+		{
+			cont = false;
+		}
+		else
+		{
+			if(mStream->fail()!=0)
+			{
+				mStream->clear();
+				cont = true;
+			}
+			else
+			{
+				cont = false;
+			}
+		}
 		if(mStream->fail()!=0 || mStream->eof()!=0) return false;
 		s += buf;
 		r += n-1;
 	}
-	while(mStream->gcount()==n-1 && r<max);
+	while(cont && r<max);
 
 	return true;
 }
 
 
-bool iFile::ReadBlock(void *p, unsigned long length)
+bool iFile::ReadBlock(void *p, size_t length)
 {
 	mStream->clear();
 	mStream->read((char *)p,length);
@@ -166,7 +182,7 @@ bool iFile::ReadBlock(void *p, unsigned long length)
 }
 
 
-bool iFile::SkipBlock(unsigned long length)
+bool iFile::SkipBlock(size_t length)
 { 
 	mStream->clear();
 	mStream->seekg(length,ios::cur); 
