@@ -72,8 +72,8 @@ public:
 	//
 	//  Reading
 	//
-	bool ReadLine(iString &s, int max = iMath::_LargeInt);
-	bool ReadBlock(void *p, unsigned long length);
+	bool ReadLine(iString &s, int max = iString::MaxLength);
+	bool ReadBlock(void *p, size_t length);
 	//
 	//  Writing
 	//
@@ -81,7 +81,7 @@ public:
 	//
 	//  Skipping
 	//
-	bool SkipBlock(unsigned long length);
+	bool SkipBlock(size_t length);
 	//
 	//  (Semi-)Random access
 	//
