@@ -55,13 +55,13 @@ void iFileLoader::SwapBytes(_type_ &p) \
 { \
 	iFileLoader_Private::SwapBytes(p); \
 } \
-void iFileLoader::SwapBytesRange(_type_ *p, long count) \
+void iFileLoader::SwapBytesRange(_type_ *p, vtkIdType count) \
 { \
 	iFileLoader_Private::SwapBytesRange(p,count); \
 }
 
 #define	IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(_type_) \
-bool iFileLoader::ReadBlock(iFile& F, _type_ *p, long len, float updateStart, float updateDuration) \
+bool iFileLoader::ReadBlock(iFile& F, _type_ *p, vtkIdType len, float updateStart, float updateDuration) \
 { \
 	return iFileLoader_Private::ReadBlockToArray(F,p,len,updateStart,updateDuration,mIsBigEndian!=iSystem::IsBigEndianMachine(),mObserver); \
 } \
@@ -69,7 +69,7 @@ iFileLoader::ReadingBuffer iFileLoader::Buffer(_type_ &d) const \
 { \
 	return ReadingBuffer(&d,1UL,iFileLoader_Private::TypeIndex(&d),sizeof(_type_)); \
 } \
-iFileLoader::ReadingBuffer iFileLoader::Buffer(_type_ *d, long l) const \
+iFileLoader::ReadingBuffer iFileLoader::Buffer(_type_ *d, vtkIdType l) const \
 { \
 	return ReadingBuffer(d,l,iFileLoader_Private::TypeIndex(d),sizeof(_type_)); \
 }
@@ -98,10 +98,10 @@ namespace iFileLoader_Private
 	}
 
 	
-	void Swap4BytesRange(char *data, long count)
+	void Swap4BytesRange(char *data, vtkIdType count)
 	{
 		char *pos;
-		long i;
+		vtkIdType i;
 
 		pos = data;
 		for(i = 0; i<count; i++)
@@ -112,10 +112,10 @@ namespace iFileLoader_Private
 	}
 
 
-	void Swap8BytesRange(char *data, long count)
+	void Swap8BytesRange(char *data, vtkIdType count)
 	{
 		char *pos;
-		long i;
+		vtkIdType i;
 
 		pos = data;
 		for(i = 0; i<count; i++)
@@ -150,7 +150,7 @@ namespace iFileLoader_Private
 
 
 	template<class T>
-	inline void SwapBytesRange(T *p, long count)
+	inline void SwapBytesRange(T *p, vtkIdType count)
 	{
 		switch(sizeof(T))
 		{
@@ -175,34 +175,34 @@ namespace iFileLoader_Private
 	//
 	//  Check validity of numbers
 	//
-	bool IsNumberValid(int v){ return true; }
-	bool IsNumberValid(long v){ return true; }
-	bool IsNumberValid(float v){ return (-iMath::_FloatMax<=v && v<=iMath::_FloatMax); }
-	bool IsNumberValid(double v){ return (-iMath::_DoubleMax<=v && v<=iMath::_DoubleMax); }
+	bool IsNumberValid(vtkTypeInt32 v){ return true; }
+	bool IsNumberValid(vtkTypeInt64 v){ return true; }
+	bool IsNumberValid(vtkTypeFloat32 v){ return (-iMath::_FloatMax<=v && v<=iMath::_FloatMax); }
+	bool IsNumberValid(vtkTypeFloat64 v){ return (-iMath::_DoubleMax<=v && v<=iMath::_DoubleMax); }
 
 
 	//
 	//  Type indices
 	//
-	const int _Int = 1;
-	const int _Long = 2;
-	const int _Float = 3;
-	const int _Double = 4;
+	const int _Int32 = 1;
+	const int _Int64 = 2;
+	const int _Float32 = 3;
+	const int _Float64 = 4;
 
-	int TypeIndex(int *){ return _Int; }
-	int TypeIndex(long *){ return _Long; }
-	int TypeIndex(float *){ return _Float; }
-	int TypeIndex(double *){ return _Double; }
+	int TypeIndex(vtkTypeInt32 *){ return _Int32; }
+	int TypeIndex(vtkTypeInt64 *){ return _Int64; }
+	int TypeIndex(vtkTypeFloat32 *){ return _Float32; }
+	int TypeIndex(vtkTypeFloat64 *){ return _Float64; }
 
 
 	//
 	//  Read blocks of data from a file
 	//
 	template<class T>
-	bool ReadBlockToArray(iFile& F, T *p, long len, float updateStart, float updateDuration, bool swapbytes, iProgressEventObserver *observer)
+	bool ReadBlockToArray(iFile& F, T *p, vtkIdType len, float updateStart, float updateDuration, bool swapbytes, iProgressEventObserver *observer)
 	{
-		const long nline = 16384L;
-		long nread, l, nstep = (len+nline-1)/nline;
+		const vtkIdType nline = 16384L;
+		vtkIdType nread, l, nstep = (len+nline-1)/nline;
 		float ustep = updateDuration/nstep;
 
 		for(l=0; l<nstep; l++) 
@@ -232,24 +232,24 @@ namespace iFileLoader_Private
 	{
 		switch(b.Type)
 		{
-		case _Int:
+		case _Int32:
 			{
-				int *d = (int *)b.Data;
+				vtkTypeInt32 *d = (vtkTypeInt32 *)b.Data;
 				return iFileLoader_Private::ReadBlockToArray(F,d,b.Length,updateStart,updateDuration,swapbytes,observer);
 			}
-		case _Long:
+		case _Int64:
 			{
-				long *d = (long *)b.Data;
+				vtkTypeInt64 *d = (vtkTypeInt64 *)b.Data;
 				return iFileLoader_Private::ReadBlockToArray(F,d,b.Length,updateStart,updateDuration,swapbytes,observer);
 			}
-		case _Float:
+		case _Float32:
 			{
-				float *d = (float *)b.Data;
+				vtkTypeFloat32 *d = (vtkTypeFloat32 *)b.Data;
 				return iFileLoader_Private::ReadBlockToArray(F,d,b.Length,updateStart,updateDuration,swapbytes,observer);
 			}
-		case _Double:
+		case _Float64:
 			{
-				double *d = (double *)b.Data;
+				vtkTypeFloat64 *d = (vtkTypeFloat64 *)b.Data;
 				return iFileLoader_Private::ReadBlockToArray(F,d,b.Length,updateStart,updateDuration,swapbytes,observer);
 			}
 		default:
@@ -324,7 +324,7 @@ void iFileLoader::Define()
 	mShift[0] = mShift[1] = mShift[2] = 0.0f;
 
 	mPeriodic[0] = mPeriodic[1] = mPeriodic[2] = false;
-	mBoundaryConditions = _BoundaryConditionsWall;
+	mBoundaryConditions = BoundaryConditions::Wall;
 
 	//
 	//  Event observers are driven directly (otherwise we would have to create at least 16 new events, which is
@@ -394,7 +394,7 @@ iDataSubject* iFileLoader::GetSubject(const iDataType &type) const
 
 void iFileLoader::SetBoundaryConditions(int s)
 {
-	if(s>=0 && s<__NumBoundaryConditions)
+	if(BoundaryConditions::IsValid(s))
 	{
 		mBoundaryConditions = s;
 	}
@@ -605,26 +605,19 @@ void iFileLoader::Reset()
 void iFileLoader::ShiftData(double dr[3])
 {
 	int i;
-	double dxmax, dx[3];
+	double dx[3];
 
 	mObserver->Started(iProgressEventObserver::_Shifting);
 	mObserver->SetProgress(0.0);
 
-	dxmax = 0.0;
-	for(i=0; i<3; i++)
+	for(i=0; i<3; i++) dx[i] = dr[i] - mShift[i];
+
+	for(i=0; i<this->NumStreams(); i++) if(mStreams[i]->ReleasedData != 0)
 	{
-		dx[i] = dr[i] - mShift[i];
-		if(fabs(dx[i]) > dxmax) dxmax = fabs(dx[i]);
+		this->ShiftDataBody(mStreams[i]->ReleasedData,dx);
 	}
 
-	if(dxmax > 1.0e-30)
-	{
-		for(i=0; i<this->NumStreams(); i++) if(mStreams[i]->ReleasedData != 0)
-		{
-			this->ShiftDataBody(mStreams[i]->ReleasedData,dx);
-		}
-		for(i=0; i<3; i++) mShift[i] = dr[i];
-	}
+	for(i=0; i<3; i++) mShift[i] = dr[i];
 
 	mObserver->Finished();
 }
@@ -653,9 +646,9 @@ iFileLoader::Stream* iFileLoader::CreateNewStream() const
 //
 //  Data reading helpers
 //
-bool iFileLoader::SkipFortranRecord(iFile& F, long len)
+bool iFileLoader::SkipFortranRecord(iFile& F, vtkIdType len)
 {
-	long lrec1, lrec2;
+	vtkIdType lrec1, lrec2;
 
 	if(!this->ReadFortranHeaderFooter(F,lrec1)) return false;
 	if(!F.SkipBlock(len)) return false;
@@ -668,7 +661,7 @@ bool iFileLoader::SkipFortranRecord(iFile& F, long len)
 
 bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b, float updateStart, float updateDuration, bool autoswap)
 {
-	long lrec1, lrec2;
+	vtkIdType lrec1, lrec2;
 
 	if(!this->ReadFortranHeaderFooter(F,lrec1)) return false;
 
@@ -684,8 +677,8 @@ bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b, float upda
 
 bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, float updateStart, float updateDuration, bool autoswap)
 {
-	long lrec1, lrec2;
-	long len = b1.Length*b1.Size + b2.Length*b2.Size;
+	vtkIdType lrec1, lrec2;
+	vtkIdType len = b1.Length*b1.Size + b2.Length*b2.Size;
 	float f1 = float(b1.Length*b1.Size)/len;
 	float f2 = float(b2.Length*b2.Size)/len;
 
@@ -705,8 +698,8 @@ bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const Rea
 
 bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, const ReadingBuffer &b3, float updateStart, float updateDuration, bool autoswap)
 {
-	long lrec1, lrec2;
-	long len = b1.Length*b1.Size + b2.Length*b2.Size + b3.Length*b3.Size;
+	vtkIdType lrec1, lrec2;
+	vtkIdType len = b1.Length*b1.Size + b2.Length*b2.Size + b3.Length*b3.Size;
 	float f1 = float(b1.Length*b1.Size)/len;
 	float f2 = float(b2.Length*b2.Size)/len;
 	float f3 = float(b3.Length*b3.Size)/len;
@@ -729,12 +722,12 @@ bool iFileLoader::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const Rea
 	
 bool iFileLoader::ReadFortranRecord(iFile& F, int nbufs, const ReadingBuffer *b, float updateStart, float updateDuration, bool autoswap) // read any number of buffers
 {
-	long lrec1, lrec2;
+	vtkIdType lrec1, lrec2;
 
 	if(b==0 || nbufs<=0 || !this->ReadFortranHeaderFooter(F,lrec1)) return false;
 
 	int i;
-	long len = 0L;
+	vtkIdType len = 0L;
 	for(i=0; i<nbufs; i++)
 	{
 		len += b[i].Length*b[i].Size;
@@ -749,23 +742,33 @@ bool iFileLoader::ReadFortranRecord(iFile& F, int nbufs, const ReadingBuffer *b,
 }
 
 
-bool iFileLoader::ReadFortranHeaderFooter(iFile& F, long &lrec)
+bool iFileLoader::ReadFortranHeaderFooter(iFile& F, vtkIdType &lrec)
 {
 	bool ret = false;
 
-	if(mFortranHeaderFooterLength == sizeof(long))
+	if(mFortranHeaderFooterLength == 8)
 	{
-		ret = F.ReadBlock(&lrec,sizeof(long));
-		if(ret && mIsBigEndian!=iSystem::IsBigEndianMachine()) this->SwapBytes(lrec);
-	}
-	else if(mFortranHeaderFooterLength == sizeof(int))
-	{
-		int ltmp;
-		ret = F.ReadBlock(&ltmp,sizeof(int));
+		vtkTypeInt64 ltmp;
+		ret = F.ReadBlock(&ltmp,8);
 		if(ret)
 		{
 			if(mIsBigEndian != iSystem::IsBigEndianMachine()) this->SwapBytes(ltmp);
-			lrec = (long)ltmp;
+			if(sizeof(vtkIdType) < 8)
+			{
+				IERROR_LOW("VTK is compiled with 32-bit Ids. The record length of this file is 64-bits, it cannot be read with this VTK installation. To be able to read this file you will have to recompile VTK with the advanced option VTK_USE_64BIT_IDS set to ON and then recompile IFrIT.");
+				return false;
+			}
+			lrec = ltmp;
+		}
+	}
+	else if(mFortranHeaderFooterLength == 4)
+	{
+		vtkTypeInt32 ltmp;
+		ret = F.ReadBlock(&ltmp,4);
+		if(ret)
+		{
+			if(mIsBigEndian != iSystem::IsBigEndianMachine()) this->SwapBytes(ltmp);
+			lrec = ltmp;
 		}
 	}
 	else
@@ -777,22 +780,22 @@ bool iFileLoader::ReadFortranHeaderFooter(iFile& F, long &lrec)
 }
 
 
-bool iFileLoader::DetectFortranFileStructure(iFile &F, long len)
+bool iFileLoader::DetectFortranFileStructure(iFile &F, vtkIdType len)
 {
 	//
-	//  Try int-sized records
+	//  Try 4-byte records
 	//
-	if(AnalyzeFirstRecordForType<int>(F,len,mIsBigEndian))
+	if(AnalyzeFirstRecordForType<vtkTypeInt32>(F,len,mIsBigEndian))
 	{
-		mFortranHeaderFooterLength = sizeof(int);
+		mFortranHeaderFooterLength = sizeof(vtkTypeInt32);
 		return true;
 	}
 	//
-	//  Try long-sized records
+	//  Try 8-byte records
 	//
-	if(AnalyzeFirstRecordForType<long>(F,len,mIsBigEndian))
+	if(AnalyzeFirstRecordForType<vtkTypeInt64>(F,len,mIsBigEndian))
 	{
-		mFortranHeaderFooterLength = sizeof(long);
+		mFortranHeaderFooterLength = sizeof(vtkTypeInt64);
 		return true;
 	}
 	//
@@ -862,19 +865,15 @@ bool iFileLoader::IsSeriesFileName(const iString &fname) const
 //
 //  Overloads
 //
-IDATASUBJECT_DEFINE_SWAP_BYTES_FUNCTIONS(int);
-IDATASUBJECT_DEFINE_SWAP_BYTES_FUNCTIONS(long);
-IDATASUBJECT_DEFINE_SWAP_BYTES_FUNCTIONS(float);
-IDATASUBJECT_DEFINE_SWAP_BYTES_FUNCTIONS(double);
-//IDATASUBJECT_DEFINE_SWAP_BYTES_FUNCTIONS(unsigned int);
-//IDATASUBJECT_DEFINE_SWAP_BYTES_FUNCTIONS(unsigned long);
+IDATASUBJECT_DEFINE_SWAP_BYTES_FUNCTIONS(vtkTypeInt32);
+IDATASUBJECT_DEFINE_SWAP_BYTES_FUNCTIONS(vtkTypeInt64);
+IDATASUBJECT_DEFINE_SWAP_BYTES_FUNCTIONS(vtkTypeFloat32);
+IDATASUBJECT_DEFINE_SWAP_BYTES_FUNCTIONS(vtkTypeFloat64);
 
-IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(int);
-IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(long);
-IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(float);
-IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(double);
-//IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(unsigned int);
-//IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(unsigned long);
+IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(vtkTypeInt32);
+IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(vtkTypeInt64);
+IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(vtkTypeFloat32);
+IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(vtkTypeFloat64);
 
 
 //
