@@ -37,7 +37,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iarray.h"
-#include "iparameter.h"
 #include "ipointermacro.h"
 #include "istring.h"
 
@@ -55,17 +54,32 @@ class iViewModule;
 class vtkDataSet;
 
 
+namespace iParameter
+{
+	//
+    // Data parameters
+	//
+	namespace BoundaryConditions
+	{
+		const int Periodic = 0;
+		const int Wall = 1;
+
+		inline bool IsValid(int m){ return m>=0 && m<=1; }
+	};
+};
+
+
 //
 //  Helper macros
 //
 #define	IDATAFILELOADER_DECLARE_SWAP_BYTES_FUNCTIONS(_type_) \
 	static void SwapBytes(_type_ &p); \
-	static void SwapBytesRange(_type_ *data, long count)
+	static void SwapBytesRange(_type_ *data, vtkIdType count)
 
 #define	IDATAFILELOADER_DECLARE_READ_BLOCK_FUNCTIONS(_type_) \
-	bool ReadBlock(iFile& F, _type_ *p, long len, float updateStart, float updateDuration); \
+	bool ReadBlock(iFile& F, _type_ *p, vtkIdType len, float updateStart, float updateDuration); \
 	ReadingBuffer Buffer(_type_ &d) const; \
-	ReadingBuffer Buffer(_type_ *d, long l) const
+	ReadingBuffer Buffer(_type_ *d, vtkIdType l) const
 
 
 class iFileLoader : public vtkObjectBase
@@ -83,10 +97,10 @@ public:
 
 	vtkTypeMacro(iFileLoader,vtkObjectBase);
 
-	IDATAFILELOADER_DECLARE_SWAP_BYTES_FUNCTIONS(int);
-	IDATAFILELOADER_DECLARE_SWAP_BYTES_FUNCTIONS(long);
-	IDATAFILELOADER_DECLARE_SWAP_BYTES_FUNCTIONS(float);
-	IDATAFILELOADER_DECLARE_SWAP_BYTES_FUNCTIONS(double);
+	IDATAFILELOADER_DECLARE_SWAP_BYTES_FUNCTIONS(vtkTypeInt32);
+	IDATAFILELOADER_DECLARE_SWAP_BYTES_FUNCTIONS(vtkTypeInt64);
+	IDATAFILELOADER_DECLARE_SWAP_BYTES_FUNCTIONS(vtkTypeFloat32);
+	IDATAFILELOADER_DECLARE_SWAP_BYTES_FUNCTIONS(vtkTypeFloat64);
 
 	//
 	//  Operation on data
@@ -117,7 +131,7 @@ public:
 	void SetBoundaryConditions(int s);
 	void SetDirectionPeriodic(int d, bool s);
 	inline int GetBoundaryConditions() const {	return mBoundaryConditions; }
-	inline bool IsBoxPeriodic() const {	return (mBoundaryConditions == iParameter::_BoundaryConditionsPeriodic); }
+	inline bool IsBoxPeriodic() const {	return (mBoundaryConditions == iParameter::BoundaryConditions::Periodic); }
 	inline bool IsDirectionPeriodic(int d) const { if(d>=0 && d<3) return this->IsBoxPeriodic() && mPeriodic[d]; else return false; }
 
 	//
@@ -148,9 +162,9 @@ public:
 	struct ReadingBuffer
 	{
 		void *Data;
-		long Length;  // does not make sense to make in unsigned as vtkIdType is signed anyway
+		vtkIdType Length;
 		int Type, Size;
-		ReadingBuffer(void *d, long l, int t, int s)
+		ReadingBuffer(void *d, vtkIdType l, int t, int s)
 		{
 			Data = d;
 			Length = l;
@@ -172,15 +186,15 @@ protected:
 	//
 	//  File reading helpers
 	//
-	IDATAFILELOADER_DECLARE_READ_BLOCK_FUNCTIONS(int);
-	IDATAFILELOADER_DECLARE_READ_BLOCK_FUNCTIONS(long);
-	IDATAFILELOADER_DECLARE_READ_BLOCK_FUNCTIONS(float);
-	IDATAFILELOADER_DECLARE_READ_BLOCK_FUNCTIONS(double);
+	IDATAFILELOADER_DECLARE_READ_BLOCK_FUNCTIONS(vtkTypeInt32);
+	IDATAFILELOADER_DECLARE_READ_BLOCK_FUNCTIONS(vtkTypeInt64);
+	IDATAFILELOADER_DECLARE_READ_BLOCK_FUNCTIONS(vtkTypeFloat32);
+	IDATAFILELOADER_DECLARE_READ_BLOCK_FUNCTIONS(vtkTypeFloat64);
 
-	bool DetectFortranFileStructure(iFile &F, long len);
-	bool ReadFortranHeaderFooter(iFile& F, long &lrec);
+	bool DetectFortranFileStructure(iFile &F, vtkIdType len);
+	bool ReadFortranHeaderFooter(iFile& F, vtkIdType &lrec);
 
-	bool SkipFortranRecord(iFile& F, long len);
+	bool SkipFortranRecord(iFile& F, vtkIdType len);
 	bool ReadFortranRecord(iFile& F, const ReadingBuffer &b, float updateStart, float updateDuration, bool autoswap = true);
 	bool ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, float updateStart, float updateDuration, bool autoswap = true);
 	bool ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, const ReadingBuffer &b3, float updateStart, float updateDuration, bool autoswap = true);
