@@ -37,7 +37,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
-#include "ivtk.h"
+
+#include <vtkType.h>
 
 
 class vtkDataObject;
@@ -52,18 +53,6 @@ template<class Source, class OutputType>
 class iGenericSource : public Source, public iViewSubjectComponent
 {
 
-#ifndef IVTK_44
-protected:
-	virtual int RequestData(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
-
-	void SaveRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
-
-	vtkInformation *mSavedRequest;
-	vtkInformationVector **mSavedInputVector;
-	vtkInformationVector *mSavedOutputVector;
-	int mReturnCode;
-#endif
-
 public:
 
 	virtual float GetMemorySize();
@@ -74,6 +63,10 @@ protected:
 	iGenericSource(iViewSubject *vo, bool usesLimits);
 	virtual ~iGenericSource();
 
+	virtual int RequestData(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
+
+	void SaveRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
+
 	virtual void ExecuteData(vtkDataObject *output);
 	void ExecuteParent();
 
@@ -82,6 +75,10 @@ protected:
 	virtual void ProduceOutput() = 0; // called to recompute the output
 
 	const bool mUsesLimits;
+	vtkInformation *mSavedRequest;
+	vtkInformationVector **mSavedInputVector;
+	vtkInformationVector *mSavedOutputVector;
+	int mReturnCode;
 
 private:
 
@@ -93,22 +90,6 @@ template<class Filter, class InputType, class OutputType>
 class iGenericFilter : public Filter, public iViewSubjectComponent
 {
 
-#ifdef IVTK_44
-protected:
-	virtual void ExecuteInformation();
-#else
-protected:
-	virtual int ProcessRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
-	virtual int RequestData(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
-
-	void SaveRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
-
-	vtkInformation *mSavedRequest;
-	vtkInformationVector **mSavedInputVector;
-	vtkInformationVector *mSavedOutputVector;
-	int mReturnCode;
-#endif
-
 public:
 
 	virtual float GetMemorySize();
@@ -119,6 +100,11 @@ protected:
 	iGenericFilter(iViewSubject *vo, int numInputs, bool ownsOutput, bool usesLimits);
 	virtual ~iGenericFilter();
 
+	virtual int ProcessRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
+	virtual int RequestData(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
+
+	void SaveRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
+
 	virtual void ExecuteData(vtkDataObject *output);
 	void ExecuteParent();
 
@@ -131,10 +117,14 @@ protected:
 	//
 	//  Helper members for transforming scalars
 	//
-	bool ScalarsInit(vtkDataSetAttributes *data, long nSizeOut = 0, int nDimOut = 0);
+	bool ScalarsInit(vtkDataSetAttributes *data, vtkIdType nSizeOut = 0, int nDimOut = 0);
 	void ScalarsDone(vtkDataSetAttributes *data);
 
 	const bool mOwnsOutput, mUsesLimits;
+	vtkInformation *mSavedRequest;
+	vtkInformationVector **mSavedInputVector;
+	vtkInformationVector *mSavedOutputVector;
+	int mReturnCode;
 
 	vtkFloatArray *wScalarArrIn, *wScalarArrOut;
 	float *wScalarPtrIn, *wScalarPtrOut;
