@@ -35,8 +35,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewsubject.h"
 
 #include <vtkDataSetAttributes.h>
+#include <vtkDemandDrivenPipeline.h>
 #include <vtkFloatArray.h>
 #include <vtkImageData.h>
+#include <vtkInformation.h>
+#include <vtkInformationVector.h>
 #include <vtkPolyData.h>
 
 
@@ -78,22 +81,6 @@ void iGenericSource<Source,OutputType>::ExecuteData(vtkDataObject * )
 }
 
 
-#ifdef IVTK_44
-	
-template<class Source, class OutputType>
-void iGenericSource<Source,OutputType>::ExecuteParent()
-{
-	this->Source::ExecuteData(this->GetOutput());
-}
-
-
-#else
-
-#include <vtkDemandDrivenPipeline.h>
-#include <vtkInformation.h>
-#include <vtkInformationVector.h>
-
-
 template<class Source, class OutputType>
 void iGenericSource<Source,OutputType>::SaveRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo)
 {
@@ -143,9 +130,6 @@ void iGenericSource<Source,OutputType>::ExecuteParent()
 }
 
 
-#endif
-
-
 template<class Source, class OutputType>
 void iGenericSource<Source,OutputType>::SyncWithData(const iDataSyncRequest &)
 {
@@ -156,11 +140,7 @@ void iGenericSource<Source,OutputType>::SyncWithData(const iDataSyncRequest &)
 template<class Source, class OutputType>
 int iGenericSource<Source,OutputType>::GetNumberOfOutputs()
 {
-#ifdef IVTK_44
-	return this->Source::GetNumberOfOutputs();
-#else
 	return this->Source::GetNumberOfOutputPorts();
-#endif
 }
 
 
@@ -198,11 +178,7 @@ iGenericFilter<Filter,InputType,OutputType>::iGenericFilter(iViewSubject *vo, in
 
 	if(numInputs > 0)  //  not all filters default to 1 input, some have 0 inputs
 	{
-#ifdef IVTK_44
-		this->SetNumberOfInputs(numInputs);
-#else
 		this->SetNumberOfInputConnections(0,numInputs);
-#endif
 	}
 }
 
@@ -238,38 +214,6 @@ void iGenericFilter<Filter,InputType,OutputType>::ExecuteData(vtkDataObject * )
 }
 
 	
-#ifdef IVTK_44
-
-template<class Filter, class InputType, class OutputType>
-void iGenericFilter<Filter,InputType,OutputType>::ExecuteInformation()
-{
-	InputType *input = InputType::SafeDownCast(this->GetInput());
-	OutputType *output = this->GetOutput();
-
-	IERROR_ASSERT(output);
-	if(input != 0)
-	{
-		this->InitExecution();
-	}
-
-	this->Filter::ExecuteInformation();
-}
-
-
-template<class Filter, class InputType, class OutputType>
-void iGenericFilter<Filter,InputType,OutputType>::ExecuteParent()
-{
-	this->Filter::ExecuteData(this->GetOutput());
-}
-
-
-#else
-
-#include <vtkDemandDrivenPipeline.h>
-#include <vtkInformation.h>
-#include <vtkInformationVector.h>
-
-
 template<class Filter, class InputType, class OutputType>
 void iGenericFilter<Filter,InputType,OutputType>::SaveRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo)
 {
@@ -390,9 +334,6 @@ void iGenericFilter<Filter,InputType,OutputType>::ExecuteParent()
 }
 
 
-#endif
-
-
 template<class Filter, class InputType, class OutputType>
 void iGenericFilter<Filter,InputType,OutputType>::SyncWithData(const iDataSyncRequest &)
 {
@@ -403,11 +344,7 @@ void iGenericFilter<Filter,InputType,OutputType>::SyncWithData(const iDataSyncRe
 template<class Filter, class InputType, class OutputType>
 int iGenericFilter<Filter,InputType,OutputType>::GetNumberOfOutputs()
 {
-#ifdef IVTK_44
-	return this->Filter::GetNumberOfOutputs();
-#else
 	return this->Filter::GetNumberOfOutputPorts();
-#endif
 }
 
 
@@ -448,7 +385,7 @@ void iGenericFilter<Filter,InputType,OutputType>::VerifyResults()
 
 
 template<class Filter, class InputType, class OutputType>
-bool iGenericFilter<Filter,InputType,OutputType>::ScalarsInit(vtkDataSetAttributes *data, long nSizeOut, int nDimOut)
+bool iGenericFilter<Filter,InputType,OutputType>::ScalarsInit(vtkDataSetAttributes *data, vtkIdType nSizeOut, int nDimOut)
 {
 	if(data==0 || data->GetScalars()==0)
 	{
