@@ -56,8 +56,8 @@ public:
 	float GetMinValue() const { return mValMin; }
 	float GetMaxValue() const { return mValMax; }
 
-	long GetMinCellIndex() const { return mCellMin; }
-	long GetMaxCellIndex() const { return mCellMax; }
+	vtkIdType GetMinCellIndex() const { return mCellMin; }
+	vtkIdType GetMaxCellIndex() const { return mCellMax; }
 
 	const iPosition& GetMinCellPosition() const { return mPosMin; }
 	const iPosition& GetMaxCellPosition() const { return mPosMax; }
@@ -82,7 +82,7 @@ private:
 	//
 	//  Properties of the Min and Max cells
 	//
-	long mCellMin, mCellMax;
+	vtkIdType mCellMin, mCellMax;
 	iPosition mPosMin, mPosMax;
 };
 
