@@ -37,7 +37,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iparallel.h"
 #include "iparallelmanager.h"
 #include "iviewmodule.h"
-#include "ivtk.h"
 
 #include <vtkDataSetSource.h>
 #include <vtkFloatArray.h>
@@ -71,11 +70,7 @@ iHistogramMaker::iHistogramMaker(iViewModule *vm) : iParallelWorker(vm->GetParal
 
 	mAttached = true;
 
-#ifdef IVTK_44
-	this->SetNumberOfInputs(1);
-#else
 	this->SetNumberOfInputConnections(0,1);
-#endif
 
 	this->AddObserver(vtkCommand::StartEvent,vm->GetProgressEventObserver());
 	this->AddObserver(vtkCommand::ProgressEvent,vm->GetProgressEventObserver());
@@ -515,7 +510,7 @@ vtkIdType iHistogramMaker::GetNumberOfCells()
 }
 
 
-void iHistogramMaker::FindPositionForCell(long cell, iPosition &pos)
+void iHistogramMaker::FindPositionForCell(vtkIdType cell, iPosition &pos)
 {
 	int i;
 
