@@ -33,6 +33,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "istring.h"
 
 
+class iColor;
+
 class vtkImageData;
 
 
@@ -84,8 +86,10 @@ public:
 	void Clear();
 	void ReplaceData(vtkImageData *n);
 	void Blend(const iImage& im, float op);
-	void Overlay(int x, int y, const iImage& ovr, float opacity = 1.0);
+	void Overlay(int x, int y, const iImage& ovr, float opacity = 1.0, bool masking = true);
 	bool CombineInPseudoColor(const iImage &imRed, const iImage &imGreen, const iImage &imBlue);
+	void Crop(int x, int y, int w, int h);
+	void DrawFrame(int width, const iColor &color);
 
 	//
 	//  Quering the data
