@@ -731,8 +731,11 @@ void iImageComposer::Compose(iViewModule *vm, iStereoImageArray &images)
 	//
 	for(i=0; i<mBackgroundWindows.Size(); i++)
 	{
-		if(!mBackgroundWindows[i]->IsEmpty()) work = true;
-		mBackgroundWindows[i]->Draw(outIm);
+		if(!mBackgroundWindows[i]->IsEmpty())
+		{
+			work = true;
+			mBackgroundWindows[i]->Draw(outIm);
+		}
 	}
 
 	//
@@ -740,8 +743,11 @@ void iImageComposer::Compose(iViewModule *vm, iStereoImageArray &images)
 	//
 	for(i=0; i<mForegroundWindows.Size(); i++)
 	{
-		if(!mForegroundWindows[i]->IsEmpty()) work = true;
-		mForegroundWindows[i]->Draw(outIm);
+		if(!mForegroundWindows[i]->IsEmpty())
+		{
+			work = true;
+			mForegroundWindows[i]->Draw(outIm);
+		}
 	}
 
 	if(work)
