@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iLineToTubeFilter : public iGenericPolyDataToPolyDataFilter<vtkTubeFilter>
 {
 	
-	IGENERICFILTER_DECLARE(iLineToTubeFilter);
+	IGENERICFILTER_DECLARE(iLineToTubeFilter,vtkTubeFilter);
 
 protected:
 	
