@@ -26,7 +26,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
-#include "ivtk.h"
 #include "imagnifier.h"
 
 
@@ -35,24 +34,30 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <vtkCamera.h>
 #include <vtkImageData.h>
+#include <vtkInformation.h>
+#include <vtkInformationVector.h>
 #include <vtkRenderWindow.h>
 #include <vtkRenderer.h>
+#include <vtkStreamingDemandDrivenPipeline.h>
 
 
-#ifdef IVTK_44
-
-void iMagnifier::ExecuteData(vtkDataObject *output)
+iMagnifier* iMagnifier::New()
 {
-	vtkImageData *data = this->AllocateOutputData(output);
-
-	this->Render(data);
+	return new iMagnifier;
 }
 
-#else
 
-#include "vtkInformation.h"
-#include "vtkInformationVector.h"
-#include "vtkStreamingDemandDrivenPipeline.h"
+iMagnifier::iMagnifier()
+{
+	this->Magnification = 1;
+	mTileX = mTileY = 0;
+}
+
+
+iMagnifier::~iMagnifier()
+{
+}
+
 
 int iMagnifier::ProcessRequest(vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -83,26 +88,6 @@ void iMagnifier::RequestMyData(vtkInformation *, vtkInformationVector **, vtkInf
 	this->Render(data);
 }
 
-#endif
-
-
-iMagnifier* iMagnifier::New()
-{
-	return new iMagnifier;
-}
-
-
-iMagnifier::iMagnifier()
-{
-	this->Magnification = 1;
-	mTileX = mTileY = 0;
-}
-
-
-iMagnifier::~iMagnifier()
-{
-}
-
 
 void iMagnifier::Render(vtkImageData *data)
 {
@@ -119,11 +104,7 @@ void iMagnifier::Render(vtkImageData *data)
 	int inExtent[6];
 
 	/// ++++++ Added ++++++++++++++++++++++++++++++++++++++++++++
-#ifdef IVTK_44
-	int inIncr[3];
-#else
 	vtkIdType inIncr[3];
-#endif
 	/// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 	int *size;
