@@ -32,7 +32,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icommoneventobservers.h"
 #include "ilegend.h"
 #include "imarker.h"
-#include "iparameter.h"
 #include "ipointglyph.h"
 #include "irendertool.h"
 #include "iviewmodule.h"
@@ -47,6 +46,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewfamilytemplate.h"
 
 
+using namespace iParameter;
+
+
 iMarkerFamily* iMarkerFamily::New(iViewModule *vm)
 {
 	return new iMarkerFamily(vm);
@@ -110,7 +112,7 @@ int iMarkerFamily::CreateMember()
 	{
 		this->BuildLegend();
 		this->SetCurrentMemberIndex(ret);
-		this->GetCurrentMember()->SetPosition(iParameter::_LocationFocalPoint);
+		this->GetCurrentMember()->SetPosition(ViewSubject::Location::FocalPoint);
 	}
 	return ret;
 }
