@@ -38,10 +38,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <vtkFloatArray.h>
 #include <vtkPointData.h>
-
-#ifndef IVTK_44
 #include <vtkStreamingDemandDrivenPipeline.h>
-#endif
 
 //
 //  Templates
@@ -62,12 +59,8 @@ void iMergeDataFilter::SetDataInput(int rank, vtkDataSet *input)
 	{
 		mDataRank = rank;
 		mDataInput = input;
-#ifdef IVTK_44
-		this->SetNthInput(1,input);
-#else
 		this->SetNumberOfInputPorts(2);
 	    this->SetInputConnection(1,input->GetProducerPort());
-#endif
 	}
 }
 
@@ -97,14 +90,12 @@ void iMergeDataFilter::InitExecution()
 	output->SetUpdateExtent(input->GetUpdateExtent()); // but it took me a lot of debugging to find out they must be here
 	if(mDataInput != 0) mDataInput->SetUpdateExtentToWholeExtent();
 
-#ifndef IVTK_44
     if(mSavedOutputVector != 0)
 	{
 		vtkInformation* outInfo = mSavedOutputVector->GetInformationObject(0);
 		outInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(),1);
 		outInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(),0);
 	}
-#endif
 }
 
 
