@@ -1131,7 +1131,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, iString* val,
 }
 
 
-void iObject::PackValuePiecewiseFunction(iString &s, const iObjectKey &key, const iPiecewiseFunction **f, int num, int index, bool prefixed) const
+void iObject::PackValuePiecewiseFunction(iString &s, const iObjectKey &key, const iPiecewiseFunction * const *f, int num, int index, bool prefixed) const
 {
 	int i, j, n, i1, i2;
 	if(f == 0) return;
@@ -1205,7 +1205,7 @@ bool iObject::UnPackValuePiecewiseFunction(const iString &s, const iObjectKey &k
 }
 
 
-void iObject::PackValueRangeCollection(iString &s, const iObjectKey &key, const iRangeCollection **f, int num, int index, bool prefixed) const
+void iObject::PackValueRangeCollection(iString &s, const iObjectKey &key, const iRangeCollection * const *f, int num, int index, bool prefixed) const
 {
 	int i, j, n, i1, i2;
 	if(f == 0) return;
