@@ -40,7 +40,7 @@ iObjectHelpBase::iObjectHelpBase(const char *tag)
 
 	if(strlen(tag) > 15)
 	{
-		IERROR_FINISH("Tag is too long.");
+		IERROR_FATAL("Tag is too long.");
 	}
 	else strcpy(mTag,tag);
 }
@@ -86,6 +86,11 @@ iObjectTypeHelp::iObjectTypeHelp(const iObjectType *type) : iObjectHelpBase(("or
 }
 
 
+iObjectTypeHelp::~iObjectTypeHelp()
+{
+}
+
+
 iObjectKeyHelp::iObjectKeyHelp(const iObjectKey *key) : iObjectHelpBase(("or."+key->HelpEntryKey()).ToCharPointer())
 {
 	mKey = key;
@@ -95,3 +100,8 @@ iObjectKeyHelp::iObjectKeyHelp(const iObjectKey *key) : iObjectHelpBase(("or."+k
 	}
 }
 
+
+iObjectKeyHelp::~iObjectKeyHelp()
+{
+}
+
