@@ -38,7 +38,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkFloatArray.h>
 #include <vtkPointData.h>
 
-#include "iparameter.h"
 using namespace iParameter;
 
 //
@@ -137,7 +136,7 @@ void iOrthoSlicer::ProduceOutput()
 	//
 	//  Decide what we do: cell vs point data, how many points, etc.
 	//
-	if(input->GetVoxelLocation() == _VoxelLocationVertex)
+	if(input->GetVoxelLocation() == VoxelLocation::Vertex)
 	{
 		//
 		//  Place points as we get them
@@ -263,7 +262,7 @@ void iOrthoSlicer::ProduceOutput()
 		}
     }
     
-	if(input->GetVoxelLocation() == _VoxelLocationVertex)
+	if(input->GetVoxelLocation() == VoxelLocation::Vertex)
 	{
 	    this->ScalarsDone(output->GetPointData());
 	}
