@@ -32,7 +32,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "imagnifier.h"
 #include "imath.h"
-#include "iparameter.h"
 #include "irendertool.h"
 
 #include <vtkCamera.h>
@@ -141,19 +140,19 @@ void iOverlayHelper::UpdateTextProperty(vtkViewport *vp, vtkTextProperty *prop)
 	{
 		switch(mRenderTool->GetFontType())
 		{
-		case _TextTypeBitmapArial:
+		case TextType::Arial:
 			{
 				prop->SetFontFamilyToArial();
 				mFontFactor = 1.0;
 				break;
 			}
-		case _TextTypeBitmapCourier:
+		case TextType::Courier:
 			{
 				prop->SetFontFamilyToCourier();
 				mFontFactor = 1.2;
 				break;
 			}
-		case _TextTypeBitmapTimes:
+		case TextType::Times:
 			{
 				prop->SetFontFamilyToTimes();
 				mFontFactor = 1.0;
