@@ -55,9 +55,9 @@ iPalette::iPalette()
 	mLT[0] = vtkLookupTable::New(); IERROR_ASSERT(mLT[0]);
 	mLT[1] = vtkLookupTable::New(); IERROR_ASSERT(mLT[1]);
 	
-	mFunR = iPiecewiseFunction::New(); IERROR_ASSERT(mFunR);
-	mFunG = iPiecewiseFunction::New(); IERROR_ASSERT(mFunG);
-	mFunB = iPiecewiseFunction::New(); IERROR_ASSERT(mFunB);
+	mFun[0] = iPiecewiseFunction::New(); IERROR_ASSERT(mFun[0]);
+	mFun[1] = iPiecewiseFunction::New(); IERROR_ASSERT(mFun[1]);
+	mFun[2] = iPiecewiseFunction::New(); IERROR_ASSERT(mFun[2]);
 
 	mCTF[0]->SetColorSpaceToRGB();
 	mCTF[1]->SetColorSpaceToRGB();
@@ -83,17 +83,17 @@ iPalette::~iPalette()
 	mLT[0]->Delete(); 
 	mLT[1]->Delete(); 
 
-	mFunR->Delete();
-	mFunG->Delete();
-	mFunB->Delete();
+	mFun[0]->Delete();
+	mFun[1]->Delete();
+	mFun[2]->Delete();
 }
 
 
 void iPalette::SetComponents(const iPiecewiseFunction *r, const iPiecewiseFunction *g, const iPiecewiseFunction *b)
 {
-	if(r != 0) mFunR->Copy(r);
-	if(g != 0) mFunG->Copy(g);
-	if(b != 0) mFunB->Copy(b);
+	if(r != 0) mFun[0]->Copy(r);
+	if(g != 0) mFun[1]->Copy(g);
+	if(b != 0) mFun[2]->Copy(b);
 
 	this->Update();
 }
@@ -104,9 +104,9 @@ iColor iPalette::GetColor(int n) const
 	n = ( n < 0 ) ? 0 : n;
 	n = ( n > 255 ) ? 255 : n;
 	float x = (float)n/255.0;
-	float r = mFunR->GetValue(x);
-	float g = mFunG->GetValue(x);
-	float b = mFunB->GetValue(x);
+	float r = mFun[0]->GetValue(x);
+	float g = mFun[1]->GetValue(x);
+	float b = mFun[2]->GetValue(x);
 	return iColor(round(255.0*r),round(255.0*g),round(255.0*b));
 }
 
@@ -122,18 +122,18 @@ void iPalette::Update()
 	mCTF[0]->RemoveAllPoints();
 	mCTF[1]->RemoveAllPoints();
 	ir = ig = ib = 0;
-	while(ir<mFunR->N() && ig<mFunG->N() && ib<mFunB->N())
+	while(ir<mFun[0]->N() && ig<mFun[1]->N() && ib<mFun[2]->N())
 	{
-		x = mFunR->X(ir);
-		if(x > mFunG->X(ig)) x = mFunG->X(ig);
-		if(x > mFunB->X(ib)) x = mFunB->X(ib);
+		x = mFun[0]->X(ir);
+		if(x > mFun[1]->X(ig)) x = mFun[1]->X(ig);
+		if(x > mFun[2]->X(ib)) x = mFun[2]->X(ib);
 		
-		mCTF[0]->AddRGBPoint(255.0*x,mFunR->GetValue(x),mFunG->GetValue(x),mFunB->GetValue(x));
-		mCTF[1]->AddRGBPoint(255.0*(1.0-x),mFunR->GetValue(x),mFunG->GetValue(x),mFunB->GetValue(x));
+		mCTF[0]->AddRGBPoint(255.0*x,mFun[0]->GetValue(x),mFun[1]->GetValue(x),mFun[2]->GetValue(x));
+		mCTF[1]->AddRGBPoint(255.0*(1.0-x),mFun[0]->GetValue(x),mFun[1]->GetValue(x),mFun[2]->GetValue(x));
 		
-		if(fabs(x-mFunR->X(ir)) < 1.0e-4) ir++;
-		if(fabs(x-mFunG->X(ig)) < 1.0e-4) ig++;
-		if(fabs(x-mFunB->X(ib)) < 1.0e-4) ib++;
+		if(fabs(x-mFun[0]->X(ir)) < 1.0e-4) ir++;
+		if(fabs(x-mFun[1]->X(ig)) < 1.0e-4) ig++;
+		if(fabs(x-mFun[2]->X(ib)) < 1.0e-4) ib++;
 	}
 
 	//
@@ -142,8 +142,8 @@ void iPalette::Update()
 	for(i=0; i<256; i++)
 	{
 		x = (float)i/255.0;
-		mLT[0]->SetTableValue(i,mFunR->GetValue(x),mFunG->GetValue(x),mFunB->GetValue(x));
-		mLT[1]->SetTableValue(255-i,mFunR->GetValue(x),mFunG->GetValue(x),mFunB->GetValue(x));
+		mLT[0]->SetTableValue(i,mFun[0]->GetValue(x),mFun[1]->GetValue(x),mFun[2]->GetValue(x));
+		mLT[1]->SetTableValue(255-i,mFun[0]->GetValue(x),mFun[1]->GetValue(x),mFun[2]->GetValue(x));
 	}
 
 	mImageNeedsUpdate = true;
@@ -152,9 +152,9 @@ void iPalette::Update()
 
 void iPalette::Copy(iPalette *p)
 {
-	mFunR->Copy(p->mFunR);
-	mFunG->Copy(p->mFunG);
-	mFunB->Copy(p->mFunB);
+	mFun[0]->Copy(p->mFun[0]);
+	mFun[1]->Copy(p->mFun[1]);
+	mFun[2]->Copy(p->mFun[2]);
 	mName = p->mName;
 
 	this->Update();
@@ -182,9 +182,9 @@ const iImage* iPalette::GetImage()
 		for(i=0; i<mImageWidth; i++)
 		{
 			x = (float)i/(mImageWidth-1);
-			r = char(round(255.0*mFunR->GetValue(x)));
-			g = char(round(255.0*mFunG->GetValue(x)));
-			b = char(round(255.0*mFunB->GetValue(x)));
+			r = char(round(255.0*mFun[0]->GetValue(x)));
+			g = char(round(255.0*mFun[1]->GetValue(x)));
+			b = char(round(255.0*mFun[2]->GetValue(x)));
 			dPtr[3*i+0] = r;
 			dPtr[3*i+1] = g;
 			dPtr[3*i+2] = b;
