@@ -44,8 +44,6 @@ class iParallelWorker;
 class iParallelManager : public vtkObject
 {
 
-	friend class iShell;
-
 	IPOINTER_AS_PART(ControlModule);
 
 public:
@@ -78,13 +76,10 @@ private:
 
 	iParallelManager(iControlModule *cm);
 
-	void ResetMaxNumberOfProcessors(int n); // overwrite default;
-
 	int mNumProcs, mMinNumProcs, mMaxNumProcs;
 	int mCount;
 
 	iParallelHelper *mHelper;
-	iParallelUpdateEventObserver *mParallelObserver;
 };
 
 #endif  // IPARALLELMANAGER_H
