@@ -71,7 +71,7 @@ int iParallelWorker::ParallelExecute(int step)
 		ret = mManager->ExecuteWorker(this);
 	}
 
-	if(ret != 0) IERROR_REPORT("Failure in iParallelWorker::ParallelExecute.");
+	if(ret != 0) IERROR_LOW("Failure in iParallelWorker::ParallelExecute.");
 	return ret;
 }
 
