@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iParticleConnector : public iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>
 {
 	
-	IGENERICFILTER_DECLARE(iParticleConnector);
+	IGENERICFILTER_DECLARE(iParticleConnector,vtkPolyDataToPolyDataFilter);
 
 public:
 	
@@ -51,6 +51,8 @@ protected:
 	
 	virtual void ProduceOutput();
 
+private:
+
 	int mAttCon, mAttSep;
 };
 
