@@ -61,7 +61,7 @@ iParticleDataConverter::iParticleDataConverter(iViewSubject *vo) : iGenericPolyD
 {
 	mSize = 0.005;
 	mPoint = iPointGlyph::New(vo); IERROR_ASSERT(mPoint);
-	this->SetType(_PointTypePoint);
+	this->SetType(PointGlyphType::Point);
 }
 
 
@@ -106,7 +106,7 @@ void iParticleDataConverter::ProduceOutput()
 
 	output->ShallowCopy(input);
 
-	if(mPoint->GetType() == _PointTypePoint) return;
+	if(mPoint->GetType() == PointGlyphType::Point) return;
 	
 	vtkPoints *inpPnts = input->GetPoints();
 	if(inpPnts == 0) return;
@@ -199,7 +199,7 @@ void iParticleDataConverter::ProduceOutput()
 		//
 		//  If lines are present, arrows and cones are oriented along the lines
 		//
-		if(mPoint->GetType()==_PointTypeCone || mPoint->GetType()==_PointTypeArrow)
+		if(mPoint->GetType()==PointGlyphType::Cone || mPoint->GetType()==PointGlyphType::Arrow)
 		{
 			orient = true;
 			inpPntsDir = new float[3*nInpPnts];
@@ -509,6 +509,6 @@ void iParticleDataConverter::ProduceOutput()
 
 float iParticleDataConverter::GetMemorySize()
 {
-	if(this->GetType() == _PointTypePoint) return 0.0; else return this->iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>::GetMemorySize();
+	if(this->GetType() == PointGlyphType::Point) return 0.0; else return this->iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>::GetMemorySize();
 }
 
