@@ -44,7 +44,7 @@ class iPointGlyph;
 class iParticleDataConverter: public iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>
 {
 
-	IGENERICFILTER_DECLARE(iParticleDataConverter);
+	IGENERICFILTER_DECLARE(iParticleDataConverter,vtkPolyDataToPolyDataFilter);
 	
 public:
 
@@ -62,6 +62,8 @@ protected:
 	
 	virtual void ProduceOutput();
 
+private:
+
 	float mSize;
 	iPointGlyph *mPoint;
 };
