@@ -66,9 +66,9 @@ public:
 
 	iParticleHelper(iParticleFileLoader *loader);
 
-	void ShiftData(bool paf, int dim, long n, bool per[3], float dr, float *pf, double *pd);
-	void FindRange(int dim, long n, float *pf, float *amin, float *amax);
-	void AddIndexAsAttribute(int att, int nc, long n, float *pf);
+	void ShiftData(bool paf, int dim, vtkIdType n, bool per[3], float dr, float *pf, double *pd);
+	void FindRange(int dim, vtkIdType n, float *pf, float *amin, float *amax);
+	void AddIndexAsAttribute(int att, int nc, vtkIdType n, float *pf);
 
 	template<class T, class D>
 	bool ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int inNum, int outOffset, float updateStart, float updateDuration, T *scale, T *offset);
@@ -90,7 +90,7 @@ protected:
 
 	int mDim, mCom, mNumProcs;
 	bool mPaf;
-	long mTot;
+	vtkIdType mTot;
 	float mDr;
 };
 
@@ -98,13 +98,13 @@ protected:
 //
 //  Main class
 //
-iParticleFileLoader::iParticleFileLoader(iDataReader *r, int priority) : iFileLoader(r,priority)
+iParticleFileLoader::iParticleFileLoader(iDataReader *r, int priority, bool useExtras) : iFileLoader(r,priority), mUseExtras(useExtras)
 {
 	this->Define();
 }
 
 
-iParticleFileLoader::iParticleFileLoader(iDataReaderExtension *ext, int priority) : iFileLoader(ext,priority)
+iParticleFileLoader::iParticleFileLoader(iDataReaderExtension *ext, int priority, bool useExtras) : iFileLoader(ext,priority), mUseExtras(useExtras)
 {
 	this->Define();
 }
@@ -187,7 +187,7 @@ void iParticleFileLoader::SetDownsampleFactor(int type, int value)
 
 void iParticleFileLoader::SetDensityAttribute(int type, int attr)
 {
-	if(type>=0 && type<this->NumStreams())
+	if(mUseExtras && type>=0 && type<this->NumStreams())
 	{
 		this->GetStream(type)->Extras.DensityAttribute = (attr > -2) ? attr : -2;
 	}
@@ -196,7 +196,7 @@ void iParticleFileLoader::SetDensityAttribute(int type, int attr)
 
 void iParticleFileLoader::SetOrderIsAttribute(int type, bool s)
 {
-	if(type>=0 && type<this->NumStreams())
+	if(mUseExtras && type>=0 && type<this->NumStreams())
 	{
 		this->GetStream(type)->Extras.OrderIsAttribute = s;
 	}
@@ -396,7 +396,7 @@ void iParticleFileLoader::ShiftPolyData(vtkPolyData *data, int d, double dx)
 {
 	if(data==0 || data->GetPoints()==0 || d<0 || d>2) return;
 
-	long n = data->GetPoints()->GetNumberOfPoints();
+	vtkIdType n = data->GetPoints()->GetNumberOfPoints();
 	float *pf = (float *)data->GetPoints()->GetVoidPointer(0);
 	double *pd = (double *)data->GetPoints()->GetVoidPointer(0);
 		
@@ -432,20 +432,7 @@ bool iParticleFileLoader::ReadIntAttributes(iFile &F, int inNum, int outOffset,
 }
 
 
-void iParticleFileLoader::ConfigureStreams(int *ntot, int *natt, bool paf)
-{
-	long *nt = new long[this->NumStreams()]; IERROR_ASSERT(nt);
-
-	int i;
-	for(i=0; i<this->NumStreams(); i++) nt[i] = ntot[i];
-
-	this->ConfigureStreams(nt,natt);
-
-	delete [] nt;
-}
-
-
-void iParticleFileLoader::ConfigureStreams(long *ntot, int *natt, bool paf)
+void iParticleFileLoader::ConfigureStreams(vtkIdType *ntot, int *natt, bool paf)
 {
 	int n;
 	ParticleStream *stream;
@@ -603,7 +590,7 @@ iParticleHelper::iParticleHelper(iParticleFileLoader *loader) : iParallelWorker(
 }
 
 
-void iParticleHelper::ShiftData(bool paf, int dim, long n, bool per[3], float dr, float *pf, double *pd)
+void iParticleHelper::ShiftData(bool paf, int dim, vtkIdType n, bool per[3], float dr, float *pf, double *pd)
 {
 	mPaf = paf;
 	mDim = dim;
@@ -617,7 +604,7 @@ void iParticleHelper::ShiftData(bool paf, int dim, long n, bool per[3], float dr
 }
 
 
-void iParticleHelper::FindRange(int dim, long tot, float *pf, float *fMin, float *fMax)
+void iParticleHelper::FindRange(int dim, vtkIdType tot, float *pf, float *fMin, float *fMax)
 {
 	mDim = dim;
 	mTot = tot;
@@ -643,7 +630,7 @@ void iParticleHelper::FindRange(int dim, long tot, float *pf, float *fMin, float
 }
 
 
-void iParticleHelper::AddIndexAsAttribute(int dim, int com, long tot, float *pf)
+void iParticleHelper::AddIndexAsAttribute(int dim, int com, vtkIdType tot, float *pf)
 {
 	mDim = dim;
 	mCom = com;
@@ -656,7 +643,7 @@ void iParticleHelper::AddIndexAsAttribute(int dim, int com, long tot, float *pf)
 
 int iParticleHelper::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 {
-	long l, kstp, kbeg, kend;
+	vtkIdType l, kstp, kbeg, kend;
 	int d = mDim;
 	int nc = mCom;
 
@@ -808,7 +795,7 @@ bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int
 	//
 	//  Read the header
 	//
-	long lrec1, lrec2;
+	vtkIdType lrec1, lrec2;
 	if(!this->mLoader->ReadFortranHeaderFooter(F,lrec1))
 	{
 		this->mLoader->GetErrorStatus()->Set("Corrupted data.");
@@ -818,7 +805,7 @@ bool iParticleHelper::ReadFortranRecordWithMaskTemplate(iFile &F, int dest, int
 	//
 	//  Find # of components in the record
 	//
-	int nCompRec = lrec1/(sizeof(T)*it.GetNumGlobalTotal());
+	int nCompRec = lrec1/((vtkIdType)sizeof(T)*it.GetNumGlobalTotal());
 	if(lrec1 != nCompRec*sizeof(T)*it.GetNumGlobalTotal())
 	{
 		this->mLoader->GetErrorStatus()->Set("Corrupted data.");
