@@ -220,12 +220,10 @@ namespace iParticleGroup_Private
 
 		virtual bool HasArtifacts(vtkRenderer *ren, vtkProperty *prop)
 		{
-			vtkPolyData *output = this->GetOutput();
-
 			//
 			//  Activate for antialiased opaque verts
 			//
-			if(output->GetNumberOfVerts()>0 && prop!=0 && ren->GetRenderWindow()!=0)
+			if(prop!=0 && ren->GetRenderWindow()!=0)
 			{
 				return (prop->GetOpacity()==1.0 && ren->GetRenderWindow()->GetPointSmoothing()!=0);
 			}
@@ -251,9 +249,9 @@ iParticleGroup* iParticleGroup::New(iParticlesViewSubject *parent)
 }
 
 
-iParticleGroup::iParticleGroup(iParticlesViewSubject *parent) : iSolidViewSubject(parent->GetViewModule(),parent->GetDataType(),parent->GetObjectName(),2,_ViewSubjectSameColor|_ViewSubjectSameOpacity|_ViewSubjectSamePalette,0.999)
+iParticleGroup::iParticleGroup(iParticlesViewSubject *parent) : iSolidViewSubject(parent->GetViewModule(),parent->GetDataType(),parent->GetSubjectName(),2,ViewSubject::Flag::SameColor|ViewSubject::Flag::SameOpacity|ViewSubject::Flag::SamePalette,0.999)
 {
-	mObjectType = _ObjectTypeParticles;
+	mSubjectId = ViewSubject::Id::Particles;
 
 	mParent = parent;
 	mParentIndex = -1;
@@ -263,9 +261,9 @@ iParticleGroup::iParticleGroup(iParticlesViewSubject *parent) : iSolidViewSubjec
 	mAttSizeDirect = mAutoScaled = false;
 	mAttSizeExtraFactor = 1.0;
 
-	mType = _PointTypePoint;
+	mType = PointGlyphType::Point;
 	mSize = 1.0;
-	mStretchToColor = _StretchLog;
+	mStretchToColor = iDataStretch::Log;
 	mLimitsToColor[0] = 0.1f;
 	mLimitsToColor[1] = 10.0f;
 
@@ -324,8 +322,8 @@ void iParticleGroup::ConfigureBody()
 	mActors[1]->SetInput(this->Pipeline()->GetOutput(0));
 	this->Pipeline()->SetNthInput(0,mConnector->GetOutput());
 
-	this->SetStretchToColor(_StretchLog);
-	this->SetStretchToSize(_StretchLog);
+	this->SetStretchToColor(iDataStretch::Log);
+	this->SetStretchToSize(iDataStretch::Log);
 }
 
 
@@ -365,10 +363,10 @@ void iParticleGroup::SetType(int t)
 
 	switch (mType) 
 	{
-	case _PointTypePoint:
-	case _PointTypeTetrahydron: 
-	case _PointTypeCluster:
-	case _PointTypeGalaxy: 
+	case PointGlyphType::Point:
+	case PointGlyphType::Tetrahydron: 
+	case PointGlyphType::Cluster:
+	case PointGlyphType::Galaxy: 
 		{ 
 			mShading = false; 
 			break; 
@@ -379,7 +377,7 @@ void iParticleGroup::SetType(int t)
 		}
 	}
 
-	if(mType == _PointTypePoint)
+	if(mType == PointGlyphType::Point)
 	{
 		mActors[0]->GetProperty()->SetPointSize(mSize);
 		mActors[1]->VisibilityOff();
@@ -458,7 +456,7 @@ void iParticleGroup::SetFixedSize(float s)
 	if(s>0.0 && s<1000.1)
 	{
 		mSize = s;
-		if(mType == _PointTypePoint) mActors[0]->GetProperty()->SetPointSize(mSize); 
+		if(mType == PointGlyphType::Point) mActors[0]->GetProperty()->SetPointSize(mSize); 
 		this->Pipeline()->UpdateContents(iParticleGroupPipeline::_FixedSize);
 		this->ClearCache();
 	}
@@ -539,7 +537,7 @@ int iParticleGroup::GetStretchToSize() const
 	}
 	else
 	{
-		return _StretchLin;
+		return iDataStretch::Linear;
 	}
 }
 
@@ -598,7 +596,7 @@ void iParticleGroup::ShowBody(bool show)
 	{
 		this->SetStretchToColor(mStretchToColor);
 		mActors[0]->VisibilityOn();
-		if(mType != _PointTypePoint) mActors[1]->VisibilityOn();
+		if(mType != PointGlyphType::Point) mActors[1]->VisibilityOn();
 	} 
 	else 
 	{
