@@ -33,28 +33,26 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "isolidviewsubject.h"
 
 
+class iEventObserver;
 class iFunctionMapping;
 class iHistogramMaker;
 class iParticleConnector;
 class iParticlesViewSubject;
 class iPiecewiseFunction;
 
-class vtkCommand;
 class vtkPolyData;
 
 
 class iParticleGroup : public iSolidViewSubject
 {
 	
-	friend class iExtensionFactory;
 	friend class iParticleGroupFamily;
 	friend class iParticlesViewSubject;
 
 public:
 	
-	IOBJECT_DECLARE_SELF(iParticleGroup,iSolidViewSubject);
-
-	static iParticleGroup* New(iParticlesViewSubject *parent); // needed for creating a special iParticleGroupFamily by iParticlesViewSubject
+	vtkTypeMacro(iParticleGroup,iSolidViewSubject);
+	static iParticleGroup* New(iParticlesViewSubject *parent = 0); // needed for creating a special iParticleGroupFamily by iParticlesViewSubject
 	static const iObjectType& Type();
 		
 	IOBJECT_DECLARE_GETSET1(Type,int);
@@ -109,6 +107,10 @@ public:
 	//void SetLineWidth(int s);
 	//inline int GetLineWidth() const { return mLineWidth; }
 
+	IOBJECT_DECLARE_GETSET1(AutoScaled,bool);
+	//void SetAutoScaled(bool s);
+	//inline bool GetAutoScaled() const { return mAutoScaled; }
+
 	IOBJECT_DECLARE_GETSET2(AttributeToConnect,int);
 	//void SetAttributeToConnect(int a);
 	//int GetAttributeToConnect() const;
@@ -116,8 +118,8 @@ public:
 	//void SetAttributeToSeparate(int a);
 	//int GetAttributeToSeparate() const;
 
-	IOBJECT_DECLARE_GET(SizeFunction,mFunction,iFunctionMapping*);
-	//inline iFunctionMapping* GetSizeFunction() const { return mFunction; }
+	IOBJECT_DECLARE_GET2(SizeFunction,iFunctionMapping * );
+	//inline iFunctionMapping* GetSizeFunction() const;
 
 	virtual void UpdateColorLookupTable();
 
@@ -130,8 +132,6 @@ public:
 	ISOLIDVIEWSUBJECT_DECLARE_INHERITED_KEYS;
 	ISOLIDVIEWSUBJECT_DECLARE_INHERITED_MEMBERS;
 
-	virtual void SetShading(bool v);
-
 protected:
 	
 	iParticleGroup(iParticlesViewSubject *parent);
@@ -142,11 +142,13 @@ protected:
 	virtual void FinishInitialization();
 	virtual float GetExtraMemorySize() const;
 
+private:
+
 	iParticlesViewSubject *mParent;
 	int mParentIndex;
 
 	int mAttColor, mAttSize;
-	bool mAttSizeDirect;
+	bool mAttSizeDirect, mAutoScaled;
 	float mAttSizeExtraFactor;
 	int mType;
 	iPiecewiseFunction *mSF;
@@ -154,14 +156,13 @@ protected:
 	float mSize;
 	int mStretchToColor, mLineWidth;
 	float mLimitsToColor[2];
-	bool mKeepPoint;
 
 	//
 	//  VTK members
 	//
 	iParticleConnector *mConnector;
 	iHistogramMaker *mHistogramMaker;
-	vtkCommand *mSizeFunctionEventObserver;
+	iEventObserver *mSizeFunctionEventObserver, *mCameraEventObserver;
 };
 
 #endif // IPARTICLEGROUP_H
