@@ -101,10 +101,10 @@ private:
 	iRangeMapping *mMapping;
 	iHistogramMaker *mHistogramMaker;
 
-	vtkPoints *mPoints;
-	vtkCellArray *mVerts;
-	vtkFloatArray *mNorms;
-	vtkFloatArray *mAtts;
+	vtkPoints *mSavedPoints;
+	vtkCellArray *mSavedVerts;
+	vtkFloatArray *mSavedNorms;
+	vtkFloatArray *mSavedAtts;
 
 	unsigned long mSortingMTime;
 };
