@@ -33,6 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibuffer.h"
 #include "ierror.h"
 #include "ifunctionmapping.h"
+#include "imath.h"
 #include "iparticleconnector.h"
 #include "iparticlegroup.h"
 #include "iparticlesplitter.h"
@@ -149,7 +150,7 @@ IVIEWSUBJECT_DEFINE_INHERITED_KEYS_REPLICATING(iParticlesViewSubject);
 
 iParticlesViewSubject::iParticlesViewSubject(iViewModule *vm, const iDataType &type, const iString &name, const iColor &color, bool shaded) : iViewSubject(vm,type,name,0U)
 {
-	mObjectType = _ObjectTypeParticles;
+	mSubjectId = ViewSubject::Id::Particles;
 
 	mGroups = new iParticleGroupFamily(this); IERROR_ASSERT(mGroups);
 	mSplitter = iParticleSplitter::New(this); IERROR_ASSERT(mSplitter);
@@ -379,7 +380,7 @@ void iParticlesViewSubject::PackGroupStateBody(iString &s, int first, int last)
 	for(i=first; i<=last; i++) iv[i] = mGroups->GetMember(i)->GetType();
 	this->PackValue(s,KeyType(),iv+first,n);
 
-	for(i=first; i<=last; i++) iv[i] = mGroups->GetMember(i)->GetPalette(0);
+	for(i=first; i<=last; i++) iv[i] = mGroups->GetMember(i)->GetPaletteId(0);
 	this->PackValue(s,KeyPalette(),iv+first,n);
 
 	for(i=first; i<=last; i++) cv[i] = mGroups->GetMember(i)->GetColor(0);
@@ -474,10 +475,10 @@ void iParticlesViewSubject::UnPackGroupStateBody(const iString &s, int first, in
 		this->ClearCache();
 	}
 
-	for(i=first; i<=last; i++) iv[i] = mGroups->GetMember(i)->GetPalette(0);
+	for(i=first; i<=last; i++) iv[i] = mGroups->GetMember(i)->GetPaletteId(0);
 	if(this->UnPackValue(s,KeyPalette(),iv+first,n))
 	{
-		for(i=first; i<=last; i++) mGroups->GetMember(i)->SetPalette(0,iv[i]);
+		for(i=first; i<=last; i++) mGroups->GetMember(i)->SetPaletteId(0,iv[i]);
 		this->ClearCache();
 	}
 
