@@ -41,8 +41,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iobjectfactory.h"
 #include "iprobefilter.h"
 #include "iviewmodule.h"
+#include "iviewsubject.h"
 #include "iviewsubjectobserver.h"
-#include "ivtk.h"
 
 #include <vtkCellArray.h>
 #include <vtkCellPicker.h>
@@ -231,10 +231,10 @@ iPicker* iPicker::New(iViewModule *vm)
 
 iPicker::iPicker(iViewModule *vm) : iExtendableObject("Picker"), mViewModule(vm), mDataFormatter(vm), mPos(vm)
 {
-	mObjName = "";
-	mObjType = _ObjectTypeUndefined;
+	mSubjectName = "";
+	mSubjectId = ViewSubject::Id::Undefined;
 	mDataTypePointer = 0;
-	mPickMethod = _PickMethodObject;
+	mPickMethod = PickMethod::Object;
 
 	//
 	//  Handler
@@ -294,7 +294,7 @@ void iPicker::Modified()
 
 void iPicker::UpdateReport()
 {
-	mObjName = "Unknown";
+	mSubjectName = "Unknown";
 	mPos = mHandler->GetPickPosition();
 
 	this->SetPointSize(mPointSize);
@@ -331,14 +331,10 @@ void iPicker::UpdateReportBody()
 	//
 	//  Get the object info
 	//
-#ifdef IVTK_44
-	vtkProp *obj = mHandler->GetProp();
-#else
 	vtkProp *obj = mHandler->GetViewProp();
-#endif
 	if(obj == 0) 
 	{
-		mObjName = "";
+		mSubjectName = "";
 		mPointActor->VisibilityOff(); 
 		return;
 	}
@@ -346,14 +342,14 @@ void iPicker::UpdateReportBody()
 
 	if(obs != 0)
 	{
-		mObjType = obs->GetObjectType();
-		mObjName = obs->GetObjectName();
+		mSubjectId = obs->GetSubjectId();
+		mSubjectName = obs->GetSubjectName();
 		mDataTypePointer = &obs->GetDataType();
 	}
 	else
 	{
-		mObjType = _ObjectTypeUndefined;
-		mObjName = "Unknown";
+		mSubjectId = ViewSubject::Id::Undefined;
+		mSubjectName = "Unknown";
 		mDataTypePointer = 0;
 	}
 
@@ -406,7 +402,7 @@ void iPicker::UpdateReportBody()
 		//
 		//  Make the correction for the surface
 		//
-		if(mObjType == _ObjectTypeSurface)
+		if(mSubjectId == ViewSubject::Id::Surface)
 		{
 			j = obs->GetIsoSurfaceData().Var;
 			if(j>=0 && j<nvar) v[j] = obs->GetIsoSurfaceData().Level;
@@ -458,7 +454,7 @@ void iPicker::SetPointSize(float s)
 
 void iPicker::ShowPickedPoint(bool s)
 {
-	if(!mObjName.IsEmpty() && s)
+	if(!mSubjectName.IsEmpty() && s)
 	{
 		mPointActor->VisibilityOn();
 	}
