@@ -30,7 +30,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ierror.h"
 #include "imath.h"
-#include "ivtk.h"
 
 #include <vtkPiecewiseFunction.h>
 
@@ -62,11 +61,7 @@ public:
 
 	void ParentChanged()
 	{
-#ifdef IVTK_44
-		this->Modified();
-#else
 		this->Update(); // Very inefficient, but needed to work around a VTK 5.0.0 bug
-#endif
 		mParent->Modified();
 	}
 
