@@ -30,7 +30,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
-#include "ivtk.h"
 
 #include <vtkArrowSource.h>
 #include <vtkCellData.h>
@@ -92,9 +91,9 @@ iPointGlyph::iPointGlyph(iViewSubject *vo) : iGenericSource<vtkPolyDataSource,vt
 {
 	int i;
 
-	mType = _PointTypePoint;
+	mType = PointGlyphType::Point;
 
-	for(i=0; i<__NumPointTypes; i++) 
+	for(i=0; i<PointGlyphType::SIZE; i++) 
 	{
 		if(type[i].Type != i) vtkErrorMacro("Incorrectly configured object.");
 		mData[i] = vtkPolyData::New(); IERROR_ASSERT(mData[i]);
@@ -108,7 +107,7 @@ iPointGlyph::~iPointGlyph()
 {
 	int i;
 
-	for(i=0; i<__NumPointTypes; i++) 
+	for(i=0; i<PointGlyphType::SIZE; i++) 
 	{
 		mData[i]->Delete();
 	}
@@ -123,9 +122,9 @@ void iPointGlyph::CreateData(int res)
 	vtkPoints *p, *op;
 	vtkFloatArray *fa;
 	vtkDataArray *da;
-	bool done[__NumPointTypes];
+	bool done[PointGlyphType::SIZE];
 
-	for(i=0; i<__NumPointTypes; i++) done[i] = false; // this is for internal checking
+	for(i=0; i<PointGlyphType::SIZE; i++) done[i] = false; // this is for internal checking
 
 	if(res < 1) res = 1;
 	if(res > 100) res = 100;
@@ -138,10 +137,10 @@ void iPointGlyph::CreateData(int res)
 	ss->SetPhiResolution(6*res);
 	ss->SetRadius(0.5);
 	ss->LatLongTessellationOn();
-	ss->SetOutput(mData[_PointTypeSphere]);
+	ss->SetOutput(mData[PointGlyphType::Sphere]);
 	ss->Update();
 	ss->Delete();
-	done[_PointTypeSphere] = true;
+	done[PointGlyphType::Sphere] = true;
 
 	//
 	//  Platonic solids
@@ -153,50 +152,50 @@ void iPointGlyph::CreateData(int res)
 	pn->ComputePointNormalsOff();
 	pn->SetInput(ps->GetOutput());
 
-	pn->SetOutput(mData[_PointTypeTetrahydron]);
+	pn->SetOutput(mData[PointGlyphType::Tetrahydron]);
 	pn->ComputeCellNormalsOn();
 	pn->FlipNormalsOn();
 	ps->SetSolidTypeToTetrahedron();
 	pn->Update();
-	mData[_PointTypeTetrahydron]->GetCellData()->Initialize(); // clears the cell colors that are set by vtkPlatonicSolidSource
-	this->ScaleData(mData[_PointTypeTetrahydron],0.5);
-	done[_PointTypeTetrahydron] = true;
+	mData[PointGlyphType::Tetrahydron]->GetCellData()->Initialize(); // clears the cell colors that are set by vtkPlatonicSolidSource
+	this->ScaleData(mData[PointGlyphType::Tetrahydron],0.5);
+	done[PointGlyphType::Tetrahydron] = true;
 
-	pn->SetOutput(mData[_PointTypeCube]);
+	pn->SetOutput(mData[PointGlyphType::Cube]);
 	pn->ComputeCellNormalsOff();
 	pn->FlipNormalsOff();
 	ps->SetSolidTypeToCube();
 	pn->Update();
-	mData[_PointTypeCube]->GetCellData()->Initialize(); // clears the cell colors that are set by vtkPlatonicSolidSource
-	this->ScaleData(mData[_PointTypeCube],0.5);
-	done[_PointTypeCube] = true;
+	mData[PointGlyphType::Cube]->GetCellData()->Initialize(); // clears the cell colors that are set by vtkPlatonicSolidSource
+	this->ScaleData(mData[PointGlyphType::Cube],0.5);
+	done[PointGlyphType::Cube] = true;
 
-	pn->SetOutput(mData[_PointTypeOctahedron]);
+	pn->SetOutput(mData[PointGlyphType::Octahedron]);
 	pn->ComputeCellNormalsOn();
 	pn->FlipNormalsOff();
 	ps->SetSolidTypeToOctahedron();
 	pn->Update();
-	mData[_PointTypeOctahedron]->GetCellData()->Initialize(); // clears the cell colors that are set by vtkPlatonicSolidSource
-	this->ScaleData(mData[_PointTypeOctahedron],0.5);
-	done[_PointTypeOctahedron] = true;
+	mData[PointGlyphType::Octahedron]->GetCellData()->Initialize(); // clears the cell colors that are set by vtkPlatonicSolidSource
+	this->ScaleData(mData[PointGlyphType::Octahedron],0.5);
+	done[PointGlyphType::Octahedron] = true;
 
-	pn->SetOutput(mData[_PointTypeIcosahedron]);
+	pn->SetOutput(mData[PointGlyphType::Icosahedron]);
 	pn->ComputeCellNormalsOn();
 	pn->FlipNormalsOff();
 	ps->SetSolidTypeToIcosahedron();
 	pn->Update();
-	mData[_PointTypeIcosahedron]->GetCellData()->Initialize(); // clears the cell colors that are set by vtkPlatonicSolidSource
-	this->ScaleData(mData[_PointTypeIcosahedron],0.5);
-	done[_PointTypeIcosahedron] = true;
+	mData[PointGlyphType::Icosahedron]->GetCellData()->Initialize(); // clears the cell colors that are set by vtkPlatonicSolidSource
+	this->ScaleData(mData[PointGlyphType::Icosahedron],0.5);
+	done[PointGlyphType::Icosahedron] = true;
 
-	pn->SetOutput(mData[_PointTypeDodecahedron]);
+	pn->SetOutput(mData[PointGlyphType::Dodecahedron]);
 	pn->ComputeCellNormalsOn();
 	pn->FlipNormalsOff();
 	ps->SetSolidTypeToDodecahedron();
 	pn->Update();
-	mData[_PointTypeDodecahedron]->GetCellData()->Initialize(); // clears the cell colors that are set by vtkPlatonicSolidSource
-	this->ScaleData(mData[_PointTypeDodecahedron],0.5);
-	done[_PointTypeDodecahedron] = true;
+	mData[PointGlyphType::Dodecahedron]->GetCellData()->Initialize(); // clears the cell colors that are set by vtkPlatonicSolidSource
+	this->ScaleData(mData[PointGlyphType::Dodecahedron],0.5);
+	done[PointGlyphType::Dodecahedron] = true;
 
 	pn->Delete();
 	ps->Delete();
@@ -206,25 +205,25 @@ void iPointGlyph::CreateData(int res)
 	//
 	vtkConeSource *cs = vtkConeSource::New(); IERROR_ASSERT(cs);
 	cs->SetResolution(6*res);
-	cs->SetOutput(mData[_PointTypeCone]);
+	cs->SetOutput(mData[PointGlyphType::Cone]);
 	cs->Update();
 	cs->Delete();
-	this->ScaleData(mData[_PointTypeCone],0.8);
-	this->SwapAxes(mData[_PointTypeCone],0,2);
-	this->ShiftData(mData[_PointTypeCone],2,0.1);
-	done[_PointTypeCone] = true;
+	this->ScaleData(mData[PointGlyphType::Cone],0.8);
+	this->SwapAxes(mData[PointGlyphType::Cone],0,2);
+	this->ShiftData(mData[PointGlyphType::Cone],2,0.1);
+	done[PointGlyphType::Cone] = true;
 
 	//
 	//  Cylinder
 	//
 	vtkCylinderSource *ts = vtkCylinderSource::New(); IERROR_ASSERT(ts);
 	ts->SetResolution(6*res);
-	ts->SetOutput(mData[_PointTypeCylinder]);
+	ts->SetOutput(mData[PointGlyphType::Cylinder]);
 	ts->Update();
 	ts->Delete();
-	this->ScaleData(mData[_PointTypeCylinder],0.7);
-	this->SwapAxes(mData[_PointTypeCylinder],1,2);
-	done[_PointTypeCylinder] = true;
+	this->ScaleData(mData[PointGlyphType::Cylinder],0.7);
+	this->SwapAxes(mData[PointGlyphType::Cylinder],1,2);
+	done[PointGlyphType::Cylinder] = true;
 	
 	//
 	//  Arrow
@@ -234,13 +233,13 @@ void iPointGlyph::CreateData(int res)
 	as->SetShaftResolution(6*res);
 	as->SetTipRadius(0.5);
 	as->SetShaftRadius(0.2);
-	as->SetOutput(mData[_PointTypeArrow]);
+	as->SetOutput(mData[PointGlyphType::Arrow]);
 	as->Update();
 	as->Delete();
-	this->ScaleData(mData[_PointTypeArrow],0.93);
-	this->SwapAxes(mData[_PointTypeArrow],0,2);
-	this->ShiftData(mData[_PointTypeArrow],2,-0.45);
-	done[_PointTypeArrow] = true;
+	this->ScaleData(mData[PointGlyphType::Arrow],0.93);
+	this->SwapAxes(mData[PointGlyphType::Arrow],0,2);
+	this->ShiftData(mData[PointGlyphType::Arrow],2,-0.45);
+	done[PointGlyphType::Arrow] = true;
 	
 	//
 	//  Point
@@ -250,12 +249,12 @@ void iPointGlyph::CreateData(int res)
 	cc->SetNumberOfPoints(1);
 	cc->SetCenter(0.0,0.0,0.0);
 	cc->SetRadius(1.0);
-	cc->SetOutput(mData[_PointTypePoint]);
+	cc->SetOutput(mData[PointGlyphType::Point]);
 	cc->Update();
 	cc->Delete();
-	p = mData[_PointTypePoint]->GetPoints();
+	p = mData[PointGlyphType::Point]->GetPoints();
 	p->SetPoint(0,0.0,0.0,0.0);
-	done[_PointTypePoint] = true;
+	done[PointGlyphType::Point] = true;
 	
 	//
 	//  Cluster
@@ -264,13 +263,13 @@ void iPointGlyph::CreateData(int res)
 	cc->SetNumberOfPoints(30*res);
 	cc->SetCenter(0.0,0.0,0.0);
 	cc->SetRadius(1.0);
-	cc->SetOutput(mData[_PointTypeCluster]);
+	cc->SetOutput(mData[PointGlyphType::Cluster]);
 	cc->Update();
 	cc->Delete();
 	//
 	//  Rearrange points radially to have a centrally concentrated cluster
 	//
-	p = mData[_PointTypeCluster]->GetPoints();
+	p = mData[PointGlyphType::Cluster]->GetPoints();
 	n = p->GetNumberOfPoints();
 	for(l=0; l<n; l++)
 	{
@@ -282,7 +281,7 @@ void iPointGlyph::CreateData(int res)
 		x[2] *= r;
 		p->SetPoint(l,x);
 	}
-	done[_PointTypeCluster] = true;
+	done[PointGlyphType::Cluster] = true;
 	
 	//
 	//  Galaxy
@@ -291,14 +290,14 @@ void iPointGlyph::CreateData(int res)
 	cc->SetNumberOfPoints(30*res);
 	cc->SetCenter(0.0,0.0,0.0);
 	cc->SetRadius(1.0);
-	cc->SetOutput(mData[_PointTypeGalaxy]);
+	cc->SetOutput(mData[PointGlyphType::Galaxy]);
 	cc->Update();
 	cc->Delete();
 	//
 	//  Rearrange points to have a spiral galaxy in z=0 plane.
 	//
 	double r1, phi;
-	p = mData[_PointTypeGalaxy]->GetPoints();
+	p = mData[PointGlyphType::Galaxy]->GetPoints();
 	n = p->GetNumberOfPoints();
 	for(l=0; l<n; l++)
 	{
@@ -320,12 +319,12 @@ void iPointGlyph::CreateData(int res)
 		}
 		p->SetPoint(l,x);
 	}
-	done[_PointTypeGalaxy] = true;
+	done[PointGlyphType::Galaxy] = true;
 	
 	//
 	//  Test that all are done
 	//
-	for(i=0; i<__NumPointTypes; i++)
+	for(i=0; i<PointGlyphType::SIZE; i++)
 	{
 		if(!done[i]) vtkErrorMacro("Some of types are left undone.");
 	}
@@ -333,7 +332,7 @@ void iPointGlyph::CreateData(int res)
 	//
 	//  Make all points float
 	//
-	for(i=0; i<__NumPointTypes; i++)
+	for(i=0; i<PointGlyphType::SIZE; i++)
 	{
 		op = mData[i]->GetPoints();
 		if(op->GetDataType() != VTK_FLOAT)
@@ -354,7 +353,7 @@ void iPointGlyph::CreateData(int res)
 	//
 	//  Make all normals float
 	//
-	for(i=0; i<__NumPointTypes; i++)
+	for(i=0; i<PointGlyphType::SIZE; i++)
 	{
 		da = mData[i]->GetPointData()->GetNormals();
 		if(da!=0 && da->GetDataType()!=VTK_FLOAT)
@@ -483,7 +482,7 @@ const char* iPointGlyph::GetName() const
 
 bool iPointGlyph::GetOriented(int t)
 {
-	if(t>=0 && t<__NumPointTypes)
+	if(t>=0 && t<PointGlyphType::SIZE)
 	{
 		return type[t].IsOriented;
 	}
@@ -493,7 +492,7 @@ bool iPointGlyph::GetOriented(int t)
 
 const char* iPointGlyph::GetName(int t)
 {
-	if(t>=0 && t<__NumPointTypes)
+	if(t>=0 && t<PointGlyphType::SIZE)
 	{
 		return type[t].Name;
 	}
@@ -503,7 +502,7 @@ const char* iPointGlyph::GetName(int t)
 
 void iPointGlyph::SetType(int t)
 {
-	if(t>=0 && t<__NumPointTypes)
+	if(t>=0 && t<PointGlyphType::SIZE)
 	{
 		mType = t;
 		this->Modified();
