@@ -63,12 +63,8 @@ void iProbeFilter::ProduceOutput()
 	}
 	else
 	{
-#ifdef IVTK_44
-		this->vtkProbeFilter::ExecuteData(output);
-#else
 		output->ShallowCopy(input); // Probe does not copy normals...
 		this->vtkProbeFilter::Probe(vtkDataSet::SafeDownCast(input),vtkDataSet::SafeDownCast(source),output);
-#endif
 	}
 }
 
