@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iReducePolyDataFilter : public iGenericPolyDataToPolyDataFilter<vtkDecimatePro>
 {
 	
-	IGENERICFILTER_DECLARE(iReducePolyDataFilter);
+	IGENERICFILTER_DECLARE(iReducePolyDataFilter,vtkDecimatePro);
 
 protected:
 	
