@@ -29,7 +29,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "irendertool.h"
 
 
-#include "ivtk.h"
 #include "iactor.h"
 #include "icamera.h"
 #include "icontrolmodule.h"
@@ -68,6 +67,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 //
 //  Helper classes
 //
@@ -94,18 +96,6 @@ protected:
 	{
 		switch(event)
 		{
-		case StartEvent:
-			{
-				if(mRenderTool->mMainWin->GetStereoRender() == 0)
-				{
-					if(mRenderTool->mDualWin != 0) mRenderTool->ShowDualWindow(false); 
-				}
-				else
-				{
-					if(mRenderTool->mDualWin == 0) mRenderTool->ShowDualWindow(true); 
-				}
-				break;
-			}
 		case EndEvent:
 			{
 				if(mRenderTool->mDualWin != 0) mRenderTool->mDualWin->Render();
@@ -177,6 +167,47 @@ private:
 };
 
 
+class iStereoRenderObserver : public iEventObserver
+{
+
+public:
+
+	vtkTypeMacro(iStereoRenderObserver,iEventObserver);
+	static iStereoRenderObserver* New(iRenderTool *rt = 0)
+	{
+		IERROR_ASSERT(rt);
+		return new iStereoRenderObserver(rt);
+	}
+
+protected:
+
+	iStereoRenderObserver(iRenderTool *rt) : iEventObserver(rt->GetViewModule()->GetControlModule()->GetShell())
+	{
+		mRenderTool = rt;
+	}
+
+	virtual void ExecuteBody(vtkObject *, unsigned long event, void *)
+	{
+		switch(event)
+		{
+		case ModifiedEvent:
+			{
+				if(mRenderTool->mMainWinStereoRender != (mRenderTool->mMainWin->GetStereoRender()!=0))
+				{
+					mRenderTool->mMainWin->SetStereoRender(mRenderTool->mMainWinStereoRender?1:0);
+					iConsole::Display(iConsole::_Notification,"Pressing 3 to toggle the stereo mode is no longer supported.\nPlease use GUI/command-line controls to toggle the stereo mode.");
+				}
+				break;
+			}
+		}
+	}
+
+private:
+
+	iRenderTool *mRenderTool;
+};
+
+
 //
 //  Main class
 //
@@ -189,7 +220,7 @@ iRenderTool* iRenderTool::New(iViewModule *vm)
 }
 
 
-iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : mViewModule(vm)
+iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : mViewModule(vm), mStereoModeOffset(2-VTK_STEREO_CRYSTAL_EYES)
 {
 	//
 	//  Keeping the rendering order (a workaround for a VTK bug)
@@ -202,6 +233,11 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	//
 	mDualWin = 0;
 	mMainWin = iShellFactory::CreateRenderWindow(this); IERROR_ASSERT(mMainWin);
+#ifdef I_NO_STEREO
+	mMainWin->SetStereoCapableWindow(0);
+#else
+	mMainWin->SetStereoCapableWindow(1);
+#endif
 	if(ren == 0)
 	{
 		mMainRen = vtkRenderer::New(); IERROR_ASSERT(mMainRen);
@@ -252,7 +288,6 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	//  Configure Window
 	//
 	mMainWin->SetSize(640,480);
-	mMainWin->StereoCapableWindowOn();
 	mMainWin->SetNumberOfLayers(2);
 	mMainWin->AddRenderer(mMainBkg->GetRenderer());
 	mMainWin->AddRenderer(mMainRen);
@@ -336,6 +371,12 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	mMainRen->AddObserver(vtkCommand::ResetCameraClippingRangeEvent,mRendererObserver);
 	mMainRen->AddObserver(vtkCommand::ModifiedEvent,mRendererObserver);
 
+	//
+	//  Disable pressing 3 in the render window
+	//
+	mStereoRenderObserver = iStereoRenderObserver::New(this); IERROR_ASSERT(mStereoRenderObserver);
+	mMainWin->AddObserver(vtkCommand::ModifiedEvent,mStereoRenderObserver);
+
 	//
 	//  RenderWindow collection
 	//
@@ -345,7 +386,9 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	//
 	//  Properties
 	//
-	mStereoType = -1;
+	mStereoMode = 0;
+	this->SetMainWinStereoRender(false);
+	mMainWin->SetStereoType(0);  // for pressing 3 in the render window
 	mAntialiasing = mBackgroundImageFixedAspect = false;
 	mStereoAlignmentMarksOn = true;
 
@@ -353,8 +396,7 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : m
 	//  Set the properties
 	//
 	mFontScale = 0;
-	mFontType = iParameter::_TextTypeBitmapArial;
-	this->SetStereoType(VTK_STEREO_RED_BLUE);
+	mFontType = TextType::Arial;
 	//this->SetAntialiasing(true);
 }
 
@@ -372,6 +414,9 @@ iRenderTool::~iRenderTool()
 
 	mMagnifier->Delete();
 
+	mMainRen->RemoveObserver(mStereoRenderObserver);
+	mStereoRenderObserver->Delete();
+
 	mMainRen->RemoveObserver(mRendererObserver);
 	mRendererObserver->Delete();
 
@@ -384,6 +429,8 @@ iRenderTool::~iRenderTool()
 
 	mDualRen->Delete();
 
+	mMainWin->RemoveAllObservers();   
+
 	mMainRen->Delete();
 	mMainWin->Delete();
 }
@@ -524,13 +571,8 @@ void iRenderTool::AddObject(vtkProp* p)
 	if(p->IsA("vtkVolume") != 0)
 	{
 		mVolumeObjects->AddItem(p);
-#ifdef IVTK_44
-		mMainRen->AddProp(p);
-		mDualRen->AddProp(p);
-#else
 		mMainRen->AddViewProp(p);
 		mDualRen->AddViewProp(p);
-#endif
 	}
 	else
 	{
@@ -539,36 +581,21 @@ void iRenderTool::AddObject(vtkProp* p)
 		//
 		mActorObjects->AddItem(p);
 
-#ifdef IVTK_44
-		mMainRen->RemoveAllProps();
-		mDualRen->RemoveAllProps();
-#else
 		mMainRen->RemoveAllViewProps();
 		mDualRen->RemoveAllViewProps();
-#endif
 
 		vtkProp *p;
 		mActorObjects->InitTraversal();
 		while((p = mActorObjects->GetNextProp()) != 0)
 		{
-#ifdef IVTK_44
-			mMainRen->AddProp(p);
-			mDualRen->AddProp(p);
-#else
 			mMainRen->AddViewProp(p);
 			mDualRen->AddViewProp(p);
-#endif
 		}
 		mVolumeObjects->InitTraversal();
 		while((p = mVolumeObjects->GetNextProp()) != 0)
 		{
-#ifdef IVTK_44
-			mMainRen->AddProp(p);
-			mDualRen->AddProp(p);
-#else
 			mMainRen->AddViewProp(p);
 			mDualRen->AddViewProp(p);
-#endif
 		}
 	}
 }
@@ -587,13 +614,8 @@ void iRenderTool::RemoveObject(vtkProp* p)
 		mActorObjects->RemoveItem(p);
 	}
 
-#ifdef IVTK_44
-	mMainRen->RemoveProp(p);
-	mDualRen->RemoveProp(p);
-#else
 	mMainRen->RemoveViewProp(p);
 	mDualRen->RemoveViewProp(p);
-#endif
 }
 
 
@@ -797,59 +819,76 @@ void iRenderTool::ShowStereoAlignmentMarks(bool s)
 }
 
 
-bool iRenderTool::GetStereo() const
+void iRenderTool::SetStereoMode(int m)
 {
-	return mMainWin->GetStereoRender() != 0;
-}
+	if(m==mStereoMode || m<0) return;
 
-
-void iRenderTool::SetStereo(bool s)
-{
-	if(s) mMainWin->StereoRenderOn(); else mMainWin->StereoRenderOff();
-}
-
-
-void iRenderTool::SetStereoType(int n)
-{
-	if(n<0 || mMainWin->GetStereoCapableWindow()==0 || n==mStereoType) return;
-
-	if(n > 0)
+	if(mStereoMode == 1) this->ShowDualWindow(false);
+	if(mStereoMode == 2)
 	{
-		mMainWin->SetStereoType(n);
-		mStereoType = mMainWin->GetStereoType();
-		if(mDualWin != 0)
+		//
+		//  This seems extraneous, but that trick was needed to avoid flicker
+		//  that Doug was complaining about. It was debugged on Robert's laptop.
+		//
+		this->SetMainWinStereoRender(false);
+		mMainWin->Render();
+	}
+	mStereoMode = m;
+
+	//
+	//  Don't get stuck in a right-eye-only mode, it is not renderable in the non-stereo mode
+	//
+	mMainWin->SetStereoType(0);
+
+	switch(mStereoMode)
+	{
+	case 0:
 		{
-			this->ShowDualWindow(false);
+			this->SetMainWinStereoRender(false);
+			break;
+		}
+	case 1:
+		{
+			this->ShowDualWindow(true);
+			break;
+		}
+	case 2:
+		{
+			if(mMainWin->GetStereoCapableWindow() == 0)
+			{
+				this->SetStereoMode(0);
+				iConsole::Display(iConsole::_Notification,"Crustal Eyes mode is not supported on this machine.");
+			}
+			else
+			{
+				mMainWin->SetStereoType(VTK_STEREO_CRYSTAL_EYES);
+				this->SetMainWinStereoRender(true);
+			}
+			break;
+		}
+	default:
+		{
+			mMainWin->SetStereoType(mStereoMode-mStereoModeOffset);
+			mStereoMode = mMainWin->GetStereoType() + mStereoModeOffset;
+			this->SetMainWinStereoRender(true);
+			break;
 		}
-		mMainWin->RemoveObserver(mDualWindowObserver);
-	}
-	else
-	{
-		mStereoType = 0;
-		mMainWin->SetStereoTypeToLeft();
-		mMainWin->AddObserver(vtkCommand::StartEvent,mDualWindowObserver);
-		mMainWin->AddObserver(vtkCommand::EndEvent,mDualWindowObserver);
-		mMainWin->AddObserver(vtkCommand::ModifiedEvent,mDualWindowObserver);
 	}
 }
 
-	
+
 void iRenderTool::ShowDualWindow(bool s)
 {
 	if(s)
 	{
 		if(mDualWin == 0) // DualWindow is not shown yet
 		{
-			if(mMainWin->GetStereoRender() == 0)
-			{
-				IERROR_LOW("Creating DualWindow in the non-stereo mode.");
-			}
 			mDualWin = iShellFactory::CreateRenderWindow(this); IERROR_ASSERT(mDualWin);
-			int *s = mMainWin->GetSize();
-			mDualWin->SetSize(s[0],s[1]);
-			mDualWin->StereoCapableWindowOn();
+			mDualWin->SetStereoCapableWindow(0);
 			mDualWin->SetStereoTypeToRight();
 			mDualWin->StereoRenderOn();
+			int *s = mMainWin->GetSize();
+			mDualWin->SetSize(s[0],s[1]);
 			this->WindowsModified();
 
 			int i;
@@ -866,7 +905,13 @@ void iRenderTool::ShowDualWindow(bool s)
 			mDualWin->SetNumberOfLayers(2);
 			mDualWin->AddRenderer(mDualBkg->GetRenderer());
 			mDualWin->AddRenderer(mDualRen);
-	
+
+			mMainWin->SetStereoTypeToLeft();
+			this->SetMainWinStereoRender(true);
+			mMainWin->AddObserver(vtkCommand::StartEvent,mDualWindowObserver);
+			mMainWin->AddObserver(vtkCommand::EndEvent,mDualWindowObserver);
+			mMainWin->AddObserver(vtkCommand::ModifiedEvent,mDualWindowObserver);
+
 			if(mStereoAlignmentMarksActor!=0 && mStereoAlignmentMarksOn) mStereoAlignmentMarksActor->VisibilityOn();
 			this->GetViewModule()->UpdateWindowNumber();
 		}
@@ -883,6 +928,9 @@ void iRenderTool::ShowDualWindow(bool s)
 			mDualWin->Delete();
 			mDualWin = 0;
 
+			this->SetMainWinStereoRender(false);
+			mMainWin->RemoveObserver(mDualWindowObserver);
+
 			if(mStereoAlignmentMarksActor != 0) mStereoAlignmentMarksActor->VisibilityOff();
 			this->GetViewModule()->UpdateWindowNumber();
 		}
@@ -916,20 +964,12 @@ vtkRenderer* iRenderTool::CreateRenderer() const
 	//  so that iActors can create special mappers for this renderer. Otherwise, vtkPolyDataMappers 
 	//  remember the last window they rendered into, and will reset at switching to a different window.
 	//
-#ifdef IVTK_44
-	vtkPropCollection *pc = mMainRen->GetProps();
-#else
 	vtkPropCollection *pc = mMainRen->GetViewProps();
-#endif
 	vtkProp *p;
 	pc->InitTraversal();
 	while((p = pc->GetNextProp()) != 0)
 	{
-#ifdef IVTK_44
-		ren->AddProp(p);
-#else
 		ren->AddViewProp(p);
-#endif
 	}
 
 	//
@@ -980,11 +1020,16 @@ void iRenderTool::SetFontScale(int s)
 
 void iRenderTool::SetFontType(int s)
 {
-	if(s>=0 && s<iParameter::__NumTextTypes)
+	if(TextType::IsValid(s))
 	{
 		mFontType = s; 
 	}
 }
 
 
+void iRenderTool::SetMainWinStereoRender(bool s)
+{
+	mMainWinStereoRender = s;
+	mMainWin->SetStereoRender(s?1:0);
+}
 
