@@ -46,12 +46,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iActor;
 class iCamera;
 class iColor;
-class iDualWindowObserver;
 class iEventObserver;
 class iImage;
 class iLightKit;
 class iMagnifier;
-class iRendererObserver;
 class iRenderToolBackground;
 class iString;
 class iStereoImage;
@@ -67,6 +65,19 @@ class vtkRenderWindowCollection;
 class vtkRenderWindowInteractor;
 
 
+namespace iParameter
+{
+	namespace TextType
+	{
+		const int Arial = 0;
+		const int Courier = 1;
+		const int Times = 2;
+
+		inline bool IsValid(int m){ return m>=0 && m<=2; }
+	};
+};
+
+
 class iRenderTool : public vtkObjectBase
 {
 	
@@ -74,6 +85,7 @@ class iRenderTool : public vtkObjectBase
 	friend class iDualWindowObserver;
 	friend class iExtensionFactory;
 	friend class iRendererObserver;
+	friend class iStereoRenderObserver;
 
 	IPOINTER_AS_PART(ViewModule);
 
@@ -116,11 +128,8 @@ public:
 	virtual void SetAntialiasing(bool s);
 	inline bool GetAntialiasing() const { return mAntialiasing; }
 
-	virtual void SetStereoType(int s);
-	inline int GetStereoType() const { return mStereoType; }
-
-	virtual void SetStereo(bool s);
-	bool GetStereo() const;
+	virtual void SetStereoMode(int m);
+	inline int GetStereoMode() const { return mStereoMode; }
 
 	void SetBackgroundImageTile(float tx, float ty, float tw, float th);
 	void SetBackgroundImageTile(const float tile[4]);
@@ -171,12 +180,12 @@ protected:
 	vtkRenderer *mMainRen, *mDualRen;
 	iRenderToolBackground *mMainBkg, *mDualBkg;
 	vtkRenderWindowInteractor *mMainInt;
-	iDualWindowObserver *mDualWindowObserver;
-	iRendererObserver *mRendererObserver;
 	vtkRenderWindowCollection *mWindowCollection;
 	iCamera *mMainCam;
 	vtkPropAssembly *mStereoAlignmentMarksActor;
 
+	iEventObserver *mDualWindowObserver, *mRendererObserver, *mStereoRenderObserver;
+
 	//
 	//  Observers registry
 	//
@@ -195,9 +204,13 @@ private:
 	//
 	iLightKit *mLights;
 	iMagnifier *mMagnifier;
-	int mStereoType, mFontScale, mFontType;
+	int mStereoMode, mFontScale, mFontType;
 	double mClippingRange[2];
 	bool mAntialiasing, mStereoAlignmentMarksOn, mAutoClippingRange, mWindowCollectionUpToDate, mBackgroundImageFixedAspect;
+	const int mStereoModeOffset;
+
+	bool mMainWinStereoRender;
+	void SetMainWinStereoRender(bool s);
 
 	//
 	//  For ordered rendering
