@@ -38,7 +38,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "icolor.h"
 #include "iimage.h"
-#include "ivtk.h"
 
 #include <vtkSetGet.h>
 
@@ -48,13 +47,8 @@ class iRenderToolBackgroundImageMapper;
 class vtkActor2D;
 class vtkRenderer;
 
-#ifdef IVTK_44
-#define IRENDERTOOLBACKGROUND_BACK_LAYER		1
-#define IRENDERTOOLBACKGROUND_FRONT_LAYER		0
-#else
 #define IRENDERTOOLBACKGROUND_BACK_LAYER		0
 #define IRENDERTOOLBACKGROUND_FRONT_LAYER		1
-#endif
 
 
 class iRenderToolBackground : public vtkObjectBase
