@@ -169,8 +169,9 @@ void Sort(vtkIdType n, vtkIdType *lptr1, vtkIdType *lptr2)
 using namespace iReplicatedPolyData_Private;
 
 
-iReplicatedPolyData::iReplicatedPolyData(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>(vo,1,true,true), iReplicated(vo->GetReplicator(),true)
+iReplicatedPolyData::iReplicatedPolyData(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>(vo,1,true,true), iReplicatedElement(true)
 {
+	this->ReplicateAs(vo);
 }
 
 
