@@ -36,12 +36,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewmodule.h"
 
 #include <vtkCamera.h>
-#include <vtkMath.h>
-#include <vtkProperty2D.h>
 #include <vtkRenderer.h>
-#include <vtkTextMapper.h>
 #include <vtkTextProperty.h>
 
+//
+//  Templates
+//
+#include "iarraytemplate.h"
+#include "igenericproptemplate.h"
+
 
 iRuler* iRuler::New(iViewModule *vm)
 {
@@ -50,16 +53,11 @@ iRuler* iRuler::New(iViewModule *vm)
 }
 
 
-iRuler::iRuler(iViewModule *vm) : mOverlayHelper(vm->GetRenderTool()), mViewModule(vm)
+iRuler::iRuler(iViewModule *vm) : iAxis(vm->GetRenderTool()), mViewModule(vm)
 {
 	mStarted = false;
 	mScale = mBaseScale = 1.0;
-	mLineWidth = this->AxisActor->GetProperty()->GetLineWidth();
-	mTickLength = TickLength;
 
-	this->LabelMappers[0]->SetTextProperty(this->LabelTextProperty);
-	this->LabelMappers[1]->SetTextProperty(this->LabelTextProperty);
-	//this->LabelTextProperty->SetJustificationToCentered();
 	this->LabelTextProperty->SetVerticalJustificationToTop();
 	this->TitleTextProperty->SetJustificationToCentered();
 	this->TitleTextProperty->SetVerticalJustificationToBottom();
@@ -68,9 +66,7 @@ iRuler::iRuler(iViewModule *vm) : mOverlayHelper(vm->GetRenderTool()), mViewModu
 	this->SetPoint2(0.75,0.9);
 	this->SetRange(0.0,1.0);
 	this->AdjustLabelsOff();
-	this->SetNumberOfLabels(2);
-
-	this->PickableOff();
+	this->SetNumberOfLabels(3);
 }
 
 
@@ -79,27 +75,16 @@ iRuler::~iRuler()
 }
 
 
-void iRuler::ReleaseGraphicsResources(vtkWindow *win)
+void iRuler::UpdateGeometry(vtkViewport *vp)
 {
-	this->vtkAxisActor2D::ReleaseGraphicsResources(win);
-}
-
-
-int iRuler::RenderOverlay(vtkViewport* viewport)
-{
-	vtkCamera *cam = mOverlayHelper->GetCamera(viewport);
-	if(cam==0 || cam->GetParallelProjection()==0) return 0;
-
-	return this->vtkAxisActor2D::RenderOverlay(viewport);
-}
-
-
-int iRuler::RenderOpaqueGeometry(vtkViewport* viewport)
-{
-	vtkCamera *cam = mOverlayHelper->GetCamera(viewport);
-	if(cam==0 || cam->GetParallelProjection()==0) return 0;
+	vtkCamera *cam = this->GetOverlayHelper()->GetCamera(vp);
+	if(cam==0 || cam->GetParallelProjection()==0)
+	{
+		this->Disable();
+		return;
+	}
 	
-	int mag = mOverlayHelper->GetRenderingMagnification();
+	int mag = this->GetOverlayHelper()->GetRenderingMagnification();
 
 	if(mag == 1)
 	{
@@ -120,59 +105,32 @@ int iRuler::RenderOpaqueGeometry(vtkViewport* viewport)
 		}
 		
 		double as[2];
-		viewport->GetAspect(as);
-		mDx = 0.5/mBaseScale*as[1]/as[0];
+		vp->GetAspect(as);
+		float dx = 0.5/mBaseScale*as[1]/as[0];
 
 		if(!this->GetViewModule()->GetOpenGLCoordinates()) s *= this->GetViewModule()->GetBoxSize();
 		this->SetRange(0.0,s);
 		mScale = s;
 		
-		this->SetPoint1(0.5-mDx,0.9);
-		this->SetPoint2(0.5+mDx,0.9);
-
-		this->AxisActor->GetProperty()->SetLineWidth(mLineWidth);
-		this->SetTickLength(mTickLength);
+		this->SetPoint1(0.5-dx,0.9);
+		this->SetPoint2(0.5+dx,0.9);
 	}
-	else
-	{
-		int winij[2];
-		mOverlayHelper->ComputePositionShiftsUnderMagnification(winij);
-		
-		this->SetPoint1(mag*(0.5-mDx)-winij[0],mag*0.9-winij[1]);
-		this->SetPoint2(mag*(0.5+mDx)-winij[0],mag*0.9-winij[1]);
-		
-		this->AxisActor->GetProperty()->SetLineWidth(mLineWidth*mag);
-		this->SetTickLength(mag*mTickLength);
-	}
-	
-	this->GetProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
-	this->LabelTextProperty->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
-	this->TitleTextProperty->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
 
-	this->GetOverlayHelper()->UpdateTextProperty(this->LabelTextProperty);
-	this->GetOverlayHelper()->UpdateTextProperty(this->TitleTextProperty);
+	this->iAxis::UpdateGeometry(vp);
+}
 
-	this->vtkAxisActor2D::RenderOpaqueGeometry(viewport);
 
-	//
-	//  This must be after RenderOpaqueGeometry
-	//
-	this->LabelTextProperty->SetFontSize(mOverlayHelper->GetFontSize(viewport,mag));
-	this->TitleTextProperty->SetFontSize(mOverlayHelper->GetFontSize(viewport,mag*1.2));
-	this->TitleMapper->GetTextProperty()->ShallowCopy(this->TitleTextProperty);
-	int *s = viewport->GetSize();
+void iRuler::UpdateOverlay(vtkViewport *vp)
+{
+	int mag = this->GetOverlayHelper()->GetRenderingMagnification();
+
 	if(mag == 1)
 	{
-		this->TitleActor->SetPosition(0.5*s[0],0.91*s[1]);
-	}
-	else
-	{
-		int winij[2];
-		mOverlayHelper->ComputePositionShiftsUnderMagnification(winij);
-		this->TitleActor->SetPosition(s[0]*(mag*0.5-winij[0]),s[1]*(mag*0.91-winij[1]));
+		int *sz = vp->GetSize();
+		this->TitleActor->SetPosition(0.5*sz[0],0.91*sz[1]);
 	}
 
-	return 1;
+	this->iAxis::UpdateOverlay(vp);
 }
 
 
@@ -182,6 +140,7 @@ void iRuler::SetBaseScale(float s)
 	{
 		mStarted = true;
 		mBaseScale = s;
+		this->Modified();
 	}
 }
 
@@ -191,13 +150,14 @@ void iRuler::SetScale(float s)
 	if(!mStarted)
 	{
 		mStarted = true;
-		mBaseScale = this->GetViewModule()->GetRenderer()->GetActiveCamera()->GetParallelScale();
+		mBaseScale = this->GetOverlayHelper()->GetRenderTool()->GetCamera()->GetDevice()->GetParallelScale();
 	}
 
 	if(s > 0.0)
 	{
 		if(!this->GetViewModule()->GetOpenGLCoordinates()) s /= this->GetViewModule()->GetBoxSize();
-		mOverlayHelper->GetRenderTool()->GetCamera()->GetDevice()->SetParallelScale(s*mBaseScale);
+		this->GetOverlayHelper()->GetRenderTool()->GetCamera()->GetDevice()->SetParallelScale(s*mBaseScale);
+		this->Modified();
 	}
 }
 
@@ -207,5 +167,6 @@ void iRuler::SetTitle(const iString &title)
 	mTitle = title;
 	this->vtkAxisActor2D::SetTitle(title.ToCharPointer());
 	if(mTitle.IsEmpty()) this->TitleVisibilityOff(); else this->TitleVisibilityOn();
+	this->Modified();
 }
 
