@@ -40,8 +40,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ioutputchannel.h"
 #include "iparallelmanager.h"
 #include "ishellfactory.h"
+#include "iversion.h"
 #include "iviewmodule.h"
-#include "ivtk.h"
 
 #include <vtkRenderWindow.h>
 #include <vtkTimerLog.h>
@@ -142,9 +142,9 @@ iShell::iShell(const iString &type, int, char **) : mType(type)
 	this->AddCommandLineOption("help",false,"show this help");
 	this->AddCommandLineOption("-help",false,"show this help");
 	this->AddCommandLineOption("i",true,"load the state from a file with name <arg>");
+	this->AddCommandLineOption("b",true,"execute a control script from a file <arg> in the screenless mode");
 	this->AddCommandLineOption("np",true,"set the number of processors to use to <arg>");
 	this->AddCommandLineOption("test",false,"test performance and exit (must be the first and only option)");
-	this->AddCommandLineOption("b",true,"execute a control script from a file <arg> in the screenless mode");
 
 	//
 	//  Set environment variables
@@ -280,7 +280,7 @@ iShell* iShell::New(const iString &t, int argc, char **argv)
 	//
 	// Make sure Image factory is up to date
 	//
-	iImageFactory::FindIcon("genie1.png");
+	iImageFactory::FindIcon("ok.png");
 	//
 	//  Parse command line options
 	//
@@ -304,13 +304,13 @@ iShell* iShell::New(const iString &t, int argc, char **argv)
 	//
 	tmp->mCurInitStep = 1;
 	tmp->mControlModule = iControlModule::New(tmp); IERROR_ASSERT(tmp->mControlModule);
-	if(tmp->mNumProcs >= 0) tmp->mControlModule->GetParallelManager()->ResetMaxNumberOfProcessors(tmp->mNumProcs);
+	if(tmp->mNumProcs >= 0) tmp->mControlModule->GetParallelManager()->SetNumberOfProcessors(tmp->mNumProcs);
 	//
 	//  Set the state file name
 	//
 	if(tmp->mStateFileName.IsEmpty())
 	{
-		iString fname = tmp->GetEnvironment(_EnvironmentBase) + "ifrit.ini";
+		iString fname = tmp->GetEnvironment(Environment::Base) + "ifrit.ini";
 		if(iFile::IsReadable(fname)) tmp->mStateFileName = fname;
 	}
 
@@ -327,17 +327,6 @@ iShell* iShell::New(const iString &t, int argc, char **argv)
 		tmp->ConstructorBody(); 
 	}
 	//
-	//  Check that vtkIdType is 64-bit on a 64-bit machine
-	//
-	if(sizeof(vtkIdType)==4 && sizeof(long)==8)
-	{
-		iConsole::Display(iConsole::_Notification,"This machine is 64-bit, but VTK has been compiled with 32-bit ids.\n"
-			                                      "    This configuration is inconsistent and is prone to crashes.   \n"
-												  "       It is highly recommended that you recompile VTK with       \n"
-												  "           advanced option VTK_USE_64BIT_IDS set to ON            \n"
-												  "                    and then recompile IFrIT.                     ");
-	}
-	//
 	//   Load widget info into ObjectKeyHelp objects.
 	//
 #ifdef I_DEBUG
@@ -477,6 +466,12 @@ void iShell::Run()
 }
 
 
+void iShell::IgnoreCommandLineArgument(const iString &arg)
+{
+	mIgnoredCommandLineArguments.Add(arg);
+}
+
+
 void iShell::AddCommandLineOption(const iString &root, bool hasValue, const iString &help)
 {
 	Option tmp;
@@ -496,6 +491,11 @@ void iShell::ParseCommandLineOptions(int argc, char **argv)
 	i = mFirstOption;
 	while(i < argc)
 	{
+		//
+		//  Check if this word needs to be ignored
+		//
+		if(mIgnoredCommandLineArguments.Find(argv[i]) > -1) break;
+
 		done = false;
 		if(iString(argv[i]).Part(0,mOptionPrefix.Length()) == mOptionPrefix)
 		{
@@ -586,7 +586,7 @@ bool iShell::AnalyseOneCommandLineOption(const struct Option &o)
 	if(o.Name == "i")
 	{
 		iString fn(o.Value);
-		iDirectory::ExpandFileName(fn,this->GetEnvironment(_EnvironmentBase));
+		iDirectory::ExpandFileName(fn,this->GetEnvironment(Environment::Base));
 		if(iFile::IsReadable(fn))
 		{
 			mStateFileName = fn;
@@ -602,7 +602,7 @@ bool iShell::AnalyseOneCommandLineOption(const struct Option &o)
 	if(o.Name == "b")
 	{
 		iString fn (o.Value);
-		iDirectory::ExpandFileName(fn,this->GetEnvironment(_EnvironmentBase));
+		iDirectory::ExpandFileName(fn,this->GetEnvironment(Environment::Base));
 		if(iFile::IsReadable(fn))
 		{
 			mScriptFileName = fn;
@@ -628,23 +628,23 @@ const iString& iShell::GetEnvironment(int key) const
 
 	switch(key)
 	{
-	case _EnvironmentBase:
+	case Environment::Base:
 		{
 			return mEnvBaseDir;
 		}
-	case _EnvironmentData:
+	case Environment::Data:
 		{
 			return mEnvDataDir;
 		}
-	case _EnvironmentImage:
+	case Environment::Image:
 		{
 			return mEnvImageDir;
 		}
-	case _EnvironmentScript:
+	case Environment::Script:
 		{
 			return mEnvScriptDir;
 		}
-	case _EnvironmentPalette:
+	case Environment::Palette:
 		{
 			return mEnvPaletteDir;
 		}
@@ -734,6 +734,8 @@ void iShell::InitHelper()
 #include <vtkCubeSource.h>
 #include <vtkGlyph3D.h>
 #include <vtkImageData.h>
+#include <vtkLookupTable.h>
+#include <vtkPointData.h>
 #include <vtkPolyDataMapper.h>
 #include <vtkProperty.h>
 #include <vtkRenderer.h>
@@ -746,9 +748,32 @@ namespace iShell_Private
 		//
 		//  Check that sizes of basic types are correct
 		//
-		if(sizeof(int)!=4 || sizeof(float)!=4 || sizeof(double)!=8 || sizeof(void*)!=sizeof(long))
+		if(sizeof(int)!=4 || sizeof(float)!=4 || sizeof(double)!=8)
 		{
-			iConsole::Display(iConsole::_HighError,"IFrIT has not been ported to this machine.");
+			int sint = sizeof(int);
+			int sflt = sizeof(float);
+			int sdbl = sizeof(double);
+			int sptr = sizeof(void*);
+			int slng = sizeof(long);
+			int svtk = sizeof(vtkIdType);
+			int ssiz = sizeof(size_t);
+			iConsole::Display(iConsole::_FatalError,"IFrIT has not been ported to this machine.");
+			exit(0);
+		}
+		//
+		//  Check that vtkIdType can address a full pointer
+		//
+		if(sizeof(vtkIdType) < sizeof(void*))
+		{
+			iConsole::Display(iConsole::_Notification,"This machine is "+iString::FromNumber(8*int(sizeof(void*)))+"-bit, but VTK has been compiled with "+iString::FromNumber(8*int(sizeof(vtkIdType)))+"-bit ids.\n"
+				"IFrIT will not be able to use more than 2GB of memory per single array.\n"
+				"Just letting you know.\n");
+		}
+		if(sizeof(vtkIdType) > sizeof(void*))
+		{
+			iConsole::Display(iConsole::_FatalError,"This machine is "+iString::FromNumber(8*int(sizeof(void*)))+"-bit, but VTK has been compiled with "+iString::FromNumber(8*int(sizeof(vtkIdType)))+"-bit ids.\n"
+				"This configuration is inconsistent and is prone to crashes.\n"
+				"Please recompile VTK with the advanced option VTK_USE_64BIT_IDS set to OFF.\n");
 			exit(0);
 		}
 	}
@@ -761,22 +786,48 @@ namespace iShell_Private
 		ren->GetActiveCamera()->SetPosition(0.0,0.0,1.0);
 		ren->ResetCamera();
 
+		ren->GetRenderWindow()->Render();
+
 		vtkTimerLog *timer = vtkTimerLog::New();
 		timer->StartTimer();
 
 		int i;
-		float r = 0.0f;
+		float r = 0;
 		do
 		{
-			for(i=0; i<10; i++)
+			for(i=0; i<35; i++)
 			{
-				ren->GetActiveCamera()->Azimuth(0.1);
+				ren->GetActiveCamera()->Azimuth(9);
+				ren->GetRenderWindow()->Render();
+			}
+			for(i=0; i<35; i++)
+			{
+				ren->GetActiveCamera()->Elevation(9);
+				ren->GetActiveCamera()->OrthogonalizeViewUp();
+				ren->GetRenderWindow()->Render();
+			}
+			for(i=0; i<40; i++)
+			{
+				ren->GetActiveCamera()->Roll(9);
+				ren->GetRenderWindow()->Render();
+			}
+			for(i=0; i<5; i++)
+			{
+				ren->GetActiveCamera()->Elevation(9);
+				ren->GetActiveCamera()->OrthogonalizeViewUp();
+				ren->GetRenderWindow()->Render();
+			}
+			for(i=0; i<5; i++)
+			{
+				ren->GetActiveCamera()->Azimuth(9);
 				ren->GetRenderWindow()->Render();
 			}
 			timer->StopTimer();
-			r += 0.01f;
+			r += 1;
 		}
-		while(timer->GetElapsedTime() < 10.0);
+		while(timer->GetElapsedTime() < 3.0);
+
+		r /= timer->GetElapsedTime();
 
 		timer->Delete();
 
@@ -786,7 +837,8 @@ namespace iShell_Private
 
 	void TestPerformance()
 	{
-		const float renRateScale[2] = { 5.62e-2f, 4.61e-2f };
+		int i;
+		const float renRateScale[2] = { 7.5f, 7.5f };
 
 		vtkRenderer *ren = vtkRenderer::New();
 		vtkRenderWindow *win = vtkRenderWindow::New();
@@ -801,13 +853,18 @@ namespace iShell_Private
 		data->SetNumberOfScalarComponents(1);
 		data->AllocateScalars();
 
-		// unsigned char *ptr = (unsigned char *)data->GetScalarPointer();
+		unsigned char *ptr = (unsigned char *)data->GetScalarPointer();
+		for(i=0; i<data->GetNumberOfPoints(); i++)
+		{
+			ptr[i] = i % 256;
+		}
 
 		vtkCubeSource *cube = vtkCubeSource::New();
 		cube->Update();
 
 		vtkGlyph3D *glyph = vtkGlyph3D::New();
 		glyph->SetScaleModeToDataScalingOff();
+		glyph->SetColorModeToColorByScalar();
 		glyph->SetScaleFactor(0.08);
 		glyph->SetSource(cube->GetOutput());
 		glyph->SetInput(data);
@@ -817,7 +874,15 @@ namespace iShell_Private
 		vtkPolyDataMapper *mapper = vtkPolyDataMapper::New();
 		vtkActor *actor = vtkActor::New();
 
-		mapper->ScalarVisibilityOff();
+		mapper->ScalarVisibilityOn();
+		mapper->SetColorModeToMapScalars();
+
+		vtkLookupTable *lut = vtkLookupTable::New();
+		lut->SetRange(0.0,255.0);
+		//lut->SetHueRange(0.0,255.0);
+		mapper->SetLookupTable(lut);
+		mapper->UseLookupTableScalarRangeOn();
+		lut->Delete();
 
 		actor->GetProperty()->SetColor(0.0,0.0,0.0);
 		actor->SetMapper(mapper);
@@ -838,23 +903,37 @@ namespace iShell_Private
 		//
 		// draw the resulting scene
 		//
+		win->SetWindowName("IFrIT - Performance Test");
 		win->Render();
 		win->SetWindowName("IFrIT - Performance Test");
 
-		iString ws = "Rendering performance (relative to NVIDIA Quadro FX 4000/AGP 8x):\n";
+		iString ws = "Rendering performance:\n\n";
 		float rr;
 
 		actor->GetProperty()->SetOpacity(1.0);
 		actor->GetProperty()->SetColor(0.0,0.0,1.0);
-		rr = TestRenderingPerformance(ren)/renRateScale[0];
-		ws += "Opaque:\t\t " + iString::FromNumber(round(rr)) + "%\n";
+		rr = TestRenderingPerformance(ren)*renRateScale[0];
+		ws += "Opaque:\t\t " + iString::FromNumber(rr,"%.1f") + "\n";
 
 		actor->GetProperty()->SetOpacity(0.03);
 		actor->GetProperty()->SetColor(1.0,0.0,0.0);
-		rr = TestRenderingPerformance(ren)/renRateScale[1];
-		ws += "Transparent:\t " + iString::FromNumber(round(rr)) + "%\n";
+		rr = TestRenderingPerformance(ren)*renRateScale[1];
+		ws += "Transparent:\t " + iString::FromNumber(rr,"%.1f") + "\n";
 
+		ws += "\n";
+		ws += "Representative rangers for values:\n";
+		ws += "1-2\tLaptop with a chipset\n";
+		ws += "5-20\tDesktop with a low-end video card\n";
+		ws += "50-200\tWorkstation with a high-end video card\n\n";
+
+		ws += iString("VTK Version: ") + VTK_VERSION + "\n";
+		ws += "IFrIT Version: " + iVersion::GetVersion() + "\n";
+
+#ifdef _WIN32
+		iConsole::Display(iConsole::_Notification,ws);
+#else
 		iConsole::Display(iConsole::_Info,ws);
+#endif
 
 		data->Delete();
 		win->RemoveRenderer(ren);
