@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iShiftPolyDataFilter : public iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>
 {
 	
-	IGENERICFILTER_DECLARE(iShiftPolyDataFilter);
+	IGENERICFILTER_DECLARE(iShiftPolyDataFilter,vtkPolyDataToPolyDataFilter);
 
 public:
 	
