@@ -128,10 +128,17 @@ void iStereoImage::Blend(const iStereoImage& im, float op)
 }
 
 
-void iStereoImage::Overlay(int x, int y, const iImage& ovr, float opacity)
+void iStereoImage::Overlay(int x, int y, const iImage& ovr, float opacity, bool masking)
 {
-	mEyeImage[0].Overlay(x,y,ovr,opacity);
-	if(mIsStereo) mEyeImage[1].Overlay(x,y,ovr,opacity);
+	mEyeImage[0].Overlay(x,y,ovr,opacity,masking);
+	if(mIsStereo) mEyeImage[1].Overlay(x,y,ovr,opacity,masking);
+}
+
+
+void iStereoImage::Overlay(int x, int y, const iStereoImage& ovr, float opacity, bool masking)
+{
+	mEyeImage[0].Overlay(x,y,ovr.LeftEye(),opacity,masking);
+	if(mIsStereo) mEyeImage[1].Overlay(x,y,ovr.RightEye(),opacity,masking);
 }
 
 
@@ -142,6 +149,13 @@ bool iStereoImage::CombineInPseudoColor(const iStereoImage &imRed, const iStereo
 }
 
 
+void iStereoImage::DrawFrame(int width, const iColor &color)
+{
+	mEyeImage[0].DrawFrame(width,color);
+	if(mIsStereo) mEyeImage[1].DrawFrame(width,color);
+}
+
+
 void iStereoImage::SetTag(const iString& tag)
 {
 	mTag = tag;
