@@ -60,8 +60,10 @@ public:
 	void ReplaceData(int n, vtkImageData *data);
 	void Blend(const iImage& im, float op);
 	void Blend(const iStereoImage& im, float op);
-	void Overlay(int x, int y, const iImage& ovr, float opacity = 1.0);
+	void Overlay(int x, int y, const iImage& ovr, float opacity = 1.0, bool masking = true);
+	void Overlay(int x, int y, const iStereoImage& ovr, float opacity = 1.0, bool masking = true);
 	bool CombineInPseudoColor(const iStereoImage &imRed, const iStereoImage &imGreen, const iStereoImage &imBlue);
+	void DrawFrame(int width, const iColor &color);
 
 	inline bool IsStereo() const { return mIsStereo; }
 	inline bool IsEmpty() const { return mEyeImage[0].IsEmpty(); }
