@@ -35,6 +35,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "imath.h"
 #include "iviewmodule.h"
+#include "ivtk.h"
 
 #include <vtkCellArray.h>
 #include <vtkDoubleArray.h>
@@ -52,7 +53,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "igenericfiltertemplate.h"
 
 
-#include "iparameter.h"
 using namespace iParameter;
 
 
@@ -60,7 +60,7 @@ iStreamLineFilter::iStreamLineFilter(iViewSubject *vo) : iGenericFilter<vtkStrea
 {
 	mLength = 2.0;
 	mVmin = 1.0e-5;
-	mDir = _StreamLineDirBothWays;
+	mDir = StreamLine::Direction::BothWays;
 	mSplitLines = 0;
 	mComputeVort = mComputeDiv = true;
 	mQuality = 0;
@@ -68,11 +68,13 @@ iStreamLineFilter::iStreamLineFilter(iViewSubject *vo) : iGenericFilter<vtkStrea
 	mDmin = 1.0e-3;
 
 	this->SetIntegratorTypeToRungeKutta45();
+#ifdef IVTK_PRE56
 	this->SetMaximumPropagationUnitToLengthUnit();
+#endif
 	this->SetMaximumPropagation(mLength);
 	this->SetTerminalSpeed(mVmin);
 	this->SetIntegrationDirectionToBoth();
-	this->ComputeVorticityOn();
+	this->SetComputeVorticity(vtkSwitch(mComputeVort));
 }
 
 
@@ -92,7 +94,7 @@ void iStreamLineFilter::SetComputeVorticity(bool d)
 	if(d != mComputeVort)
 	{
 		mComputeVort = d;
-		this->SetComputeVorticity(d?1:0);
+		this->SetComputeVorticity(vtkSwitch(d));
 		this->Modified();
 	}
 }
@@ -121,24 +123,24 @@ void iStreamLineFilter::SetMinimumSpeed(float v)
 
 void iStreamLineFilter::SetDirection(int d)
 {
-	if(d>=0 && d<__NumStreamLineDirs)
+	if(StreamLine::Direction::IsValid(d))
 	{
 		mDir = d;
 		switch(mDir)
 		{
-		case iParameter::_StreamLineDirBackward:
-		case iParameter::_StreamLineDirDownStream:
+		case StreamLine::Direction::Backward:
+		case StreamLine::Direction::DownStream:
 			{
 				this->SetIntegrationDirectionToBackward();
 				break;
 			}
-		case iParameter::_StreamLineDirForward:
-		case iParameter::_StreamLineDirUpStream:
+		case StreamLine::Direction::Forward:
+		case StreamLine::Direction::UpStream:
 			{
 				this->SetIntegrationDirectionToForward();
 				break;
 			}
-		case iParameter::_StreamLineDirBothWays:
+		case StreamLine::Direction::BothWays:
 			{
 				this->SetIntegrationDirectionToBoth();
 				break;
@@ -253,11 +255,11 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 	int idir, idirMin = 0, idirMax = -1;
 	switch (mDir) 
 	{
-	case _StreamLineDirUpStream: { idirMin = 0; idirMax = 0; break; }
-	case _StreamLineDirDownStream: { idirMin = 1; idirMax = 1; break; }
-	case _StreamLineDirForward:
-	case _StreamLineDirBackward:
-	case _StreamLineDirBothWays: { idirMin = 0; idirMax = 1; break; }
+	case StreamLine::Direction::UpStream: { idirMin = 0; idirMax = 0; break; }
+	case StreamLine::Direction::DownStream: { idirMin = 1; idirMax = 1; break; }
+	case StreamLine::Direction::Forward:
+	case StreamLine::Direction::Backward:
+	case StreamLine::Direction::BothWays: { idirMin = 0; idirMax = 1; break; }
 	}
 
 	int isplit, isplitMax = 1;
@@ -288,7 +290,7 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 		for(idir=idirMin; idir<=idirMax; idir++)
 		{
 			sdir = 1.0 - 2.0*idir;
-			if(ptrNorms!=0 && ((mDir==_StreamLineDirForward && sdir*vtkMath::Dot(vn,v0)<0.0) || (mDir==_StreamLineDirBackward && sdir*vtkMath::Dot(vn,v0)>0.0)))
+			if(ptrNorms!=0 && ((mDir==StreamLine::Direction::Forward && sdir*vtkMath::Dot(vn,v0)<0.0) || (mDir==StreamLine::Direction::Backward && sdir*vtkMath::Dot(vn,v0)>0.0)))
 			{
 				break;
 			}
@@ -323,7 +325,7 @@ void iStreamLineFilter::ProduceOutputForImageData(vtkImageData *input, vtkPolyDa
 						l = GetVector(x1,v1);
 					}
 
-					if((mDir==_StreamLineDirForward && sdir*vtkMath::Dot(vn,v0)<0.0 || (mDir==_StreamLineDirBackward && sdir*vtkMath::Dot(vn,v0)>0.0)))
+					if((mDir==StreamLine::Direction::Forward && sdir*vtkMath::Dot(vn,v0)<0.0 || (mDir==StreamLine::Direction::Backward && sdir*vtkMath::Dot(vn,v0)>0.0)))
 					{
 						break;
 					}
