@@ -30,11 +30,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
+#include "imath.h"
 
 #include <math.h>
 #include <stdio.h>
 
 
+const int iString::MaxLength = iMath::_LargeInt;
+
+
 //
 //  A clever small trick: we can gain more in efficiency if we allocate memory in discrete chunks - 
 //  this way appending small string would not require re-allocating memory with a huge speed-up.
@@ -589,6 +593,25 @@ iString iString::FromNumber(long d, const char *format)
 	return iString(s);
 }
 
+#ifndef I_NO_LONG_LONG
+// 
+//  Not all compilers may support long long type...
+//
+iString iString::FromNumber(long long d, const char *format)
+{
+	const unsigned int n = 99;
+	char s[n];
+	sprintf(s,format,d);
+#ifdef I_CHECK1
+	if(strlen(s) > n)
+	{
+		IERROR_FATAL("Array out of bounds.");
+	}
+#endif
+	return iString(s);
+}
+#endif
+
 
 iString iString::FromNumber(float d, const char *format)
 {
@@ -652,8 +675,31 @@ int iString::ToInt(bool &ok) const
 float iString::ToFloat(bool &ok) const
 {
 	float d; char c;
-	ok = (sscanf(mArr->GetPointer(0),"%g%c",&d,&c) == 1);
-	return d;
+	switch(sscanf(mArr->GetPointer(0),"%g%c",&d,&c))
+	{
+	case 1:
+		{
+			//
+			//  Perfect match
+			//
+			ok = true;
+			return d;
+			break;
+		}
+	case 2:
+		{
+			//
+			//  Workaround for a MAC bug
+			//
+			ok = (c == '.');
+			return d;
+		}
+	default:
+		{
+			ok = false;
+			return d;
+		}
+	}
 }
 
 
