@@ -235,7 +235,7 @@ void iSurfacePipeline::UpdateContents(int n, int info)
 
 void iSurfacePipeline::UpdateIsoSurfacePipeline(int force)
 { 
-	if(force==0 && mParent->GetMethod()!=_SurfaceMethodIsoSurface) return;
+	if(force==0 && mParent->GetMethod()!=SurfaceMethod::IsoSurface) return;
 
 	switch(mParent->GetIsoSurfaceReduction())
 	{
@@ -337,7 +337,7 @@ void iSurfacePipeline::UpdateNormalsFlipped()
 	int var = mParent->GetIsoSurfaceVar();
 	bool s = mParent->GetNormalsFlipped();
 
-	if(mParent->GetMethod() != _SurfaceMethodIsoSurface) var = -1;
+	if(mParent->GetMethod() != SurfaceMethod::IsoSurface) var = -1;
 
 	if((s && var!=mSpecialVar) || (!s && var==mSpecialVar)) 
 	{
@@ -367,7 +367,7 @@ void iSurfacePipeline::UpdateMethod()
 {
 	switch(mParent->GetMethod())
 	{
-	case _SurfaceMethodIsoSurface:
+	case SurfaceMethod::IsoSurface:
 		{
 			this->UpdateIsoSurfacePipeline(0);
 			mProbeFilter[0]->SetInput(mIsoSurfaceExitGateway->GetOutput());
@@ -375,14 +375,14 @@ void iSurfacePipeline::UpdateMethod()
 			this->Modified();
 			break;
 		}
-	case _SurfaceMethodSphere:
+	case SurfaceMethod::Sphere:
 		{
 			mProbeFilter[0]->SetInput(mSphereSource->GetOutput());
 			mProbeFilter[1]->SetInput(mSphereSource->GetOutput());
 			this->Modified();
 			break;
 		}
-	case _SurfaceMethodPlane:
+	case SurfaceMethod::Plane:
 		{
 			mProbeFilter[0]->SetInput(mPlaneSource->GetOutput());
 			mProbeFilter[1]->SetInput(mPlaneSource->GetOutput());
