@@ -106,12 +106,10 @@ namespace iSurfaceViewSubject_Private
 
 		virtual bool HasArtifacts(vtkRenderer *ren, vtkProperty *prop)
 		{
-			vtkPolyData *output = this->GetOutput();
-
 			//
 			//  Activate for mildly transparent surfaces
 			//
-			if((output->GetNumberOfPolys()>0 || output->GetNumberOfStrips()>0) && prop!=0)
+			if(prop != 0)
 			{
 				return (prop->GetOpacity()>0.2 && prop->GetOpacity()<1.0);
 			}
@@ -132,20 +130,13 @@ using namespace iSurfaceViewSubject_Private;
 //
 // iSurfaceViewSubject class
 //
-iSurfaceViewSubject::iSurfaceViewSubject(iViewModule *vm, const iDataType &type, const iString &name) : iSolidViewSubject(vm,type,name,2,_ViewSubjectHasPosition|_ViewSubjectSameOpacity|_ViewSubjectSameColor), mSize(vm,true)
+iSurfaceViewSubject::iSurfaceViewSubject(iViewModule *vm, const iDataType &type, const iString &name) : iSolidViewSubject(vm,type,name,2,ViewSubject::Flag::HasPosition|ViewSubject::Flag::SameOpacity|ViewSubject::Flag::SameColor), mSize(vm,true)
 {
-	mObjectType = _ObjectTypeSurface;
+	mSubjectId = ViewSubject::Id::Surface;
 
 	mLev = 0.0f;
 	mVar = 0;
-#if defined(IVTK_44) && defined(VTK_USE_PATENTED)
-	//
-	//  vtkMarchingContourFilter has an obscure bug undet VTK 5 and in multi-threaded mode.
-	//
-	mIsoSurfaceMethod = 1;
-#else
 	mIsoSurfaceMethod = 0;
-#endif
 
 	//
 	//  mPaintVar[0,1] = -1 means no painting on the exterior,interior.
@@ -181,7 +172,7 @@ iSurfaceViewSubject::iSurfaceViewSubject(iViewModule *vm, const iDataType &type,
 
 	mShading = true;
 	this->UpdateMaterialProperties();
-	mMethod = _SurfaceMethodIsoSurface;
+	mMethod = SurfaceMethod::IsoSurface;
 	mSize = 0.5;
 	mDir[0] = 0.0;
 	mDir[1] = 0.0;
@@ -230,8 +221,8 @@ void iSurfaceViewSubject::ResetPipeline()
 
 void iSurfaceViewSubject::ShowColorBarsBody(bool show)
 {
-	if(this->GetPaintVar(0) >= 0) this->GetViewModule()->GetColorBars()->ShowBar(_ColorBarsPrioritySurfaceExterior,this->GetPaintVar(0),this->GetDataType(),mPalettes[0],show);
-	if(this->GetPaintVar(1) >= 0) this->GetViewModule()->GetColorBars()->ShowBar(_ColorBarsPrioritySurfaceInterior,this->GetPaintVar(1),this->GetDataType(),mPalettes[1],show);
+	if(this->GetPaintVar(0) >= 0) this->GetViewModule()->GetColorBars()->ShowBar(ColorBarsPriority::SurfaceExterior,this->GetPaintVar(0),this->GetDataType(),mPalettes[0],show);
+	if(this->GetPaintVar(1) >= 0) this->GetViewModule()->GetColorBars()->ShowBar(ColorBarsPriority::SurfaceInterior,this->GetPaintVar(1),this->GetDataType(),mPalettes[1],show);
 }
 
 
@@ -462,7 +453,7 @@ void iSurfaceViewSubject::SolidViewSubjectUnPackStateBody(const iString &s)
 	if(this->UnPackValue(s,KeyOutputProperties(),b) && b) this->OutputProperties();
 #ifdef IOBJECT_BACKWARD_COMPATIBLE
 	if(this->UnPackValue(s,KeyAttachProbeToMarker(),i)) this->AttachToMarker(i);
-	if(this->UnPackValue(s,KeyProbePositionToPickedPoint(),b) && b) this->SetPosition(_LocationPickedPoint); 
+	if(this->UnPackValue(s,KeyProbePositionToPickedPoint(),b) && b) this->SetPosition(ViewSubject::Location::PickedPoint); 
 #endif
 	iObject::ReportMissingKeys(true);
 }
@@ -473,7 +464,7 @@ void iSurfaceViewSubject::SetMethod(int m)
 	if(m>=0 && m<3)
 	{
 		mMethod = m;
-		this->SetShading(mMethod != _SurfaceMethodPlane);
+		this->SetShading(mMethod != SurfaceMethod::Plane);
 		this->Pipeline()->UpdateContents(iSurfacePipeline::_Method);
 		this->ClearCache();
 	}
