@@ -68,9 +68,9 @@ IVIEWSUBJECT_DEFINE_INHERITED_KEYS_FIELD(iTensorFieldViewSubject);
 //
 // iTensorFieldViewSubject class
 //
-iTensorFieldViewSubject::iTensorFieldViewSubject(iViewModule *vm, const iDataType &type, const iDataType &scalarType, const iString &name) : iFieldViewSubject(vm,type,scalarType,name,1,_ViewSubjectAlwaysShaded)
+iTensorFieldViewSubject::iTensorFieldViewSubject(iViewModule *vm, const iDataType &type, const iDataType &scalarType, const iString &name) : iFieldViewSubject(vm,type,scalarType,name,1,ViewSubject::Flag::AlwaysShaded)
 {
-	mObjectType = _ObjectTypeTensorField;
+	mSubjectId = ViewSubject::Id::TensorField;
 
 	mMethod = 0;
 	mScalingOn = true;
