@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iTensorGlyphFilter : public iGenericFilter<vtkTensorGlyph,vtkDataSet,vtkPolyData>
 {
 
-	IGENERICFILTER_DECLARE(iTensorGlyphFilter);
+	IGENERICFILTER_DECLARE(iTensorGlyphFilter,vtkTensorGlyph);
 
 protected:
 	
