@@ -40,16 +40,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iparallelworker.h"
 #include "iuniformgriddata.h"
 #include "iviewmodule.h"
-#include "ivtk.h"
 
 #include <vtkFloatArray.h>
-#include <vtkPointData.h>
-#ifndef IVTK_44
 #include <vtkInformation.h>
-#endif
-
-#include "iparameter.h"
-using namespace iParameter;
+#include <vtkPointData.h>
 
 //
 //  Templates (needed for some compilers)
@@ -59,6 +53,9 @@ using namespace iParameter;
 #include "icalculatortemplate.h"
 
 
+using namespace iParameter;
+
+
 //
 //  Helper classes for parallel executions
 //
@@ -139,7 +136,7 @@ iUniformGridFileLoader::iUniformGridFileLoader(iDataReader *r, int priority, boo
 
 	mOriginOffset[0] = mOriginOffset[1] = mOriginOffset[2] = 0.0;
 
-	mVoxelLocation = _VoxelLocationVertex;
+	mVoxelLocation = VoxelLocation::Vertex;
 
 	mFileDims[0] = mFileDims[1] = mFileDims[2] = 0;
 	mDataDims[0] = mDataDims[1] = mDataDims[2] = 0;
@@ -251,7 +248,7 @@ void iUniformGridFileLoader::ReadBinFile(const iString &fname)
 	//
 	//  Allocate memory; erase the old mBuffer if needed.
 	//
-	long newBufferSize = long(ndim[0]+mBufferSizeOffset)*long(ndim[1]+mBufferSizeOffset)*long(ndim[2]+mBufferSizeOffset)*long(nvar);
+	vtkIdType newBufferSize = (vtkIdType)(ndim[0]+mBufferSizeOffset)*(vtkIdType)(ndim[1]+mBufferSizeOffset)*(vtkIdType)(ndim[2]+mBufferSizeOffset)*nvar;
 	if(newBufferSize>mBufferSize || newBufferSize<mBufferSize/2) // do not use too much extra memory
 	{
 		if(mBuffer != 0) delete [] mBuffer;
@@ -316,7 +313,7 @@ void iUniformGridFileLoader::ReadTxtFile(const iString &fname)
 {
 	int i, n1, n2, n3, ret;
 	iString s;
-	long ntot, l;
+	vtkIdType ntot, l;
 	float f[999];
 	iFile F(fname);
 	bool err;
@@ -374,7 +371,7 @@ void iUniformGridFileLoader::ReadTxtFile(const iString &fname)
 	//
 	//  Allocate memory; erase the old mBuffer if needed.
 	//
-	long newBufferSize = long(n1+mBufferSizeOffset)*long(n2+mBufferSizeOffset)*long(n3+mBufferSizeOffset)*long(nvar);
+	vtkIdType newBufferSize = (vtkIdType)(n1+mBufferSizeOffset)*(vtkIdType)(n2+mBufferSizeOffset)*(vtkIdType)(n3+mBufferSizeOffset)*nvar;
 	if(newBufferSize>mBufferSize || newBufferSize<mBufferSize/2) // do not use too much extra memory
 	{
 		if(mBuffer != 0) delete [] mBuffer;
@@ -484,7 +481,7 @@ void iUniformGridFileLoader::FinalizeBody()
 		//
 		//  Implement periodic BC
 		//
-		if(mUsePeriodicOffsets && mVoxelLocation==_VoxelLocationCenter && this->IsBoxPeriodic())
+		if(mUsePeriodicOffsets && mVoxelLocation==VoxelLocation::Center && this->IsBoxPeriodic())
 		{
 			//
 			//  Expand the box and add extra values.
@@ -501,7 +498,7 @@ void iUniformGridFileLoader::FinalizeBody()
 
 void iUniformGridFileLoader::SetVoxelLocation(int m)
 { 
-	if(m>=0 && m<__NumVoxelLocations && mVoxelLocation!=m)
+	if(VoxelLocation::IsValid(m) && mVoxelLocation!=m)
 	{
 		int oldLoc = mVoxelLocation;
 		mVoxelLocation = m;
@@ -511,13 +508,13 @@ void iUniformGridFileLoader::SetVoxelLocation(int m)
 			if(mUsePeriodicOffsets && this->IsBoxPeriodic())
 			{
 				int i;
-				if(oldLoc==_VoxelLocationVertex && mVoxelLocation==_VoxelLocationCenter)
+				if(oldLoc==VoxelLocation::Vertex && mVoxelLocation==VoxelLocation::Center)
 				{
 					for(i=0; i<3; i++) if(this->IsDirectionPeriodic(i)) mDataDims[i] = mFileDims[i] + 1;
 					mHelper->ExpandUp(mBuffer,mNumComponents,mFileDims,mDataDims);
 					mHelper->PadPeriodically(mBuffer,mNumComponents,mFileDims,mDataDims);
 				}
-				if(oldLoc==_VoxelLocationCenter && mVoxelLocation==_VoxelLocationVertex)
+				if(oldLoc==VoxelLocation::Center && mVoxelLocation==VoxelLocation::Vertex)
 				{
 					mHelper->CollapseDown(mBuffer,mNumComponents,mDataDims,mFileDims);
 					for(i=0; i<3; i++) mDataDims[i] = mFileDims[i];
@@ -551,7 +548,6 @@ void iUniformGridFileLoader::ReleaseData()
 
 void iUniformGridFileLoader::Polish(vtkDataSet *ds)
 {
-#ifndef IVTK_44
 	//
 	//  Extra class needed under VTK 5. What a mess!
 	//
@@ -572,7 +568,6 @@ void iUniformGridFileLoader::Polish(vtkDataSet *ds)
 		info->Set(vtkDataObject::ORIGIN(),org,3);
 		info->Set(vtkDataObject::SPACING(),spa,3);
 	}
-#endif
 }
 
 
@@ -611,7 +606,7 @@ void iUniformGridFileLoader::ComputeSpacing(double org[3], double spa[3])
 	//  if it is 1, we have cell data and we place the first point into the center of the first cell (mOriginOffset).
 	//
 	float shift;
-	if(mVoxelLocation == _VoxelLocationVertex)
+	if(mVoxelLocation == VoxelLocation::Vertex)
 	{
 		shift = 0.0;
 	}
@@ -1018,7 +1013,7 @@ void iUniformScalarsFileLoader::OperateOnData()
 	{
 		fMin = iMath::_LargeFloat;
 		fMax = -iMath::_LargeFloat;
-		long l;
+		vtkIdType l;
 		for(l=0; l<size; l++)
 		{
 			f = mBuffer[n+nvar*l];
@@ -1112,9 +1107,9 @@ void iUniformGridHelper::ExpandUp(float *array, int nc, int oldDims[3], int newD
 		mLoader->GetObserver()->Started(iProgressEventObserver::_Formatting);
 	}
 
-	long oldN12 = nc*oldDims[0]*oldDims[1]; 
-	long newN12 = nc*newDims[0]*newDims[1];
-	long size12 = oldN12*sizeof(float);
+	vtkIdType oldN12 = nc*oldDims[0]*oldDims[1]; 
+	vtkIdType newN12 = nc*newDims[0]*newDims[1];
+	vtkIdType size12 = oldN12*sizeof(float);
 
 	if(newN12 > oldN12)
 	{
@@ -1132,9 +1127,9 @@ void iUniformGridHelper::ExpandUp(float *array, int nc, int oldDims[3], int newD
 		}
 	}
 
-	long oldN1 = nc*oldDims[0]; 
-	long newN1 = nc*newDims[0];
-	long size1 = oldN1*sizeof(float);
+	vtkIdType oldN1 = nc*oldDims[0]; 
+	vtkIdType newN1 = nc*newDims[0];
+	vtkIdType size1 = oldN1*sizeof(float);
 
 	if(newN1 > oldN1)
 	{
@@ -1182,10 +1177,10 @@ void iUniformGridHelper::CollapseDown(float *array, int nc, int oldDims[3], int
 		return;
 	}
 
-	long oldN12 = nc*oldDims[0]*oldDims[1]; 
-	long oldN1 = nc*oldDims[0]; 
-	long newN1 = nc*newDims[0];
-	long size1 = newN1*sizeof(float);
+	vtkIdType oldN12 = nc*oldDims[0]*oldDims[1]; 
+	vtkIdType oldN1 = nc*oldDims[0]; 
+	vtkIdType newN1 = nc*newDims[0];
+	vtkIdType size1 = newN1*sizeof(float);
 
 	if(mLoader->GetObserver() != 0)
 	{
@@ -1213,8 +1208,8 @@ void iUniformGridHelper::CollapseDown(float *array, int nc, int oldDims[3], int
 		}
 	}
 
-	long newN12 = nc*newDims[0]*newDims[1];
-	long size12 = newN12*sizeof(float);
+	vtkIdType newN12 = nc*newDims[0]*newDims[1];
+	vtkIdType size12 = newN12*sizeof(float);
 
 	if(newN12 < oldN12)
 	{
@@ -1243,7 +1238,7 @@ void iUniformGridHelper::PadPeriodically(float *array, int nc, int oldDims[3], i
 {
 	int i, j, k;
 	float *ptr;
-	long size, offset;
+	vtkIdType size, offset;
 
 	if(array==0 || nc<1 || oldDims[0]<1 || oldDims[1]<1 || oldDims[2]<1)
 	{
@@ -1367,7 +1362,7 @@ void iUniformGridHelper::ExecuteShiftData(iParallel::ProcessorInfo &p)
 	}
 	
 	int ddim = mDims[d];
-	long off0 = 0L, off1 = 0L, add2;
+	vtkIdType off0 = 0, off1 = 0, add2;
 	
 	int kbeg, kend, kstp;
 	iParallel::SplitRange(p,mDims[d1],kbeg,kend,kstp);
@@ -1383,9 +1378,9 @@ void iUniformGridHelper::ExecuteShiftData(iParallel::ProcessorInfo &p)
 		{
 			switch(d) 
 			{
-			case 0: { off0 = mNumCom*(long)mDims[0]*(l1+mDims[1]*l2); off1 = mNumCom;	break; }
-			case 1: { off0 = mNumCom*(l1+(long)mDims[0]*mDims[1]*l2); off1 = mNumCom*mDims[0]; break; }
-			case 2: { off0 = mNumCom*(l1+(long)mDims[0]*l2); off1 = mNumCom*(long)mDims[0]*mDims[1]; break; }
+			case 0: { off0 = mNumCom*(vtkIdType)mDims[0]*(l1+mDims[1]*l2); off1 = mNumCom;	break; }
+			case 1: { off0 = mNumCom*(l1+(vtkIdType)mDims[0]*mDims[1]*l2); off1 = mNumCom*mDims[0]; break; }
+			case 2: { off0 = mNumCom*(l1+(vtkIdType)mDims[0]*l2); off1 = mNumCom*(vtkIdType)mDims[0]*mDims[1]; break; }
 			}
 			
 			for(l=0; l<ddim-1; l++) 
@@ -1517,9 +1512,9 @@ void iUniformScalarsHelper::ExecuteOperateOnData1(iParallel::ProcessorInfo &p)
 
 	if(arr1==0 || (mDoVector && arr2==0)) return;
 
-	long size = (long)mDims[0]*mDims[1]*mDims[2];
+	vtkIdType size = (vtkIdType)mDims[0]*mDims[1]*mDims[2];
 	int nout = mLoader->GetCalculatorOutput();
-	long l, kbeg, kend, kstp;
+	vtkIdType l, kbeg, kend, kstp;
 	iParallel::SplitRange(p,size,kbeg,kend,kstp);
 
 	float progScale = mProgStep/kstp;
@@ -1558,8 +1553,8 @@ void iUniformScalarsHelper::ExecuteOperateOnData1(iParallel::ProcessorInfo &p)
 void iUniformScalarsHelper::ExecuteOperateOnData2(iParallel::ProcessorInfo &p)
 {
 	float fMin, fMax;
-	long size = (long)mDims[0]*mDims[1]*mDims[2];
-	long kbeg, kend, kstp;
+	vtkIdType size = (vtkIdType)mDims[0]*mDims[1]*mDims[2];
+	vtkIdType kbeg, kend, kstp;
 	iParallel::SplitRange(p,size,kbeg,kend,kstp);
 
 	//
@@ -1567,7 +1562,7 @@ void iUniformScalarsHelper::ExecuteOperateOnData2(iParallel::ProcessorInfo &p)
 	//
 	iDataLimits *lim = mLoader->GetSubject(0)->GetLimits();
 
-	long l, larr;
+	vtkIdType l, larr;
 	int n;
 
 	float *arr1 = mLoader->GetDataPointer();
