@@ -100,7 +100,7 @@ protected:
 	int mVoxelLocation;
 	int mFileDims[3], mDataDims[3];
 
-	long mBufferSize;
+	vtkIdType mBufferSize;
 	float *mBuffer;
 
 private:
