@@ -108,7 +108,7 @@ float iVectorFieldGlyphPipeline::GetContentsMemorySize() const
 	float s = 0.0f;
 	s += mDataReplicated->GetMemorySize();
 	s += mGlyph->GetMemorySize();
-	s += mFilter->GetMemorySize();
+	if(mFilter != 0) s += mFilter->GetMemorySize();
 	return s;
 }
 
@@ -137,7 +137,7 @@ void iVectorFieldGlyphPipeline::UpdateSize()
 
 void iVectorFieldGlyphPipeline::UpdateSampleRate()
 { 
-	mFilter->SetSampleRate(mParent->GetGlyphSampleRate(),mParent->GetGlyphSampleRate(),mParent->GetGlyphSampleRate());
+	if(mFilter != 0) mFilter->SetSampleRate(mParent->GetGlyphSampleRate(),mParent->GetGlyphSampleRate(),mParent->GetGlyphSampleRate());
 	this->Modified();
 }
 
