@@ -42,6 +42,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "imarkerfamily.h"
 #include "ipicker.h"
 #include "ireplicatedactor.h"
+#include "istreamlinefilter.h"
 #include "ivectorfieldglyphpipeline.h"
 #include "ivectorfieldstreamlinepipeline.h"
 #include "iviewmodule.h"
@@ -103,26 +104,26 @@ IOBJECT_DEFINE_POSITION_KEY(iVectorFieldViewSubject,SourcePosition,-sx);
 //
 // iVectorFieldViewSubject class
 //
-iVectorFieldViewSubject::iVectorFieldViewSubject(iViewModule *vm, const iDataType &type, const iDataType &scalarType, const iString &name) : iFieldViewSubject(vm,type,scalarType,name,2,_ViewSubjectAlwaysShaded|_ViewSubjectHasPosition), mSourceSize(vm,true)
+iVectorFieldViewSubject::iVectorFieldViewSubject(iViewModule *vm, const iDataType &type, const iDataType &scalarType, const iString &name) : iFieldViewSubject(vm,type,scalarType,name,2,ViewSubject::Flag::AlwaysShaded|ViewSubject::Flag::HasPosition), mSourceSize(vm,true)
 {
-	mObjectType = _ObjectTypeVectorField;
+	mSubjectId = ViewSubject::Id::VectorField;
 
-	mMethod = _VectorMethodGlyph;
+	mMethod = VectorField::Method::Glyph;
 	mLineQuality = 0;
 	mLineLength = 1.0;
-	mLineDir = _StreamLineDirBothWays;
+	mLineDir = StreamLine::Direction::BothWays;
 	mTubeSize = 1;
 	mTubeRangeFactor = 10;
 	mTubeVariationFactor = 0.01; 
 	mColorByOffset = 0;
 
 	mSourceShow = false;
-	mSourceType = _VectorSourcePlane;
+	mSourceType = StreamLine::Source::Plane;
 	mNumLines = 4;
 	mSourceDir[0] = mSourceDir[1] = 0.0; mSourceDir[2] = 1.0;
 	mSourceSize = 0.5;
 
-	mColorBy = _VectorColorByNone;
+	mColorBy = VectorField::ColorBy::None;
 	//
 	//  Do VTK stuff
 	//	
@@ -204,22 +205,22 @@ void iVectorFieldViewSubject::UpdateColorByExtra()
 {
 	if(mColorByOffset > 0)
 	{
-		mActors[0]->SetScalarVisibility(mColorBy != _VectorColorByNone);
+		mActors[0]->SetScalarVisibility(mColorBy != VectorField::ColorBy::None);
 		switch (mColorBy) 
 		{
-		case _VectorColorByMagnitude:
+		case VectorField::ColorBy::Magnitude:
 			{ 
 				mActors[0]->ColorByArrayComponent(0,1); 
 				mActors[0]->SyncWithLimits(this->GetLimits(),0);
 				break;
 			}
-		case _VectorColorByVorticity:
+		case VectorField::ColorBy::Vorticity:
 			{
 				mActors[0]->ColorByArrayComponent(0,2); 
 				mActors[0]->SyncWithLimits(this->GetLimits(),0,2.0);
 				break;
 			}
-		case _VectorColorByDivergence:
+		case VectorField::ColorBy::Divergence:
 			{
 				mActors[0]->ColorByArrayComponent(0,3); 
 				mActors[0]->SyncWithLimits(this->GetLimits(),0,2.0);
@@ -233,7 +234,7 @@ void iVectorFieldViewSubject::UpdateColorByExtra()
 
 void iVectorFieldViewSubject::UpdateAfterMarkerMove()
 {
-	if(mSourceType == _VectorSourceMarker)
+	if(mSourceType == StreamLine::Source::Marker)
 	{
 		int i;
 		vtkIdType l[1];
@@ -277,14 +278,14 @@ void iVectorFieldViewSubject::UpdateStreamLineSource()
 { 
 	switch(mSourceType)
 	{
-	case _VectorSourceMarker:
+	case StreamLine::Source::Marker:
 		{
 			this->UpdateAfterMarkerMove();
 			break;
 		}
-	case _VectorSourceDisk:
-	case _VectorSourcePlane:
-	case _VectorSourceSphere:
+	case StreamLine::Source::Disk:
+	case StreamLine::Source::Plane:
+	case StreamLine::Source::Sphere:
 		{
 			int i, k;
 			vtkIdType n, l;
@@ -345,7 +346,7 @@ void iVectorFieldViewSubject::UpdateStreamLineSource()
 				//
 				switch(mSourceType)
 				{
-				case _VectorSourceDisk:
+				case StreamLine::Source::Disk:
 					{
 						//
 						//  Random point on the disk
@@ -366,7 +367,7 @@ void iVectorFieldViewSubject::UpdateStreamLineSource()
 						}
 						break;
 					}
-				case _VectorSourcePlane:
+				case StreamLine::Source::Plane:
 					{
 						//
 						//  Random point on the plane
@@ -380,7 +381,7 @@ void iVectorFieldViewSubject::UpdateStreamLineSource()
 						}
 						break;
 					}
-				case _VectorSourceSphere:
+				case StreamLine::Source::Sphere:
 					{
 						//
 						//  Random point on the sphere
@@ -447,24 +448,24 @@ void iVectorFieldViewSubject::SetShowSourceObject(bool s)
 
 void iVectorFieldViewSubject::SetSourceType(int v)
 {
-	if(v>=0 && v<__NumVectorSources && (v<_VectorSourceMarker || (this->GetViewModule()->GetMarkerFamily()->IsVisible())))
+	if(StreamLine::Source::IsValid(v) && (v<StreamLine::Source::Marker || (this->GetViewModule()->GetMarkerFamily()->IsVisible())))
 	{
 		mSourceType = v;
 		switch(mSourceType)
 		{
-		case _VectorSourceDisk:
+		case StreamLine::Source::Disk:
 			{
 				mActors[1]->SetInput(mSourceDisk->GetOutput());
 				this->SetShowSourceObject(mSourceShow);
 				break;
 			}
-		case _VectorSourcePlane:
+		case StreamLine::Source::Plane:
 			{
 				mActors[1]->SetInput(mSourcePlane->GetOutput());
 				this->SetShowSourceObject(mSourceShow);
 				break;
 			}
-		case _VectorSourceSphere:
+		case StreamLine::Source::Sphere:
 			{
 				mActors[1]->SetInput(mSourceSphere->GetOutput());
 				this->SetShowSourceObject(mSourceShow);
@@ -500,20 +501,20 @@ void iVectorFieldViewSubject::SetSourceOpacity(float v)
 
 void iVectorFieldViewSubject::SetMethod(int v)
 { 
-	if(v>=0 && v<__NumVectorMethods) 
+	if(VectorField::Method::IsValid(v)) 
 	{
 		mMethod = v;
 		switch(mMethod)
 		{
-		case _VectorMethodGlyph:
+		case VectorField::Method::Glyph:
 			{
 				mColorByOffset = 0;
 				mActors[0]->SetInput(vtkPolyData::SafeDownCast(this->Pipeline()->GetOutput(0)));
 				break;
 			}
-		case _VectorMethodStreamLine:
-		case _VectorMethodStreamTube:
-		case _VectorMethodStreamBand:
+		case VectorField::Method::StreamLine:
+		case VectorField::Method::StreamTube:
+		case VectorField::Method::StreamBand:
 			{
 				mColorByOffset = 4;
 				mActors[0]->SetInput(vtkPolyData::SafeDownCast(this->Pipeline(1)->GetOutput(0)));
@@ -530,7 +531,7 @@ void iVectorFieldViewSubject::SetMethod(int v)
 
 void iVectorFieldViewSubject::SetLineDir(int v)
 { 
-	if(v>=0 && v<__NumStreamLineDirs) 
+	if(StreamLine::Direction::IsValid(v)) 
 	{
 		mLineDir = v;
 		this->Pipeline(1)->UpdateContents(iVectorFieldStreamLinePipeline::_Direction);
@@ -682,7 +683,7 @@ void iVectorFieldViewSubject::FieldViewSubjectUnPackStateBody(const iString &s)
 	iObject::ReportMissingKeys(false);
  	if(this->UnPackValue(s,KeyAttachSourceToMarker(),i)) this->AttachToMarker(i);
 	if(this->UnPackValuePosition(s,KeySourcePosition(),mPosition)) this->SetPosition(mPosition);
-	if(this->UnPackValue(s,KeySourcePositionToPickedPoint(),b) && b) this->SetPosition(_LocationPickedPoint); 
+	if(this->UnPackValue(s,KeySourcePositionToPickedPoint(),b) && b) this->SetPosition(ViewSubject::Location::PickedPoint); 
 	iObject::ReportMissingKeys(true);
 #endif
 }
