@@ -44,6 +44,30 @@ class vtkCellArray;
 class vtkFloatArray;
 class vtkPoints;
 
+namespace iParameter
+{
+	namespace VectorField
+	{
+		namespace Method
+		{
+			const int Glyph =		0;
+			const int StreamLine =	1;
+			const int StreamTube =	2;
+			const int StreamBand =	3;
+
+			inline bool IsValid(int m){ return m>=0 && m<=3; }
+		};
+
+		namespace ColorBy
+		{
+			const int Magnitude =	-4;
+			const int Vorticity =	-3;
+			const int Divergence =	-2;
+			const int None =		-1;
+		};
+	};
+};
+
 
 class iVectorFieldViewSubject : public iFieldViewSubject
 {
