@@ -181,8 +181,7 @@ IOBJECT_DEFINE_KEY(iViewModule,RulerTitle,rt,String,1);
 IOBJECT_DEFINE_KEY(iViewModule,Size,s,Int,2);
 IOBJECT_DEFINE_KEY(iViewModule,UpdateRate,r,Int,1);
 IOBJECT_DEFINE_KEY(iViewModule,StereoAlignmentMarks,sam,Bool,1);
-IOBJECT_DEFINE_KEY(iViewModule,Stereo,ss,Bool,1);
-IOBJECT_DEFINE_KEY(iViewModule,StereoType,st,Int,1);
+IOBJECT_DEFINE_KEY(iViewModule,StereoMode,sm,Int,1);
 IOBJECT_DEFINE_KEY(iViewModule,WindowNumber,wn,Int,1);
 
 IOBJECT_DEFINE_KEY(iViewModule,JustifyLabelLeft,-lj,Bool,1);
@@ -192,7 +191,7 @@ IOBJECT_DEFINE_KEY(iViewModule,FontSize,-fsize,Int,1);  // for backward compatib
 #define IVIEWMODULE_DEFINE_VIEWSUBJECT(_name_) \
 i##_name_##ViewSubject* iViewModule::Get##_name_##ViewSubject(int n) const \
 { \
-	return static_cast<i##_name_##ViewSubject*>((n==-1)?mViewObjectFamilies[_ObjectType##_name_]->GetCurrentMember()->GetViewSubject():mViewObjectFamilies[_ObjectType##_name_]->GetMember(n)->GetViewSubject()); \
+	return static_cast<i##_name_##ViewSubject*>((n==-1)?mViewObjectFamilies[ViewSubject::Id::_name_]->GetCurrentMember()->GetViewSubject():mViewObjectFamilies[ViewSubject::Id::_name_]->GetMember(n)->GetViewSubject()); \
 } // we can do C-style cast here since it is guaranteed to be correct
 
 
@@ -326,7 +325,7 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	//
 	//  Set bounding box
 	//	
-	this->SetBoundingBoxType(_BoundingBoxTypeDefault);
+	this->SetBoundingBoxType(BoundingBoxType::Default);
 
 	//
 	//  Ruler actor
@@ -393,13 +392,13 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 
 	vtkInteractorStyleFlight *isf = vtkInteractorStyleFlight::New();
 
-	mInteractorStyle[_InteractorStyleTrackball] = vtkInteractorStyleTrackballCamera::New();
-	mInteractorStyle[_InteractorStyleJoystick] = vtkInteractorStyleJoystickCamera::New();
-	mInteractorStyle[_InteractorStyleFlight] = isf;
-	mInteractorStyle[_InteractorStyleKeyboard] = iKeyboardInteractorStyle::New();
-//	mInteractorStyle[_InteractorStyleKeyboard] = vtkInteractorStyleUnicam::New();
+	mInteractorStyle[InteractorStyle::Trackball] = vtkInteractorStyleTrackballCamera::New();
+	mInteractorStyle[InteractorStyle::Joystick] = vtkInteractorStyleJoystickCamera::New();
+	mInteractorStyle[InteractorStyle::Flight] = isf;
+	mInteractorStyle[InteractorStyle::Keyboard] = iKeyboardInteractorStyle::New();
+//	mInteractorStyle[InteractorStyle::Keyboard] = vtkInteractorStyleUnicam::New();
 
-	for(i=0; i<__NumInteractorStyles; i++)
+	for(i=0; i<InteractorStyle::SIZE; i++)
 	{
 		IERROR_ASSERT(mInteractorStyle[i]);
 		mMeasuringBox->AttachToInteractorStyle(mInteractorStyle[i]);
@@ -435,7 +434,7 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 
 	mObsRecord = iRecordEventObserver::New(this); IERROR_ASSERT(mObsRecord);
 
-	for(i=0; i<__NumInteractorStyles; i++) mInteractorStyle[i]->AddObserver(vtkCommand::InteractionEvent,mObsRecord);
+	for(i=0; i<InteractorStyle::SIZE; i++) mInteractorStyle[i]->AddObserver(vtkCommand::InteractionEvent,mObsRecord);
 
 	//
 	//  Must be created before marker family
@@ -481,8 +480,8 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	this->SetAntialiasing(mAntialiasing);
 	this->SetBackgroundColor(mBackgroundColor);
 
-	mWriter->SetImageFormat(_ImageFormatPNG);
-	mWriter->SetAnimationOutput(_AnimationOutputImage);
+	mWriter->SetImageFormat(ImageFormat::PNG);
+	mWriter->SetAnimationOutput(AnimationOutput::Image);
 
 	//
 	//  Initialize the interactor
@@ -546,7 +545,7 @@ iViewModule::~iViewModule()
 	mUpdateTimer->Delete();
 	mAnimator->Delete();
 
-	for(i=0; i<__NumInteractorStyles; i++) mInteractorStyle[i]->Delete();
+	for(i=0; i<InteractorStyle::SIZE; i++) mInteractorStyle[i]->Delete();
 
 	mRenderTool->RemoveObject(mBox1Actor);
 	mBox1Actor->Delete();
@@ -637,7 +636,7 @@ bool iViewModule::BecomeClone(iViewModule *v)
 
 			for(i=0; i<mViewObjectFamilies.Size(); i++) mViewObjectFamilies[i]->Reset();
 
-			for(i=0; i<=mViewObjectFamilies[_ObjectTypeParticles]->GetMaxMemberIndex(); i++)
+			for(i=0; i<=mViewObjectFamilies[ViewSubject::Id::Particles]->GetMaxMemberIndex(); i++)
 			{
 				this->GetParticlesViewSubject(i)->BecomeClone(0);
 			}
@@ -671,7 +670,7 @@ bool iViewModule::BecomeClone(iViewModule *v)
 			//
 			//  Particles family is never shown as a whole, so show individual members
 			//
-			for(i=0; i<=mViewObjectFamilies[_ObjectTypeParticles]->GetMaxMemberIndex(); i++)
+			for(i=0; i<=mViewObjectFamilies[ViewSubject::Id::Particles]->GetMaxMemberIndex(); i++)
 			{
 				this->GetParticlesViewSubject(i)->BecomeClone(v->GetParticlesViewSubject(i));
 				this->GetParticlesViewSubject(i)->Show(v->GetParticlesViewSubject(i)->IsVisible());
@@ -826,14 +825,14 @@ void iViewModule::UpdateAfterFileLoad()
 	//
 	//  Also make sure the current particles have the data (if there is any particle data)
 	//
-	if(!mViewObjectFamilies[_ObjectTypeParticles]->GetCurrentMember()->IsThereData())
+	if(!mViewObjectFamilies[ViewSubject::Id::Particles]->GetCurrentMember()->IsThereData())
 	{
 		int i;
-		for(i=0; i<=mViewObjectFamilies[_ObjectTypeParticles]->GetMaxMemberIndex(); i++)
+		for(i=0; i<=mViewObjectFamilies[ViewSubject::Id::Particles]->GetMaxMemberIndex(); i++)
 		{
-			if(mViewObjectFamilies[_ObjectTypeParticles]->GetMember(i)->IsThereData())
+			if(mViewObjectFamilies[ViewSubject::Id::Particles]->GetMember(i)->IsThereData())
 			{
-				mViewObjectFamilies[_ObjectTypeParticles]->SetCurrentMemberIndex(i);
+				mViewObjectFamilies[ViewSubject::Id::Particles]->SetCurrentMemberIndex(i);
 				break;
 			}
 		}
@@ -865,26 +864,26 @@ void iViewModule::ShowBoundingBox(bool s)
 		
 	switch(mBoxType)
 	{
-	case _BoundingBoxTypeDefault:
+	case BoundingBoxType::Default:
 		{
 			mBox1Actor->GetMapper()->ScalarVisibilityOn();
 			mBox1Actor->GetProperty()->SetLineWidth(4.0);
 			mBox1Actor->VisibilityOn();
 			break;
 		}
-	case _BoundingBoxTypeClassic:
+	case BoundingBoxType::Classic:
 		{
 			mBox2Actor->VisibilityOn();
 			break;
 		}
-	case _BoundingBoxTypeHairThin:
+	case BoundingBoxType::HairThin:
 		{
 			mBox1Actor->GetMapper()->ScalarVisibilityOff();
 			mBox1Actor->GetProperty()->SetLineWidth(1.0);
 			mBox1Actor->VisibilityOn();
 			break;
 		}
-	case _BoundingBoxTypeAxes:
+	case BoundingBoxType::Axes:
 		{
 			mBox3Actor->VisibilityOn();
 			mBox3AxesLabels->VisibilityOn();
@@ -1069,18 +1068,18 @@ void iViewModule::SetUpdateRate(int r)
 
 void iViewModule::SetInteractorStyle(int n)
 {
-	if(n>=0 && n<__NumInteractorStyles)
+	if(n>=0 && n<InteractorStyle::SIZE)
 	{
 		//
 		//  Specials
 		//
-		if(n == _InteractorStyleFlight)
+		if(n == InteractorStyle::Flight)
 		{
 			mSavedProjection = mRenderTool->GetCamera()->GetDevice()->GetParallelProjection();
 			mRenderTool->GetCamera()->GetDevice()->ParallelProjectionOff();
 			//mRenderTool->GetInteractor()->SetLastEventPosition(mRenderTool->GetInteractor()->GetEventPosition());
 		} 
-		else if(mCurrentInteractorStyle == _InteractorStyleFlight)
+		else if(mCurrentInteractorStyle == InteractorStyle::Flight)
 		{
 			mRenderTool->GetCamera()->GetDevice()->SetParallelProjection(mSavedProjection);
 			mRenderTool->GetCamera()->Reset();
@@ -1138,7 +1137,7 @@ void iViewModule::SetBackgroundImageFixedAspect(bool s)
 
 void iViewModule::SetBoundingBoxType(int s)
 {
-	if(s!=mBoxType && s>=0 && s<__NumBoundingBoxTypes)
+	if(s!=mBoxType && BoundingBoxType::IsValid(s))
 	{
 		mBoxType = s;
 		this->ShowBoundingBox(mIsBoundingBoxOn);
@@ -1382,7 +1381,6 @@ void iViewModule::ExtendableObjectPackStateBody(iString &s) const
 	this->PackValue(s,KeyAntialiasing(),mAntialiasing);
 	this->PackValue(s,KeyJustifyLabelLeft(),mLabelJustificationLeft);
 	this->PackValue(s,KeyMarkerLegend(),mMarkerFamily->IsLegendVisible());
-	this->PackValue(s,KeyStereo(),this->GetStereo());
 	this->PackValue(s,KeyStereoAlignmentMarks(),mIsStereoAlignmentMarksOn);
 	this->PackValue(s,KeyArtifactCorrection(),mArtifactCorrection);
 	this->PackValue(s,KeyBackgroundImageFixedAspect(),mBackgroundImageFixedAspect);
@@ -1400,7 +1398,7 @@ void iViewModule::ExtendableObjectPackStateBody(iString &s) const
 	this->PackValue(s,KeyAnimationOutput(),mWriter->GetAnimationOutput());
 	this->PackValue(s,KeyMarkerLegendPosition(),mMarkerFamily->GetLegendPosition());
 	this->PackValue(s,KeyImageMagnification(),mImageMagnification);
-	this->PackValue(s,KeyStereoType(),this->GetStereoType());
+	this->PackValue(s,KeyStereoMode(),this->GetStereoMode());
 	this->PackValue(s,KeyMarkerHandles(),mMarkerFamily->IsHandlesVisible());
 	this->PackValue(s,KeyMarkerCaptionsTransparent(),iCaption::Transparent);
 
@@ -1438,16 +1436,16 @@ void iViewModule::ExtendableObjectPackStateBody(iString &s) const
 	//  Extra keys for data quering
 	//
 	this->PackValue(s,KeyMarkerCurrent(),mMarkerFamily->GetCurrentMemberIndex());
-	this->PackValue(s,KeyCrossSectionCurrent(),mViewObjectFamilies[_ObjectTypeCrossSection]->GetCurrentMemberIndex());
+	this->PackValue(s,KeyCrossSectionCurrent(),mViewObjectFamilies[ViewSubject::Id::CrossSection]->GetCurrentMemberIndex());
 	this->PackValue(s,KeyParticlesCurrent(),this->GetParticlesObject()->GetActiveDataTypeIndex());
-	this->PackValue(s,KeySurfaceCurrent(),mViewObjectFamilies[_ObjectTypeSurface]->GetCurrentMemberIndex());
+	this->PackValue(s,KeySurfaceCurrent(),mViewObjectFamilies[ViewSubject::Id::Surface]->GetCurrentMemberIndex());
 
 	i = mMarkerFamily->GetMaxMemberIndex();
 	if(i==0 && !mMarkerFamily->GetMember(0)->IsVisible()) i = -1;
 	this->PackValue(s,KeyMarkerMax(),i);
 	this->PackValue(s,KeyParticlesMax(),this->GetParticlesObject()->GetNumberOfTypes()-1);
-	this->PackValue(s,KeySurfaceMax(),mViewObjectFamilies[_ObjectTypeSurface]->GetMaxMemberIndex());
-	this->PackValue(s,KeyCrossSectionMax(),mViewObjectFamilies[_ObjectTypeCrossSection]->GetMaxMemberIndex());
+	this->PackValue(s,KeySurfaceMax(),mViewObjectFamilies[ViewSubject::Id::Surface]->GetMaxMemberIndex());
+	this->PackValue(s,KeyCrossSectionMax(),mViewObjectFamilies[ViewSubject::Id::CrossSection]->GetMaxMemberIndex());
 }
 
 
@@ -1487,7 +1485,6 @@ void iViewModule::ExtendableObjectUnPackStateBody(const iString &s)
 	if(this->UnPackValue(s,KeyAntialiasing(),b)) this->SetAntialiasing(b);
 //	if(this->UnPackValue(s,KeyJustifyLabelLeft(),b)) this->justifyLabelLeft(b);
 	if(this->UnPackValue(s,KeyMarkerLegend(),b)) mMarkerFamily->ShowLegend(b);
-	if(this->UnPackValue(s,KeyStereo(),b)) this->SetStereo(b);
 	if(this->UnPackValue(s,KeyStereoAlignmentMarks(),b)) this->ShowStereoAlignmentMarks(b);
 	if(this->UnPackValue(s,KeyArtifactCorrection(),b)) this->SetArtifactCorrection(b);
 	if(this->UnPackValue(s,KeyBackgroundImageFixedAspect(),b)) this->SetBackgroundImageFixedAspect(b);
@@ -1503,7 +1500,7 @@ void iViewModule::ExtendableObjectUnPackStateBody(const iString &s)
 	if(this->UnPackValue(s,KeyAnimationOutput(),i)) mWriter->SetAnimationOutput(i);
 	if(this->UnPackValue(s,KeyMarkerLegendPosition(),i)) mMarkerFamily->SetLegendPosition(i);
 	if(this->UnPackValue(s,KeyImageMagnification(),i)) this->SetImageMagnification(i);
-	if(this->UnPackValue(s,KeyStereoType(),i)) this->SetStereoType(i);
+	if(this->UnPackValue(s,KeyStereoMode(),i)) this->SetStereoMode(i);
 	if(this->UnPackValue(s,KeyMarkerHandles(),b)) mMarkerFamily->ShowHandles(b);
 	if(this->UnPackValue(s,KeyMarkerCaptionsTransparent(),b)) iCaption::Transparent = b;
 
@@ -1562,7 +1559,7 @@ void iViewModule::ExtendableObjectUnPackStateBody(const iString &s)
 	}
 	if(this->UnPackValue(s,KeyCrossSectionCurrent(),i))
 	{
-		mViewObjectFamilies[_ObjectTypeCrossSection]->SetCurrentMemberIndex(i);
+		mViewObjectFamilies[ViewSubject::Id::CrossSection]->SetCurrentMemberIndex(i);
 		this->ClearCache();
 	}
 	if(this->UnPackValue(s,KeyParticlesCurrent(),i))
@@ -1572,7 +1569,7 @@ void iViewModule::ExtendableObjectUnPackStateBody(const iString &s)
 	}
 	if(this->UnPackValue(s,KeySurfaceCurrent(),i))
 	{
-		mViewObjectFamilies[_ObjectTypeSurface]->SetCurrentMemberIndex(i);
+		mViewObjectFamilies[ViewSubject::Id::Surface]->SetCurrentMemberIndex(i);
 		this->ClearCache();
 	}
 
@@ -1742,29 +1739,16 @@ const iString& iViewModule::GetRulerTitle() const
 }
 
 
-void iViewModule::SetStereo(bool s)
+void iViewModule::SetStereoMode(int m)
 {
-	mRenderTool->SetStereo(s);
+	mRenderTool->SetStereoMode(m);
 	this->ClearCache();
 }
 
 
-bool iViewModule::GetStereo() const
+int iViewModule::GetStereoMode() const
 {
-	return 	mRenderTool->GetStereo();
-}
-
-
-void iViewModule::SetStereoType(int n)
-{
-	mRenderTool->SetStereoType(n);
-	this->ClearCache();
-}
-
-
-int iViewModule::GetStereoType() const
-{
-	return mRenderTool->GetStereoType();
+	return 	mRenderTool->GetStereoMode();
 }
 
 
@@ -1875,7 +1859,7 @@ void iViewModule::ForceCrossSectionToUsePolygonalMethod(bool s)
 {
 	int k;
 
-	for(k=0; k<=mViewObjectFamilies[_ObjectTypeCrossSection]->GetMaxMemberIndex(); k++)
+	for(k=0; k<=mViewObjectFamilies[ViewSubject::Id::CrossSection]->GetMaxMemberIndex(); k++)
 	{
 		this->GetCrossSectionViewSubject(k)->ForcePolygonalMethod(s);
 	}
@@ -1890,7 +1874,7 @@ iMarker* iViewModule::GetMarker(int n) const
 
 iViewObject* iViewModule::GetParticlesObject(int n) const
 { 
-	return (n==-1) ? mViewObjectFamilies[_ObjectTypeParticles]->GetCurrentMember() : mViewObjectFamilies[_ObjectTypeParticles]->GetMember(n); 
+	return (n==-1) ? mViewObjectFamilies[ViewSubject::Id::Particles]->GetCurrentMember() : mViewObjectFamilies[ViewSubject::Id::Particles]->GetMember(n); 
 }
 
 
