@@ -35,7 +35,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iarray.h"
 #include "imath.h"
-#include "iparameter.h"
 #include "istereoimagearray.h"
 
 
@@ -87,6 +86,35 @@ class vtkRenderWindowInteractor;
 class vtkTimerLog;
 
 
+namespace iParameter
+{
+	namespace ImageType
+	{
+		const int Snapshot =		0;
+		const int AnimationFrame =	1;
+	};
+
+	namespace InteractorStyle
+	{
+		const int Trackball =	0;
+		const int Joystick =	1;
+		const int Flight =		2;
+		const int Keyboard =	3;
+		const int SIZE =		4;
+	};
+
+	namespace BoundingBoxType
+	{
+		const int Default =		0;
+		const int Classic =		1;
+		const int HairThin =	2;
+		const int Axes =		3;
+
+		inline bool IsValid(int m){ return m>=0 && m<=3; }
+	};
+};
+
+
 //
 //  helper macros
 //
@@ -127,8 +155,7 @@ public:
 	IOBJECT_DECLARE_GETSET2(RulerScale,float);
 	IOBJECT_DECLARE_GETSET2(RulerTitle,const iString&);
 	IOBJECT_DECLARE_GETSET2(OpenGLCoordinates,bool);
-	IOBJECT_DECLARE_GETSET2(Stereo,bool);
-	IOBJECT_DECLARE_GETSET2(StereoType,int);
+	IOBJECT_DECLARE_GETSET2(StereoMode,int);
 	IOBJECT_DECLARE_GETSET2(FontScale,int);
 	IOBJECT_DECLARE_GETSET2(FontType,int);
 	
@@ -263,8 +290,8 @@ public:
 	void RenderStereoImage(iStereoImage &image);
 	void CreateImages(iStereoImageArray &images);
 	void RenderImages(iStereoImageArray &images);
-	void DumpImages(int m = iParameter::_ImageTypeSnapshot);
-	virtual void DumpImages(const iStereoImageArray& images, int m = iParameter::_ImageTypeSnapshot);
+	void DumpImages(int m = iParameter::ImageType::Snapshot);
+	virtual void DumpImages(const iStereoImageArray& images, int m = iParameter::ImageType::Snapshot);
 
 	void UpdateLabel(float *v = 0);
 	void UpdateIcon();
@@ -392,7 +419,7 @@ private:
 	iWriter *mWriter;
 	iClipPlane *mClipPlane;
 
-	vtkInteractorStyle *mInteractorStyle[iParameter::__NumInteractorStyles];
+	vtkInteractorStyle *mInteractorStyle[iParameter::InteractorStyle::SIZE];
 	iCaptionInteractorStyle *mInteractorStyleCaption;
 
 	//
