@@ -46,7 +46,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iarraytemplate.h"
 
 
-#include "iparameter.h"
 using namespace iParameter;
 
 
@@ -70,9 +69,9 @@ IOBJECT_DEFINE_KEY(iViewSubject,Visible,vis,Bool,1);
 IOBJECT_DEFINE_POSITION_KEY(iViewSubject,Position,x);
 
 
-iViewSubject::iViewSubject(iViewModule *vm, const iDataType &type, const iString &name, unsigned int flags) : iObject(name), iDataConsumer(vm,type), mObjectName(name), mPosition(vm), mAlwaysShaded((flags&_ViewSubjectAlwaysShaded)!=0U), mNoReplicating((flags&_ViewSubjectNoReplicating)!=0U), mHasPosition((flags&_ViewSubjectHasPosition)!=0U), iReplicatedElement(false)
+iViewSubject::iViewSubject(iViewModule *vm, const iDataType &type, const iString &name, unsigned int flags) : iObject(name), iDataConsumer(vm,type), mSubjectName(name), mPosition(vm), mAlwaysShaded((flags&ViewSubject::Flag::AlwaysShaded)!=0U), mNoReplicating((flags&ViewSubject::Flag::NoReplicating)!=0U), mHasPosition((flags&ViewSubject::Flag::HasPosition)!=0U), iReplicatedElement(false)
 {
-	mObjectType = _ObjectTypeUndefined;
+	mSubjectId = ViewSubject::Id::Undefined;
 
 	mIsInitialized = mIsConfigured = false;
 
@@ -522,7 +521,7 @@ void iViewSubject::SetPosition(int location, bool detach)
 {
 	switch(location)
 	{
-	case _LocationPickedPoint:
+	case ViewSubject::Location::PickedPoint:
 		{
 			if(!this->GetViewModule()->GetPicker()->GetObjectName().IsEmpty())
 			{
@@ -530,12 +529,12 @@ void iViewSubject::SetPosition(int location, bool detach)
 			}
 			break;
 		}
-	case _LocationFocalPoint:
+	case ViewSubject::Location::FocalPoint:
 		{
 			this->SetPosition(this->GetViewModule()->GetRenderTool()->GetCamera()->GetFocalPoint(),detach);
 			break;
 		}
-	case _LocationBoxCenter:
+	case ViewSubject::Location::BoxCenter:
 		{
 			iPosition p(this->GetViewModule());
 			p[0] = p[1] = p[2] = 0.0;
