@@ -60,16 +60,16 @@ iViewSubjectObserver::~iViewSubjectObserver()
 }
 
 
-int iViewSubjectObserver::GetObjectType() const
+int iViewSubjectObserver::GetSubjectId() const
 {
-	if(mSubject != 0) return mSubject->GetObjectType(); else return _ObjectTypeUndefined;
+	if(mSubject != 0) return mSubject->GetSubjectId(); else return ViewSubject::Id::Undefined;
 }
 
 
-const iString& iViewSubjectObserver::GetObjectName() const
+const iString& iViewSubjectObserver::GetSubjectName() const
 {
 	static const iString none("Unknown");
-	if(mSubject != 0) return mSubject->GetObjectName(); else return none;
+	if(mSubject != 0) return mSubject->GetSubjectName(); else return none;
 }
 
 
