@@ -57,8 +57,8 @@ public:
 	static iViewSubjectObserver* New(iViewSubject *vo = 0);
 
 	iViewSubject* GetSubject() const { return mSubject; }
-	int GetObjectType() const;
-	const iString& GetObjectName() const;
+	int GetSubjectId() const;
+	const iString& GetSubjectName() const;
 	const iDataType& GetDataType() const;
 
 	virtual void SetIsoSurfaceData(const IsoSurfaceData &val) { mIsoSurfaceData = val; }
