@@ -237,7 +237,12 @@ void iViewSubjectParallelPipeline::ProduceOutput()
 	//
 	//  Do we need to re-distribute the data?
 	//
-	if(mWorkPipelines.Size()!=this->GetManager()->GetNumberOfProcessors() || input->GetMTime()>this->mConfigureTime)// || this->GetMTime()>this->mConfigureTime) // the latter is needed when DataTypes are changed
+	bool redo = (mWorkPipelines.Size() != this->GetManager()->GetNumberOfProcessors());
+	for(j=0; !redo && j<this->GetNumberOfInputs(); j++) 
+	{
+		if(this->GetInputs()[j]->GetMTime() > this->mConfigureTime) redo = true;
+	}
+	if(redo)
 	{
 		this->ConfigurePipelines(input);
 	}
