@@ -93,11 +93,7 @@ void iViewSubjectPipeline::RemoveInternalData(bool keepOutputs)
 	int i, j;
 	for(i=0; i<mInternalFilters.Size(); i++)
 	{
-#ifdef IVTK_44
-		for(j=0; j<mInternalFilters[i]->GetNumberOfOutputs(); j++) mInternalFilters[i]->GetOutputs()[j]->Initialize();
-#else
 		for(j=0; j<mInternalFilters[i]->GetNumberOfOutputPorts(); j++) mInternalFilters[i]->GetOutputDataObject(j)->Initialize();
-#endif
 	}
 	if(!keepOutputs)
 	{
