@@ -95,7 +95,7 @@ protected:
 	virtual void RemoveInternalDataForExtraComponents(bool keepOutputs);
 
 	vtkDataSet *mGlobalInput;
-	iSearchableArray<ivtkFilter*> mInternalFilters;
+	iSearchableArray<vtkAlgorithm*> mInternalFilters;
 };
 
 #endif  // IVIEWSUBJECTPIPELINE_H
