@@ -42,6 +42,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ifunctionmapping.h"
 #include "ihistogrammaker.h"
 #include "ipalette.h"
+#include "ipaletteset.h"
 #include "ipiecewisefunction.h"
 #include "ireplicatedgriddata.h"
 #include "ireplicatedvolume.h"
@@ -51,18 +52,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <vtkToolkits.h>
 
+#include <vtkFixedPointVolumeRayCastMapper.h> 
 #include <vtkStructuredPoints.h>
 #include <vtkVolumeProperty.h>
 #include <vtkVolumeRayCastCompositeFunction.h>
 #include <vtkVolumeRayCastMIPFunction.h>
 #include <vtkVolumeRayCastMapper.h>
-#include <vtkVolumeTextureMapper2D.h>
-
-#ifndef IVTK_44
-#include <vtkFixedPointVolumeRayCastMapper.h> 
 //#include <vtkVolumeShearWarpMapper.h> 
+#include <vtkVolumeTextureMapper2D.h>
 #include <vtkVolumeTextureMapper3D.h>
-#endif
 
 //
 //  Allow for the IFrIT own support for VolumePro1000
@@ -141,9 +139,6 @@ namespace iVolumeViewSubject_Private
 			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
 			mMapper->IntermixIntersectingGeometryOn();
 			mMapper->AutoAdjustSampleDistancesOn();
-#ifdef IVTK_44
-			mMapper->UseImageClipperOff();
-#endif
 			mMapper->SetInput(input);
 
 			mCF = vtkVolumeRayCastCompositeFunction::New(); IERROR_ASSERT(mCF);
@@ -211,9 +206,6 @@ namespace iVolumeViewSubject_Private
 		{
 			mMapper = vtkVolumeTextureMapper2D::New(); IERROR_ASSERT(mMapper);
 			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
-#ifdef IVTK_44
-			mMapper->UseImageClipperOff();
-#endif
 			mMapper->SetInput(input);
 		}
 
@@ -229,9 +221,7 @@ namespace iVolumeViewSubject_Private
 
 		virtual void SetBlendMode(int m)
 		{
-#ifndef IVTK_44
 			mMapper->SetBlendMode(m);
-#endif
 		}
 
 	private:
@@ -240,7 +230,6 @@ namespace iVolumeViewSubject_Private
 	};
 
 
-#ifndef IVTK_44
 	class Texture3DHelper : public UniformGridVolumeRenderingHelper
 	{
 
@@ -391,7 +380,6 @@ namespace iVolumeViewSubject_Private
 		vtkVolumeShearWarpMapper *mMapper;
 	};
 */
-#endif
 
 
 #ifdef VTK_USE_VOLUMEPRO
@@ -406,9 +394,6 @@ namespace iVolumeViewSubject_Private
 			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
 			mMapper->IntermixIntersectingGeometryOn();
 			mMapper->SuperSamplingOn();
-#ifdef IVTK_44
-			mMapper->UseImageClipperOff();
-#endif
 			mMapper->SetInput(input);
 		}
 
@@ -458,7 +443,7 @@ using namespace iVolumeViewSubject_Private;
 // 
 iVolumeViewSubject::iVolumeViewSubject(iViewModule *vm, const iDataType &type, const iString &name) : iViewSubject(vm,type,name,0U)
 {
-	mObjectType = _ObjectTypeVolume;
+	mSubjectId = ViewSubject::Id::Volume;
 
 	mVar = 0;
 	mPalette = 1;
@@ -477,7 +462,7 @@ iVolumeViewSubject::iVolumeViewSubject(iViewModule *vm, const iDataType &type, c
 	
 	mVolume->GetProperty()->SetShade(mShading?1:0);
 	mVolume->GetProperty()->SetScalarOpacity(mOpacityFunction->GetVTKFunction());
-	mVolume->GetProperty()->SetColor(this->GetViewModule()->GetControlModule()->GetPalette(iMath::Abs(mPalette)-1)->GetColorTransferFunction(mPalette < 0));
+	mVolume->GetProperty()->SetColor(iPaletteSet::Default()->GetColorTransferFunction(1));
 	mVolume->GetProperty()->SetInterpolationTypeToLinear();
 	this->UpdateMaterialProperties();
 	
@@ -526,16 +511,12 @@ void iVolumeViewSubject::ConfigureBody()
 	//
 	m = new RayCastHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
 
-#ifndef IVTK_44
 	m = new FixedPointRayCastHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
 //	m = new ShearWarpRayCastHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
 	mMethod = 2;
-#endif
 
 	m = new Texture2DHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
-#ifndef IVTK_44
 	m = new Texture3DHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
-#endif
 #ifdef VTK_USE_VOLUMEPRO
 	m = new VolumeProHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
 #endif
@@ -586,7 +567,7 @@ void iVolumeViewSubject::ShowClipPlane(bool s)
 void iVolumeViewSubject::ShowColorBars(bool show)
 {
 	if(!this->IsVisible()) return;
-	this->GetViewModule()->GetColorBars()->ShowBar(_ColorBarsPriorityVolume,mVar,this->GetDataType(),mPalette,show);
+	this->GetViewModule()->GetColorBars()->ShowBar(ColorBarsPriority::Volume,mVar,this->GetDataType(),mPalette,show);
 	this->ClearCache();
 }
 
@@ -622,12 +603,14 @@ void iVolumeViewSubject::UpdateVar()
 
 void iVolumeViewSubject::SetPalette(int p)
 { 
-	if(p!=0 && p>=-this->GetViewModule()->GetControlModule()->GetNumberOfPalettes() && p<=this->GetViewModule()->GetControlModule()->GetNumberOfPalettes())
+	vtkColorTransferFunction *ctf = iPaletteSet::Default()->GetColorTransferFunction(p);
+
+	if(ctf != 0)
 	{
 		this->ShowColorBars(false);
 		mPalette = p;
 		this->ShowColorBars(true);
-		mVolume->GetProperty()->SetColor(this->GetViewModule()->GetControlModule()->GetPalette(iMath::Abs(mPalette)-1)->GetColorTransferFunction(mPalette < 0));
+		mVolume->GetProperty()->SetColor(ctf);
 		this->ClearCache();
 	}
 }
