@@ -44,9 +44,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkPNMWriter.h>
 #include <vtkTIFFWriter.h>
 
-#ifndef IVTK_44
-
-#include "vtkGenericMovieWriter.h"
+#include <vtkGenericMovieWriter.h>
 
 #ifdef IVTK_SUPPORTS_AVI
 #include <vtkAVIWriter.h>
@@ -56,11 +54,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkMPEG2Writer.h>
 #endif
 
-#else
-
-class vtkGenericMovieWriter;
-
-#endif
 
 //
 //  Templates
@@ -101,7 +94,6 @@ public:
 
 	void Finish()
 	{
-#ifndef IVTK_44
 		int i;
 
 		for(i=0; i<mImageWriters.Size(); i++) if(mImageWriters[i]->GetInput() != 0)
@@ -113,7 +105,6 @@ public:
 				return;
 			}
 		}
-#endif
 		mStarted = false;
 	}
 
@@ -127,9 +118,7 @@ protected:
 
 	virtual ~iGenericMultiImageMovieWriter()
 	{
-#ifndef IVTK_44
 		while(mImageWriters.Size() > 0) mImageWriters.RemoveLast()->Delete();
-#endif
 	}
 
 	virtual vtkGenericMovieWriter* CreateWriter() const = 0;  // factory method
@@ -214,7 +203,6 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 {
 	if(mStarted)
 	{
-#ifndef IVTK_44
 		while(2*images.Size() < mImageWriters.Size()) mImageWriters.RemoveLast()->Delete();
 		while(2*images.Size() > mImageWriters.Size())
 		{
@@ -247,11 +235,9 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 				mImageWriters[i+1]->SetInput(0);
 			}
 		}
-#endif
 		mStarted = false;
 	}
 
-#ifndef IVTK_44
 	if(!mStarted && 2*images.Size()!=mImageWriters.Size())
 	{
 		IERROR_LOW("Unable to write a movie file: different frames have varied number of images.");
@@ -281,7 +267,6 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 			}
 		}
 	}
-#endif
 }
 
 
@@ -319,33 +304,33 @@ iWriter::~iWriter()
 
 void iWriter::SetImageFormat(int i)
 {
-	if(i>=0 && i<__NumImageFormats && i!=mImageFormat)
+	if(ImageFormat::IsValid(i) && i!=mImageFormat)
 	{
 		mImageFormat = i;
 		if(mImageWriter != 0) mImageWriter->Delete();
 		switch(mImageFormat) 
 		{
-		case _ImageFormatJPG:
+		case ImageFormat::JPG:
 			{
 				mImageWriter = vtkJPEGWriter::New(); IERROR_ASSERT(mImageWriter); 
 				break;
 			}
-		case _ImageFormatPNM:
+		case ImageFormat::PNM:
 			{
 				mImageWriter = vtkPNMWriter::New(); IERROR_ASSERT(mImageWriter); 
 				break;
 			}
-		case _ImageFormatBMP:
+		case ImageFormat::BMP:
 			{
 				mImageWriter = vtkBMPWriter::New(); IERROR_ASSERT(mImageWriter); 
 				break;
 			}
-		case _ImageFormatTIF:
+		case ImageFormat::TIF:
 			{
 				mImageWriter = vtkTIFFWriter::New(); IERROR_ASSERT(mImageWriter); 
 				break;
 			}
-		case _ImageFormatEPS:
+		case ImageFormat::EPS:
 			{
 				iPostScriptWriter *p = iPostScriptWriter::New(); IERROR_ASSERT(p);
 				p->SetPaperFormat(mPostScriptPaperFormat);
@@ -370,11 +355,8 @@ void iWriter::SetImageFormat(int i)
 
 void iWriter::SetAnimationOutput(int i)
 {
-	if(i>=0 && i<__NumAnimationOutputs && i!=mAnimationOutput)
+	if(AnimationOutput::IsValid(i) && i!=mAnimationOutput)
 	{
-#ifdef IVTK_44
-		mAnimationOutput = 0;
-#else
 		mAnimationOutput = i;
 		if(mMovieWriter != 0)
 		{
@@ -384,14 +366,14 @@ void iWriter::SetAnimationOutput(int i)
 		switch(mAnimationOutput)
 		{
 #ifdef IVTK_SUPPORTS_MPEG
-		case _AnimationOutputMPEG2:
+		case AnimationOutput::MPEG2:
 			{
 				mMovieWriter = MultiImageMovieWriter<vtkMPEG2Writer>::New(this->GetViewModule(),"mpg"); IERROR_ASSERT(mMovieWriter);
 				break;
 			}
 #endif
 #ifdef IVTK_SUPPORTS_AVI
-		case _AnimationOutputAVI:
+		case AnimationOutput::AVI:
 			{
 				mMovieWriter = MultiImageMovieWriter<vtkAVIWriter>::New(this->GetViewModule(),"avi"); IERROR_ASSERT(mMovieWriter);
 				break;
@@ -405,7 +387,6 @@ void iWriter::SetAnimationOutput(int i)
 				mAnimationOutput = 0;
 			}
 		}
-#endif
 		this->GetViewModule()->ClearCache();
 	}
 }
@@ -417,7 +398,7 @@ void iWriter::SetPostScriptPaperFormat(int i)
 	{
 		mPostScriptPaperFormat = i;
 		this->GetViewModule()->ClearCache();
-		if(mImageFormat == _ImageFormatEPS) iRequiredCast<iPostScriptWriter>(INFO,mImageWriter)->SetPaperFormat(i);
+		if(mImageFormat == ImageFormat::EPS) iRequiredCast<iPostScriptWriter>(INFO,mImageWriter)->SetPaperFormat(i);
 	}
 }
 
@@ -428,7 +409,7 @@ void iWriter::SetPostScriptOrientation(int i)
 	{
 		mPostScriptOrientation = i;	
 		this->GetViewModule()->ClearCache();
-		if(mImageFormat == _ImageFormatEPS) iRequiredCast<iPostScriptWriter>(INFO,mImageWriter)->SetOrientation(i);
+		if(mImageFormat == ImageFormat::EPS) iRequiredCast<iPostScriptWriter>(INFO,mImageWriter)->SetOrientation(i);
 	}
 }
 
@@ -459,13 +440,13 @@ void iWriter::WriteFrame(const iStereoImageArray& images, int mode)
 	
 	switch(mode) 
 	{
-	case _ImageTypeSnapshot:
+	case ImageType::Snapshot:
 		{
 			root = mCurrentSnapshotImageFilePrefix;
 			cur = &mCurrentSnapshotImageIndex;
 			break;
 		}
-	case _ImageTypeAnimationFrame:
+	case ImageType::AnimationFrame:
 		{
 			root = mCurrentAnimationImageFilePrefix;
 			cur = &mCurrentAnimationImageIndex;
@@ -478,10 +459,10 @@ void iWriter::WriteFrame(const iStereoImageArray& images, int mode)
 		}
 	}
 
-	path = this->GetViewModule()->GetControlModule()->GetShell()->GetEnvironment(_EnvironmentImage);
+	path = this->GetViewModule()->GetControlModule()->GetShell()->GetEnvironment(Environment::Image);
 	root += iString::FromNumber(*cur,"-%05d");
 
-	if(mode==_ImageTypeSnapshot || mMovieWriter==0)
+	if(mode==ImageType::Snapshot || mMovieWriter==0)
 	{
 		this->WriteImageFrame(images,path,root);
 		(*cur)++;
@@ -500,11 +481,11 @@ void iWriter::WriteImageFrame(const iStereoImageArray& images, const iString &pa
 
 	switch(mImageFormat) 
 	{
-	case _ImageFormatJPG: { suf = ".jpg"; break; }
-	case _ImageFormatPNM: { suf = ".ppm"; break; }
-	case _ImageFormatBMP: { suf = ".bmp"; break; }
-	case _ImageFormatTIF: { suf = ".tif"; break; }
-	case _ImageFormatEPS: { suf = ".eps"; break; }
+	case ImageFormat::JPG: { suf = ".jpg"; break; }
+	case ImageFormat::PNM: { suf = ".ppm"; break; }
+	case ImageFormat::BMP: { suf = ".bmp"; break; }
+	case ImageFormat::TIF: { suf = ".tif"; break; }
+	case ImageFormat::EPS: { suf = ".eps"; break; }
 	default:			  { suf = ".png"; }
 	}
 	
