@@ -47,6 +47,30 @@ class iViewModule;
 
 class vtkImageWriter;
 
+namespace iParameter
+{
+	namespace ImageFormat
+	{
+		const int PNG =		0;
+		const int JPG =		1;
+		const int PNM =		2;
+		const int BMP =		3;
+		const int TIF =		4;
+		const int EPS =		5;
+
+		inline bool IsValid(int m){ return m>=0 && m<=5; }
+	};
+
+	namespace AnimationOutput
+	{
+		const int Image =	0;
+		const int MPEG2 =	1;
+		const int AVI   =	2;
+
+		inline bool IsValid(int m){ return m>=0 && m<=2; }
+	};
+};
+
 
 class iWriter : public vtkObjectBase
 {
