@@ -241,7 +241,7 @@ namespace iHelpFactory_Private
 				//
 				//  Not a reference, compress
 				//
-				usize = strlen(data[i].Buffer);
+				usize = int(strlen(data[i].Buffer));
 				cmax = dataCompressor->GetMaximumCompressionSpace(usize);
 				csize = dataCompressor->Compress((const unsigned char *)data[i].Buffer,usize,(unsigned char*)ws.GetWritePointer(cmax),cmax);
 
@@ -406,7 +406,7 @@ iHelpDataBuffer::iHelpDataBuffer(iHelpData &data, bool null) : mData(data), mNul
 		//
 		//  Uncompressed data, set the length
 		//
-		mData.Length = strlen(mData.Buffer);
+		mData.Length = int(strlen(mData.Buffer));
 	}
 }
 
