@@ -86,10 +86,12 @@ public:
 	virtual void SetTabMode(int n, int m, const iString &title, const iImage *image) = 0;
 	virtual int GetTabMode() = 0;
 	virtual void ChangeIcon(int n, const iImage &image) = 0;
+	virtual void SetOrientation(int v) = 0;
+	virtual int GetOrientation() = 0;
 
 protected:
 
-	ibgFrameBookSubject(iggFrameBook *owner, bool withFeedback, bool tabsOnTop);
+	ibgFrameBookSubject(iggFrameBook *owner, bool withFeedback);
 };
 
 
