@@ -62,13 +62,16 @@ protected:
 	virtual void SetFullScreen(bool) = 0;
 	virtual void MakeCurrent() = 0;
 
-	virtual void* GetGenericWindowId() const = 0;
+	virtual void* GetDisplayId() const = 0;
+	virtual void* GetWindowId() const = 0;
 	virtual void SetWindowName(const iString &s) = 0;
 
 	virtual void RenderIntoMemory(iImage &) = 0;
 	virtual bool IsReadyForDumpingImage() = 0;
 
-	virtual bool IsCurrent() = 0;
+	virtual bool IsCurrent() const = 0;
+
+	virtual void RequestStereo(bool s) = 0;
 
 	//
 	//  Render the scene
