@@ -35,6 +35,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetsubject.h"
 
 
+#include <vtkType.h>
+
 class iString;
 
 class iggWidget;
@@ -64,7 +66,7 @@ public:
 
 	virtual void SetValue(int v) = 0;
 	virtual void SetValue(int v, double dv) = 0;
-	virtual void SetValue(int v, unsigned long lv) = 0;
+	virtual void SetValue(int v, vtkIdType lv) = 0;
 	virtual void SetNumberOfTicks(int n) = 0;
 	virtual void SetRange(int smin, int smax, int pagestep = 0) = 0;
 	virtual void SetText(const iString &text) = 0;
