@@ -53,15 +53,15 @@ void ibgWidgetTextEditorSubject::OnTextChangedBody()
 }
 
 
-void ibgWidgetTextEditorSubject::OnSelectionChangedBody(int paraFrom, int indexFrom, int paraTo, int indexTo)
+void ibgWidgetTextEditorSubject::OnSelectionChangedBody(int lineFrom, int indexFrom, int lineTo, int indexTo)
 {
-	mConcreteOwner->OnSelectionChanged(paraFrom,indexFrom,paraTo,indexTo);
+	mConcreteOwner->OnSelectionChanged(lineFrom,indexFrom,lineTo,indexTo);
 }
 
 
-void ibgWidgetTextEditorSubject::OnCursorPositionChangedBody(int para, int index)
+void ibgWidgetTextEditorSubject::OnCursorPositionChangedBody(int line, int index)
 {
-	mConcreteOwner->OnCursorPositionChanged(para,index);
+	mConcreteOwner->OnCursorPositionChanged(line,index);
 }
 
 
@@ -71,15 +71,15 @@ void ibgWidgetTextEditorSubject::OnReturnPressedBody()
 }
 
 
-//void ibgWidgetTextEditorSubject::OnMousePressBody(int para, int index)
+//void ibgWidgetTextEditorSubject::OnMousePressBody(int line, int index)
 //{
-//	mConcreteOwner->OnMousePress(para,index);
+//	mConcreteOwner->OnMousePress(line,index);
 //}
 
 
-//void ibgWidgetTextEditorSubject::OnMouseReleaseBody(int para, int index)
+//void ibgWidgetTextEditorSubject::OnMouseReleaseBody(int line, int index)
 //{
-//	mConcreteOwner->OnMouseRelease(para,index);
+//	mConcreteOwner->OnMouseRelease(line,index);
 //}
 
 #endif
