@@ -39,7 +39,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 int ibgWindowHelper::mFontOffset = 0; // default value
 
 
-ibgWindowHelper::ibgWindowHelper(const iImage *icon, const iString &title) : mIcon(icon), mTitle(title)
+ibgWindowHelper::ibgWindowHelper(const iImage *icon, const iString &title, bool disableClose) : mIcon(icon), mTitle(title), mDisableClose(disableClose)
 {
 	mSavedGeometry[0] = mSavedGeometry[1] = 100;
 	mSavedGeometry[2] = mSavedGeometry[3] = 0;
