@@ -68,19 +68,20 @@ public:
 	virtual void ShowAsWindow() = 0;
 	virtual void ShowAsIcon() = 0;
 
-	virtual void RestoreIcon() = 0;
+	virtual void RestoreDecoration() = 0;
 
 	inline static int GetFontOffset(){ return mFontOffset; }
 
 protected:
 
-	ibgWindowHelper(const iImage *icon, const iString &title);
+	ibgWindowHelper(const iImage *icon, const iString &title, bool disableClose);
 
 	static void ChangeFontSize(int s);
 
 	const iImage *mIcon;
 	const iString &mTitle;
 
+	bool mDisableClose;
 	int mSavedGeometry[4];
 
 	static int mFontOffset;
