@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "istring.h"
 
 
-#ifndef I_NO_CONSOLEIO
+#ifndef I_NO_CONSOLE_IO
 #ifdef _WIN32
 #include <conio.h>
 #define getch() _getch()
@@ -85,7 +85,7 @@ void iclControlScript::OutputText(const iString &s0) const
 		{
 			cout << "Press <Enter> to continue...";
 			cout.flush();
-#ifndef I_NO_CONSOLEIO
+#ifndef I_NO_CONSOLE_IO
 			getch();
 			cout << "\r                            \r";
 #else
