@@ -93,7 +93,7 @@ void iggExtensionFrameBook::Block(bool s)
 
 void iggExtensionFrameBook::OnInt1Body(int i)
 {
-	if(!iRequiredCast<iggShell>(INFO,this->GetShell())->CheckCondition(iggParameter::_ConditionSlowRemoteConnection) && !mBlocked && i>=0 && i<mPages.Size() && mPages[i].Index>=0)
+	if(!iRequiredCast<iggShell>(INFO,this->GetShell())->CheckCondition(iParameter::Condition::SlowRemoteConnection) && !mBlocked && i>=0 && i<mPages.Size() && mPages[i].Index>=0)
 	{
 		mBlocked = true; // avoid loops
 		this->GetMainWindow()->OpenBookPage(mPages[i].Index);
