@@ -35,9 +35,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "icommandinterpreter.h"
 #include "ierror.h"
-#include "iparameter.h"
 #include "istring.h"
 
+
 using namespace iParameter;
 
 
@@ -68,7 +68,7 @@ void iggControlScript::OutputText(const iString &s) const
 {
 	if(mCommandInterpreter != 0)
 	{
-		mCommandInterpreter->DislayLineOfText(s,_CommandInterpreterTextTypeResult);
+		mCommandInterpreter->DislayLineOfText(s,CommandInterpreterType::Result);
 	}
 	else
 	{
@@ -83,7 +83,7 @@ void iggControlScript::OutputError(const iString &s) const
 {
 	if(mCommandInterpreter != 0)
 	{
-		mCommandInterpreter->DislayLineOfText(s,_CommandInterpreterTextTypeError);
+		mCommandInterpreter->DislayLineOfText(s,CommandInterpreterType::Error);
 	}
 	else
 	{
