@@ -32,9 +32,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IGGDATATYPEPROVIDER_H
 
 
-#include "ishellcomponent.h"
+#include "iggelement.h"
 
 
+#include "iarray.h"
+
 class iDataInfo;
 class iDataType;
 class iObjectKey;
@@ -44,7 +46,7 @@ class iggPageObject;
 class iggWidget;
 
 
-class iggDataTypeProvider : protected iShellComponent
+class iggDataTypeProvider : public iggElement
 {
 
 public:
@@ -91,8 +93,8 @@ public:
 	iggKeywordDataTypeProvider(const iString &keywords, iggWidget *parent);
 	virtual ~iggKeywordDataTypeProvider();
 
-	void FindAvailableData();
-	bool IsThereDataType() const;
+	virtual void FindAvailableData();
+	virtual bool IsThereDataType() const;
 
 	virtual int GetActiveDataTypeIndex() const;
 	virtual void SetActiveDataTypeIndex(int v);
@@ -107,6 +109,36 @@ protected:
 };
 
 
+class iggCompositeDataTypeProvider : public iggKeywordDataTypeProvider
+{
+
+public:
+
+	iggCompositeDataTypeProvider(iggWidget *parent);
+	virtual ~iggCompositeDataTypeProvider();
+
+	void AddProvider(iggKeywordDataTypeProvider *p);
+	void SetCurrentIndex(int n);
+	inline int GetCurrentIndex() const { return mCurrentIndex; }
+	inline int GetNumberOfProviders() const { return mProviders.Size(); }
+	iggKeywordDataTypeProvider* GetCurrentProvider() const;
+	iggKeywordDataTypeProvider* GetProvider(int n) const;
+
+	virtual void FindAvailableData();
+	virtual bool IsThereDataType() const;
+
+	virtual int GetActiveDataTypeIndex() const;
+	virtual void SetActiveDataTypeIndex(int v);
+	virtual const iDataInfo& GetDataInfo() const;
+	virtual const iDataType& GetActiveDataType() const;
+
+protected:
+
+	int mCurrentIndex;
+	iArray<iggKeywordDataTypeProvider*> mProviders;
+};
+
+
 class iggViewSubjectDataTypeProvider : public iggDataTypeProvider
 {
 
@@ -126,13 +158,12 @@ protected:
 };
 
 
-class iggScalarFieldDataTypeProvider : public iggViewSubjectDataTypeProvider
+class iggScalarDataTypeProvider : public iggViewSubjectDataTypeProvider
 {
 
 public:
 
-	iggScalarFieldDataTypeProvider(iggPageObject *page);
-	virtual ~iggScalarFieldDataTypeProvider();
+	iggScalarDataTypeProvider(iggPageObject *page);
 
 	virtual const iDataInfo& GetDataInfo() const;
 	virtual const iDataType& GetActiveDataType() const;
