@@ -50,6 +50,22 @@ class ibgDialogSubject;
 class ibgWindowSubject;
 
 
+namespace iParameter
+{
+	//
+	//  Dialog modes masks
+	//
+	namespace DialogFlag
+	{
+		const unsigned int Blocking = 1U;
+		const unsigned int WithEventLoop = 2U;
+		const unsigned int Modal = 3U;
+		const unsigned int NoTitleBar = 4U;
+		const unsigned int Unattached = 8U;
+	};
+};
+
+
 class iggDialog : public iggElement
 {
 
