@@ -53,8 +53,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetbuttonsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
+
+
+using namespace iParameter;
 
 
 namespace iggDialogAnimatingProgress_Private
@@ -114,7 +115,7 @@ namespace iggDialogAnimatingProgress_Private
 using namespace iggDialogAnimatingProgress_Private;
 
 
-iggDialogAnimatingProgress::iggDialogAnimatingProgress(iggMainWindow *parent) : iggDialog(parent,_DialogBlocking|_DialogNoTitleBar,0,"Animating...",0,4,0), iScriptObserver(0)
+iggDialogAnimatingProgress::iggDialogAnimatingProgress(iggMainWindow *parent) : iggDialog(parent,DialogFlag::Blocking|DialogFlag::NoTitleBar,0,"Animating...",0,4,0), iScriptObserver(0)
 {
 	mFrame->AddLine(new iggWidgetTextArea("%bAnimating the scene...",mFrame),4);
 	
