@@ -66,7 +66,7 @@ void iggDialogAuto::Show(bool s)
 void iggDialogAuto::ForceShow(bool s)
 {
 	this->iggDialog::Show(s);
-	if((mMode & iggParameter::_DialogModal) == 0) this->GetMainWindow()->PlaceAutoDialogs();
+	if((mMode & iParameter::DialogFlag::Modal) == 0) this->GetMainWindow()->PlaceAutoDialogs();
 }
 
 #endif
