@@ -53,9 +53,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgettexteditorsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
+
+
 using namespace iParameter;
+using namespace iParameter;
+
 
 //
 //  Templates (needed for some compilers)
@@ -84,7 +86,7 @@ namespace iggDialogCommandLine_Private
 			mCurLine = 0;
 		}
 
-		void Compile(const iString &text0, iString &msg, int &para, int &index)
+		void Compile(const iString &text0, iString &msg, int &line, int &index)
 		{
 			iString text(text0);
 			int io = text.Length() - 1;
@@ -95,13 +97,13 @@ namespace iggDialogCommandLine_Private
 			if(!this->Script()->Compile())
 			{
 				msg = this->Script()->GetErrorStatus()->Message();
-				para = this->Script()->GetThisLine();
+				line = this->Script()->GetThisLine();
 				index = this->Script()->GetErrorPosition();
 			}
 			else 
 			{
 				msg.Clear();
-				para = -1;
+				line = -1;
 				index = 0;
 			}
 		}
@@ -126,7 +128,7 @@ namespace iggDialogCommandLine_Private
 				iString w(mCurCode.Section("\n",i,i));
 				w.Replace("<","&lt;");
 				w.Replace(">","&gt;");
-				this->DislayLineOfText("<nobr><b>"+w+"</b></nobr>",_CommandInterpreterTextTypeCode);
+				this->DislayLineOfText("<nobr><b>"+w+"</b></nobr>",CommandInterpreterType::Code);
 			}
 
 			this->Exec();
@@ -151,7 +153,7 @@ namespace iggDialogCommandLine_Private
 			iString w(mCurCode);
 			w.Replace("<","&lt;");
 			w.Replace(">","&gt;");
-			this->DislayLineOfText("<nobr><b>"+w+"</b></nobr>",_CommandInterpreterTextTypeCode);
+			this->DislayLineOfText("<nobr><b>"+w+"</b></nobr>",CommandInterpreterType::Code);
 
 			this->ExecLine(mCurCode);
 
@@ -170,17 +172,17 @@ namespace iggDialogCommandLine_Private
 
 			switch(type)
 			{
-			case _CommandInterpreterTextTypeError:
+			case CommandInterpreterType::Error:
 				{
 					mBrowser->AppendTextLine(text,error);
 					break;
 				}
-			case _CommandInterpreterTextTypeResult:
+			case CommandInterpreterType::Result:
 				{
 					mBrowser->AppendTextLine(text,result);
 					break;
 				}
-			case _CommandInterpreterTextTypeCode:
+			case CommandInterpreterType::Code:
 				{
 					mBrowser->AppendTextLine(text,code);
 					break;
@@ -278,19 +280,19 @@ namespace iggDialogCommandLine_Private
 
 		void OnReturnPressed()
 		{
-			int para, index;
+			int line, index;
 
-			mSubject->GetCursorPosition(para,index);
+			mSubject->GetCursorPosition(line,index);
 
-			if(para > 0)
+			if(line > 0)
 			{
-				iString s = this->GetLine(para-1);
+				iString s = this->GetLine(line-1);
 				s.ReduceWhiteSpace();
 				if(s[s.Length()-1] == ';')
 				{
 					s.Clear();
 					int i, p;
-					for(i=0; i<para; i++)
+					for(i=0; i<line; i++)
 					{
 						s += this->GetLine(i) + "\n";
 					}
@@ -302,12 +304,12 @@ namespace iggDialogCommandLine_Private
 						mInterpreter->RunMultiLine(s);
 						if(mInterpreter->Script()->GetErrorStatus()->NoError())
 						{
-							for(i=0; i<para; i++) this->RemoveLine(0);
+							for(i=0; i<line; i++) this->RemoveLine(0);
 						}
 					}
 					else
 					{
-						this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),msg,_PopupWindowError);
+						this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),msg,PopupWindow::Error);
 						mSubject->Select(p,i,p,999);
 					}
 				}
@@ -483,14 +485,14 @@ namespace iggDialogCommandLine_Private
 			int i, n;
             iString fn;
 
-			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(_EnvironmentScript);
+			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(Environment::Script);
 			fn = this->GetMainWindow()->GetFileName("Save script file",mOldFileName,"Script file (*.ics)",false);
 			if(!fn.IsEmpty() && fn.Part(-4).Lower()!=".ics") fn += ".ics";
 
 			iFile f(fn);
 			if(!f.Open(iFile::_Write,iFile::_Text))
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to create a file.",_PopupWindowError);
+				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to create a file.",PopupWindow::Error);
 				return;
 			}
 
@@ -502,7 +504,7 @@ namespace iggDialogCommandLine_Private
 			{
 				if(!f.WriteLine(ws.Section("\n",i,i)))
 				{
-					this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Unable to write into a file.",_PopupWindowError);
+					this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Unable to write into a file.",PopupWindow::Error);
 					break;
 				}
 			}
@@ -522,7 +524,7 @@ namespace iggDialogCommandLine_Private
 
 	public:
 
-		ViewScriptDialog(CommandInterpreter *ci, iggDialogCommandLine *parent) : iggDialog(parent,_DialogModal,0,"View Script Text",0,3)
+		ViewScriptDialog(CommandInterpreter *ci, iggDialogCommandLine *parent) : iggDialog(parent,DialogFlag::Modal,0,"View Script Text",0,3)
 		{
 			mInterpreter = ci;
 			mBrowser = new iggWidgetTextBrowser(false,true,mFrame);
