@@ -62,8 +62,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgettexteditorsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
 
 #include <limits.h>
 
@@ -73,6 +71,9 @@ using namespace iggParameter;
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 namespace iggDialogDataExplorer_Private
 {
 	struct Variable
@@ -142,7 +143,7 @@ namespace iggDialogDataExplorer_Private
 
 	public:
 
-		VariablePropertyDialog(iggWidgetListView *list, iggWidgetHistogramArea *area, iggDialog *parent) : iggDialog(parent,_DialogModal,0,"Variable Properties",0,1)
+		VariablePropertyDialog(iggWidgetListView *list, iggWidgetHistogramArea *area, iggDialog *parent) : iggDialog(parent,DialogFlag::Modal,0,"Variable Properties",0,1)
 		{
 			mList = list;
 			mArea = area;
@@ -261,7 +262,7 @@ namespace iggDialogDataExplorer_Private
 				{
 					if(mVariables[i].Name==v.Name && mVariables[i].View==v.View && mVariables[i].Data.Type(0)==v.Data.Type(0))
 					{
-						if(this->GetMainWindow()->PopupWindow(mDataExplorer->GetFrame(),"This variables is already on the list!",_PopupWindowMessage,"Cancel","Add anyway") == 0) return; else break;
+						if(this->GetMainWindow()->PopupWindow(mDataExplorer->GetFrame(),"This variables is already on the list!",PopupWindow::Message,"Cancel","Add anyway") == 0) return; else break;
 					}
 				}
 
@@ -302,9 +303,9 @@ namespace iggDialogDataExplorer_Private
 			}
 		}
 
-		virtual void Select(int paraFrom, int paraTo)
+		virtual void Select(int lineFrom, int lineTo)
 		{
-			iggWidgetListView::Select(paraFrom,paraTo);
+			iggWidgetListView::Select(lineFrom,lineTo);
 			this->UpdateDependents();
 		}
 
@@ -661,7 +662,7 @@ namespace iggDialogDataExplorer_Private
 
 		virtual void OnMousePress(int x, int y, int b)
 		{
-			if(b != _MouseLeftButton) return;
+			if(b != MouseButton::LeftButton) return;
 
 			if(!mUnderInteraction && mInfoList!=0)
 			{
@@ -670,32 +671,32 @@ namespace iggDialogDataExplorer_Private
 				mPosY = y;
 				this->UpdateInfoList();
 				mDialog->ShowFractionInfo(true);
-				mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+				mSubject->RequestPainting(DrawMode::Foreground);
 			}
 		}
 
 		virtual void OnMouseRelease(int /*x*/, int /*y*/, int b)
 		{
-			if(b != _MouseLeftButton) return;
+			if(b != MouseButton::LeftButton) return;
 
 			if(mUnderInteraction)
 			{
 				mUnderInteraction = false;
 				mDialog->ShowFractionInfo(false);
-				mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+				mSubject->RequestPainting(DrawMode::Foreground);
 			}
 		}
 
 		virtual void OnMouseMove(int x, int y, int b)
 		{
-			if(b != _MouseLeftButton) return;
+			if(b != MouseButton::LeftButton) return;
 
 			if(mUnderInteraction)
 			{
 				mPosX = x;
 				mPosY = y;
 				this->UpdateInfoList();
-				mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+				mSubject->RequestPainting(DrawMode::Foreground);
 			}
 		}
 
@@ -750,7 +751,7 @@ namespace iggDialogDataExplorer_Private
 			{
 				if(i < n-1)
 				{
-					mSubject->Begin(ibgWidgetDrawAreaSubject::_Foreground,true);
+					mSubject->Begin(DrawMode::Foreground,true);
 				}
 				d = v[i].Explorer->GetInfo();
 				range[0] = (mDialog->ApplyStretch(d.Minimum,false)-min)/(max-min+1.0e-36f);
@@ -814,9 +815,9 @@ namespace iggDialogDataExplorer_Private
 			mAddButton = addbutton;
 		}
 
-		virtual void Select(int paraFrom, int paraTo)
+		virtual void Select(int lineFrom, int lineTo)
 		{
-			iggWidgetListView::Select(paraFrom,paraTo);
+			iggWidgetListView::Select(lineFrom,lineTo);
 			mAddButton->Enable(this->HasSelection());
 		}
 
@@ -1229,7 +1230,7 @@ iggDialogDataExplorer::iggDialogDataExplorer(iggMainWindow *parent) : iggDialog(
 {
 	iggFrame *box1, *box2, *tmp1, *tmp2;
 
-	this->SetStretch(iParameter::_StretchLog);
+	this->SetStretch(iDataStretch::Log);
 
 	mProvider = new iggKeywordDataTypeProvider("",this->GetFrame()); IERROR_ASSERT(mProvider);
 
@@ -1240,7 +1241,7 @@ iggDialogDataExplorer::iggDialogDataExplorer(iggMainWindow *parent) : iggDialog(
 	box1 = new iggFrame(tmp1,2);
 	box2 = new iggFrame(tmp1,2);
 
-	iggFrameDataTypeSelector *dts = new iggFrameDataTypeSelector(mProvider,false,"Use data",box2,_ListDataTypesWithVariables);
+	iggFrameDataTypeSelector *dts = new iggFrameDataTypeSelector(mProvider,false,"Use data",box2,ListDataTypes::WithVariables);
 	ExploredVariablesList *el = new ExploredVariablesList(this,box1);
 	AvailableVariablesList *al = new AvailableVariablesList(this,el,dts,box2);
 	tmp1->AddLine(new iggWidgetTextArea("   Shown variables",tmp1),new iggWidgetTextArea("   All variables",tmp1));
