@@ -49,8 +49,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetbuttonsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
+
+
+using namespace iParameter;
 using namespace iParameter;
 
 
@@ -83,11 +84,11 @@ namespace iggDialogEventRecorder_Private
 		virtual void Execute()
 		{
 			iString fn, oldfn = mDialog->GetEventRecorder()->GetFileName();
-			if(oldfn.IsEmpty()) oldfn = this->GetShell()->GetEnvironment(_EnvironmentBase);
+			if(oldfn.IsEmpty()) oldfn = this->GetShell()->GetEnvironment(Environment::Base);
 			fn = this->GetMainWindow()->GetFileName("Open record file",oldfn,"Event record (*.ier)",false);
 			if(!fn.IsEmpty() && fn.Part(-4).Lower()!=".ier") fn += ".ier";
 
-			if(!mDialog->SetFile(fn)) this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to open a record file.",_PopupWindowError);
+			if(!mDialog->SetFile(fn)) this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to open a record file.",PopupWindow::Error);
 		}
 
 		iggWidgetTextDisplay *mDisplay;
@@ -97,12 +98,12 @@ namespace iggDialogEventRecorder_Private
 	//
 	//  Control button
 	//
-	enum Control
+	namespace ControlMode
 	{
-		_Record,
-		_Play,
-		_Rewind,
-		_Stop
+		const int Record =	0;
+		const int Play =	1;
+		const int Rewind =	2;
+		const int Stop =	3;
 	};
 
 
@@ -111,40 +112,40 @@ namespace iggDialogEventRecorder_Private
 
 	public:
 
-		ControlButton(Control type, iggDialogEventRecorder *dialog, iggFrame *parent) : iggWidget(parent)
+		ControlButton(int type, iggDialogEventRecorder *dialog, iggFrame *parent) : iggWidget(parent)
 		{
 			mType = type;
 			mDialog = dialog;
 
 			switch(type)
 			{
-			case _Record:
+			case ControlMode::Record:
 				{
-					mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeToggleButton,"",1);
+					mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::ToggleButton,"",1);
 					mIconOn = iImageFactory::FindIcon("er_recon.png");
 					mIconOff = iImageFactory::FindIcon("er_rec.png");
 					this->SetBaloonHelp("Record");
 					break;
 				}
-			case _Play:
+			case ControlMode::Play:
 				{
-					mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeToggleButton,"",1);
+					mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::ToggleButton,"",1);
 					mIconOn = iImageFactory::FindIcon("er_playon.png");
 					mIconOff = iImageFactory::FindIcon("moveright.png");
 					this->SetBaloonHelp("Play");
 					break;
 				}
-			case _Rewind:
+			case ControlMode::Rewind:
 				{
-					mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeToolButton,"",1);
+					mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::ToolButton,"",1);
 					mIconOn = 0;
 					mIconOff = iImageFactory::FindIcon("moveleft2.png");
 					this->SetBaloonHelp("Rewind");
 					break;
 				}
-			case _Stop:
+			case ControlMode::Stop:
 				{
-					mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeToolButton,"",1);
+					mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::ToolButton,"",1);
 					mIconOn = 0;
 					mIconOff = iImageFactory::FindIcon("er_stop.png");
 					this->SetBaloonHelp("Stop");
@@ -165,7 +166,7 @@ namespace iggDialogEventRecorder_Private
 		{
 			switch(mType)
 			{
-			case _Record:
+			case ControlMode::Record:
 				{
 					if(mDialog->GetEventRecorder()->IsRecording())
 					{
@@ -180,7 +181,7 @@ namespace iggDialogEventRecorder_Private
 					this->Enable(mDialog->IsReady());
 					break;
 				}
-			case _Play:
+			case ControlMode::Play:
 				{
 					if(mDialog->GetEventRecorder()->IsPlaying())
 					{
@@ -195,12 +196,12 @@ namespace iggDialogEventRecorder_Private
 					this->Enable(mDialog->IsReady() && !mDialog->GetEventRecorder()->IsAtEnd());
 					break;
 				}
-			case _Rewind:
+			case ControlMode::Rewind:
 				{
 					this->Enable(mDialog->GetCurrentFrame()>0 && mDialog->GetEventRecorder()->IsStopped());
 					break;
 				}
-			case _Stop:
+			case ControlMode::Stop:
 				{
 					this->Enable(!mDialog->GetEventRecorder()->IsStopped());
 					break;
@@ -213,7 +214,7 @@ namespace iggDialogEventRecorder_Private
 			mDialog->SetStateChanged();
 			switch(mType)
 			{
-			case _Record:
+			case ControlMode::Record:
 				{
 					if(mButton->IsDown())
 					{
@@ -223,7 +224,7 @@ namespace iggDialogEventRecorder_Private
 					else mButton->SetDown(true);
 					break;
 				}
-			case _Play:
+			case ControlMode::Play:
 				{
 					if(mButton->IsDown())
 					{
@@ -233,14 +234,14 @@ namespace iggDialogEventRecorder_Private
 					else mButton->SetDown(true);
 					break;
 				}
-			case _Rewind:
+			case ControlMode::Rewind:
 				{
 					mDialog->GetEventRecorder()->Rewind();
 					mDialog->ResetCurrentFrame();
 					mDialog->UpdateDialog();
 					break;
 				}
-			case _Stop:
+			case ControlMode::Stop:
 				{
 					mDialog->GetEventRecorder()->Stop();
 					mDialog->UpdateDialog();
@@ -249,7 +250,7 @@ namespace iggDialogEventRecorder_Private
 			}
 		}
 
-		Control mType;
+		int mType;
 		const iImage *mIconOn, *mIconOff;
 		ibgWidgetButtonSubject *mButton;
 		iggDialogEventRecorder *mDialog;
@@ -266,7 +267,7 @@ namespace iggDialogEventRecorder_Private
 		DumpImagesCheckBox(iggDialogEventRecorder *dialog, iggFrame *parent) : iggWidget(parent)
 		{
 			mDialog = dialog;
-			mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,"Dump images while playing",1);
+			mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Dump images while playing",1);
 
 			this->SetBaloonHelp("Dump images while playing","If this box is checked, IFrIT will create images for each frame during the playback. This feature can be used to create animations by first recording all events while interactively changing the visualizatin scene, and then playing the recorded sequence of events back into a series of images.");
 		}
@@ -306,7 +307,7 @@ iggDialogEventRecorder::iggDialogEventRecorder(iggMainWindow *parent) : iggDialo
 
 	tmp = new iggFrame(mFrame,5);
 	mFrameDisplay = new iggWidgetNumberDisplay("Current frame",tmp);
-	tmp->AddLine(new ControlButton(_Record,this,tmp),new ControlButton(_Play,this,tmp),new ControlButton(_Rewind,this,tmp),new ControlButton(_Stop,this,tmp),mFrameDisplay);
+	tmp->AddLine(new ControlButton(ControlMode::Record,this,tmp),new ControlButton(ControlMode::Play,this,tmp),new ControlButton(ControlMode::Rewind,this,tmp),new ControlButton(ControlMode::Stop,this,tmp),mFrameDisplay);
 	mFrame->AddLine(tmp);
 
 	mFrame->AddLine(new DumpImagesCheckBox(this,mFrame));
@@ -384,7 +385,7 @@ void iggDialogEventRecorder::UpdateInteraction()
 		mStateChanged = false;
 		this->UpdateDialog();
 	}
-	if(mDumpImages && this->GetEventRecorder()->IsPlaying()) this->GetShell()->GetControlModule()->GetViewModule()->DumpImages(_ImageTypeAnimationFrame);
+	if(mDumpImages && this->GetEventRecorder()->IsPlaying()) this->GetShell()->GetControlModule()->GetViewModule()->DumpImages(ImageType::AnimationFrame);
 	this->GetMainWindow()->ProcessEvents();
 }
 
