@@ -52,8 +52,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgettexteditorsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
 
 //
 //  Templates (needed for some compilers)
@@ -61,6 +59,9 @@ using namespace iggParameter;
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 namespace iggDialogFileSetExplorer_Private
 {
 	class View : public iggWidgetListView
@@ -90,7 +91,7 @@ namespace iggDialogFileSetExplorer_Private
 				int i, j, n;
 				if(!mDir.Open(dr->GetLastFileSetName()))
 				{
-					this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Unable to open directory containing "+dr->GetLastFileSetName()+" file.",_PopupWindowError);
+					this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Unable to open directory containing "+dr->GetLastFileSetName()+" file.",PopupWindow::Error);
 					this->Clear();
 					mDialog->MustBeClosed();
 					return;
@@ -179,7 +180,7 @@ namespace iggDialogFileSetExplorer_Private
 		LoadAllCheckBox(iggDialogFileSetExplorer *dialog, iggFrame *parent) : iggWidget(parent)
 		{
 			mDialog = dialog;
-			mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,"Load data for all windows",1);
+			mButton = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Load data for all windows",1);
 
 			this->SetBaloonHelp("Load data for all visualization windows");
 		}
