@@ -44,8 +44,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ibgwidgetbuttonsubject.h"
 
-#include "iggparameter.h"
-using namespace iggParameter;
+
+using namespace iParameter;
 
 
 namespace iggDialogHelp_Private
@@ -88,14 +88,14 @@ namespace iggDialogHelp_Private
 
 	protected:
 
-		virtual void OnMousePress(int para, int index)
+		virtual void OnMousePress(int line, int index)
 		{
-			mBrowser->OnMousePress(-1-para,-1-index);
+			mBrowser->OnMousePress(-1-line,-1-index);
 		}
 
-		virtual void OnMouseRelease(int para, int index)
+		virtual void OnMouseRelease(int line, int index)
 		{
-			mBrowser->OnMouseRelease(-1-para,-1-index);
+			mBrowser->OnMouseRelease(-1-line,-1-index);
 		}
 
 		virtual void OnLinkFollowed(const char *tag)
