@@ -54,9 +54,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetselectionboxsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
 
 //
 //  Templates (needed for some compilers)
@@ -64,6 +61,10 @@ using namespace iParameter;
 #include "iggwidgetkeyhandlertemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
+
 namespace iggDialogImageComposer_Private
 {
 	class Area : public iggWidgetDrawArea
@@ -88,7 +89,7 @@ namespace iggDialogImageComposer_Private
 			iImageComposerForegroundWindow *fw;
 
 			mIsMovingForegroundWindow = false;
-			if(b!=_MouseLeftButton || !this->FindPosition(ic,dx,dy,x,y)) return;
+			if(b!=MouseButton::LeftButton || !this->FindPosition(ic,dx,dy,x,y)) return;
 
 			//
 			//  Find what is under mouse cursor
@@ -112,7 +113,7 @@ namespace iggDialogImageComposer_Private
 					//
 					mDialog->SetCurrentForegroundWindow(i);
 					mIsMovingForegroundWindow = true;
-					mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+					mSubject->RequestPainting(DrawMode::Foreground);
 					return;
 				}
 			}
@@ -140,7 +141,7 @@ namespace iggDialogImageComposer_Private
 
 		virtual void OnMouseRelease(int /*dx*/, int /*dy*/, int b)
 		{
-			if(b != _MouseLeftButton) return;
+			if(b != MouseButton::LeftButton) return;
 
 			if(mIsMovingForegroundWindow)
 			{
@@ -148,14 +149,14 @@ namespace iggDialogImageComposer_Private
 				iImageComposerForegroundWindow *fw = ic->GetForegroundWindow(mDialog->GetCurrentForegroundWindow());
 				fw->SetPosition(fw->GetPositionX()+mPosX-mOldPosX,fw->GetPositionY()+mPosY-mOldPosY);
 				mIsMovingForegroundWindow = false;
-				mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+				mSubject->RequestPainting(DrawMode::Foreground);
 				this->UpdateDependents();
 			}
 		}
 
 		virtual void OnMouseMove(int dx, int dy, int b)
 		{
-			if(b != _MouseLeftButton)
+			if(b != MouseButton::LeftButton)
 			{
 				mIsMovingForegroundWindow = false;
 				return;
@@ -168,7 +169,7 @@ namespace iggDialogImageComposer_Private
 				this->FindPosition(ic,dx,dy,x,y);
 				mPosX = x;
 				mPosY = y;
-				mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+				mSubject->RequestPainting(DrawMode::Foreground);
 			}
 		}
 
@@ -587,12 +588,12 @@ namespace iggDialogImageComposer_Private
 		virtual void Execute()
 		{
 			iString fn;
-			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(_EnvironmentBase);
+			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(Environment::Base);
 			fn = this->GetMainWindow()->GetFileName("Open image file",mOldFileName,"Images (*.jpg *.jpeg *.pnm *.bmp *.png *.tif *.tiff)");
 
 			if(mDialog->GetCurrentBackgroundWindow()>=0 && !mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->LoadWallpaperImage(fn))
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to load an image from file.",_PopupWindowError);
+				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to load an image from file.",PopupWindow::Error);
 			}
 		}
 
@@ -639,7 +640,7 @@ namespace iggDialogImageComposer_Private
 
 	public:
 
-		ScaleSpinBox(const iObjectKey &key, iggDialogImageComposer *dialog, iggFrame *parent) : iggWidgetKeyHandler<float>(_WidgetTypeOther,key,_RenderModeNoRender,parent,0,0)
+		ScaleSpinBox(const iObjectKey &key, iggDialogImageComposer *dialog, iggFrame *parent) : iggWidgetKeyHandler<float>(WidgetType::Other,key,RenderMode::NoRender,parent,0,0)
 		{
 			mSubject = iggSubjectFactory::CreateWidgetSpinBoxSubject(this,5,100,"",5);
 			mDialog = dialog;
@@ -995,13 +996,13 @@ iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialo
 	tmp2->AddLine(new iggWidgetTextArea("Source",tmp2),wid);
 
 	iggFrame *tmp3 = new ZoomWidgetsFrame(this,tmp2);
-	mIndexHolders[3] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomX(),_RenderModeNoRender,tmp3,0);
+	mIndexHolders[3] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomX(),RenderMode::NoRender,tmp3,0);
 	mIndexHolders[3]->AddDependent(mArea);
 	tmp3->AddLine(new iggWidgetTextArea("Center X",tmp3),mIndexHolders[3]);
-	mIndexHolders[4] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomY(),_RenderModeNoRender,tmp3,0);
+	mIndexHolders[4] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomY(),RenderMode::NoRender,tmp3,0);
 	mIndexHolders[4]->AddDependent(mArea);
 	tmp3->AddLine(new iggWidgetTextArea("Center Y",tmp3),mIndexHolders[4]);
-	mIndexHolders[5] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomFactor(),_RenderModeNoRender,tmp3,0);
+	mIndexHolders[5] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomFactor(),RenderMode::NoRender,tmp3,0);
 	mIndexHolders[5]->AddDependent(mArea);
 	tmp3->AddLine(new iggWidgetTextArea("Factor",tmp3),mIndexHolders[5]);
 	tmp3->SetColStretch(1,10);
