@@ -43,11 +43,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggframe.h"
 #include "iggmainwindow.h"
-#include "iggparameter.h"
 #include "iggwidgetarea.h"
 #include "iggwidgetprogressbar.h"
 
-using namespace iggParameter;
+
+using namespace iParameter;
 
 
 const bool iggDialogLoadFile::mIsMultiThread = false;
@@ -80,7 +80,7 @@ using namespace iggDialogLoadFile_Private;
 //
 //  Main class
 //
-iggDialogLoadFile::iggDialogLoadFile(iggMainWindow *parent) : iggDialog(parent,mIsMultiThread?0U:_DialogBlocking,0,"Loading file...",0,2,"Abort")
+iggDialogLoadFile::iggDialogLoadFile(iggMainWindow *parent) : iggDialog(parent,mIsMultiThread?0U:DialogFlag::Blocking,0,"Loading file...",0,2,"Abort")
 {
 	mProgressBar = new ProgressBar(mFrame);
 	mLabel = new iggWidgetTextArea("",mFrame);
