@@ -38,6 +38,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iimagefactory.h"
 #include "ifile.h"
 #include "ipalette.h"
+#include "ipaletteset.h"
 #include "ipiecewisefunction.h"
 #include "ishell.h"
 
@@ -51,8 +52,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetentrysubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
+
+
+using namespace iParameter;
 using namespace iParameter;
 
 
@@ -77,21 +79,21 @@ namespace iggDialogPaletteEditor_Private
 		virtual void Execute()
 		{
 			iString fn;
-			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(_EnvironmentPalette);
+			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(Environment::Palette);
 			fn = this->GetMainWindow()->GetFileName("Open palette file",mOldFileName,"Palette file (*.ipf)");
 			if(!fn.IsEmpty() && fn.Part(-4).Lower()!=".ipf") fn += ".ipf";
 
 			iFile f(fn);
 			if(!f.Open(iFile::_Read,iFile::_Text))
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to open a palette file.",_PopupWindowError);
+				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to open a palette file.",PopupWindow::Error);
 				return;
 			}
 
 			iString ws;
-			if(!f.ReadLine(ws) || !this->GetShell()->GetControlModule()->UnPackValuePalette(ws,mDialog->GetCurrentPalette()))
+			if(!f.ReadLine(ws) || !iPaletteSet::Default()->UnPackValuePalette(ws,mDialog->GetCurrentPalette()))
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Palette file is corrupted.",_PopupWindowError);
+				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Palette file is corrupted.",PopupWindow::Error);
 			}
 			else
 			{
@@ -124,22 +126,22 @@ namespace iggDialogPaletteEditor_Private
 		virtual void Execute()
 		{
 			iString fn;
-			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(_EnvironmentPalette);
+			if(mOldFileName.IsEmpty()) mOldFileName = this->GetShell()->GetEnvironment(Environment::Palette);
 			fn = this->GetMainWindow()->GetFileName("Save palette file",mOldFileName,"Palette file (*.ipf)",false);
 			if(!fn.IsEmpty() && fn.Part(-4).Lower()!=".ipf") fn += ".ipf";
 
 			iFile f(fn);
 			if(!f.Open(iFile::_Write,iFile::_Text))
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to create a palette file.",_PopupWindowError);
+				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Failed to create a palette file.",PopupWindow::Error);
 				return;
 			}
 
 			iString ws;
-			this->GetShell()->GetControlModule()->PackValuePalette(ws,mDialog->GetCurrentPalette());
+			iPaletteSet::Default()->PackValuePalette(ws,mDialog->GetCurrentPalette());
 			if(!f.WriteLine(ws))
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Unable to write into a palette file.",_PopupWindowError);
+				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Unable to write into a palette file.",PopupWindow::Error);
 			}
 			else
 			{
@@ -170,14 +172,14 @@ namespace iggDialogPaletteEditor_Private
 			return mEditor->GetCurrentPalette();
 		}
 
-		virtual int GetCurrentPaletteIndex() const
+	protected:
+
+		virtual int GetPaletteId() const
 		{
 			return mEditor->GetCurrentPaletteIndex() + 1;
 		}
 
-	protected:
-
-		virtual void SetCurrentPaletteIndexBody(int n)
+		virtual void SetPaletteId(int n)
 		{
 			mEditor->SetCurrentPaletteIndex(n-1);
 		}
@@ -209,25 +211,7 @@ namespace iggDialogPaletteEditor_Private
 
 		virtual iPiecewiseFunction* GetFunction()
 		{
-			switch(mType)
-			{
-			case 0:
-				{
-					return mEditor->GetCurrentPalette()->GetRedComponent();
-				}
-			case 1:
-				{
-					return mEditor->GetCurrentPalette()->GetGreenComponent();
-				}
-			case 2:
-				{
-					return mEditor->GetCurrentPalette()->GetBlueComponent();
-				}
-			default:
-				{
-					return 0;
-				}
-			}
+			return mEditor->GetCurrentPalette()->GetComponent(mType);
 		}
 
 		virtual void OnRender()
@@ -298,7 +282,7 @@ namespace iggDialogPaletteEditor_Private
 		{
 			if(s.Find("*") >= 0)
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"A palette name may not contain symbols '*'",_PopupWindowError);
+				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"A palette name may not contain symbols '*'",PopupWindow::Error);
 				mSubject->SetText(mDialog->GetCurrentPalette()->GetName());
 			}
 			else
@@ -329,13 +313,13 @@ namespace iggDialogPaletteEditor_Private
 		virtual void Execute()
 		{
 			mDialog->Apply(true);
-			if(!this->GetShell()->GetControlModule()->AddEmptyPalette())
+			if(!iPaletteSet::Default()->AddEmptyPalette())
 			{
-				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Unable to create a new palette.\nPerhaps, there is not enough free memory.",_PopupWindowError);
+				this->GetMainWindow()->PopupWindow(mDialog->GetFrame(),"Unable to create a new palette.\nPerhaps, there is not enough free memory.",PopupWindow::Error);
 			}
 			else
 			{
-				mDialog->SetCurrentPaletteIndex(this->GetShell()->GetControlModule()->GetNumberOfPalettes()-1);
+				mDialog->SetCurrentPaletteIndex(iPaletteSet::Default()->GetNumberOfPalettes()-1);
 			}
 		}
 
@@ -350,7 +334,7 @@ using namespace iggDialogPaletteEditor_Private;
 iggDialogPaletteEditor::iggDialogPaletteEditor(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("paled.png"),"Palette Editor","sr.gg.de",2)
 {
 	mCurrentPalette = new iPalette;
-	mCurrentPalette->Copy(this->GetShell()->GetControlModule()->GetPalette(0));
+	mCurrentPalette->Copy(iPaletteSet::Default()->GetPalette(0));
 	mCurrentPaletteIndex = 0;
 
 	iggFrame *cpb = new iggFrame(mFrame,2);
@@ -370,11 +354,11 @@ iggDialogPaletteEditor::iggDialogPaletteEditor(iggMainWindow *parent) : iggDialo
 
 	iggWidget *pf1, *pf2, *pf3;
 	pf1 = new PiecewiseFunctionControls(0,this,spb);
-	ps->AddDependent(pf1);
+	ps->AddBuddy(pf1);
 	pf2 = new PiecewiseFunctionControls(1,this,spb);
-	ps->AddDependent(pf2);
+	ps->AddBuddy(pf2);
 	pf3 = new PiecewiseFunctionControls(2,this,spb);
-	ps->AddDependent(pf3);
+	ps->AddBuddy(pf3);
 	spb->AddLine(pf1,pf2,pf3);
 
 	spb->SetRowStretch(0,0);
@@ -423,10 +407,10 @@ void iggDialogPaletteEditor::SetChanged(bool s)
 
 void iggDialogPaletteEditor::SetCurrentPaletteIndex(int n)
 {
-	if(n>0 && n<=this->GetShell()->GetControlModule()->GetNumberOfPalettes())
+	if(n>=0 && n<iPaletteSet::Default()->GetNumberOfPalettes())
 	{
 		if(mApplyButton->IsEnabled()) this->Apply(true);
-		mCurrentPalette->Copy(this->GetShell()->GetControlModule()->GetPalette(n));
+		mCurrentPalette->Copy(iPaletteSet::Default()->GetPalette(n));
 		mCurrentPaletteIndex = n;
 		this->UpdateDialog();
 	}
@@ -437,9 +421,9 @@ void iggDialogPaletteEditor::Apply(bool ask)
 {
 	if(mApplyButton->IsEnabled() && (!ask || this->GetMainWindow()->AskForConfirmation("Do you want to apply changes?","Apply")))
 	{
-		this->GetShell()->GetControlModule()->GetPalette(mCurrentPaletteIndex)->Copy(mCurrentPalette);
+		iPaletteSet::Default()->GetPalette(mCurrentPaletteIndex)->Copy(mCurrentPalette);
 		iggFramePaletteSelectionBase::UpdateAll();
-		this->GetShell()->GetControlModule()->Render(_RenderOptionAll);
+		this->GetShell()->GetControlModule()->Render(RenderOption::All);
 		mApplyButton->Enable(false);
 	}
 }
