@@ -54,8 +54,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetentrysubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
 
 //
 //  Templates
@@ -63,6 +61,9 @@ using namespace iggParameter;
 #include "iggwidgetkeyslidertemplate.h"
 
 
+using namespace iParameter;
+
+
 namespace iggDialogPickerWindow_Private
 {
 	class MoveFocalPointFrame : public iggFrameMoveFocalPointButton
@@ -92,7 +93,7 @@ namespace iggDialogPickerWindow_Private
 
 	public:
 
-		DummyPositionSlider(iggDialogPickerWindow *dialog, iggFrame *parent) : iggWidgetKeyPositionSlider(0,"",iMarker::KeyPosition(true),_RenderModeNoRender,parent,0)
+		DummyPositionSlider(iggDialogPickerWindow *dialog, iggFrame *parent) : iggWidgetKeyPositionSlider(0,"",iMarker::KeyPosition(true),RenderMode::NoRender,parent,0)
 		{
 			mDialog = dialog;
 			this->Show(false);
@@ -129,8 +130,8 @@ iggDialogPickerWindow::iggDialogPickerWindow(iggMainWindow *parent) : iggDialog(
 	pm->InsertItem("Point picker");
 	pm->InsertItem("Object picker");
 	mInfoFrame->AddLine(pm,new MoveFocalPointFrame(mInfoFrame));
-	mInfoFrame->AddLine(new iggWidgetKeyFloatSlider(0.001,0.1,20,1,0,"Pick accuracy",iPicker::KeyAccuracy(),_RenderModeUseGlobal,mInfoFrame),2);
-	mInfoFrame->AddLine(new iggWidgetKeyFloatSlider(0.01,100.0,40,1,0,"Marker size",iPicker::KeyPointSize(),_RenderModeUseGlobal,mInfoFrame),2);
+	mInfoFrame->AddLine(new iggWidgetKeyFloatSlider(0.001,0.1,20,1,0,"Pick accuracy",iPicker::KeyAccuracy(),RenderMode::UseGlobal,mInfoFrame),2);
+	mInfoFrame->AddLine(new iggWidgetKeyFloatSlider(0.01,100.0,40,1,0,"Marker size",iPicker::KeyPointSize(),RenderMode::UseGlobal,mInfoFrame),2);
 	mInfoFrame->SetColStretch(1,10);
 
 	//
