@@ -47,8 +47,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkTimerLog.h>
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
+
+
+using namespace iParameter;
 
 
 namespace iggDialogRenderingProgress_Private
@@ -80,7 +81,7 @@ namespace iggDialogRenderingProgress_Private
 using namespace iggDialogRenderingProgress_Private;
 
 
-iggDialogRenderingProgress::iggDialogRenderingProgress(iggMainWindow *parent) : iggDialog(parent,_DialogBlocking|_DialogNoTitleBar,0,"Rendering...",0,1)
+iggDialogRenderingProgress::iggDialogRenderingProgress(iggMainWindow *parent) : iggDialog(parent,DialogFlag::Blocking|DialogFlag::NoTitleBar,0,"Rendering...",0,1)
 {
 	mBlockParent = true;  // no explicit blocking required, since it is a semi-modal dialog
 	mIsParentBlocked = false;
