@@ -61,9 +61,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkTimerLog.h>
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
 
 //
 //  Templates (needed for some compilers)
@@ -71,6 +68,10 @@ using namespace iParameter;
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
+
 //
 //  Helper class
 //
@@ -170,7 +171,11 @@ public:
 		mSubject->GetCursorPosition(line,index);
 		iString ws = mSubject->GetLine(line);
 		ws.ReduceWhiteSpace();
+
+		bool mod = this->TextModified();
 		if(s && ws.Length()>0 && ws[0]!='#') mSubject->SetLineColor(line,mBreakPointColor); else mSubject->UnSetLineColor(line);
+		this->SetModified(mod);
+
 		this->OnCursorPositionChanged(line,index);
 	}
 
@@ -207,9 +212,9 @@ protected:
 		mDebugger->Debug(false);
 	}
 
-	virtual void OnCursorPositionChanged(int para, int /*index*/)
+	virtual void OnCursorPositionChanged(int line, int /*index*/)
 	{
-		bool b = this->IsBreakPoint(para);
+		bool b = this->IsBreakPoint(line);
 
 		if(mBreakPointButtons[0] != 0) mBreakPointButtons[0]->Enable(!b);
 		if(mBreakPointButtons[1] != 0) mBreakPointButtons[1]->Enable(b);
@@ -342,7 +347,7 @@ namespace iggDialogScriptDebugger_Private
 		
 	public:
 
-		FindDialog(iggDialogScriptDebuggerEditor *ed, iggMenuWindow *mw) : iggDialog(mw,_DialogModal,iImageFactory::FindIcon("searchfind.png"),"Find",0,2)
+		FindDialog(iggDialogScriptDebuggerEditor *ed, iggMenuWindow *mw) : iggDialog(mw,DialogFlag::Modal,iImageFactory::FindIcon("searchfind.png"),"Find",0,2)
 		{
 			FindText *t = new FindText(mFrame);
 			FindCheckBox *cs = new FindCheckBox("Case sensitive",mFrame);
@@ -707,7 +712,7 @@ void iggDialogScriptDebugger::OnScriptStopBody(const iString &error)
 {
 	if(!error.IsEmpty() && error!="Animation finished.")
 	{
-		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Run time error:\n")+error,_PopupWindowWarning);
+		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Run time error:\n")+error,PopupWindow::Warning);
 	}
 	mEditor->ClearSelection();
 }
@@ -810,13 +815,13 @@ bool iggDialogScriptDebugger::CheckSyntax(bool silent)
 	iAnimatorScript *s = this->GetAnimator()->GetScript();
 	if(!s->Compile())
 	{
-		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Syntax error: line ")+iString::FromNumber(s->GetThisLine()+1)+"\n"+s->GetErrorStatus()->Message(),_PopupWindowError);
+		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Syntax error: line ")+iString::FromNumber(s->GetThisLine()+1)+"\n"+s->GetErrorStatus()->Message(),PopupWindow::Error);
 		mEditor->ShowError(s);
 		return false;
 	}
 	else
 	{
-		if(!silent) this->GetMainWindow()->PopupWindow(mGlobalFrame,"Congratulations: script contains no errors!",_PopupWindowMessage);
+		if(!silent) this->GetMainWindow()->PopupWindow(mGlobalFrame,"Congratulations: script contains no errors!",PopupWindow::Message);
 		return true;
 	}
 }
@@ -888,7 +893,7 @@ void iggDialogScriptDebugger::CheckModified()
 {
 	if(mEditor->TextModified())
 	{
-		switch(mMainWindow->PopupWindow(mGlobalFrame,"The current script is not saved.",_PopupWindowWarning,"Save","Ignore")) 
+		switch(mMainWindow->PopupWindow(mGlobalFrame,"The current script is not saved.",PopupWindow::Warning,"Save","Ignore")) 
 		{
 		case 0: // The user clicked the Save button or pressed Enter
 			{ 
@@ -923,7 +928,7 @@ void iggDialogScriptDebugger::LoadFromFile(const iString &filename)
 	{
 		if(mCurrentFileName.IsEmpty())
 		{
-			fn = this->GetFileName("Open script file",this->GetShell()->GetEnvironment(_EnvironmentScript),"Animation script file (*.ias)");
+			fn = this->GetFileName("Open script file",this->GetShell()->GetEnvironment(Environment::Script),"Animation script file (*.ias)");
 		}
 		else
 		{
@@ -941,7 +946,7 @@ void iggDialogScriptDebugger::LoadFromFile(const iString &filename)
 	iFile f(fn);
 	if(!f.Open(iFile::_Read,iFile::_Text))
 	{
-		mMainWindow->PopupWindow(mGlobalFrame,"Failed to open a script file.",_PopupWindowError);
+		mMainWindow->PopupWindow(mGlobalFrame,"Failed to open a script file.",PopupWindow::Error);
 		return;
 	}
 
@@ -967,7 +972,7 @@ void iggDialogScriptDebugger::SaveToFile(const iString &filename)
 	{
 		if(mCurrentFileName.IsEmpty())
 		{
-			fn = this->GetFileName("Save script file",this->GetShell()->GetEnvironment(_EnvironmentScript),"Animation script file (*.ias)",false);
+			fn = this->GetFileName("Save script file",this->GetShell()->GetEnvironment(Environment::Script),"Animation script file (*.ias)",false);
 		}
 		else
 		{
@@ -985,7 +990,7 @@ void iggDialogScriptDebugger::SaveToFile(const iString &filename)
 	iFile f(fn);
 	if(!f.Open(iFile::_Write,iFile::_Text))
 	{
-		mMainWindow->PopupWindow(mGlobalFrame,"Failed to open a script file.",_PopupWindowError);
+		mMainWindow->PopupWindow(mGlobalFrame,"Failed to open a script file.",PopupWindow::Error);
 		return;
 	}
 
@@ -999,7 +1004,7 @@ void iggDialogScriptDebugger::SaveToFile(const iString &filename)
 		{
 			if(!f.WriteLine(line))
 			{
-				mMainWindow->PopupWindow(mGlobalFrame,"Error in writing a script file.",_PopupWindowError);
+				mMainWindow->PopupWindow(mGlobalFrame,"Error in writing a script file.",PopupWindow::Error);
 				f.Close();
 				return;
 			}
@@ -1032,11 +1037,11 @@ void iggDialogScriptDebugger::BuildMenus()
 	//
 	this->GetSubject()->BeginMenu("&Edit",false);
 	{
-		if(mEditor->HasEditingFunction(_TextEditorFunctionUndo)) this->GetSubject()->AddMenuItem(_MenuEditUndo,"&Undo",iImageFactory::FindIcon("undo.png"),"Ctrl+U",false,false);
-		if(mEditor->HasEditingFunction(_TextEditorFunctionRedo)) this->GetSubject()->AddMenuItem(_MenuEditRedo,"&Redo",iImageFactory::FindIcon("redo.png"),"Ctrl+R",false,false);
-		if(mEditor->HasEditingFunction(_TextEditorFunctionCut)) this->GetSubject()->AddMenuItem(_MenuEditCut,"Cu&t",iImageFactory::FindIcon("editcut.png"),"Ctrl+X",false,false);
-		if(mEditor->HasEditingFunction(_TextEditorFunctionCopy)) this->GetSubject()->AddMenuItem(_MenuEditCopy,"&Copy",iImageFactory::FindIcon("editcopy.png"),"Ctrl+C",false,false);
-		if(mEditor->HasEditingFunction(_TextEditorFunctionPaste)) this->GetSubject()->AddMenuItem(_MenuEditPaste,"&Paste",iImageFactory::FindIcon("editpaste.png"),"Ctrl+V",false,false);
+		if(mEditor->HasEditingFunction(TextEditorFunction::Undo)) this->GetSubject()->AddMenuItem(_MenuEditUndo,"&Undo",iImageFactory::FindIcon("undo.png"),"Ctrl+U",false,false);
+		if(mEditor->HasEditingFunction(TextEditorFunction::Redo)) this->GetSubject()->AddMenuItem(_MenuEditRedo,"&Redo",iImageFactory::FindIcon("redo.png"),"Ctrl+R",false,false);
+		if(mEditor->HasEditingFunction(TextEditorFunction::Cut)) this->GetSubject()->AddMenuItem(_MenuEditCut,"Cu&t",iImageFactory::FindIcon("editcut.png"),"Ctrl+X",false,false);
+		if(mEditor->HasEditingFunction(TextEditorFunction::Copy)) this->GetSubject()->AddMenuItem(_MenuEditCopy,"&Copy",iImageFactory::FindIcon("editcopy.png"),"Ctrl+C",false,false);
+		if(mEditor->HasEditingFunction(TextEditorFunction::Paste)) this->GetSubject()->AddMenuItem(_MenuEditPaste,"&Paste",iImageFactory::FindIcon("editpaste.png"),"Ctrl+V",false,false);
 		this->GetSubject()->AddMenuSeparator();
 		this->GetSubject()->AddMenuItem(_MenuEditFind,"&Find",iImageFactory::FindIcon("searchfind.png"),"Ctrl+F",false,false);
 	}
@@ -1070,11 +1075,11 @@ void iggDialogScriptDebugger::BuildMenus()
 	this->GetSubject()->AddToolBarButton(_MenuFileOpen,"Open an existing script from a file");
 	this->GetSubject()->AddToolBarButton(_MenuFileSave,"Save the current script into a file");
 	this->GetSubject()->AddToolBarSeparator();
-	if(mEditor->HasEditingFunction(_TextEditorFunctionUndo)) this->GetSubject()->AddToolBarButton(_MenuEditUndo,"Undo");
-	if(mEditor->HasEditingFunction(_TextEditorFunctionRedo)) this->GetSubject()->AddToolBarButton(_MenuEditRedo,"Redo");
-	if(mEditor->HasEditingFunction(_TextEditorFunctionCut)) this->GetSubject()->AddToolBarButton(_MenuEditCut,"Cut the current selection");
-	if(mEditor->HasEditingFunction(_TextEditorFunctionCopy)) this->GetSubject()->AddToolBarButton(_MenuEditCopy,"Copy the current selection to the clipboard");
-	if(mEditor->HasEditingFunction(_TextEditorFunctionPaste)) this->GetSubject()->AddToolBarButton(_MenuEditPaste,"Paste the contents of the clipboard");
+	if(mEditor->HasEditingFunction(TextEditorFunction::Undo)) this->GetSubject()->AddToolBarButton(_MenuEditUndo,"Undo");
+	if(mEditor->HasEditingFunction(TextEditorFunction::Redo)) this->GetSubject()->AddToolBarButton(_MenuEditRedo,"Redo");
+	if(mEditor->HasEditingFunction(TextEditorFunction::Cut)) this->GetSubject()->AddToolBarButton(_MenuEditCut,"Cut the current selection");
+	if(mEditor->HasEditingFunction(TextEditorFunction::Copy)) this->GetSubject()->AddToolBarButton(_MenuEditCopy,"Copy the current selection to the clipboard");
+	if(mEditor->HasEditingFunction(TextEditorFunction::Paste)) this->GetSubject()->AddToolBarButton(_MenuEditPaste,"Paste the contents of the clipboard");
 	this->GetSubject()->AddToolBarButton(_MenuEditFind,"Search the script text");
 	this->GetSubject()->AddToolBarSeparator();
 	this->GetSubject()->AddToolBarButton(_MenuDebugSyntax,"Check the script syntax");
@@ -1144,7 +1149,7 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 		case _MenuEditCopy:
 		case _MenuEditPaste:
 			{
-				mEditor->UseEditingFunction(id-_MenuEditUndo+_TextEditorFunctionUndo);
+				mEditor->UseEditingFunction(id-_MenuEditUndo+TextEditorFunction::Undo);
 				break;
 			}
 		case _MenuEditFind:
