@@ -52,15 +52,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggextensionfactory.h"
 #include "iggsubjectfactory.h"
 
-#include "iggparameter.h"
-using namespace iggParameter;
-
 //
 //  Templates (needed for some compilers)
 //
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 class iggExtensionWindowHelper
 {
 
@@ -138,7 +138,7 @@ namespace iggExtensionWindow_Private
 
 	public:
 
-		BookControl(iggExtensionWindowHelper *helper, iggFrameFlip *panel, iggFrame *parent) : iggFrameBook(parent,true,false), mPanel(panel)
+		BookControl(iggExtensionWindowHelper *helper, iggFrameFlip *panel, iggFrame *parent) : iggFrameBook(parent,true,1), mPanel(panel)
 		{
 			helper->AddWidget(this);
 		}
@@ -180,7 +180,7 @@ namespace iggExtensionWindow_Private
 		SelectionControlButton(int index, iggWidgetTextArea *title, iggAbstractExtension *ext, iggFrameFlip *panel, iggFrame *parent) : iggWidget(parent), mIndex(index), mPanel(panel)
 		{
 			mTitle = title;
-			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeToggleButton,"",1);
+			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::ToggleButton,"",1);
 			if(ext->GetIcon() != 0) mSubject->SetIcon(*ext->GetIcon());
 			this->AddDependent(parent);
 			this->SetBaloonHelp("Select current extension");
