@@ -43,8 +43,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgframesubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
 
 //
 //  Templates
@@ -52,6 +50,9 @@ using namespace iggParameter;
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 //
 //  Base Frame class
 //
@@ -426,9 +427,10 @@ void iggFrame::FlipThroughAllChildren()
 //
 //  FrameBook class
 //
-iggFrameBook::iggFrameBook(iggFrameBase *parent, bool withFeedback, bool tabsOnTop) : iggFrameBase(parent)
+iggFrameBook::iggFrameBook(iggFrameBase *parent, bool withFeedback, int orientation) : iggFrameBase(parent)
 {
-	mSubject = iggSubjectFactory::CreateFrameBookSubject(this,withFeedback,tabsOnTop);
+	mSubject = iggSubjectFactory::CreateFrameBookSubject(this,withFeedback);
+	mSubject->SetOrientation(orientation);
 
 	mNeedsBaloonHelp = false;
 }
@@ -539,6 +541,28 @@ void iggFrameBook::FlipThroughAllChildren()
 }
 
 
+void iggFrameBook::SetOrientation(int v)
+{
+	int i, j;
+
+	for(i=0; i<mPages.Size(); i++)
+	{
+		for(j=0; j<mPages[i].Frame->mChildren.Size(); j++)
+		{
+			iggFrameBook *b = dynamic_cast<iggFrameBook*>(mPages[i].Frame->mChildren[j]);
+			if(b != 0) b->SetOrientation(v);
+		}
+	}
+
+	mSubject->SetOrientation(v);
+}
+
+
+int iggFrameBook::GetOrientation() const
+{
+	return mSubject->GetOrientation();
+}
+
 //
 //  FrameFlip class 
 //
