@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframeattachposition.h"
 
 
@@ -46,4 +50,4 @@ iggFrameAttachPosition::iggFrameAttachPosition(iggWidget *buddy, const iObjectKe
 	this->AddBuddy(buddy);  //  if the position changes, the attachment is broken
 }
 
-
+#endif
