@@ -53,7 +53,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggsubjectfactory.h"
 using namespace iParameter;
-using namespace iggParameter;
+using namespace iParameter;
 
 
 namespace iggFrameDataTypeSelector_Private
@@ -149,7 +149,7 @@ namespace iggFrameDataTypeSelector_Private
 		{
 			switch(mSelector->GetMode())
 			{
-			case _ListDataTypesWithData:
+			case ListDataTypes::WithData:
 				{
 					if(mSetIcon != 0) mSubject->SetIcon(*mSetIcon);
 					break;
@@ -166,14 +166,14 @@ namespace iggFrameDataTypeSelector_Private
 		{
 			switch(mSelector->GetMode())
 			{
-			case _ListDataTypesWithData:
+			case ListDataTypes::WithData:
 				{
-					mSelector->SetMode(_ListDataTypesAll);
+					mSelector->SetMode(ListDataTypes::All);
 					break;
 				}
 			default:
 				{
-					mSelector->SetMode(_ListDataTypesWithData);
+					mSelector->SetMode(ListDataTypes::WithData);
 					break;
 				}
 			}
@@ -211,7 +211,7 @@ iggFrameDataTypeSelector::iggFrameDataTypeSelector(iggDataTypeProvider *provider
 
 	iggWidget *cb = new DataTypeComboBox(hor?title:"",this,mBase);
 	RestrictButton *rb = 0;
-	if(mode == iggParameter::_ListDataTypesAll) rb = new RestrictButton(this,mBase);
+	if(mode == iParameter::ListDataTypes::All) rb = new RestrictButton(this,mBase);
 
 	if(withapply)
 	{
@@ -256,7 +256,7 @@ const iDataInfo* iggFrameDataTypeSelector::GetDataInfo()
 
 	switch(mMode)
 	{
-	case _ListDataTypesWithData:
+	case ListDataTypes::WithData:
 		{
 			mInfoPointer->Erase();
 			for(i=0; i<n; i++) if(dr->IsThereData(pi.Type(i)))
@@ -265,7 +265,7 @@ const iDataInfo* iggFrameDataTypeSelector::GetDataInfo()
 			}
 			break;
 		}
-	case _ListDataTypesWithVariables:
+	case ListDataTypes::WithVariables:
 		{
 			mInfoPointer->Erase();
 			for(i=0; i<n; i++) if(dr->IsThereData(pi.Type(i)) && dr->GetLimits(pi.Type(i))!=0 && dr->GetLimits(pi.Type(i))->GetNumVars()>0)
@@ -274,7 +274,7 @@ const iDataInfo* iggFrameDataTypeSelector::GetDataInfo()
 			}
 			break;
 		}
-	case _ListDataTypesAll:
+	case ListDataTypes::All:
 	default:
 		{
 			*mInfoPointer = pi;
@@ -296,7 +296,7 @@ const iDataInfo* iggFrameDataTypeSelector::GetDataInfo()
 
 void iggFrameDataTypeSelector::SetMode(int m)
 {
-	if(m>=_ListDataTypesAll && m<=_ListDataTypesWithVariables)
+	if(m>=ListDataTypes::All && m<=ListDataTypes::WithVariables)
 	{
 		mMode = m;
 		mBase->UpdateWidget();
@@ -342,7 +342,7 @@ void iggFrameDataTypeSelector::Apply()
 			this->UpdateWidget();
 		}
 
-		this->GetShell()->GetControlModule()->Render(_RenderOptionClones);
+		this->GetShell()->GetControlModule()->Render(RenderOption::Clones);
 	}
 }
 
