@@ -180,7 +180,7 @@ void iggFrameDataVariableList::UpdateList()
 		}
 		for(i=n; i<np; i++)
 		{
-			mBoxCombo->SetItem("",mOffset+n,false); // this deletes an item, so they shift down
+			mBoxCombo->RemoveItem(mOffset+n); // this deletes an item, so they shift down
 		}
 	}
 }
