@@ -43,8 +43,6 @@ class iggFrameDoubleButton : public iggFrame
 
 public:
 
-	virtual ~iggFrameDoubleButton(){}
-
 	virtual void OnButton1() = 0;
 	virtual void OnButton2() = 0;
 
@@ -82,8 +80,8 @@ class iggFrameMoveFocalPointButton : public iggFrameDoubleButton
 
 public:
 
-	iggFrameMoveFocalPointButton(iggFrame *parent, bool withmarker = false);
-	iggFrameMoveFocalPointButton(const iString &title, iggFrame *parent, bool withmarker = false);
+	iggFrameMoveFocalPointButton(iggFrame *parent, bool withmarker = false, bool stretching = false);
+	iggFrameMoveFocalPointButton(const iString &title, iggFrame *parent, bool withmarker = false, bool stretching = false);
 
 	virtual void GetPosition(double x[3]) const = 0;
 	virtual int GetWindowNumber() const { return -1; }
@@ -100,7 +98,7 @@ protected:
 
 private:
 
-	void Define(bool withmarker);
+	void Define(bool withmarker, bool stretching);
 };
 
 #endif  // IGGFRAMEDOUBLEBUTTON_H
