@@ -42,8 +42,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetbuttonsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
+
+
+using namespace iParameter;
 
 
 namespace iggFrameHistogramAreaExtra_Private
@@ -56,7 +57,7 @@ namespace iggFrameHistogramAreaExtra_Private
 		ShowInLogCheckBox(iggWidgetHistogramArea *area, iggFrame *parent) : iggWidget(parent)
 		{
 			mArea = area;
-			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,"Show Y-axis in log",1);
+			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Show Y-axis in log",1);
 
 			this->SetBaloonHelp("Show histogram in log scale");
 		}
@@ -87,7 +88,7 @@ namespace iggFrameHistogramAreaExtra_Private
 		ShowInFullResolutionCheckBox(iggWidgetHistogramArea *area, iggFrame *parent) : iggWidget(parent)
 		{
 			mArea = area;
-			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,"Full resoluton (may be slow)",1);
+			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Full resoluton (may be slow)",1);
 
 			this->SetBaloonHelp("Show histogram with full resolution (slow for large data sets)");
 		}
@@ -141,6 +142,13 @@ iggFrameHistogramAreaExtra::iggFrameHistogramAreaExtra(iggWidgetHistogramArea *a
 }
 
 
+void iggFrameHistogramAreaExtra::DisplayNumbers(float min, float max)
+{
+	mDisplayMin->Display(min);
+	mDisplayMax->Display(max);
+}
+
+
 void iggFrameHistogramAreaExtra::UpdateWidgetBody()
 {
 	float min = 0.0, max = 0.0;
