@@ -39,15 +39,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggwidgetkeyhandler.h"
 
-#include "iggparameter.h"
-using namespace iggParameter;
-
 //
 //  templates
 //
 #include "iggwidgetkeyhandlertemplate.h"
 
 
+using namespace iParameter;
+
+
 iggFramePaletteSelection::iggFramePaletteSelection(bool withbrightness, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggFramePaletteSelectionBase(true,withbrightness,parent)
 {
 	//
@@ -68,18 +68,17 @@ void iggFramePaletteSelection::SetIndex(int i)
 {
 	mDummy->SetIndex(i);
 	mDummy->UpdateWidget();
-	this->SetCurrentPaletteIndex(mDummy->GetValue());
 	this->UpdateWidget();
 }
 
 
-void iggFramePaletteSelection::SetCurrentPaletteIndexBody(int i)
+void iggFramePaletteSelection::SetPaletteId(int n)
 {
-	mDummy->SetValue(i);
+	mDummy->SetValue(n);
 }
 
 
-int iggFramePaletteSelection::GetCurrentPaletteIndex() const
+int iggFramePaletteSelection::GetPaletteId() const
 {
 	mDummy->UpdateWidget();
 	return mDummy->GetValue();
