@@ -35,7 +35,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "icontrolmodule.h"
 #include "ierror.h"
+#include "imath.h"
 #include "ipalette.h"
+#include "ipaletteset.h"
 #include "ishell.h"
 
 #include "iggdialogpaletteeditor.h"
@@ -86,12 +88,39 @@ namespace iggFramePaletteSelectionBase_Private
 	};
 
 	
-	class IsReversedCheckBox : public iggWidgetSimpleCheckBox
+	class UseBrightnessCheckBox : public iggWidgetSimpleCheckBox
 	{
 
 	public:
 
-		IsReversedCheckBox(iggFramePaletteSelectionBase *parent) : iggWidgetSimpleCheckBox("Reversed",parent)
+		UseBrightnessCheckBox(iggFramePaletteSelectionBase *parent) : iggWidgetSimpleCheckBox("Use object brightness",parent)
+		{
+			mFrame = parent;
+			this->SetBaloonHelp("Use object brightness as the current palette","This check box replaces the current palette with a custom palette made of the same color as the color of the object, but with varied brightness.");
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			this->SetChecked(mFrame->GetBrightnessPalette());
+		}
+
+		virtual void OnChecked(bool s)
+		{
+			mFrame->SetBrightnessPalette(s);
+		}
+
+		iggFramePaletteSelectionBase *mFrame;
+	};
+
+
+	class UseReversedCheckBox : public iggWidgetSimpleCheckBox
+	{
+
+	public:
+
+		UseReversedCheckBox(iggFramePaletteSelectionBase *parent) : iggWidgetSimpleCheckBox("Reverse",parent)
 		{
 			mFrame = parent;
 			this->SetBaloonHelp("Reverse the current palette","Use this check box to flip the order of colors in the current palette.");
@@ -101,17 +130,17 @@ namespace iggFramePaletteSelectionBase_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			if(mFrame->GetCurrentPaletteIndex() != 0)
+			if(!mFrame->GetBrightnessPalette())
 			{
 				this->Enable(true);
-				this->SetChecked(mFrame->GetCurrentPaletteIndex() < 0);
+				this->SetChecked(mFrame->GetReversedPalette());
 			}
 			else this->Enable(false);
 		}
 
 		virtual void OnChecked(bool s)
 		{
-			mFrame->SetCurrentPaletteIndex(iMath::Abs(mFrame->GetCurrentPaletteIndex())*(s?-1:1));
+			mFrame->SetReversedPalette(s);
 		}
 
 		iggFramePaletteSelectionBase *mFrame;
@@ -123,12 +152,10 @@ namespace iggFramePaletteSelectionBase_Private
 
 	public:
 
-		PaletteList(IsReversedCheckBox *rb, bool withbrightness, iggFramePaletteSelectionBase *parent) : iggWidget(parent)
+		PaletteList(iggFramePaletteSelectionBase *parent) : iggWidget(parent)
 		{
 			mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,"Palette");
 			mFrame = parent;
-			mReverseBox = rb;
-			mOffset = (withbrightness ? 0 : 1);
 
 			this->SetBaloonHelp("Choose palette from the list","Choose a palette from the list of all available palettes. Use Palette Editor from the dialog menus to create new or change existing palettes.");
 		}
@@ -146,25 +173,28 @@ namespace iggFramePaletteSelectionBase_Private
 
 		virtual void UpdateWidgetBody()
 		{
-			int i, np = this->GetShell()->GetControlModule()->GetNumberOfPalettes();
-
-			mSubject->Clear();
-			if(mOffset == 0) mSubject->InsertItem("Brightness");
-			for(i=0; i<np; i++)
+			if(!mFrame->GetBrightnessPalette())
 			{
-				mSubject->InsertItem(this->GetShell()->GetControlModule()->GetPalette(i)->GetName());
-			}
+				this->Enable(true);
 
-			mSubject->SetValue(iMath::Abs(mFrame->GetCurrentPaletteIndex())-mOffset);
+				int i, np = iPaletteSet::Default()->GetNumberOfPalettes();
+
+				mSubject->Clear();
+				for(i=0; i<np; i++)
+				{
+					mSubject->InsertItem(iPaletteSet::Default()->GetPalette(i)->GetName());
+				}
+
+				mSubject->SetValue(mFrame->GetCurrentPaletteIndex());
+			}
+			else this->Enable(false);
 		}
 
 		virtual void OnInt1Body(int n)
 		{
-			mFrame->SetCurrentPaletteIndex((mOffset+n)*(mReverseBox->IsChecked()?-1:1));
+			mFrame->SetCurrentPaletteIndex(n);
 		}
 
-		int mOffset;
-		IsReversedCheckBox *mReverseBox;
 		iggFramePaletteSelectionBase *mFrame;
 		ibgWidgetComboBoxSubject *mSubject;
 	};
@@ -199,12 +229,21 @@ namespace iggFramePaletteSelectionBase_Private
 using namespace iggFramePaletteSelectionBase_Private;
 
 
-iggFramePaletteSelectionBase::iggFramePaletteSelectionBase(bool witheditor, bool withbrightness, iggFrame *parent) : iggFrame("Current palette",parent,3)
+iggFramePaletteSelectionBase::iggFramePaletteSelectionBase(bool witheditor, bool withbrightness, iggFrame *parent) : iggFrame("Current palette",parent,3), mWithBrightness(withbrightness)
 {
 	PaletteView *view = new PaletteView(this);
-	IsReversedCheckBox *rb = new IsReversedCheckBox(this);
-	PaletteList *list = new PaletteList(rb,withbrightness,this);
-	list->AddDependent(rb);
+	PaletteList *list = new PaletteList(this);
+	UseReversedCheckBox *rb = new UseReversedCheckBox(this);
+
+	if(withbrightness)
+	{
+		UseBrightnessCheckBox *bb = new UseBrightnessCheckBox(this);
+		bb->AddDependent(view);
+		bb->AddDependent(list);
+		bb->AddDependent(rb);
+		this->AddLine(bb,3);
+	}
+
 	this->AddLine(view,3);
 	this->AddLine(list,2,rb,1);
 
@@ -217,6 +256,8 @@ iggFramePaletteSelectionBase::iggFramePaletteSelectionBase(bool witheditor, bool
 
 	list->AddDependent(view);
 	List().AddUnique(this);
+
+	mOldPaletteId = 1;
 }
 
 
@@ -226,13 +267,71 @@ iggFramePaletteSelectionBase::~iggFramePaletteSelectionBase()
 }
 
 
+void iggFramePaletteSelectionBase::SetReversedPalette(bool s)
+{
+	int id = this->GetPaletteId();
+
+	if(s && id>0)
+	{
+		this->SetPaletteId(-id);
+	}
+
+	if(!s && id<0)
+	{
+		this->SetPaletteId(-id);
+	}
+}
+
+
+bool iggFramePaletteSelectionBase::GetReversedPalette() const
+{
+	return (this->GetPaletteId() < 0);
+}
+
+
+void iggFramePaletteSelectionBase::SetBrightnessPalette(bool s)
+{
+	int id = this->GetPaletteId();
+
+	if(s && id!=0)
+	{
+		mOldPaletteId = id;
+		this->SetPaletteId(0);
+	}
+
+	if(!s && id==0)
+	{
+		this->SetPaletteId(mOldPaletteId);
+	}
+}
+
+
+bool iggFramePaletteSelectionBase::GetBrightnessPalette() const
+{
+	if(mWithBrightness) return (this->GetPaletteId() == 0); else return false;
+}
+
+
 void iggFramePaletteSelectionBase::SetCurrentPaletteIndex(int n)
 {
-	if(n>=-this->GetShell()->GetControlModule()->GetNumberOfPalettes() && n<=this->GetShell()->GetControlModule()->GetNumberOfPalettes())
+	int id = this->GetPaletteId();
+
+	if(n+1 != iMath::Abs(id))
 	{
-		this->SetCurrentPaletteIndexBody(n);
+		if(n>=0 && n<iPaletteSet::Default()->GetNumberOfPalettes())
+		{
+			this->SetPaletteId((1+n)*(id<0?-1:1));
+		}
+		else IERROR_LOW("Incorrect palette number.");
 	}
-	else IERROR_LOW("Incorrect palette number.");
+}
+
+
+int iggFramePaletteSelectionBase::GetCurrentPaletteIndex() const
+{
+	int id = this->GetPaletteId();
+	
+	if(id == 0) return iMath::Abs(mOldPaletteId)-1; else return iMath::Abs(id)-1;
 }
 
 
@@ -254,7 +353,7 @@ iPointerArray<iggFramePaletteSelectionBase>& iggFramePaletteSelectionBase::List(
 
 iPalette* iggFramePaletteSelectionBase::GetCurrentPalette() const
 {
-	return this->GetShell()->GetControlModule()->GetPalette(iMath::Abs(this->GetCurrentPaletteIndex())-1);
+	return iPaletteSet::Default()->GetPalette(this->GetCurrentPaletteIndex());
 }
 
 #endif
