@@ -43,15 +43,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ibgwidgetareasubject.h"
 
-#include "iggparameter.h"
-using namespace iggParameter;
-
 //
 //  Templates (needed for some compilers)
 //
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 namespace iggFramePiecewiseFunctionControls_Private
 {
 	//
@@ -156,7 +156,7 @@ namespace iggFramePiecewiseFunctionControls_Private
 			{
 				fun->AddPoint(mCurPoint);
 				if(mCurPoint < fun->N()-1) mCurPoint++;
-				mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+				mSubject->RequestPainting(DrawMode::Foreground);
 				mFrame->OnChange();
 			}
 		}
@@ -168,7 +168,7 @@ namespace iggFramePiecewiseFunctionControls_Private
 			{
 				fun->RemovePoint(mCurPoint);
 				if(mCurPoint > 0) mCurPoint--;
-				mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+				mSubject->RequestPainting(DrawMode::Foreground);
 				mFrame->OnChange();
 			}
 		}
@@ -186,7 +186,7 @@ namespace iggFramePiecewiseFunctionControls_Private
 			{
 				fun->Copy(mDefaultFunction);
 				mCurPoint = 0;
-				mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+				mSubject->RequestPainting(DrawMode::Foreground);
 				mFrame->OnChange();
 			}
 		}
@@ -315,15 +315,15 @@ namespace iggFramePiecewiseFunctionControls_Private
 			xl = float(x)/mSubject->Width();
 			yl = float(y)/mSubject->Height();
 			
-			if(b==_MouseLeftButton || b==_MouseRightButton) 
+			if(b==MouseButton::LeftButton || b==MouseButton::RightButton) 
 			{
 				i = fun->FindPoint(xl,yl,d);
 				if(round(d*mSubject->Width()) < 5*sym)
 				{
 					mCurPoint = i;
 					fun->MovePoint(mCurPoint,xl,yl);
-					mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
-					if(b == _MouseRightButton) this->OnRender(); else if(mRenderButton!=0 && !mRenderButton->IsEnabled()) mRenderButton->Enable(true);
+					mSubject->RequestPainting(DrawMode::Foreground);
+					if(b == MouseButton::RightButton) this->OnRender(); else if(mRenderButton!=0 && !mRenderButton->IsEnabled()) mRenderButton->Enable(true);
 					mFrame->OnChange();
 				}
 			}
