@@ -44,8 +44,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggwidgetkeyslider.h"
 #include "iggwidgetotherbutton.h"
 
-#include "iggparameter.h"
-using namespace iggParameter;
+
+using namespace iParameter;
 
 
 namespace iggFramePosition_Private
@@ -114,9 +114,9 @@ iggFramePosition::iggFramePosition(const iString &title, const iObjectKey &key,
 		IERROR_FATAL("iggFramePosition is configured incorrectly.");
 	}
 
-	this->AddLine(new iggWidgetKeyPositionSlider(8,"%b%+X",key,_RenderModeUseGlobal,this,0));
-	this->AddLine(new iggWidgetKeyPositionSlider(8,"%b%+Y",key,_RenderModeUseGlobal,this,1));
-	this->AddLine(new iggWidgetKeyPositionSlider(8,"%b%+Z",key,_RenderModeUseGlobal,this,2));
+	this->AddLine(new iggWidgetKeyPositionSlider(8,"%b%+X",key,RenderMode::UseGlobal,this,0));
+	this->AddLine(new iggWidgetKeyPositionSlider(8,"%b%+Y",key,RenderMode::UseGlobal,this,1));
+	this->AddLine(new iggWidgetKeyPositionSlider(8,"%b%+Z",key,RenderMode::UseGlobal,this,2));
 
 	const iObjectKey *p = iObjectKeyRegistry::FindKey(iViewSubject::KeyMoveTo().RetypedKey(key.Type()));
 	if(p != 0)
