@@ -51,8 +51,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetentrysubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
 
 //
 //  Templates (needed for some compilers)
@@ -60,6 +58,9 @@ using namespace iggParameter;
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 namespace iggFrameRangeMapping_Private
 {
 	//
@@ -124,8 +125,8 @@ namespace iggFrameRangeMapping_Private
 
 				float aMin, aMax;
 				int npic = rc->GetN();
-				float attMin = rc->GetGlobalMin();
-				float attMax = rc->GetGlobalMax();
+				float attMin = rc->GetStretchedGlobalMin();
+				float attMax = rc->GetStretchedGlobalMax();
 
 				dx = ixmax/(attMax-attMin);
 
@@ -139,8 +140,8 @@ namespace iggFrameRangeMapping_Private
 					{
 						i1 = i;
 					}
-					aMin = rc->GetMin(i1);
-					aMax = rc->GetMax(i1);
+					aMin = rc->GetStretchedMin(i1);
+					aMax = rc->GetStretchedMax(i1);
 					
 					ix1 = round(dx*(aMin-attMin));
 					if(ix1>=0 && ix1<lineWidth/2) ix1 = lineWidth/2;
@@ -171,7 +172,7 @@ namespace iggFrameRangeMapping_Private
 		void OnAddRange()
 		{
 			mParent->OnAddRange();
-			mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+			mSubject->RequestPainting(DrawMode::Foreground);
 		}
 
 		void OnRemoveRange();
@@ -375,8 +376,8 @@ namespace iggFrameRangeMapping_Private
 
 			float aMin, aMax, a;
 			int npic = rc->GetN();
-			float attMin = rc->GetGlobalMin();
-			float attMax = rc->GetGlobalMax();
+			float attMin = rc->GetStretchedGlobalMin();
+			float attMax = rc->GetStretchedGlobalMax();
 
 			int oldCurRange = mCurRange;
 
@@ -388,8 +389,8 @@ namespace iggFrameRangeMapping_Private
 				indmin = -1;
 				for(i=0; i<npic; i++)
 				{
-					aMin = rc->GetMin(i);
-					aMax = rc->GetMax(i);
+					aMin = rc->GetStretchedMin(i);
+					aMax = rc->GetStretchedMax(i);
 
 					ix1 = round(dx*(aMin-attMin));
 					if(ix1>=0 && ix1<lineWidth/2) ix1 = lineWidth/2;
@@ -419,33 +420,37 @@ namespace iggFrameRangeMapping_Private
 			}					
 			
 			a = x/dx + attMin;
-			aMin = rc->GetMin(mCurRange);
-			aMax = rc->GetMax(mCurRange);
+			aMin = rc->GetStretchedMin(mCurRange);
+			aMax = rc->GetStretchedMax(mCurRange);
 			if(isMax) aMax = a; else aMin = a;
-			rc->SetRange(mCurRange,aMin,aMax);
+			rc->SetRange(mCurRange,rc->ResetStretch(aMin),rc->ResetStretch(aMax));
 			
 			if(mCurRange != oldCurRange)
 			{
 				mParent->SetCurrentRange(mCurRange);
 			}
 			
-			mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+			if(mExtra != 0) mExtra->DisplayNumbers(rc->ResetStretch(aMin),rc->ResetStretch(aMax));
 
-			if(b == _MouseRightButton) this->OnRender(); else if(!mRenderButton->IsEnabled()) mRenderButton->Enable(true);
+			mSubject->RequestPainting(DrawMode::Foreground);
+
+			mParent->OnChange();
+
+			if(b == MouseButton::RightButton) this->OnRender(); else if(!mRenderButton->IsEnabled()) mRenderButton->Enable(true);
 		}
 	}
 
 	void Area::OnRemoveRange()
 	{
 		mParent->OnRemoveRange();
-		mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+		mSubject->RequestPainting(DrawMode::Foreground);
 		if(!mRenderButton->IsEnabled()) mRenderButton->Enable(true);
 	}
 	
 	void Area::OnReset()
 	{
 		mParent->OnReset();
-		mSubject->RequestPainting(ibgWidgetDrawAreaSubject::_Foreground);
+		mSubject->RequestPainting(DrawMode::Foreground);
 		if(!mRenderButton->IsEnabled()) mRenderButton->Enable(true);
 	}
 
@@ -456,6 +461,7 @@ namespace iggFrameRangeMapping_Private
 		{
 			rm->Modified();
 		}
+		if(mExtra != 0) mExtra->UpdateWidget();
 		this->GetShell()->GetControlModule()->Render();
 		mRenderButton->Enable(false);
 	}
