@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframereplicate.h"
 
 
@@ -85,3 +89,4 @@ void iggFrameReplicate::UpdateChildren()
 	}
 }
 
+#endif
