@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframetopparent.h"
 
 
@@ -46,3 +50,4 @@ void iggFrameTopParent::AttachSubject(ibgFrameSubject *subject)
 	iggWidget::AttachSubject(subject);
 }
 
+#endif
