@@ -40,7 +40,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iarray.h"
 #include "istring.h"
 
-#include "iggparameter.h"
 
 class iColor;
 class iDataInfo;
@@ -82,6 +81,20 @@ class ibgMainWindowSubject;
 class ibgWindowSubject;
 
 
+namespace iParameter
+{
+	//
+	//  Popup types
+	//
+	namespace PopupWindow
+	{
+		const int Message =		0;
+		const int Warning =		1;
+		const int Error =		2;
+	};
+};
+
+
 class iggMainWindow : public iObject, public iggMenuWindow
 {
 
@@ -130,9 +143,9 @@ public:
 	//
 	//  User notification
 	//
-	int PopupWindow(const iString &text, int type = iggParameter::_PopupWindowMessage, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
-	int PopupWindow(const iggFrame *parent, const iString &text, int type = iggParameter::_PopupWindowMessage, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
-	int PopupWindow(const iggRenderWindow *parent, const iString &text, int type = iggParameter::_PopupWindowMessage, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
+	int PopupWindow(const iString &text, int type = iParameter::PopupWindow::Message, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
+	int PopupWindow(const iggFrame *parent, const iString &text, int type = iParameter::PopupWindow::Message, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
+	int PopupWindow(const iggRenderWindow *parent, const iString &text, int type = iParameter::PopupWindow::Message, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
 
 	void WriteToLog(const iString &prefix, const iString &message, const iColor &c = iColor(0,0,0));
 	void WriteToLog(const iString &message);
@@ -317,6 +330,7 @@ private:
 	static const iObjectKey& KeyWindowUnderFocusCurrent();
 	static const iObjectKey& KeyIsIdiosyncratic();
 	static const iObjectKey& KeyTabMode();
+	static const iObjectKey& KeyBookOrientation();
 	static const iObjectKey& KeyTheme();
 	static const iObjectKey& KeySlidersAreEditable();
 	static const iObjectKey& KeyAllowPrePopulateToolBar();
