@@ -101,7 +101,7 @@ iString iggMenuWindow::GetFileName(const iString &header, const iString &file, c
 			{
 				if(iFile::IsReadable(res))
 				{
-					if(mMainWindow->PopupWindow("Do you want to overwrite the existing file?",iggParameter::_PopupWindowWarning,"Ok","Cancel") == 1) res.Clear();
+					if(mMainWindow->PopupWindow("Do you want to overwrite the existing file?",iParameter::PopupWindow::Warning,"Ok","Cancel") == 1) res.Clear();
 				}
 			}
 		}
