@@ -57,4 +57,10 @@ void iggPage::ShowPage(int n)
 	if(mBook != 0) mBook->OpenPage(n);
 }
 
+
+void iggPage::SetOrientation(int v)
+{
+	if(mBook != 0) mBook->SetOrientation(v);
+}
+
 #endif
