@@ -60,9 +60,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetselectionboxsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
 
 //
 //  Templates (needed for some compilers)
@@ -70,6 +67,10 @@ using namespace iParameter;
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
+
 namespace iggPageCrossSection_Private
 {
 	//
@@ -82,7 +83,7 @@ namespace iggPageCrossSection_Private
 		
 		DownsampleCheckBox(iggFrame *parent) : iggWidget(parent)
 		{
-			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,"Downsample while moving",1);
+			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Downsample while moving",1);
 			this->SetBaloonHelp("Toggles whether the cross section is downsampled while moving.","When the cross section is moving across the box, the data are being constantly resampled. If the size of the dataset is too large, resampling will take too much time, and the position slider will not feel interactive, but will be \"dragging\" behind. To avoid this, if this box is checked, IFrIT will downsample the data to maintain the interactive performance.");
 		}
 
@@ -108,7 +109,7 @@ namespace iggPageCrossSection_Private
 
 	public:
 		
-		PositionSlider(iggFrame *parent) : iggWidgetKeyPositionSlider(8,"Position",iCrossSectionViewSubject::KeyLocation(true),_RenderModeImmediate,parent)
+		PositionSlider(iggFrame *parent) : iggWidgetKeyPositionSlider(8,"Position",iCrossSectionViewSubject::KeyLocation(true),RenderMode::Immediate,parent)
 		{
 			mDownsampleBuddy = 0;
 			mSelfChecking = true;
@@ -128,7 +129,7 @@ namespace iggPageCrossSection_Private
 			if(mDownsampleBuddy->IsDown())
 			{
 				int oldrf, mod = -1;
-				if(this->GetExecuteFlags() & _ModuleOptionAll) mod = -2;
+				if(this->GetExecuteFlags() & ModuleOption::All) mod = -2;
 
 				this->GetShell()->GetControlModule()->QueryValue(iCrossSectionViewSubject::KeySampleRate(),oldrf);
 				int newrf = round(oldrf*sqrt(10.0*this->GetShell()->GetControlModule()->GetUpdateTime(mod)));
@@ -299,7 +300,7 @@ namespace iggPageCrossSection_Private
 using namespace iggPageCrossSection_Private;
 
 
-iggPageCrossSection::iggPageCrossSection(iggFrameBase *parent) : iggPageObject(parent,iParameter::_ObjectTypeCrossSection)
+iggPageCrossSection::iggPageCrossSection(iggFrameBase *parent) : iggPageObject(parent,ViewSubject::Id::CrossSection)
 {
 	const iImage *icon = iImageFactory::FindIcon("xsec.png");
 
