@@ -67,9 +67,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgethelper.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
 
 //
 //  Templates
@@ -81,6 +78,10 @@ using namespace iParameter;
 #include "iggwidgetkeyslidertemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
+
 namespace iggPageData_Private
 {
 	//
@@ -150,12 +151,12 @@ namespace iggPageData_Private
 
 					if(mOut)
 					{
-						if(s==_StretchLog && fmax-fmin>2.0f) d = 1.0f; else d = 0.5f*(fmax-fmin);
+						if(s==iDataStretch::Log && fmax-fmin>2.0f) d = 1.0f; else d = 0.5f*(fmax-fmin);
 					}
 					else
 					{
 
-						if(s==_StretchLog && fmax-fmin>4.0f) d = -1.0f; else d = -0.25f*(fmax-fmin);
+						if(s==iDataStretch::Log && fmax-fmin>4.0f) d = -1.0f; else d = -0.25f*(fmax-fmin);
 
 						const iObjectKey &keyLL = mPage->GetProvider(0)->Translate(iDataSubject::KeyLowerLimit());
 						const iObjectKey &keyUL = mPage->GetProvider(0)->Translate(iDataSubject::KeyUpperLimit());
@@ -202,7 +203,7 @@ namespace iggPageData_Private
 		LimitsStretchComboBox(const iggPageData *page, iggFrame *parent, int index) : iggWidgetKeyStretchComboBox(iDataSubject::KeyStretch(),parent,index,0), mPage(page)
 		{
 			this->AttachDataTypeProvider(mPage->GetProvider(0));
-			this->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionClones);
+			this->SetExecuteFlags(ObjectOption::One|ModuleOption::One|RenderOption::Clones);
 		}
 
 	protected:
@@ -234,10 +235,10 @@ namespace iggPageData_Private
 		
 	public:
 		
-		LimitsNameEdit(const iggPageData *page, iggFrame *parent, int index) : iggWidgetKeyTextLineEdit(false,"Name",iDataSubject::KeyName(),_RenderModeUseGlobal,parent,index,0), mPage(page)
+		LimitsNameEdit(const iggPageData *page, iggFrame *parent, int index) : iggWidgetKeyTextLineEdit(false,"Name",iDataSubject::KeyName(),RenderMode::UseGlobal,parent,index,0), mPage(page)
 		{
 			this->AttachDataTypeProvider(mPage->GetProvider(0));
-			this->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionClones);
+			this->SetExecuteFlags(ObjectOption::One|ModuleOption::One|RenderOption::Clones);
 		}
 
 	protected:
@@ -271,9 +272,9 @@ namespace iggPageData_Private
 		
 	public:
 		
-		LimitsRangeSlider(bool low, const iggPageData *page, iggFrame *parent, int index) : iggWidgetKeyVariableLimitsSlider(page->GetProvider(0),7,low?"Min":"Max",low?iDataSubject::KeyLowerLimit():iDataSubject::KeyUpperLimit(),0,0,_RenderModeUseGlobal,parent,index), mPage(page)
+		LimitsRangeSlider(bool low, const iggPageData *page, iggFrame *parent, int index) : iggWidgetKeyVariableLimitsSlider(page->GetProvider(0),7,low?"Min":"Max",low?iDataSubject::KeyLowerLimit():iDataSubject::KeyUpperLimit(),0,0,RenderMode::UseGlobal,parent,index), mPage(page)
 		{
-			this->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionClones);
+			this->SetExecuteFlags(ObjectOption::One|ModuleOption::One|RenderOption::Clones);
 			mSubject->FreezeNumberOfDigits(true);
 		}
 
@@ -431,9 +432,9 @@ namespace iggPageData_Private
 
 	public:
 
-		ShiftingSlider(const iString &title, const iObjectKey &key, iggFrame *parent, int index) : iggWidgetKeyDoubleSlider(-1.0,1.0,200,0,5,title,key,_RenderModeUseGlobal,parent,index)
+		ShiftingSlider(const iString &title, const iObjectKey &key, iggFrame *parent, int index) : iggWidgetKeyDoubleSlider(-1.0,1.0,200,0,5,title,key,RenderMode::UseGlobal,parent,index)
 		{
-			this->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionClones);
+			this->SetExecuteFlags(ObjectOption::One|ModuleOption::One|RenderOption::Clones);
 		}
 
 	protected:
@@ -443,7 +444,7 @@ namespace iggPageData_Private
 			this->QueryValue(mValue);
 			this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->SetDataShift(mIndex,mValue);
 			
-			if(final || this->GetRenderMode()==_RenderModeImmediate)
+			if(final || this->GetRenderMode()==RenderMode::Immediate)
 			{
 				this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->ShiftData();
 				this->GetShell()->GetControlModule()->Execute("",this->GetMainWindow()->IsAutoRender(),this->GetExecuteFlags());
@@ -463,7 +464,7 @@ namespace iggPageData_Private
 
 		EraseCheckBox(const iDataType &type, const iString &title, iggFrame *parent) : iggWidget(parent), mType(type)
 		{
-			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,title,1);
+			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,title,1);
 
 			iString tt = "Check this box if you would like to erase these data.";
 			this->SetBaloonHelp(tt);
@@ -658,7 +659,7 @@ namespace iggPageData_Private
 
 	public:
 
-		CalculatorDialog(const iDataInfo &info, iggWidgetKeyTextLineEdit *le, iggMainWindow *mw) : iggDialog(mw,_DialogModal,0,"Array Calculator","sr.gg.da",2), mInfo(info)
+		CalculatorDialog(const iDataInfo &info, iggWidgetKeyTextLineEdit *le, iggMainWindow *mw) : iggDialog(mw,DialogFlag::Modal,0,"Array Calculator","sr.gg.da",2), mInfo(info)
 		{
 			mLineEdit = le;
 
@@ -778,14 +779,14 @@ namespace iggPageData_Private
 				}
 				else
 				{
-					mFrame->GetMainWindow()->PopupWindow("Result is not a scalar",_PopupWindowError);
+					mFrame->GetMainWindow()->PopupWindow("Result is not a scalar",PopupWindow::Error);
 					return false;
 				}
 			}
 			else
 			{
 				mCalculatorLineEdit->SelectText(calc.GetErrorPosition());
-				mFrame->GetMainWindow()->PopupWindow(calc.GetErrorMessage(),_PopupWindowError);
+				mFrame->GetMainWindow()->PopupWindow(calc.GetErrorMessage(),PopupWindow::Error);
 				return false;
 			}
 		}
@@ -810,7 +811,6 @@ namespace iggPageData_Private
 
 	protected:
 
-
 		virtual void UpdateWidgetBody()
 		{
 			this->Enable(this->GetMainWindow()->GetReloadDataInfo().Count()>0 && this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->IsThereData(this->GetMainWindow()->GetReloadDataInfo()));
@@ -822,6 +822,35 @@ namespace iggPageData_Private
 			this->Enable(false);
 		}
 	};
+
+
+	class ParticleExtraPage : public iggFrame
+	{
+
+	public:
+
+		ParticleExtraPage(iggFrameBook *parent, iggDataTypeProvider *provider) : iggFrame(parent,2)
+		{
+			mProvider = provider; IERROR_ASSERT(mProvider);
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			bool b;
+
+			const iObjectKey &key = mProvider->Translate(iParticleDataSubject::KeyUseExtras());
+			if(this->GetShell()->GetControlModule()->QueryValue(key,b))
+			{
+				this->Enable(b);
+			}
+
+			this->iggFrame::UpdateWidgetBody();
+		}
+
+		iggDataTypeProvider *mProvider;
+	};
 };
 
 
@@ -832,14 +861,14 @@ iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
 {
 	const iImage *icon = iImageFactory::FindIcon("data.png");
 
-	mInfoBuffer = new iDataInfo[__NumDataWith]; IERROR_ASSERT(mInfoBuffer);
+	mInfoBuffer = new iDataInfo[DataWith::COUNT]; IERROR_ASSERT(mInfoBuffer);
 	mProvider = new iggCompositeDataTypeProvider(this); IERROR_ASSERT(mProvider);
 	mProvider->AddProvider(new iggKeywordDataTypeProvider("scalars",this));
 	mProvider->AddProvider(new iggKeywordDataTypeProvider("particles",this));
 
-	iDataType::FindTypesByKeywords(mInfoBuffer[_DataWithParticleDownsampling],"particles");
-	mInfoBuffer[_DataWithBoundaryCondition] = mInfoBuffer[_DataWithParticleDownsampling] + iUniformScalarsDataSubject::DataType() + iUniformVectorsDataSubject::DataType() + iUniformTensorsDataSubject::DataType();
-	mInfoBuffer[_DataWithVariableCalculation] = iUniformScalarsDataSubject::DataType();
+	iDataType::FindTypesByKeywords(mInfoBuffer[DataWith::ParticleDownsampling],"particles");
+	mInfoBuffer[DataWith::BoundaryCondition] = mInfoBuffer[DataWith::ParticleDownsampling] + iUniformScalarsDataSubject::DataType() + iUniformVectorsDataSubject::DataType() + iUniformTensorsDataSubject::DataType();
+	mInfoBuffer[DataWith::VariableCalculation] = iUniformScalarsDataSubject::DataType();
 
 	this->GetMainWindow()->GetExtensionWindow()->AddReloadingDataTypes(this);
 
@@ -872,7 +901,7 @@ iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
 				sbpage0->AddLine(orb);
 				sbpage0->AddSpace(2);
 
-				iggWidgetKeyRadioBox *bc = new iggReloading<iggWidgetKeyRadioBox>(mInfoBuffer[_DataWithBoundaryCondition],0,1,"Boundary conditions",0,iDataReader::KeyBoundaryConditions(),sbpage0);
+				iggWidgetKeyRadioBox *bc = new iggReloading<iggWidgetKeyRadioBox>(mInfoBuffer[DataWith::BoundaryCondition],0,1,"Boundary conditions",0,iDataReader::KeyBoundaryConditions(),sbpage0);
 				bc->InsertItem("Periodic");
 				bc->InsertItem("Wall");
 				sbpage0->AddLine(bc);
@@ -977,21 +1006,21 @@ iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
 			//
 			//  Operate page
 			//
-			iggFrame *fbpage3 = new iggReloading<iggFrame>(mInfoBuffer[_DataWithVariableCalculation],mProvider->GetProvider(0),fb,2);
+			iggFrame *fbpage3 = new iggReloading<iggFrame>(mInfoBuffer[DataWith::VariableCalculation],mProvider->GetProvider(0),fb,2);
 			fb->AddPage("Operate",icon,fbpage3);
 			{
-				iggFrameDataVariableList *ol = new iggFrameDataVariableList(mInfoBuffer[_DataWithVariableCalculation],mProvider->GetProvider(0),"Assign result to...",iUniformScalarsDataSubject::KeyVariableCalculatorOutput(),0,fbpage3);
+				iggFrameDataVariableList *ol = new iggFrameDataVariableList(mInfoBuffer[DataWith::VariableCalculation],mProvider->GetProvider(0),"Assign result to...",iUniformScalarsDataSubject::KeyVariableCalculatorOutput(),0,fbpage3);
 				ol->Complete();
 				iggFrame *of = new iggFrame(fbpage3,1);
 				of->AddSpace(10);
-				iggWidgetKeyTextLineEdit *oe = new iggWidgetKeyTextLineEdit(true,"= ",iUniformScalarsDataSubject::KeyVariableCalculatorFunction(),_RenderModeNoRender,of);
+				iggWidgetKeyTextLineEdit *oe = new iggWidgetKeyTextLineEdit(true,"= ",iUniformScalarsDataSubject::KeyVariableCalculatorFunction(),RenderMode::NoRender,of);
 				of->AddLine(oe);
 				of->AddSpace(10);
 				fbpage3->AddLine(ol,of);
 				fbpage3->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",fbpage3));
 				fbpage3->AddSpace(2);
 
-				CalculatorDialog *cd = new CalculatorDialog(mInfoBuffer[_DataWithVariableCalculation],oe,this->GetMainWindow());
+				CalculatorDialog *cd = new CalculatorDialog(mInfoBuffer[DataWith::VariableCalculation],oe,this->GetMainWindow());
 				fbpage3->AddLine(new iggWidgetLaunchButton(cd,"Launch calculator",fbpage3,true));
 				fbpage3->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",fbpage3));
 
@@ -1021,13 +1050,13 @@ iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
 			iggFrame *pbpage0 = new iggFrame(pb,2);
 			pb->AddPage("Downsample",icon,pbpage0);
 			{
-				iggWidgetKeyIntSlider *dl = new iggReloading<iggWidgetKeyIntSlider>(mInfoBuffer[_DataWithParticleDownsampling],mProvider->GetProvider(1),1,100,3,"Factor",iParticleDataSubject::KeyDownsampleFactor(),_RenderModeNoRender,pbpage0);
+				iggWidgetKeyIntSlider *dl = new iggReloading<iggWidgetKeyIntSlider>(mInfoBuffer[DataWith::ParticleDownsampling],mProvider->GetProvider(1),1,100,3,"Factor",iParticleDataSubject::KeyDownsampleFactor(),RenderMode::NoRender,pbpage0);
 				dl->AttachDataTypeProvider(mProvider->GetProvider(1));
 
 				pbpage0->AddLine(dl,2);
 				pbpage0->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",pbpage0));
 
-				iggWidgetKeyRadioBox *db = new iggReloading<iggWidgetKeyRadioBox>(mInfoBuffer[_DataWithParticleDownsampling],mProvider->GetProvider(1),1,"Downsample mask",0,iParticleDataSubject::KeyDownsampleMode(),pbpage0);
+				iggWidgetKeyRadioBox *db = new iggReloading<iggWidgetKeyRadioBox>(mInfoBuffer[DataWith::ParticleDownsampling],mProvider->GetProvider(1),1,"Downsample mask",0,iParticleDataSubject::KeyDownsampleMode(),pbpage0);
 				db->InsertItem("Regular");
 				db->InsertItem("Regular 2D");
 				db->InsertItem("Regular 3D");
@@ -1045,17 +1074,17 @@ iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
 			//
 			//  Operate page
 			//
-			iggFrame *pbpage1 = new iggFrame(pb,2);
+			iggFrame *pbpage1 = new ParticleExtraPage(pb,mProvider->GetProvider(1));
 			pb->AddPage("Operate",icon,pbpage1);
 			{
-				iggWidgetKeyCheckBox *oa = new iggReloading<iggWidgetKeyCheckBox>(mInfoBuffer[_DataWithParticleDownsampling],mProvider->GetProvider(1),"Include the particle number as an attribute",iParticleDataSubject::KeyOrderIsAttribute(),pbpage1);
+				iggWidgetKeyCheckBox *oa = new iggReloading<iggWidgetKeyCheckBox>(mInfoBuffer[DataWith::ParticleDownsampling],mProvider->GetProvider(1),"Include the particle number as an attribute",iParticleDataSubject::KeyOrderIsAttribute(),pbpage1);
 				oa->AttachDataTypeProvider(mProvider->GetProvider(1));
 				pbpage1->AddLine(oa);
 				pbpage1->AddLine(new iggWidgetTextArea("%b(May require reloading of data)",pbpage1));
 
 				pbpage1->AddSpace(2);
 
-				iggFrameDataVariableList *al = new iggFrameDataVariableList(mInfoBuffer[_DataWithParticleDownsampling],mProvider->GetProvider(1),"Compute density of...",iParticleDataSubject::KeyDensityAttribute(),0,pbpage1);
+				iggFrameDataVariableList *al = new iggFrameDataVariableList(mInfoBuffer[DataWith::ParticleDownsampling],mProvider->GetProvider(1),"Compute density of...",iParticleDataSubject::KeyDensityAttribute(),0,pbpage1);
 				al->InsertItem("Do not compute");
 				al->InsertItem("Particle number");
 				al->Complete();
@@ -1099,7 +1128,7 @@ void iggPageData::UpdateOnDataLoad()
 
 void iggPageData::AddReloadingType(int key, const iDataType &type)
 {
-	if(key>=0 && key<__NumDataWith)
+	if(key>=0 && key<DataWith::COUNT)
 	{
 		mInfoBuffer[key] += type;
 	}
