@@ -43,6 +43,21 @@ class iggCompositeDataTypeProvider;
 class iggKeywordDataTypeProvider;
 
 
+namespace iParameter
+{
+	//
+	//  Reloading widget conditions
+	//
+	namespace DataWith
+	{
+		const int BoundaryCondition = 0;
+		const int VariableCalculation = 1;
+		const int ParticleDownsampling = 2;
+		const int COUNT = 3;
+	};
+};
+
+
 class iggPageData : public iggPageMain
 {
 
