@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggpageobject.h"
 
 
@@ -77,3 +81,4 @@ iViewObject* iggPageObject::GetViewObject() const
 	return this->GetViewModule()->GetViewObjectFamily(mType)->GetCurrentMember();
 }
 
+#endif
