@@ -66,10 +66,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ibgwidgetbuttonsubject.h"
 
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
-
 //
 //  Templates (needed for some compilers)
 //
@@ -77,6 +73,10 @@ using namespace iParameter;
 #include "iggwidgetkeyslidertemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
+
 namespace iggPageParticles_Private
 {
 	//
@@ -92,6 +92,11 @@ namespace iggPageParticles_Private
 			mDependent = dependent;
 		}
 
+		virtual void OnChange()
+		{
+			this->GetShell()->GetControlModule()->GetViewModule()->GetParticlesViewSubject()->ClearCache();
+		}
+
 		virtual bool IsActive()
 		{
 			int att;
@@ -233,7 +238,7 @@ namespace iggPageParticles_Private
 using namespace iggPageParticles_Private;
 
 
-iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,iParameter::_ObjectTypeParticles)
+iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,ViewSubject::Id::Particles)
 {
 	int i;
 
@@ -277,7 +282,7 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,
 	iggWidgetKeyComboBox *tb = new iggWidgetKeyComboBox("Type",0,iParticleGroup::KeyType(),tf1);
 	tf1->AddLine(tb);
 	tf1->AddSpace(10);
-	for(i=0; i<__NumPointTypes; i++)
+	for(i=0; i<PointGlyphType::SIZE; i++)
 	{
 		tb->InsertItem(iPointGlyph::GetName(i));
 	}
@@ -288,10 +293,10 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,
 	//
 	//  Opacity
 	//
-	iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(1.0e-4,1.0,40,1,5,"Opacity",iParticleGroup::KeyOpacity(),_RenderModeUseGlobal,page0);
+	iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(1.0e-4,1.0,40,1,5,"Opacity",iParticleGroup::KeyOpacity(),RenderMode::UseGlobal,page0);
 	os->SetStretch(2,10);
 	page0->AddLine(os,2);
-	iggWidgetKeyFloatSlider *ss = new iggWidgetKeyFloatSlider(1.0e-2,1.0e2,40,1,5,"Size",iParticleGroup::KeyFixedSize(),_RenderModeUseGlobal,page0);
+	iggWidgetKeyFloatSlider *ss = new iggWidgetKeyFloatSlider(1.0e-2,1.0e2,40,1,5,"Size",iParticleGroup::KeyFixedSize(),RenderMode::UseGlobal,page0);
 	ss->SetStretch(2,10);
 	page0->AddLine(ss,2);
 	iggFrame *tmp = new iggFrame(page0,4);
@@ -334,8 +339,8 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,
 
 	pbpage0->AddSpace(5);
 
-	iggWidgetKeyVariableLimitsSlider *al = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Min",iParticleGroup::KeyLowerLimitToColor(),&iParticleGroup::KeyAttributeToColor(),&iParticleGroup::KeyStretchToColor(),_RenderModeUseGlobal,pbpage0,0,&iParticleGroup::KeyAttributeToColor());
-	iggWidgetKeyVariableLimitsSlider *au = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Max",iParticleGroup::KeyUpperLimitToColor(),&iParticleGroup::KeyAttributeToColor(),&iParticleGroup::KeyStretchToColor(),_RenderModeUseGlobal,pbpage0,0,&iParticleGroup::KeyAttributeToColor());
+	iggWidgetKeyVariableLimitsSlider *al = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Min",iParticleGroup::KeyLowerLimitToColor(),&iParticleGroup::KeyAttributeToColor(),&iParticleGroup::KeyStretchToColor(),RenderMode::UseGlobal,pbpage0,0,&iParticleGroup::KeyAttributeToColor());
+	iggWidgetKeyVariableLimitsSlider *au = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Max",iParticleGroup::KeyUpperLimitToColor(),&iParticleGroup::KeyAttributeToColor(),&iParticleGroup::KeyStretchToColor(),RenderMode::UseGlobal,pbpage0,0,&iParticleGroup::KeyAttributeToColor());
 	pl->AddDependent(al);
 	pl->AddDependent(au);
 	ls->AddDependent(al);
@@ -391,14 +396,14 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,
 	tmp->AddLine(lz);
 	tmp->AddSpace(10);
 	sf->AddLine(sl,tmp);
-	sf->AddLine(new iggWidgetKeyCheckBox("Use as size; scale by",iParticleGroup::KeyAttributeSizeDirect(),sf),new iggWidgetKeyFloatLineEdit("",iParticleGroup::KeyAttributeSizeExtraFactor(),_RenderModeUseGlobal,sf));
+	sf->AddLine(new iggWidgetKeyCheckBox("Use as size; scale by",iParticleGroup::KeyAttributeSizeDirect(),sf),new iggWidgetKeyFloatLineEdit("",iParticleGroup::KeyAttributeSizeExtraFactor(),RenderMode::UseGlobal,sf));
 	
 	sbpage0->AddLine(sf);
 
 	sbpage0->AddSpace(5);
 
-	iggWidgetKeyVariableLimitsSlider *bl = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Min",iParticleGroup::KeyLowerLimitToSize(),&iParticleGroup::KeyAttributeToSize(),&iParticleGroup::KeyStretchToSize(),_RenderModeUseGlobal,sbpage0,0,&iParticleGroup::KeyAttributeToSize());
-	iggWidgetKeyVariableLimitsSlider *bu = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Max",iParticleGroup::KeyUpperLimitToSize(),&iParticleGroup::KeyAttributeToSize(),&iParticleGroup::KeyStretchToSize(),_RenderModeUseGlobal,sbpage0,0,&iParticleGroup::KeyAttributeToSize());
+	iggWidgetKeyVariableLimitsSlider *bl = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Min",iParticleGroup::KeyLowerLimitToSize(),&iParticleGroup::KeyAttributeToSize(),&iParticleGroup::KeyStretchToSize(),RenderMode::UseGlobal,sbpage0,0,&iParticleGroup::KeyAttributeToSize());
+	iggWidgetKeyVariableLimitsSlider *bu = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Max",iParticleGroup::KeyUpperLimitToSize(),&iParticleGroup::KeyAttributeToSize(),&iParticleGroup::KeyStretchToSize(),RenderMode::UseGlobal,sbpage0,0,&iParticleGroup::KeyAttributeToSize());
 	sl->AddDependent(bl);
 	sl->AddDependent(bu);
 	lz->AddDependent(bl);
