@@ -64,9 +64,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetselectionboxsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
 
 //
 //  Templates (needed for some compilers)
@@ -74,6 +71,10 @@ using namespace iParameter;
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
+
 namespace iggPageSurface_Private
 {
 	//
@@ -258,7 +259,7 @@ namespace iggPageSurface_Private
 			mSubject->PlaceWidget(1,3,mSpinBox3,1,true);
 
 			mSubject->PlaceWidget(0,4,iggSubjectFactory::CreateWidgetDisplayAreaSubject(frame,""),1,true);
-			mButton = iggSubjectFactory::CreateWidgetButtonSubject(frame,_ButtonTypePushButton,"Create",1);
+			mButton = iggSubjectFactory::CreateWidgetButtonSubject(frame,ButtonType::PushButton,"Create",1);
 			mSubject->PlaceWidget(1,4,mButton,1,true);
 
 			this->SetColStretch(0,10);
@@ -308,15 +309,15 @@ namespace iggPageSurface_Private
 			//  Split one if for debugging
 			//
 			if(mSpinBox1->GetValue() == mSpinBox2->GetValue()) return false;
-			dc1 = this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(_ObjectTypeSurface)->GetMember(mSpinBox1->GetValue()-1)->GetActiveDataTypeIndex();
-			dc2 = this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(_ObjectTypeSurface)->GetMember(mSpinBox2->GetValue()-1)->GetActiveDataTypeIndex();
+			dc1 = this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(ViewSubject::Id::Surface)->GetMember(mSpinBox1->GetValue()-1)->GetActiveDataTypeIndex();
+			dc2 = this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(ViewSubject::Id::Surface)->GetMember(mSpinBox2->GetValue()-1)->GetActiveDataTypeIndex();
 				
 			if(!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyMethod(),m1,-1,mSpinBox1->GetValue()-1)) return false;
 			if(!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyMethod(),m2,-1,mSpinBox2->GetValue()-1)) return false;
 			if(!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceVar(),v1,-1,mSpinBox1->GetValue()-1)) return false;
 			if(!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceVar(),v2,-1,mSpinBox2->GetValue()-1)) return false;
 
-			return (m1==m2) && (m1!=_SurfaceMethodIsoSurface || v1==v2) && (dc1==dc2);
+			return (m1==m2) && (m1!=SurfaceMethod::IsoSurface || v1==v2) && (dc1==dc2);
 		}
 
 		virtual void OnInt1Body(int)
@@ -341,7 +342,7 @@ namespace iggPageSurface_Private
 				return;
 			}
 
-			dc = this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(_ObjectTypeSurface)->GetMember(mSpinBox1->GetValue()-1)->GetActiveDataTypeIndex();
+			dc = this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(ViewSubject::Id::Surface)->GetMember(mSpinBox1->GetValue()-1)->GetActiveDataTypeIndex();
 
 			if(
 				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyMethod(),m,-1,mSpinBox1->GetValue()-1) ||
@@ -378,7 +379,7 @@ namespace iggPageSurface_Private
 				dstp[i] = (dmax[i]-dmin[i])/(nmax+1);
 			}
 
-			if((m==_SurfaceMethodIsoSurface) && (fabs(lstp)<0.01))
+			if((m==SurfaceMethod::IsoSurface) && (fabs(lstp)<0.01))
 			{
 				IERROR_LOW("Cannot create new isosurface: the two limits are too close.");
 				mWidgetHelper->Enable(false);
@@ -399,7 +400,7 @@ namespace iggPageSurface_Private
 
 				if(this->GetShell()->GetControlModule()->CreateObject(iSurfaceViewSubject::Type(),false))
 				{
-					this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(_ObjectTypeSurface)->GetCurrentMember()->SetActiveDataTypeIndex(dc);
+					this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(ViewSubject::Id::Surface)->GetCurrentMember()->SetActiveDataTypeIndex(dc);
 					//
 					//  Set the parameters of the new instance
 					//
@@ -454,7 +455,7 @@ namespace iggPageSurface_Private
 using namespace iggPageSurface_Private;
 
 
-iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageObject(parent,iParameter::_ObjectTypeSurface)
+iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageObject(parent,ViewSubject::Id::Surface)
 {
 	const iImage *icon = iImageFactory::FindIcon("surf.png");
 
@@ -495,7 +496,7 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageObject(parent,iPar
 	//
 	//  Opacity
 	//
-	iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,5,"Opacity",iSurfaceViewSubject::KeyOpacity(),_RenderModeUseGlobal,page0top);
+	iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,5,"Opacity",iSurfaceViewSubject::KeyOpacity(),RenderMode::UseGlobal,page0top);
 	page0top->AddLine(os,3);
 	iggWidgetAllInstancesCheckBox *li = new iggWidgetAllInstancesCheckBox(page0top);
 	li->AddDependent(os);
@@ -546,7 +547,7 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageObject(parent,iPar
 	
 	mspage0->AddSpace(10);
 
-	iggWidget *il = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Level",iSurfaceViewSubject::KeyIsoSurfaceLevel(),&iSurfaceViewSubject::KeyIsoSurfaceVar(),0,_RenderModeUseGlobal,mspage0);
+	iggWidget *il = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Level",iSurfaceViewSubject::KeyIsoSurfaceLevel(),&iSurfaceViewSubject::KeyIsoSurfaceVar(),0,RenderMode::UseGlobal,mspage0);
 	io->AddDependent(il);
 	mspage0->AddLine(il,3);
 	
