@@ -51,9 +51,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ibgwidgetentrysubject.h"
 
-#include "iggparameter.h"
-using namespace iggParameter;
-
 //
 //  Templates (needed for some compilers)
 //
@@ -61,7 +58,11 @@ using namespace iggParameter;
 #include "iggwidgetkeyslidertemplate.h"
 
 
-iggPageTensorField::iggPageTensorField(iggFrameBase *parent) : iggPageObject(parent,iParameter::_ObjectTypeTensorField)
+using namespace iParameter;
+using namespace iParameter;
+
+
+iggPageTensorField::iggPageTensorField(iggFrameBase *parent) : iggPageObject(parent,ViewSubject::Id::TensorField)
 {
 	const iImage *icon = iImageFactory::FindIcon("tens.png");
 
@@ -88,17 +89,17 @@ iggPageTensorField::iggPageTensorField(iggFrameBase *parent) : iggPageObject(par
 	//
 	//  Glyph size
 	//
-	page0->AddLine(new iggWidgetKeySizeSlider(1.0e-5,0,"Glyph size",iTensorFieldViewSubject::KeyGlyphSize(true),_RenderModeUseGlobal,page0),2);
+	page0->AddLine(new iggWidgetKeySizeSlider(1.0e-5,0,"Glyph size",iTensorFieldViewSubject::KeyGlyphSize(true),RenderMode::UseGlobal,page0),2);
 	page0->AddSpace(2);
 	//
 	//  Tensor magnitude and downsample
 	//
-	//iggWidgetKeyRelativeFloatSlider *ms = new iggWidgetKeyRelativeFloatSlider(iDataSubject::KeyMax(),0.0,1.0,100,0,5,"Tensor magnitude",iDataSubject::KeyUpperLimit(),_RenderModeUseGlobal,page0,0);
+	//iggWidgetKeyRelativeFloatSlider *ms = new iggWidgetKeyRelativeFloatSlider(iDataSubject::KeyMax(),0.0,1.0,100,0,5,"Tensor magnitude",iDataSubject::KeyUpperLimit(),RenderMode::UseGlobal,page0,0);
 	//ms->AttachDataTypeProvider(mProvider);
-	iggWidgetKeyVariableLimitsSlider *ms = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Tensor magnitude",iDataSubject::KeyUpperLimit(),0,0,_RenderModeUseGlobal,page0,0);
+	iggWidgetKeyVariableLimitsSlider *ms = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Tensor magnitude",iDataSubject::KeyUpperLimit(),0,0,RenderMode::UseGlobal,page0,0);
 	ms->SetStretch(5,10,0);
 	page0->AddLine(ms,2);
-	iggWidgetKeyIntSlider *rs = new iggWidgetKeyIntSlider(1,20,5,"Sample rate",iTensorFieldViewSubject::KeyGlyphSampleRate(),_RenderModeUseGlobal,page0);
+	iggWidgetKeyIntSlider *rs = new iggWidgetKeyIntSlider(1,20,5,"Sample rate",iTensorFieldViewSubject::KeyGlyphSampleRate(),RenderMode::UseGlobal,page0);
 	rs->SetStretch(5,10,0);
 	page0->AddLine(rs,2);
 	page0->AddSpace(10);
