@@ -45,6 +45,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "imarker.h"
 #include "imarkerfamily.h"
 #include "ipalette.h"
+#include "ipaletteset.h"
 #include "ipointglyph.h"
 #include "irendertool.h"
 #include "ishell.h"
@@ -86,11 +87,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <vtkCamera.h>
 #include <vtkRenderer.h>
+#include <vtkRenderWindow.h>
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
 
 //
 //  Templates (needed for some compilers)
@@ -100,6 +99,9 @@ using namespace iParameter;
 #include "iggwidgetkeyslidertemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
 
 namespace iggPageView_Private
 {
@@ -111,9 +113,9 @@ namespace iggPageView_Private
 		
 	public:
 		
-		ShowColorBarCheckBox(const iObjectKey &key, iggFrame *parent) : iggWidgetKeyHandler<int>(_WidgetTypeOther,key,_RenderModeImmediate,parent,3,0)
+		ShowColorBarCheckBox(const iObjectKey &key, iggFrame *parent) : iggWidgetKeyHandler<int>(WidgetType::Other,key,RenderMode::Immediate,parent,3,0)
 		{
-			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,"Show",1);
+			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Show",1);
 		}
 		
 	protected:
@@ -188,17 +190,17 @@ namespace iggPageView_Private
 				//
 				//  Update palettes
 				//
-				int i, np = this->GetShell()->GetControlModule()->GetNumberOfPalettes();
+				int i, np = iPaletteSet::Default()->GetNumberOfPalettes();
 				mPaletteList->Clear();
 				mPaletteList->SetOffset(np-1);
-				for(i=-np+1; i<=0; i++)
+				for(i=np-1; i>=0; i--)
 				{
-					mPaletteList->InsertItem(this->GetShell()->GetControlModule()->GetPalette(-i)->GetName()+" reversed");
+					mPaletteList->InsertItem(iPaletteSet::Default()->GetPalette(i)->GetName()+" reversed");
 				}
 				mPaletteList->InsertItem("Do not show");
 				for(i=0; i<np; i++)
 				{
-					mPaletteList->InsertItem(this->GetShell()->GetControlModule()->GetPalette(i)->GetName());
+					mPaletteList->InsertItem(iPaletteSet::Default()->GetPalette(i)->GetName());
 				}
 				//
 				//  Update data type
@@ -261,7 +263,7 @@ namespace iggPageView_Private
 
 	public:
 
-		ViewImageDialog(iggMainWindow *parent, const iImage &image) : iggDialog(parent,_DialogModal,0,"View Image",0,1)
+		ViewImageDialog(iggMainWindow *parent, const iImage &image) : iggDialog(parent,DialogFlag::Modal,0,"View Image",0,1)
 		{
 			mArea = new iggWidgetImageArea(image,false,mFrame);
 			mFrame->AddLine(mArea);
@@ -448,9 +450,9 @@ namespace iggPageView_Private
 			this->Select(this->GetShell()->GetControlModule()->GetCurrentViewModuleIndex(),this->GetShell()->GetControlModule()->GetCurrentViewModuleIndex());
 		}
 
-		virtual void OnCursorPositionChanged(int para, int index)
+		virtual void OnCursorPositionChanged(int line, int index)
 		{
-			if(this->GetShell()->GetControlModule()->SetCurrentViewModuleIndex(para)) this->GetMainWindow()->UpdateAll();
+			if(this->GetShell()->GetControlModule()->SetCurrentViewModuleIndex(line)) this->GetMainWindow()->UpdateAll();
 		}
 	};
 
@@ -561,7 +563,7 @@ namespace iggPageView_Private
 
 	public:
 
-		DialogWait(bool create, iggMainWindow *parent) : iggDialog(parent,_DialogBlocking|_DialogNoTitleBar,0,"Working...",0,3,0)
+		DialogWait(bool create, iggMainWindow *parent) : iggDialog(parent,DialogFlag::Blocking|DialogFlag::NoTitleBar,0,"Working...",0,3,0)
 		{
 			mFlipper = new iggWidgetLogoFlipper(mFrame);
 			mFrame->AddLine(0,mFlipper);
@@ -592,19 +594,19 @@ namespace iggPageView_Private
 
 			switch(mType)
 			{
-			case _ModuleTypeNew:
+			case ModuleType::New:
 				{
 					mSubject->SetText("Create new window");
 					this->SetBaloonHelp("Create a new independent window","This button creates a new visualization window. The new window is independent of other windows and has default values of all parameters.");
 					break;
 				}
-			case _ModuleTypeCopy:
+			case ModuleType::Copy:
 				{
 					mSubject->SetText("Copy current window");
 					this->SetBaloonHelp("Copy the current window","This button creates a new visualization window which is a copy of the current visualization window, i.e. it has the same values of all parameters for all objects. The new window is independent of other windows, and has no data associated with it.");
 					break;
 				}
-			case _ModuleTypeClone:
+			case ModuleType::Clone:
 				{
 					mSubject->SetText("Clone current window");
 					this->SetBaloonHelp("Clone the current window","This button creates a clone of the current visualization window. The clone shares the data with the parent window, and at birth has the same values of all parameters for all visualization objects. It does have a separate set of visualization objects however, so the parameters of the parent and the clone window can be changed independently.");
@@ -693,7 +695,7 @@ namespace iggPageView_Private
 
 		WindowUnderFocusCurrentCheckBox(iggFrame *parent) : iggWidget(parent)
 		{
-			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,"Make window under focus current",1);
+			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Make window under focus current",1);
 			this->SetBaloonHelp("Toggles whether the visualization window with the keyboard focus becomes the current one","When this box is checked, moving the leyboard focus into a visualization window will make that window the current one.");
         }
 
@@ -720,7 +722,7 @@ namespace iggPageView_Private
 
 		WidgetsControlAllWindowsCheckBox(iggFrame *parent) : iggWidget(parent)
 		{
-			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,"Widgets control all windows",1);
+			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Widgets control all windows",1);
 			this->SetBaloonHelp("Toggles whether widgets control all visualization windows or only the current one","When this box is checked, widget controls in the gui window will affect all visualization windows, not just the current one. This option should be used with care, since it only makes sense if different visualization windows display similar scenes (for example, the same visualization object for different data files). If the scenes in different visualization windows are unlike each other, the effects of this option may be quite unexpected.");
         }
 
@@ -734,7 +736,7 @@ namespace iggPageView_Private
 		{
 			if(mSubject->IsDown())
 			{
-				iggWidgetKeyHandlerBase::SetGlobalExecuteFlags(_ModuleOptionAll|_RenderOptionAll);
+				iggWidgetKeyHandlerBase::SetGlobalExecuteFlags(ModuleOption::All|RenderOption::All);
 			}
 			else
 			{
@@ -890,8 +892,8 @@ namespace iggPageView_Private
 
 		RulerScaleDialog(iggMainWindow *parent) : iggDialogAuto(parent,"Ruler Scale",2), iggRenderWindowObserver(mFrame)
 		{
-			mFrame->AddLine(new iggWidgetTextArea("Scale",mFrame),new iggWidgetKeyFloatLineEdit("",iViewModule::KeyRulerScale(),_RenderModeUseGlobal,mFrame));
-			mFrame->AddLine(new iggWidgetTextArea("Title",mFrame),new iggWidgetKeyTextLineEdit(false,"",iViewModule::KeyRulerTitle(),_RenderModeUseGlobal,mFrame));
+			mFrame->AddLine(new iggWidgetTextArea("Scale",mFrame),new iggWidgetKeyFloatLineEdit("",iViewModule::KeyRulerScale(),RenderMode::UseGlobal,mFrame));
+			mFrame->AddLine(new iggWidgetTextArea("Title",mFrame),new iggWidgetKeyTextLineEdit(false,"",iViewModule::KeyRulerTitle(),RenderMode::UseGlobal,mFrame));
 			mFrame->AddSpace(10);
 		}
 
@@ -966,10 +968,10 @@ namespace iggPageView_Private
 
 		RecordLabelDialog(iggMainWindow *parent) : iggDialogAuto(parent,"Record Label Properties",3)
 		{
-			mFrame->AddLine(new iggWidgetTextArea("Name",mFrame),new iggWidgetKeyTextLineEdit(false,"",iViewModule::KeyLabelName(),_RenderModeUseGlobal,mFrame),static_cast<iggWidget*>(0));
-			mFrame->AddLine(new iggWidgetTextArea("Unit",mFrame),new iggWidgetKeyTextLineEdit(false,"",iViewModule::KeyLabelUnit(),_RenderModeUseGlobal,mFrame),static_cast<iggWidget*>(0));
-			mFrame->AddLine(new iggWidgetTextArea("Scale",mFrame),new iggWidgetKeyFloatLineEdit("",iViewModule::KeyLabelScale(),_RenderModeUseGlobal,mFrame),static_cast<iggWidget*>(0));
-			mFrame->AddLine(new iggWidgetTextArea("Offset",mFrame),new iggWidgetKeyFloatLineEdit("",iViewModule::KeyLabelOffset(),_RenderModeUseGlobal,mFrame),static_cast<iggWidget*>(0));
+			mFrame->AddLine(new iggWidgetTextArea("Name",mFrame),new iggWidgetKeyTextLineEdit(false,"",iViewModule::KeyLabelName(),RenderMode::UseGlobal,mFrame),static_cast<iggWidget*>(0));
+			mFrame->AddLine(new iggWidgetTextArea("Unit",mFrame),new iggWidgetKeyTextLineEdit(false,"",iViewModule::KeyLabelUnit(),RenderMode::UseGlobal,mFrame),static_cast<iggWidget*>(0));
+			mFrame->AddLine(new iggWidgetTextArea("Scale",mFrame),new iggWidgetKeyFloatLineEdit("",iViewModule::KeyLabelScale(),RenderMode::UseGlobal,mFrame),static_cast<iggWidget*>(0));
+			mFrame->AddLine(new iggWidgetTextArea("Offset",mFrame),new iggWidgetKeyFloatLineEdit("",iViewModule::KeyLabelOffset(),RenderMode::UseGlobal,mFrame),static_cast<iggWidget*>(0));
 			mFrame->AddLine(new iggWidgetKeySpinBox(0,7,"Number of digits after the point",0,iViewModule::KeyLabelDigits(),mFrame),3);
 			mFrame->AddSpace(10);
 		}
@@ -1003,24 +1005,6 @@ namespace iggPageView_Private
 	};
 
 
-	class ShowInStereoCheckBox : public iggWidgetKeyCheckBox, public iggRenderWindowObserver
-	{
-
-	public:
-
-		ShowInStereoCheckBox(iggFrame *parent) : iggWidgetKeyCheckBox("Show in stereo",iViewModule::KeyStereo(),parent), iggRenderWindowObserver(parent)
-		{
-		}
-
-	protected:
-
-		virtual void OnRenderWindowModified()
-		{
-			this->UpdateWidget();
-		}
-	};
-
-
 	class ClippingRangeButton : public iggWidgetSimpleButton
 	{
 
@@ -1140,7 +1124,7 @@ namespace iggPageView_Private
 
 	public:
 
-		StepOnPath(iggFrame *parent) : iggWidgetKeyIntSlider(0,100,5,"Step on path",iAnimator::KeyPositionOnPath(),_RenderModeUseGlobal,parent), iggRenderWindowObserver(parent)
+		StepOnPath(iggFrame *parent) : iggWidgetKeyIntSlider(0,100,5,"Step on path",iAnimator::KeyPositionOnPath(),RenderMode::UseGlobal,parent), iggRenderWindowObserver(parent)
 		{
 		}
 
@@ -1300,7 +1284,7 @@ namespace iggPageView_Private
 
 	public:
 
-		WindowSizeDialog(iggMainWindow *parent) : iggDialog(parent,_DialogModal,0,"Visualization Window Size",0,2,"Set")
+		WindowSizeDialog(iggMainWindow *parent) : iggDialog(parent,DialogFlag::Modal,0,"Visualization Window Size",0,2,"Set")
 		{
 			mBoxes[0] = new iggWidgetSimpleSpinBox(120,32768,1,"",mFrame);
 			mBoxes[1] = new iggWidgetSimpleSpinBox(120,32768,1,"",mFrame);
@@ -1405,7 +1389,7 @@ namespace iggPageView_Private
 
 		virtual void Execute()
 		{
-			if(this->GetMainWindow()->PopupWindow("Please confirm: reseting the counter will overwrite the animation files created so far.",_PopupWindowMessage,"Reset","Cancel") == 0)
+			if(this->GetMainWindow()->PopupWindow("Please confirm: reseting the counter will overwrite the animation files created so far.",PopupWindow::Message,"Reset","Cancel") == 0)
 			{
 				this->GetShell()->GetControlModule()->GetViewModule()->GetWriter()->ResetAnimationImageIndex();
 			}
@@ -1491,9 +1475,66 @@ namespace iggPageView_Private
 
 		int mDir;
 	};
-};
 
 
+	class StereoModeSelector : public iggWidgetKeyComboBox 
+	//class StereoModeSelector : public iggWidgetKeyRadioBox
+	{
+
+	public:
+
+		StereoModeSelector(iggFrame *parent) : 
+		  iggWidgetKeyComboBox("Method",0,iViewModule::KeyStereoMode(),parent)
+		  //iggWidgetKeyRadioBox(1,"Method",0,iViewModule::KeyStereoMode(),parent)
+		  {
+			  this->InsertItem("Mono");
+			  this->InsertItem("Dual windows");
+			  this->InsertItem("Crystal eyes");
+			  this->InsertItem("Blue-red");
+			  this->InsertItem("Interlaced");
+			  this->InsertItem("Left eye only");
+			  this->InsertItem("Right eye only");
+			  this->InsertItem("Dresden display");
+			  this->InsertItem("Anaglyph");
+#ifndef IVTK_PRE54
+			  this->InsertItem("Checkerboard");
+#endif
+		  }
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			this->SetItem("Crystal eyes",2,this->GetShell()->GetControlModule()->GetViewModule()->GetRenderWindow()->GetStereoCapableWindow()!=0);
+		}
+	};
+
+	
+	class StereoHardwareStatus : public iggWidgetTextDisplay
+	{
+
+	public:
+
+		StereoHardwareStatus(iggFrame *parent) : iggWidgetTextDisplay("Stereo harware status: ",parent)
+		{
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			if(this->GetShell()->GetControlModule()->GetViewModule()->GetRenderWindow()->GetStereoCapableWindow() != 0)
+			{
+				this->Display("DETECTED");
+			}
+			else
+			{
+				this->Display("NOT FOUND");
+			}
+		}
+	};
+};
+
 using namespace iggPageView_Private;
 
 
@@ -1585,7 +1626,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 
 			iggFrame *vf = new iggFrame("View angle",sbpage0,1);
 			vf->AddSpace(1);
-			vf->AddLine(new iggWidgetKeyFloatSlider(10.0,120.0,110,0,3,"",iCamera::KeyViewAngle(),_RenderModeUseGlobal,vf));
+			vf->AddLine(new iggWidgetKeyFloatSlider(10.0,120.0,110,0,3,"",iCamera::KeyViewAngle(),RenderMode::UseGlobal,vf));
 			vf->AddLine(new iggWidgetKeyCheckBox("Vertical",iCamera::KeyViewAngleVertical(),vf));
 			vf->AddSpace(10);
 
@@ -1616,13 +1657,13 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			sb->AddPage("Lights",icon,sbpage1);
 
 			iggFrame *db = new iggFrame("Main light direction",sbpage1,1);
-			db->AddLine(new iggWidgetKeyTrackBall(iViewModule::KeyLightAngles(),true,_RenderModeUseGlobal,db));
+			db->AddLine(new iggWidgetKeyTrackBall(iViewModule::KeyLightAngles(),true,RenderMode::UseGlobal,db));
 			sbpage1->AddLine(db);
 
 			iggFrame *ib = new iggFrame("Intensity",sbpage1,1);
-			iggWidgetKeyFloatSlider *mli = new iggWidgetKeyFloatSlider(0.01f,10.0f,200,1,0,"Main light",iViewModule::KeyLightIntensity(),_RenderModeUseGlobal,ib,0);
-			iggWidgetKeyFloatSlider *fli = new iggWidgetKeyFloatSlider(0.01f,10.0f,200,1,0,"Fill light",iViewModule::KeyLightIntensity(),_RenderModeUseGlobal,ib,1);
-			iggWidgetKeyFloatSlider *hli = new iggWidgetKeyFloatSlider(0.01f,10.0f,200,1,0,"Head light",iViewModule::KeyLightIntensity(),_RenderModeUseGlobal,ib,2);
+			iggWidgetKeyFloatSlider *mli = new iggWidgetKeyFloatSlider(0.01f,10.0f,200,1,0,"Main light",iViewModule::KeyLightIntensity(),RenderMode::UseGlobal,ib,0);
+			iggWidgetKeyFloatSlider *fli = new iggWidgetKeyFloatSlider(0.01f,10.0f,200,1,0,"Fill light",iViewModule::KeyLightIntensity(),RenderMode::UseGlobal,ib,1);
+			iggWidgetKeyFloatSlider *hli = new iggWidgetKeyFloatSlider(0.01f,10.0f,200,1,0,"Head light",iViewModule::KeyLightIntensity(),RenderMode::UseGlobal,ib,2);
 			hli->AddBuddy(mli);
 			fli->AddBuddy(mli);
 			mli->SetStretch(3,10);
@@ -1655,20 +1696,17 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 				iggFrame *vbpage0 = new iggFrame(vb,3);
 				vb->AddPage("Stereo",icon,vbpage0);
 
-				vbpage0->AddLine(new ShowInStereoCheckBox(vbpage0));
-				iggWidgetKeyRadioBox *sm = new iggWidgetKeyRadioBox(1,"Method",0,iViewModule::KeyStereoType(),vbpage0);
-				sm->InsertItem("Both eyes in 2 windows");
-				sm->InsertItem("Crystal eyes");
-				sm->InsertItem("Blue-red");
-				sm->InsertItem("Interlaced");
-				sm->InsertItem("Left eye only");
-				sm->InsertItem("Right eye only");
-				sm->InsertItem("Dresden display");
-				vbpage0->AddLine(sm,new iggWidgetTextArea("To toggle in and out\n of stereo mode,\n press 3 within\n the visualization window",vbpage0));
-				vbpage0->AddLine(new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Angle between eyes",iCamera::KeyEyeAngle(),_RenderModeUseGlobal,vbpage0),2);
-				vbpage0->AddLine(new iggWidgetKeyCheckBox("Show alighnment marks in a two-window mode",iViewModule::KeyStereoAlignmentMarks(),vbpage0),2);
+				StereoModeSelector *sm = new StereoModeSelector(vbpage0);
+				vbpage0->AddLine(sm,new iggWidgetTextArea("",vbpage0));
+				vbpage0->AddLine(new iggWidgetKeyCheckBox("Show alighnment marks in a dual window mode",iViewModule::KeyStereoAlignmentMarks(),vbpage0),2);
+				vbpage0->AddLine(new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Angle between eyes",iCamera::KeyEyeAngle(),RenderMode::UseGlobal,vbpage0),2);
+
+				vbpage0->AddSpace(2);
+
+				vbpage0->AddLine(new StereoHardwareStatus(vbpage0),2);
 
 				vbpage0->AddSpace(10);
+				vbpage0->SetColStretch(0,0);
 				vbpage0->SetColStretch(1,10);
 				vbpage0->SetColStretch(2,3);
 			}
@@ -1694,8 +1732,8 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 
 			sbpage3->AddSpace(10);
 			iggFrame *tmp = new iggFrame(sbpage3,2);
-			tmp->AddLine(new iggWidgetTextArea("Side offset",tmp),new iggWidgetKeyFloatSlider(0.01,0.3,29,0,0,"",iColorBars::KeySideOffset(),_RenderModeUseGlobal,tmp));
-			tmp->AddLine(new iggWidgetTextArea("Bar size",tmp),new iggWidgetKeyFloatSlider(0.2,1.0,8,0,0,"",iColorBars::KeySize(),_RenderModeUseGlobal,tmp));
+			tmp->AddLine(new iggWidgetTextArea("Side offset",tmp),new iggWidgetKeyFloatSlider(0.01,0.3,29,0,0,"",iColorBars::KeySideOffset(),RenderMode::UseGlobal,tmp));
+			tmp->AddLine(new iggWidgetTextArea("Bar size",tmp),new iggWidgetKeyFloatSlider(0.2,1.0,8,0,0,"",iColorBars::KeySize(),RenderMode::UseGlobal,tmp));
 			tmp->SetColStretch(1,10);
 			sbpage3->AddLine(tmp,3);
 
@@ -1712,9 +1750,9 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			sbpage4->AddSpace(2);
 
 			iggFrame *cb = new iggFrame("Clip plane direction",sbpage4,1);
-			cb->AddLine(new iggWidgetKeyTrackBall(iViewModule::KeyClipPlaneDirection(),false,_RenderModeUseGlobal,cb));
+			cb->AddLine(new iggWidgetKeyTrackBall(iViewModule::KeyClipPlaneDirection(),false,RenderMode::UseGlobal,cb));
 			sbpage4->AddLine(cb);
-			sbpage4->AddLine(new iggWidgetKeyFloatSlider(-2.0f,2.0f,400,0,0,"Clip plane distance",iViewModule::KeyClipPlaneDistance(),_RenderModeUseGlobal,sbpage4),2);
+			sbpage4->AddLine(new iggWidgetKeyFloatSlider(-2.0f,2.0f,400,0,0,"Clip plane distance",iViewModule::KeyClipPlaneDistance(),RenderMode::UseGlobal,sbpage4),2);
 			sbpage4->AddLine(new iggWidgetKeyCheckBox("Show as glass plane",iViewModule::KeyGlassClipPlane(),sbpage4));
 
 			sbpage4->AddSpace(10);
@@ -1752,7 +1790,6 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			iggFrame *tmp = new iggFrame(abpage0);
 			iggWidgetKeyRadioBox *ao = new iggWidgetKeyRadioBox(1,"Animation output",0,iViewModule::KeyAnimationOutput(),tmp);
 			ao->InsertItem("Series of images");
-#ifndef IVTK_44
 
 #ifdef IVTK_SUPPORTS_MPEG
 			ao->InsertItem("MPEG2 movie");
@@ -1765,7 +1802,6 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			ao->InsertItem("AVI movie");
 #endif
 
-#endif
 			tmp->AddLine(ao);
 			tmp->AddSpace(10);
 			abpage0->AddLine(as,tmp);
@@ -1773,7 +1809,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 
 			abpage0->AddSpace(10);
 
-			iggWidgetKeyLargeIntSlider *af = new iggWidgetKeyLargeIntSlider(1,150,5,"Frames per file",iAnimator::KeyNumberOfFrames(),_RenderModeNoRender,abpage0);
+			iggWidgetKeyLargeIntSlider *af = new iggWidgetKeyLargeIntSlider(1,150,5,"Frames per file",iAnimator::KeyNumberOfFrames(),RenderMode::NoRender,abpage0);
 			af->SetRange(1,150,1);
 			abpage0->AddLine(af,2);
 
@@ -1795,27 +1831,27 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			iggFrame *abpage1 = new iggFrame(ab,2);
 			ab->AddPage("Settings",icon,abpage1);
 
-			iggWidgetKeyFloatSlider *tmpfs = new iggWidgetKeyFloatSlider(1.0e-4,1.0,40,1,0,"Flyby speed",iAnimator::KeyFlybySpeed(),_RenderModeNoRender,abpage1);
+			iggWidgetKeyFloatSlider *tmpfs = new iggWidgetKeyFloatSlider(1.0e-4,1.0,40,1,0,"Flyby speed",iAnimator::KeyFlybySpeed(),RenderMode::NoRender,abpage1);
 			tmpfs->SetStretch(2,10);
 			abpage1->AddLine(tmpfs);
-			tmpfs = new iggWidgetKeyFloatSlider(0.0,0.1,30,0,0,"Cross section speed",iAnimator::KeyCrossSectionSpeed(),_RenderModeNoRender,abpage1);
+			tmpfs = new iggWidgetKeyFloatSlider(0.0,0.1,30,0,0,"Cross section speed",iAnimator::KeyCrossSectionSpeed(),RenderMode::NoRender,abpage1);
 			tmpfs->SetStretch(2,10);
 			abpage1->AddLine(tmpfs);
 
 			abpage1->AddSpace(2);
 
 			iggFrame *ar = new iggFrame("Rotations",abpage1,1);
-			tmpfs = new iggWidgetKeyFloatSlider(-10.0,10.0,200,0,4,"Azimuth (phi)",iAnimator::KeyPhi(),_RenderModeNoRender,ar);
+			tmpfs = new iggWidgetKeyFloatSlider(-10.0,10.0,200,0,4,"Azimuth (phi)",iAnimator::KeyPhi(),RenderMode::NoRender,ar);
 			tmpfs->SetStretch(3,10,0);
 			ar->AddLine(tmpfs);
-			tmpfs = new iggWidgetKeyFloatSlider(-10.0,10.0,200,0,4,"Elevation (theta)",iAnimator::KeyTheta(),_RenderModeNoRender,ar);
+			tmpfs = new iggWidgetKeyFloatSlider(-10.0,10.0,200,0,4,"Elevation (theta)",iAnimator::KeyTheta(),RenderMode::NoRender,ar);
 			tmpfs->SetStretch(3,10,0);
 			ar->AddLine(tmpfs);
-			tmpfs = new iggWidgetKeyFloatSlider(-10.0,10.0,200,0,4,"Roll angle",iAnimator::KeyRoll(),_RenderModeNoRender,ar);
+			tmpfs = new iggWidgetKeyFloatSlider(-10.0,10.0,200,0,4,"Roll angle",iAnimator::KeyRoll(),RenderMode::NoRender,ar);
 			tmpfs->SetStretch(3,10,0);
 			ar->AddLine(tmpfs);
 			abpage1->AddLine(ar);
-			abpage1->AddLine(new iggWidgetKeyFloatSlider(0.98,1.02,400,1,5,"Zoom",iAnimator::KeyZoom(),_RenderModeNoRender,abpage1));
+			abpage1->AddLine(new iggWidgetKeyFloatSlider(0.98,1.02,400,1,5,"Zoom",iAnimator::KeyZoom(),RenderMode::NoRender,abpage1));
 
 			abpage1->AddSpace(10);
 			abpage1->SetColStretch(0,10);
@@ -1830,7 +1866,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 
 			abpage2->AddLine(new iggWidgetKeyCheckBox("Use script",iAnimator::KeyUseScript(),abpage2));
 			abpage2->AddLine(new iggWidgetKeyCheckBox("Inherit settings from widgets",iAnimator::KeyInheritSettings(),abpage2));
-			abpage2->AddLine(new iggWidgetKeyTextLineEdit(true,"Current script",iAnimator::KeyScriptFileName(),_RenderModeNoRender,abpage2));
+			abpage2->AddLine(new iggWidgetKeyTextLineEdit(true,"Current script",iAnimator::KeyScriptFileName(),RenderMode::NoRender,abpage2));
 			abpage2->AddLine(new iggWidgetLaunchButton(this->GetMainWindow()->GetDialogScriptDebugger(),"Launch script debugger",abpage2));
 
 			abpage2->AddSpace(10);
@@ -1887,7 +1923,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 
 			iggFrame *atbox = new iggFrame("Title",abpage4,3);
 			iggFrame *atf = new iggFrame(atbox,3);
-			iggWidgetKeyTextLineEdit *atle = new iggWidgetKeyTextLineEdit(true,"",iAnimator::KeyTitlePageFile(),_RenderModeNoRender,atf);
+			iggWidgetKeyTextLineEdit *atle = new iggWidgetKeyTextLineEdit(true,"",iAnimator::KeyTitlePageFile(),RenderMode::NoRender,atf);
 			atf->AddLine(atle,3);
 			ViewImageArea *atia = new ViewImageArea(atbox);
 			LoadButton *alb = new LoadButton(atia,"Open title page file",iAnimator::KeyTitlePageFile(),iAnimator::KeyTitlePageImage(),atf);
@@ -1912,7 +1948,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 
 			iggFrame *albox = new iggFrame("Logo",abpage4,3);
 			iggFrame *alf = new iggFrame(albox,3);
-			iggWidgetKeyTextLineEdit *alle = new iggWidgetKeyTextLineEdit(true,"",iAnimator::KeyLogoFile(),_RenderModeNoRender,alf);
+			iggWidgetKeyTextLineEdit *alle = new iggWidgetKeyTextLineEdit(true,"",iAnimator::KeyLogoFile(),RenderMode::NoRender,alf);
 			alf->AddLine(alle,3);
 			ViewImageArea *alia = new ViewImageArea(albox);
 			alb = new LoadButton(alia,"Open title page file",iAnimator::KeyLogoFile(),iAnimator::KeyLogoImage(),alf);
@@ -1931,7 +1967,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			tmpcb->InsertItem("Lower rigt");
 			tmpcb->SetStretch(10,0);
 			albox->AddLine(tmpcb,2);
-			iggWidgetKeyFloatSlider *tmpfs = new iggWidgetKeyFloatSlider(0,1.0,10,0,4,"Opacity",iAnimator::KeyLogoOpacity(),_RenderModeNoRender,albox);
+			iggWidgetKeyFloatSlider *tmpfs = new iggWidgetKeyFloatSlider(0,1.0,10,0,4,"Opacity",iAnimator::KeyLogoOpacity(),RenderMode::NoRender,albox);
 			tmpfs->SetStretch(10,0);
 			albox->AddLine(tmpfs,2);
 
@@ -1975,19 +2011,19 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			iggWidgetKeyComboBox *mcs = new iggWidgetKeyComboBox("",0,iMarker::KeyType(),msb2);
 			mcs->AddDependent(mcm);
 			mcm->AddDependent(mbpage0);
-			for(i=0; i<__NumPointTypes; i++)
+			for(i=0; i<PointGlyphType::SIZE; i++)
 			{
 				mcs->InsertItem(iPointGlyph::GetName(i));
 			}
 
-			iggWidget *mct = new iggWidgetKeyTextLineEdit(false,"",iMarker::KeyCaptionText(),_RenderModeUseGlobal,msb2);
+			iggWidget *mct = new iggWidgetKeyTextLineEdit(false,"",iMarker::KeyCaptionText(),RenderMode::UseGlobal,msb2);
 
 			msb1->AddLine(new iggWidgetTextArea("Type",msb1));
 			msb2->AddLine(mcs);
 			msb1->AddLine(new iggWidgetTextArea("Caption",msb1));
 			msb2->AddLine(mct);
 			msb1->AddLine(new iggWidgetTextArea("Marker size",msb1));
-			msb2->AddLine(new iggWidgetKeySizeSlider(1.0e-5,0,"",iMarker::KeySize(true),_RenderModeUseGlobal,msb2));
+			msb2->AddLine(new iggWidgetKeySizeSlider(1.0e-5,0,"",iMarker::KeySize(true),RenderMode::UseGlobal,msb2));
 
 			iggFrame *mcb = new iggFrame("Controls",mbpage0,1);
 			iggFrameCreateDeleteButton *mcd = new iggFrameCreateDeleteButton(page3,iMarker::Type(),false,"marker",mcb);
@@ -2028,10 +2064,10 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			mb->AddPage("Material ",icon,mbpage1);
 
 			mbpage1->AddLine(new iggFrameMaterialProperties(false,false,iMarker::Type(),mbpage1));
-			mbpage1->AddLine(new iggWidgetKeyFloatSlider(0.0f,1.0f,10,0,0,"Opacity",iMarker::KeyOpacity(),_RenderModeUseGlobal,mbpage1));
+			mbpage1->AddLine(new iggWidgetKeyFloatSlider(0.0f,1.0f,10,0,0,"Opacity",iMarker::KeyOpacity(),RenderMode::UseGlobal,mbpage1));
 
 			iggWidget *mct = new iggWidgetKeyCheckBox("Captions are transparent",iViewModule::KeyMarkerCaptionsTransparent(),mbpage1);
-			mct->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionAll);
+			mct->SetExecuteFlags(ObjectOption::One|ModuleOption::One|RenderOption::All);
 			mbpage1->AddLine(mct);
 
 			mbpage1->AddSpace(10);
@@ -2063,15 +2099,15 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			mb->AddPage("Transform",icon,mbpage3);
 
 			iggFrame *mtb = new iggFrame("Scale",mbpage3,1);
-			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"X",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,3));
-			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"Y",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,4));
-			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"Z",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,5));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"X",iMarker::KeyTransform(),RenderMode::UseGlobal,mtb,3));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"Y",iMarker::KeyTransform(),RenderMode::UseGlobal,mtb,4));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"Z",iMarker::KeyTransform(),RenderMode::UseGlobal,mtb,5));
 			mbpage3->AddLine(mtb);
 
 			mtb = new iggFrame("Rotate",mbpage3,1);
-			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"X",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,0));
-			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"Y",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,1));
-			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"Z",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,2));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"X",iMarker::KeyTransform(),RenderMode::UseGlobal,mtb,0));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"Y",iMarker::KeyTransform(),RenderMode::UseGlobal,mtb,1));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"Z",iMarker::KeyTransform(),RenderMode::UseGlobal,mtb,2));
 			mbpage3->AddLine(mtb);
 
 			mbpage3->AddSpace(10);
@@ -2091,13 +2127,13 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 		iggFrame *wfb = new iggFrame("Windows",page4,1);
 		WindowNumberComboBox *wnb = new WindowNumberComboBox(wfb,this);
 		wfb->AddLine(wnb);
-		CreateWindowButton *wcb1 = new CreateWindowButton(_ModuleTypeNew,wfb);
+		CreateWindowButton *wcb1 = new CreateWindowButton(ModuleType::New,wfb);
 		wcb1->AddDependent(wnb);
 		wfb->AddLine(wcb1);
-		CreateWindowButton *wcb2 = new CreateWindowButton(_ModuleTypeCopy,wfb);
+		CreateWindowButton *wcb2 = new CreateWindowButton(ModuleType::Copy,wfb);
 		wcb2->AddDependent(wnb);
 		wfb->AddLine(wcb2);
-		CreateWindowButton *wcb3 = new CreateWindowButton(_ModuleTypeClone,wfb);
+		CreateWindowButton *wcb3 = new CreateWindowButton(ModuleType::Clone,wfb);
 		wcb3->AddDependent(wnb);
 		wfb->AddLine(wcb3);
 		DeleteWindowButton *wdb = new DeleteWindowButton(wfb);
