@@ -38,7 +38,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ishell.h"
 #include "iviewmodule.h"
 #include "ivolumeviewsubject.h"
-#include "ivtk.h"
 
 #include "iggdatatypeprovider.h"
 #include "iggframedatavariablelist.h"
@@ -56,8 +55,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetbuttonsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
 
 //
 //  Templates (needed for some compilers)
@@ -66,6 +63,10 @@ using namespace iggParameter;
 #include"iggwidgetkeyslidertemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
+
 namespace iggPageVolume_Private
 {
 	//
@@ -78,9 +79,9 @@ namespace iggPageVolume_Private
 		
 		WindowSizeFrame(iggFrame *parent) : iggFrame("Window size",parent,1)
 		{
-			mSubject1 = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypePushButton,"256x256",1);
-			mSubject2 = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypePushButton,"512x512",2);
-			mSubject3 = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypePushButton,"1024x1024",3);
+			mSubject1 = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::PushButton,"256x256",1);
+			mSubject2 = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::PushButton,"512x512",2);
+			mSubject3 = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::PushButton,"1024x1024",3);
 
 			mSubject->PlaceWidget(0,0,mSubject1,1,true);
 			mSubject->PlaceWidget(0,1,mSubject2,1,true);
@@ -160,7 +161,7 @@ namespace iggPageVolume_Private
 using namespace iggPageVolume_Private;
 
 
-iggPageVolume::iggPageVolume(iggFrameBase *parent) : iggPageObject(parent,iParameter::_ObjectTypeVolume)
+iggPageVolume::iggPageVolume(iggFrameBase *parent) : iggPageObject(parent,ViewSubject::Id::Volume)
 {
 	const iImage *icon = iImageFactory::FindIcon("volv.png");
 
@@ -277,10 +278,10 @@ iggPageVolume::iggPageVolume(iggFrameBase *parent) : iggPageObject(parent,iParam
 	page4->AddSpace(10);
 
 	iggFrame *rs = new iggFrame("Downsampling settings",page4,1);
-	iggWidgetKeyFloatSlider *fs = new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Image downsampling",iVolumeViewSubject::KeyImageDownsampleFactor(),_RenderModeUseGlobal,rs);
+	iggWidgetKeyFloatSlider *fs = new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Image downsampling",iVolumeViewSubject::KeyImageDownsampleFactor(),RenderMode::UseGlobal,rs);
 	fs->SetStretch(3,10);
 	rs->AddLine(fs);
-	fs = new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Depth downsampling",iVolumeViewSubject::KeyDepthDownsampleFactor(),_RenderModeUseGlobal,rs);
+	fs = new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Depth downsampling",iVolumeViewSubject::KeyDepthDownsampleFactor(),RenderMode::UseGlobal,rs);
 	fs->SetStretch(3,10);
 	rs->AddLine(fs);
 
