@@ -127,6 +127,13 @@ namespace iggParameter
 	const int _PopupWindowMessage = 0;
 	const int _PopupWindowWarning = 1;
 	const int _PopupWindowError = 2;
+
+	//
+	//  Running conditions
+	//
+	const int _ConditionOldWindowManager = 1;
+	const int _ConditionSmallDesktopSize = 2;
+	const int _ConditionSlowRemoteConnection = 4;
 };
 
 #endif  // IGGPARAMETER_H
