@@ -54,8 +54,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #endif
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
 
 //
 //  Templates (needed for some compilers)
@@ -63,6 +61,9 @@ using namespace iggParameter;
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 iggRenderWindow::iggRenderWindow(iViewModule *vm) : mViewModule(vm)
 {
 	IERROR_ASSERT(vm);
@@ -73,9 +74,6 @@ iggRenderWindow::iggRenderWindow(iViewModule *vm) : mViewModule(vm)
 
 	mMaxStep = mCurStep = 0;
 
-	GenericContext = 0;
-	GenericDisplayId = 0;
-
 	this->DoubleBufferOn();
 
 	//
@@ -129,7 +127,14 @@ void iggRenderWindow::Initialize()
 		this->OpenGLInit();
 
 		mSubject->Initialize(this->GetOffScreenRendering()==0);
-		
+
+		//
+		//  Check if we have stereo
+		//
+		unsigned char ucTest;
+		glGetBooleanv(GL_STEREO,&ucTest);
+		this->StereoCapableWindow = (ucTest != 0) ? 1 : 0;
+
 		this->Mapped = 1;
 	}
 }
@@ -289,7 +294,7 @@ void iggRenderWindow::SetBorders(int arg)
 	mSubject->SetBorder(arg != 0);
 	if(arg != 0)
 	{
-		mSubject->GetHelper()->RestoreIcon();
+		mSubject->GetHelper()->RestoreDecoration();
 	}
 
 	this->Borders = arg;
@@ -312,7 +317,7 @@ void iggRenderWindow::SetFullScreen(int arg)
 		if(arg == 0)
 		{
 			mSubject->GetHelper()->RestoreWindowGeometry();
-			mSubject->GetHelper()->RestoreIcon();
+			mSubject->GetHelper()->RestoreDecoration();
 		}
 
 		this->FullScreen = arg;
@@ -320,11 +325,11 @@ void iggRenderWindow::SetFullScreen(int arg)
 
 		if(arg!=0 && this->GetViewModule()->GetRenderTool()->GetFullScreenMode()==2)
 		{
-			if(this->GetMainWindow()->PopupWindow(this,"Is the window placement correct?",iggParameter::_PopupWindowMessage,"Ok","Cancel") == 1)
+			if(this->GetMainWindow()->PopupWindow(this,"Is the window placement correct?",iParameter::PopupWindow::Message,"Ok","Cancel") == 1)
 			{
 				mSubject->SetFullScreen(0);
 				mSubject->GetHelper()->RestoreWindowGeometry();
-				mSubject->GetHelper()->RestoreIcon();
+				mSubject->GetHelper()->RestoreDecoration();
 				this->FullScreen = 0;
 				this->Modified();
 			}
@@ -344,48 +349,21 @@ int* iggRenderWindow::GetScreenSize()
 }
 
 
-//
-//  Window system access
-//
-void* iggRenderWindow::GetGenericContext()
-{
-	if(GenericContext == 0)
-	{
-#ifdef IOPENGL_WIN
-		GenericContext = (void *)GetDC((HWND)this->GetGenericWindowId());
-#else
-		GenericContext = XCreateGC((Display *)this->GetGenericDisplayId(),(unsigned long)this->GetGenericWindowId(),0,0);
-#endif
-    }
-
-	return GenericContext;
-}
-
-
 void* iggRenderWindow::GetGenericDisplayId()
 {
-	if(GenericDisplayId == 0)
-	{
-#ifdef IOPENGL_WIN
-		GenericDisplayId = (void *)wglGetCurrentContext();
-#else
-		GenericDisplayId = XOpenDisplay((char *)0);
-#endif
-	}
-
-	return GenericDisplayId;
+	return mSubject->GetDisplayId();
 }
 
 
 void* iggRenderWindow::GetGenericWindowId()
 {
-	return mSubject->GetGenericWindowId();
+	return mSubject->GetWindowId();
 }
 
 
 void iggRenderWindow::SetWindowName(const char *s)
 {
-	if(iRequiredCast<iggShell>(INFO,mSubject->GetShell())->CheckCondition(iggParameter::_ConditionSlowRemoteConnection))
+	if(iRequiredCast<iggShell>(INFO,mSubject->GetShell())->CheckCondition(Condition::SlowRemoteConnection))
 	{
 		iString ws(s);
 		mSubject->SetWindowName(ws+" (click to render)");
@@ -458,9 +436,105 @@ void iggRenderWindow::OnCloseAttempt()
 	this->GetMainWindow()->PopupWindow(this,"Render Window can not be closed. Use window controls in the main window to delete Render Windows.");
 }
 
+
 bool iggRenderWindow::IsCurrent()
 {
 	return mSubject->IsCurrent();
 }
 
+
+void iggRenderWindow::SetStereoCapableWindow(int capable)
+{
+	if(!mInitialized)
+	{
+		mSubject->RequestStereo(capable != 0);
+	}
+	else
+	{
+		vtkWarningMacro(<< "Requesting a StereoCapableWindow must be performed before the window is realized, i.e. before a render.");
+    }
+}
+
+
+//
+//  Unused pure virtual overwrites
+//
+#define ERR \
+	IERROR_FATAL("Misconfiguration error.\nYou are seeing this message because IFrIT was never tested on your window system.\nPlease send this message and the line number listed below to ifrit.bugs@gmail.com.")
+
+void iggRenderWindow::SetDisplayId(void *)
+{
+	ERR;
+}
+void iggRenderWindow::SetWindowId(void *)
+{
+	ERR;
+}
+void iggRenderWindow::SetParentId(void *)
+{
+	ERR;
+}
+void* iggRenderWindow::GetGenericParentId()
+{
+	ERR;
+	return 0;
+}
+void* iggRenderWindow::GetGenericContext()
+{
+	ERR;
+	return 0;
+}
+void* iggRenderWindow::GetGenericDrawable()
+{
+	ERR;
+	return 0;
+}
+void iggRenderWindow::SetWindowInfo(char *)
+{
+	ERR;
+}
+void iggRenderWindow::SetParentInfo(char *)
+{
+	ERR;
+}
+
+void iggRenderWindow::Finalize()
+{
+	ERR;
+}
+void iggRenderWindow::HideCursor()
+{
+	ERR;
+}
+void iggRenderWindow::ShowCursor()
+{
+	ERR;
+}
+void iggRenderWindow::WindowRemap()
+{
+	ERR;
+}
+int iggRenderWindow::GetEventPending()
+{
+	ERR;
+	return 0;
+}
+void iggRenderWindow::SetNextWindowId(void *)
+{
+	ERR;
+}
+void iggRenderWindow::SetNextWindowInfo(char *)
+{
+	ERR;
+}
+
+void iggRenderWindow::CreateAWindow()
+{
+	ERR;
+}
+void iggRenderWindow::DestroyWindow()
+{
+	ERR;
+}
+
 #endif
