@@ -36,6 +36,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "iviewmodule.h"
 
+#include "iggelement.h"
 #include "iggrenderwindow.h"
 
 #include "ibgrenderwindowsubject.h"
@@ -43,8 +44,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkInteractorStyle.h>
 #include <vtkCommand.h>
 
-#include "iggparameter.h"
-using namespace iggParameter;
+
+using namespace iParameter;
 
 
 iggRenderWindowInteractor::iggRenderWindowInteractor(iShell *shell) : mShell(shell)
@@ -155,8 +156,8 @@ void iggRenderWindowInteractor::OnMouseMove(int x, int y, int b)
 {
 	if(!this->Enabled || b==0) return;  //  No interaction without a button pressed
 		
-	this->SetControlKey(b & _MouseControlKey);
-	this->SetShiftKey(b & _MouseShiftKey);
+	this->SetControlKey(b & MouseButton::ControlKey);
+	this->SetShiftKey(b & MouseButton::ShiftKey);
 	this->SetEventPosition(x,y);
 	this->SetKeySym("0");
 	this->InvokeEvent(vtkCommand::MouseMoveEvent,0);
@@ -167,24 +168,24 @@ void iggRenderWindowInteractor::OnMousePress(int x, int y, int b)
 {
 	if(!this->Enabled) return;
 	
-	this->SetControlKey(b & _MouseControlKey);
-	this->SetShiftKey(b & _MouseShiftKey);
+	this->SetControlKey(b & MouseButton::ControlKey);
+	this->SetShiftKey(b & MouseButton::ShiftKey);
 	this->SetEventPosition(x,y);
 	this->SetKeySym("0");
 
-	switch(b & _MouseAnyButton)
+	switch(b & MouseButton::AnyButton)
 	{
-	case _MouseLeftButton:
+	case MouseButton::LeftButton:
 		{
 			this->InvokeEvent(vtkCommand::LeftButtonPressEvent,0);
 			break;
 		}
-	case _MouseMiddleButton:
+	case MouseButton::MiddleButton:
 		{
 			this->InvokeEvent(vtkCommand::MiddleButtonPressEvent,0);
 			break;
 		}
-	case _MouseRightButton:
+	case MouseButton::RightButton:
 		{
 			this->InvokeEvent(vtkCommand::RightButtonPressEvent,0);
 			break;
@@ -197,24 +198,24 @@ void iggRenderWindowInteractor::OnMouseRelease(int x, int y, int b)
 {
 	if(!this->Enabled) return;
 	
-	this->SetControlKey(b & _MouseControlKey);
-	this->SetShiftKey(b & _MouseShiftKey);
+	this->SetControlKey(b & MouseButton::ControlKey);
+	this->SetShiftKey(b & MouseButton::ShiftKey);
 	this->SetEventPosition(x,y);
 	this->SetKeySym("0");
 
-	switch(b & _MouseAnyButton)
+	switch(b & MouseButton::AnyButton)
 	{
-	case _MouseLeftButton:
+	case MouseButton::LeftButton:
 		{
 			this->InvokeEvent(vtkCommand::LeftButtonReleaseEvent,0);
 			break;
 		}
-	case _MouseMiddleButton:
+	case MouseButton::MiddleButton:
 		{
 			this->InvokeEvent(vtkCommand::MiddleButtonReleaseEvent,0);
 			break;
 		}
-	case _MouseRightButton:
+	case MouseButton::RightButton:
 		{
 			this->InvokeEvent(vtkCommand::RightButtonReleaseEvent,0);
 			break;
@@ -241,8 +242,8 @@ void iggRenderWindowInteractor::OnKeyPress(char key, int b)
 #endif
 	else
 	{
-		this->SetControlKey(b & _MouseControlKey);
-		this->SetShiftKey(b & _MouseShiftKey);
+		this->SetControlKey(b & MouseButton::ControlKey);
+		this->SetShiftKey(b & MouseButton::ShiftKey);
 		this->SetKeyCode(key);
 		this->SetKeySym("0");
 		this->InvokeEvent(vtkCommand::CharEvent,0);
