@@ -43,7 +43,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ioutputchannel.h"
 #include "iversion.h"
 #include "iviewmodule.h"
-#include "ivtk.h"
 
 #include "iggdialog.h"
 #include "iggextensionwindow.h"
@@ -67,8 +66,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #endif
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
+
+
+using namespace iParameter;
 using namespace iParameter;
 
 
@@ -77,7 +77,7 @@ class iggDialogFlashWindow : public iggDialog
 
 public:
 
-	iggDialogFlashWindow(iShell *shell) : iggDialog(shell,_DialogUnattached|_DialogBlocking|_DialogNoTitleBar,0,"",0,3,0)
+	iggDialogFlashWindow(iShell *shell) : iggDialog(shell,DialogFlag::Unattached|DialogFlag::Blocking|DialogFlag::NoTitleBar,0,"",0,3,0)
 	{
 		mFrame->AddLine(new iggWidgetTextArea("%b%+   IFrIT - Ionization FRont Interactive Tool   ",mFrame),3);
 		mFrame->AddLine(new iggWidgetTextArea("Version "+iVersion::GetVersion(),mFrame),3);
@@ -155,7 +155,7 @@ protected:
 			}
 		case iConsole::_Warning:
 			{
-				mMainWindow->PopupWindow(message,iggParameter::_PopupWindowMessage);
+				mMainWindow->PopupWindow(message,iParameter::PopupWindow::Message);
 				break;
 			}
 		case iConsole::_LowError:
@@ -165,17 +165,17 @@ protected:
 			}
 		case iConsole::_HighError:
 			{
-				mMainWindow->PopupWindow(m,iggParameter::_PopupWindowWarning);
+				mMainWindow->PopupWindow(m,iParameter::PopupWindow::Warning);
 				break;
 			}
 		case iConsole::_FatalError:
 			{
-				mMainWindow->PopupWindow(m,iggParameter::_PopupWindowError);
+				mMainWindow->PopupWindow(m,iParameter::PopupWindow::Error);
 				break;
 			}
 		case iConsole::_Notification:
 			{
-				mMainWindow->PopupWindow(m,iggParameter::_PopupWindowWarning);
+				mMainWindow->PopupWindow(m,iParameter::PopupWindow::Warning);
 				break;
 			}
 		}
@@ -360,7 +360,7 @@ void iggShell::Start()
 		}
 
 		int mwg[4], vwg[4];
-		iggRenderWindow *visWindow = iRequiredCast<iggRenderWindow>(INFO,this->ControlModule()->GetViewModule()->GetRenderWindow());
+		iggRenderWindow *visWindow = iRequiredCast<iggRenderWindow>(INFO,this->GetControlModule()->GetViewModule()->GetRenderWindow());
 
 		//
 		//  squeeze windows to the minimum possible size
@@ -421,7 +421,7 @@ void iggShell::Start()
 			//
 			//  Show the visualization window and give window manager a chance to decorate it.
 			//			     
-			this->ControlModule()->Render(_RenderOptionAll);
+			this->GetControlModule()->Render(RenderOption::All);
 			mSubject->ProcessEvents(false);
 
 			//
@@ -465,7 +465,7 @@ void iggShell::Start()
 	}
 	else
 	{
-		this->ControlModule()->Render(_RenderOptionAll);
+		this->GetControlModule()->Render(RenderOption::All);
 		mMainWindow->GetSubject()->Show(true);
 		mMainWindow->GetExtensionWindow()->GetSubject()->Show(true);
 	}
@@ -540,19 +540,19 @@ bool iggShell::AnalyseOneExtendedCommandLineOption(const struct Option &o)
 	//
 	if(o.Name == "owm")
 	{
-		mConditionFlags |= _ConditionOldWindowManager;
+		mConditionFlags |= Condition::OldWindowManager;
 		return true;
 	}
 
 	if(o.Name == "sds")
 	{
-		mConditionFlags |= _ConditionSmallDesktopSize;
+		mConditionFlags |= Condition::SmallDesktopSize;
 		return true;
 	} 
 
 	if(o.Name == "src")
 	{
-		mConditionFlags |= _ConditionSlowRemoteConnection;
+		mConditionFlags |= Condition::SlowRemoteConnection;
 		return true;
 	}
 	
@@ -565,7 +565,7 @@ bool iggShell::AnalyseOneExtendedCommandLineOption(const struct Option &o)
 //
 bool iggShell::IsDesktopSmall(bool vert) const
 {
-	if(this->CheckCondition(_ConditionSmallDesktopSize)) return true;
+	if(this->CheckCondition(Condition::SmallDesktopSize)) return true;
 
 	int w, h;
 	mSubject->GetDesktopDimensions(w,h);
