@@ -34,6 +34,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "icolor.h"
+#include "icontrolmodule.h"
 #include "ierror.h"
 #include "imath.h"
 
@@ -45,18 +46,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <vtkMath.h>
 
-#include "iparameter.h"
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
-
-
 //
 //  Templates
 //
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
+
 int iggWidget::mGlobalExecuteFlags = 0;
 
 //
@@ -94,7 +93,7 @@ void iggWidget::Define()
 	mWidgetSubject = 0;
 	mWidgetHelper = 0;
 
-	mExecuteFlags = _DefaultOption;
+	mExecuteFlags = DefaultOption;
 
 	mInitialized = false;
 
@@ -327,17 +326,17 @@ void iggWidget::SetExecuteFlags(int f)
 	mExecuteFlags = f;
 
 #ifdef I_CHECK1
-	int objOption = f & _ObjectOptionMask;
-	int modOption = f & _ModuleOptionMask;
-	int renOption = f & _RenderOptionMask;
+	int objOption = f & ObjectOption::Mask;
+	int modOption = f & ModuleOption::Mask;
+	int renOption = f & RenderOption::Mask;
 
 	//
 	//  Check that modes are valid
 	//
 	if(
-		(objOption!=_ObjectOptionOne && objOption!=_ObjectOptionAll) ||
-		(modOption!=_ModuleOptionOne && modOption!=_ModuleOptionAll && modOption!=_ModuleOptionClones) || 
-		(renOption!=_RenderOptionOne && renOption!=_RenderOptionAll && renOption!=_RenderOptionClones && renOption!=_RenderOptionAuto))
+		(objOption!=ObjectOption::One && objOption!=ObjectOption::All) ||
+		(modOption!=ModuleOption::One && modOption!=ModuleOption::All && modOption!=ModuleOption::Clones) || 
+		(renOption!=RenderOption::One && renOption!=RenderOption::All && renOption!=RenderOption::Clones && renOption!=RenderOption::Auto))
 	{
 		IERROR_LOW("Invalid option.");
 	}
@@ -356,9 +355,9 @@ int iggWidget::GetExecuteFlags() const
 	if(mGlobalExecuteFlags == 0) return mExecuteFlags;
 
 	int flags = 0;
-	if((mGlobalExecuteFlags & _ObjectOptionMask) != 0) flags = flags | (mGlobalExecuteFlags & _ObjectOptionMask); else flags = flags | (mExecuteFlags & _ObjectOptionMask); 
-	if((mGlobalExecuteFlags & _ModuleOptionMask) != 0) flags = flags | (mGlobalExecuteFlags & _ModuleOptionMask); else flags = flags | (mExecuteFlags & _ModuleOptionMask); 
-	if((mGlobalExecuteFlags & _RenderOptionMask) != 0) flags = flags | (mGlobalExecuteFlags & _RenderOptionMask); else flags = flags | (mExecuteFlags & _RenderOptionMask); 
+	if((mGlobalExecuteFlags & ObjectOption::Mask) != 0) flags = flags | (mGlobalExecuteFlags & ObjectOption::Mask); else flags = flags | (mExecuteFlags & ObjectOption::Mask); 
+	if((mGlobalExecuteFlags & ModuleOption::Mask) != 0) flags = flags | (mGlobalExecuteFlags & ModuleOption::Mask); else flags = flags | (mExecuteFlags & ModuleOption::Mask); 
+	if((mGlobalExecuteFlags & RenderOption::Mask) != 0) flags = flags | (mGlobalExecuteFlags & RenderOption::Mask); else flags = flags | (mExecuteFlags & RenderOption::Mask); 
 	return flags;
 }
 
