@@ -64,6 +64,33 @@ class ibgWidgetHelper;
 class ibgWidgetSubject;
 
 
+namespace iParameter
+{
+	namespace WidgetType
+	{
+		const int Other = 0;
+		const int Entry = 1;
+	};
+
+	namespace RenderMode
+	{
+		const int UseGlobal = 0;
+		const int Immediate = 1;
+		const int Delayed = 2;
+		const int NoRender = 3;
+	};
+
+	namespace ButtonType
+	{
+		const int PushButton = 0;
+		const int ToolButton = 1;
+		const int SwitchButton = 2;
+		const int ToggleButton = 3;
+		const int CheckBox = 4;
+	};
+};
+
+
 class iggWidget : public iggElement
 {
 
