@@ -42,9 +42,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetbuttonsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
 
 //
 // Templates
@@ -52,6 +49,10 @@ using namespace iParameter;
 #include "iggwidgetkeyhandlertemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
+
 //
 //******************************************
 //
@@ -59,7 +60,7 @@ using namespace iParameter;
 //
 //******************************************
 //
-iggWidgetKeyButton::iggWidgetKeyButton(int type, const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<bool>(_WidgetTypeOther,key,_RenderModeImmediate,parent,index,indkey)
+iggWidgetKeyButton::iggWidgetKeyButton(int type, const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<bool>(WidgetType::Other,key,RenderMode::Immediate,parent,index,indkey)
 {
 	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,type,text,1);
 	mReverse = false;
@@ -99,7 +100,7 @@ void iggWidgetKeyButton::OnVoid1Body()
 //
 //******************************************
 //
-iggWidgetKeyCheckBox::iggWidgetKeyCheckBox(const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyButton(_ButtonTypeCheckBox,text,key,parent,index,indkey)
+iggWidgetKeyCheckBox::iggWidgetKeyCheckBox(const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyButton(ButtonType::CheckBox,text,key,parent,index,indkey)
 {
 }
 
@@ -111,7 +112,7 @@ iggWidgetKeyCheckBox::iggWidgetKeyCheckBox(const iString &text, const iObjectKey
 //
 //******************************************
 //
-iggWidgetKeyExecButton::iggWidgetKeyExecButton(const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyButton(_ButtonTypePushButton,text,key,parent,index,indkey)
+iggWidgetKeyExecButton::iggWidgetKeyExecButton(const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyButton(ButtonType::PushButton,text,key,parent,index,indkey)
 {
 }
 
@@ -137,7 +138,7 @@ void iggWidgetKeyExecButton::QueryValue(bool &val) const
 //
 //******************************************
 //
-iggWidgetKeyToolButton::iggWidgetKeyToolButton(const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyButton(_ButtonTypeToolButton,text,key,parent,index,indkey)
+iggWidgetKeyToolButton::iggWidgetKeyToolButton(const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyButton(ButtonType::ToolButton,text,key,parent,index,indkey)
 {
 }
 
@@ -163,7 +164,7 @@ void iggWidgetKeyToolButton::QueryValue(bool &val) const
 //
 //******************************************
 //
-iggWidgetKeyToggleButton::iggWidgetKeyToggleButton(const iImage *icon, const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyButton(_ButtonTypeToggleButton,text,key,parent,index,indkey), mIcon(icon)
+iggWidgetKeyToggleButton::iggWidgetKeyToggleButton(const iImage *icon, const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyButton(ButtonType::ToggleButton,text,key,parent,index,indkey), mIcon(icon)
 {
 	if(icon != 0) mSubject->SetIcon(*icon);
 }
@@ -175,13 +176,13 @@ iggWidgetKeyToggleButton::iggWidgetKeyToggleButton(const iImage *icon, const iSt
 //
 //******************************************
 //
-iggWidgetKeyFileNameButton::iggWidgetKeyFileNameButton(const iString &text, const iString &header, const iString &selection, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<iString>(_WidgetTypeOther,key,_RenderModeImmediate,parent,index,indkey)
+iggWidgetKeyFileNameButton::iggWidgetKeyFileNameButton(const iString &text, const iString &header, const iString &selection, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<iString>(WidgetType::Other,key,RenderMode::Immediate,parent,index,indkey)
 {
-	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeToolButton,text,1);
+	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::ToolButton,text,1);
 
 	mHeader = header;
 	mSelection = selection;
-	mDefault = this->GetMainWindow()->GetShell()->GetEnvironment(_EnvironmentBase);
+	mDefault = this->GetMainWindow()->GetShell()->GetEnvironment(Environment::Base);
 }
 
 
@@ -201,7 +202,7 @@ void iggWidgetKeyFileNameButton::UpdateWidgetBody()
 
 void iggWidgetKeyFileNameButton::QueryValue(iString &val) const
 {
-	val = this->GetMainWindow()->GetFileName(mHeader,this->GetMainWindow()->GetShell()->GetEnvironment(_EnvironmentBase),"Images (*.jpg *.jpeg *.pnm *.bmp *.png *.tif *.tiff)");
+	val = this->GetMainWindow()->GetFileName(mHeader,this->GetMainWindow()->GetShell()->GetEnvironment(Environment::Base),"Images (*.jpg *.jpeg *.pnm *.bmp *.png *.tif *.tiff)");
 }
 
 
@@ -223,9 +224,9 @@ void iggWidgetKeyFileNameButton::OnVoid1Body()
 //
 //******************************************
 //
-iggWidgetKeyExecIntButton::iggWidgetKeyExecIntButton(int value, const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<int>(_WidgetTypeOther,key,_RenderModeImmediate,parent,index,indkey)
+iggWidgetKeyExecIntButton::iggWidgetKeyExecIntButton(int value, const iString &text, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<int>(WidgetType::Other,key,RenderMode::Immediate,parent,index,indkey)
 {
-	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypePushButton,text,1);
+	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::PushButton,text,1);
 	mValue = value;
 }
 
