@@ -38,8 +38,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetcolorselectionsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
 
 //
 //  templates
@@ -47,7 +45,10 @@ using namespace iggParameter;
 #include "iggwidgetkeyhandlertemplate.h"
 
 
-iggWidgetKeyColorSelection::iggWidgetKeyColorSelection(const iObjectKey &key, iggFrame *parent, bool horizontal, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<iColor>(_WidgetTypeOther,key,_RenderModeImmediate,parent,index,indkey)
+using namespace iParameter;
+
+
+iggWidgetKeyColorSelection::iggWidgetKeyColorSelection(const iObjectKey &key, iggFrame *parent, bool horizontal, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<iColor>(WidgetType::Other,key,RenderMode::Immediate,parent,index,indkey)
 {
 	mSubject = iggSubjectFactory::CreateWidgetColorSelectionSubject(this,horizontal);
 }
