@@ -39,10 +39,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggdatatypeprovider.h"
 #include "iggframe.h"
 
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
-
 //
 //  templates
 //
@@ -50,7 +46,11 @@ using namespace iParameter;
 #include "iggwidgetkeyhandlertemplate.h"
 
 
-int iggWidgetKeyHandlerBase::mGlobalRenderMode = _RenderModeDelayed;
+using namespace iParameter;
+using namespace iParameter;
+
+
+int iggWidgetKeyHandlerBase::mGlobalRenderMode = RenderMode::Delayed;
 #ifdef I_CHECK1
 bool iggWidgetKeyHandlerBase::mCheckNullIndexKeys =  false;
 #endif
@@ -195,7 +195,7 @@ iPointerArray<iggWidgetKeyHandlerBase>& iggWidgetKeyHandlerBase::VariableLimitsL
 
 void iggWidgetKeyHandlerBase::SetGlobalRenderMode(int m)
 {
-	if(m != _RenderModeUseGlobal)
+	if(m != RenderMode::UseGlobal)
 	{
 		mGlobalRenderMode = m;
 	}
@@ -204,7 +204,7 @@ void iggWidgetKeyHandlerBase::SetGlobalRenderMode(int m)
 
 int iggWidgetKeyHandlerBase::GetRenderMode() const
 {
-	if(mRenderMode != _RenderModeUseGlobal)
+	if(mRenderMode != RenderMode::UseGlobal)
 	{
 		return mRenderMode;
 	}
@@ -212,13 +212,13 @@ int iggWidgetKeyHandlerBase::GetRenderMode() const
 	{
 		switch(mType)
 		{
-		case _WidgetTypeEntry:
+		case WidgetType::Entry:
 			{
 				return mGlobalRenderMode;
 			}
 		default:
 			{
-				return _RenderModeImmediate;
+				return RenderMode::Immediate;
 			}
 		}
 	}
