@@ -35,9 +35,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggframe.h"
 
-#include "iggparameter.h"
-using namespace iggParameter;
-
 //
 //  templates
 //
@@ -46,6 +43,9 @@ using namespace iggParameter;
 #include "iggwidgetkeylineedittemplate.h"
 
 
+using namespace iParameter;
+
+
 //
 //******************************************
 //
