@@ -36,6 +36,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggsubjectfactory.h"
 
 
+using namespace iParameter;
+
+
 //
 //******************************************
 //
@@ -44,9 +47,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //******************************************
 //
 template<class T>
-iggWidgetKeyLineEdit<T>::iggWidgetKeyLineEdit(bool numeric, bool readonly, const iString &label, const iObjectKey &key, int rm, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<T>(_WidgetTypeEntry,key,rm,parent,index,indkey)
+iggWidgetKeyLineEdit<T>::iggWidgetKeyLineEdit(bool numeric, bool readonly, const iString &label, const iObjectKey &key, int rm, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<T>(WidgetType::Entry,key,rm,parent,index,indkey)
 {
-	this->mSubject = this->mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,(numeric)?10:0,label,(rm==_RenderModeNoRender)?0:new iggWidgetRenderModeButton(this)); IERROR_ASSERT(mSubject);
+	this->mSubject = this->mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,(numeric)?10:0,label,(rm==RenderMode::NoRender)?0:new iggWidgetRenderModeButton(this)); IERROR_ASSERT(mSubject);
 	this->mSubject->SetEditable(!readonly);
 	this->SetRenderMode(rm);
 }
@@ -56,7 +59,7 @@ template<class T>
 void iggWidgetKeyLineEdit<T>::SetRenderMode(int m)
 {
 	iggWidgetKeyHandler<T>::SetRenderMode(m);
-	this->mSubject->SetDelayedEdit(this->GetRenderMode()==_RenderModeDelayed);
+	this->mSubject->SetDelayedEdit(this->GetRenderMode()==RenderMode::Delayed);
 }
 
 
