@@ -43,8 +43,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <limits.h>
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
 
 //
 //  templates
@@ -52,6 +50,9 @@ using namespace iggParameter;
 #include "iggwidgetkeyhandlertemplate.h"
 
 
+using namespace iParameter;
+
+
 //
 //******************************************
 //
@@ -59,7 +60,7 @@ using namespace iggParameter;
 //
 //******************************************
 //
-iggWidgetKeySelectionBox::iggWidgetKeySelectionBox(int offset, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<int>(_WidgetTypeOther,key,_RenderModeImmediate,parent,index,indkey)
+iggWidgetKeySelectionBox::iggWidgetKeySelectionBox(int offset, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<int>(WidgetType::Other,key,RenderMode::Immediate,parent,index,indkey)
 {
 	mOffset = offset;
 }
@@ -303,6 +304,7 @@ bool iggWidgetKeyTextComboBox::ConvertFromText(const iString &text, int &val) co
 	bool ok;
 	iString ws = text;
 
+	ws.ReduceWhiteSpace();
 	val = ws.Section(" ",mSection,mSection).ToInt(ok);
 	if(!ok && mInvalidValue<iMath::_IntMax)
 	{
