@@ -44,9 +44,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetentrysubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
 
 //
 //  Template
@@ -56,6 +53,10 @@ using namespace iParameter;
 #include "iggwidgetkeyslidertemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
+
 //
 //******************************************
 //
@@ -517,7 +518,7 @@ iggWidgetKeyVariableLimitsSlider::iggWidgetKeyVariableLimitsSlider(const iggData
 
 	mStep = 0.0f;
 
-	this->SetExecuteFlags(_ObjectOptionOne|_ModuleOptionOne|_RenderOptionClones);
+	this->SetExecuteFlags(ObjectOption::One|ModuleOption::One|RenderOption::Clones);
 
 	this->AttachDataTypeProvider(provider);
 }
