@@ -44,8 +44,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetselectionboxsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
+
+
+using namespace iParameter;
 
 
 //
@@ -239,7 +240,7 @@ int iggWidgetSimpleSpinBox::GetValue() const
 //
 iggWidgetSimpleCheckBox::iggWidgetSimpleCheckBox(const iString &title, iggFrame *parent) : iggWidget(parent)
 {
-	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,title,1);
+	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,title,1);
 }
 
 
