@@ -158,7 +158,8 @@ public:
 
 	iggWidgetSimpleCheckBox(const iString &title, iggFrame *parent);
 
-	bool IsDown() const;
+	void SetChecked(bool s);
+	bool IsChecked() const;
 
 protected:
 
