@@ -49,9 +49,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetbuttonsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
-using namespace iParameter;
 
 //
 //  Templates (needed for some compilers)
@@ -59,12 +56,16 @@ using namespace iParameter;
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+using namespace iParameter;
+
+
 //
 //  Show button
 //
 iggWidgetShowButton::iggWidgetShowButton(const iObjectType &type, iggFrame *parent) : iggWidget(parent), mType(type)
 {
-	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,"Show",1);
+	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Show",1);
 
 	iString tt = "Shows/hides the "+type.FullName()+" object. Press Shift+F1 for more help.";
 	this->SetBaloonHelp(tt,type.GetHelp()->GetHTML());
@@ -106,7 +107,7 @@ void iggWidgetShowButton::UpdateWidgetBody()
 //
 iggWidgetLaunchButton::iggWidgetLaunchButton(iggDialog *dialog, const iString &text, iggFrame *parent, bool destructive) : iggWidget(parent)
 {
-	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypePushButton,text,1);
+	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::PushButton,text,1);
 
 	mDialog = dialog; if(dialog == 0) this->Enable(false);
 	mWindow = 0;
@@ -116,7 +117,7 @@ iggWidgetLaunchButton::iggWidgetLaunchButton(iggDialog *dialog, const iString &t
 
 iggWidgetLaunchButton::iggWidgetLaunchButton(iggMenuWindow *window, const iString &text, iggFrame *parent, bool destructive) : iggWidget(parent)
 {
-	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypePushButton,text,1);
+	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::PushButton,text,1);
 
 	mDialog = 0;
 	mWindow = window; if(window == 0) this->Enable(false);
@@ -161,7 +162,7 @@ void iggWidgetLaunchButton::OnVoid1Body()
 //
 iggWidgetAllInstancesCheckBox::iggWidgetAllInstancesCheckBox(iggFrame *parent) : iggWidget(parent)
 {
-	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeCheckBox,"Lock for all instances",1);
+	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::CheckBox,"Lock for all instances",1);
 	
 	this->SetBaloonHelp("Toggles whether sliders affects all instances or the current one only.","Properties of all instances can be changed together if this checkbox is checked. This is convenient when a large number of instances are present that are used in a similar fashion.");
 }
@@ -179,14 +180,14 @@ void iggWidgetAllInstancesCheckBox::OnVoid1Body()
 {
 	int i, ef;
 
-	ef = _DefaultOption;
+	ef = DefaultOption;
 	if(mSubject->IsDown())
 	{
 		//
 		//  Unset the object mode flag
 		//
-		ef &= (~_ObjectOptionMask);
-		ef |= _ObjectOptionAll;
+		ef &= (~ObjectOption::Mask);
+		ef |= ObjectOption::All;
 	}
 
 	iggWidgetKeyHandlerBase *kh;
@@ -203,7 +204,7 @@ void iggWidgetAllInstancesCheckBox::OnVoid1Body()
 //
 iggWidgetSimpleButton::iggWidgetSimpleButton(const iString &text, iggFrame *parent, bool tool) : iggWidget(parent)
 {
-	int type = tool ? _ButtonTypeToolButton : _ButtonTypePushButton;
+	int type = tool ? ButtonType::ToolButton : ButtonType::PushButton;
 	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,type,text,1);
 }
 
