@@ -45,8 +45,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgetbuttonsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
 
 //
 //  Template
@@ -54,6 +52,9 @@ using namespace iggParameter;
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 //
 //  RenderMode button
 //
@@ -69,7 +70,7 @@ iggWidgetRenderModeButton::iggWidgetRenderModeButton(iggWidgetKeyHandlerBase *pa
 	}
 	if(registered) List().AddUnique(this);
 
-	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeToolButton,"",1);
+	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,ButtonType::ToolButton,"",1);
 	mSubject->SetFlat(true);
 	mSubject->SetSize(16,16);
 
@@ -92,12 +93,12 @@ void iggWidgetRenderModeButton::UpdateWidgetBody()
 {
 	switch(mKeyHandler->GetRenderMode())
 	{
-	case _RenderModeDelayed:
+	case RenderMode::Delayed:
 		{
 			if(mDelayIcon != 0) mSubject->SetIcon(*mDelayIcon);
 			break;
 		}
-	case _RenderModeImmediate:
+	case RenderMode::Immediate:
 		{
 			if(mReadyIcon != 0) mSubject->SetIcon(*mReadyIcon);
 			break;
@@ -114,14 +115,14 @@ void iggWidgetRenderModeButton::OnVoid1Body()
 {
 	switch(mKeyHandler->GetRenderMode())
 	{
-	case _RenderModeDelayed:
+	case RenderMode::Delayed:
 		{
-			mKeyHandler->SetRenderMode(_RenderModeImmediate);
+			mKeyHandler->SetRenderMode(RenderMode::Immediate);
 			break;
 		}
-	case _RenderModeImmediate:
+	case RenderMode::Immediate:
 		{
-			mKeyHandler->SetRenderMode(_RenderModeDelayed);
+			mKeyHandler->SetRenderMode(RenderMode::Delayed);
 			break;
 		}
 	default:
@@ -135,7 +136,7 @@ void iggWidgetRenderModeButton::OnVoid1Body()
 
 void iggWidgetRenderModeButton::ResetToGlobal()
 {
-	mKeyHandler->SetRenderMode(_RenderModeUseGlobal);
+	mKeyHandler->SetRenderMode(RenderMode::UseGlobal);
 	this->UpdateWidget();
 }
 
