@@ -45,8 +45,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibgwidgettexteditorsubject.h"
 
 #include "iggsubjectfactory.h"
-#include "iggparameter.h"
-using namespace iggParameter;
 
 //
 //  Templates
@@ -54,6 +52,9 @@ using namespace iggParameter;
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 //
 //  iggWidgetTextEditor class
 //
@@ -130,9 +131,9 @@ void iggWidgetTextEditor::RemoveLine(int n)
 //
 //  Selection
 //
-/*void iggWidgetTextEditor::Select(int paraFrom, int indexFrom, int paraTo, int indexTo, int selNum)
+/*void iggWidgetTextEditor::Select(int lineFrom, int indexFrom, int lineTo, int indexTo, int selNum)
 {
-	mSubject->Select(paraFrom,indexFrom,paraTo,indexTo,false,selNum);
+	mSubject->Select(lineFrom,indexFrom,lineTo,indexTo,false,selNum);
 }*/
 
 
@@ -154,7 +155,7 @@ void iggWidgetTextEditor::UseEditingFunction(int type)
 //
 //  iggWidgetTextBrowser class
 //
-iggWidgetTextBrowser::iggWidgetTextBrowser(bool wrapping, bool blockselection, iggFrame *parent) : iggWidgetTextEditor(_TextEditorReadOnly|_TextEditorWithHTML|(wrapping?_TextEditorWrapping:0U),parent)
+iggWidgetTextBrowser::iggWidgetTextBrowser(bool wrapping, bool blockselection, iggFrame *parent) : iggWidgetTextEditor(TextEditorFlag::ReadOnly|TextEditorFlag::WithHTML|(wrapping?TextEditorFlag::Wrapping:0U),parent)
 {
 	mBlockSelection = blockselection;
 	mNeedsBaloonHelp = false;
@@ -233,7 +234,7 @@ void iggWidgetTextBrowser::AppendTextLine(const iString &prefix, const iString &
 }
 
 
-void iggWidgetTextBrowser::OnSelectionChanged(int /*paraFrom*/, int /*indexFrom*/, int /*paraTo*/, int /*indexTo*/)
+void iggWidgetTextBrowser::OnSelectionChanged(int /*lineFrom*/, int /*indexFrom*/, int /*lineTo*/, int /*indexTo*/)
 {
 	//
 	//  remove selection if it is present
@@ -245,7 +246,7 @@ void iggWidgetTextBrowser::OnSelectionChanged(int /*paraFrom*/, int /*indexFrom*
 //
 //  iggWidgetListView class
 //
-iggWidgetListView::iggWidgetListView(bool withHTML, iggFrame *parent) : iggWidgetTextEditor(withHTML?(_TextEditorReadOnly|_TextEditorWithHTML):_TextEditorReadOnly,parent)
+iggWidgetListView::iggWidgetListView(bool withHTML, iggFrame *parent) : iggWidgetTextEditor(withHTML?(TextEditorFlag::ReadOnly|TextEditorFlag::WithHTML):TextEditorFlag::ReadOnly,parent)
 {
 	mSelectedRange[0] = 0;
 	mSelectedRange[1] = -1;
@@ -297,29 +298,29 @@ void iggWidgetListView::Clear()
 }
 
 
-void iggWidgetListView::Select(int paraFrom, int paraTo)
+void iggWidgetListView::Select(int lineFrom, int lineTo)
 {
 	//
 	//  Select full lines only
 	//
-	if(paraFrom>=0 && paraTo>=0 && paraFrom<this->GetNumberOfLines() && paraTo<this->GetNumberOfLines())
+	if(lineFrom>=0 && lineTo>=0 && lineFrom<this->GetNumberOfLines() && lineTo<this->GetNumberOfLines())
 	{
-		mSubject->Select(paraFrom,0,paraTo,mSubject->GetLine(paraTo).Length(),true); // justify left
-		mSelectedRange[0] = paraFrom;
-		mSelectedRange[1] = paraTo;
+		mSubject->Select(lineFrom,0,lineTo,mSubject->GetLine(lineTo).Length(),true); // justify left
+		mSelectedRange[0] = lineFrom;
+		mSelectedRange[1] = lineTo;
 	}
 }
 
 
-void iggWidgetListView::OnSelectionChanged(int paraFrom, int /*indexFrom*/, int paraTo, int /*indexTo*/)
+void iggWidgetListView::OnSelectionChanged(int lineFrom, int /*indexFrom*/, int lineTo, int /*indexTo*/)
 {
-	this->Select(paraFrom,paraTo);
+	this->Select(lineFrom,lineTo);
 }
 
 
-void iggWidgetListView::OnCursorPositionChanged(int para, int /*index*/)
+void iggWidgetListView::OnCursorPositionChanged(int line, int /*index*/)
 {
-	this->Select(para,para);
+	this->Select(line,line);
 }
 
 
@@ -518,12 +519,12 @@ void iggWidgetHelpBrowser::ModifyText(const char *tag, iString &text)
 }
 
 
-//void iggWidgetHelpBrowser::OnMousePress(int para, int index)
+//void iggWidgetHelpBrowser::OnMousePress(int line, int index)
 //{
 //}
 
 
-//void iggWidgetHelpBrowser::OnMouseRelease(int para, int index)
+//void iggWidgetHelpBrowser::OnMouseRelease(int line, int index)
 //{
 //}
 
