@@ -44,6 +44,32 @@ class ibgWidgetHelpBrowserSubject;
 class ibgWidgetTextEditorSubject;
 
 
+namespace iParameter
+{
+	namespace TextEditorFlag
+	{
+		//
+		//  Text editor masks
+		//
+		const unsigned int ReadOnly = 1U;
+		const unsigned int WithHTML = 2U;
+		const unsigned int Wrapping = 4U;
+	};
+
+	namespace TextEditorFunction
+	{
+		//
+		//  Text editor capabilities
+		//
+		const int Undo = 1;
+		const int Redo = 2;
+		const int Cut = 3;
+		const int Copy = 4;
+		const int Paste = 5;
+	}
+};
+
+
 class iggWidgetTextEditor : public iggWidget
 {
 
@@ -84,7 +110,7 @@ public:
 	//
 	//  Selection
 	//
-//	void Select(int paraFrom, int indexFrom, int paraTo, int indexTo, int selNum = 0);
+//	void Select(int lineFrom, int indexFrom, int lineTo, int indexTo, int selNum = 0);
 
 	//
 	//  Editing functions
@@ -97,10 +123,10 @@ protected:
 	virtual void UpdateWidgetBody();
 
 	virtual void OnTextChanged(){}
-	virtual void OnSelectionChanged(int /*paraFrom*/, int /*indexFrom*/, int /*paraTo*/, int /*indexTo*/){}
-	virtual void OnCursorPositionChanged(int /*para*/, int /*index*/){}
-	virtual void OnMousePress(int /*para*/, int /*index*/){}
-	virtual void OnMouseRelease(int /*para*/, int /*index*/){}
+	virtual void OnSelectionChanged(int /*lineFrom*/, int /*indexFrom*/, int /*lineTo*/, int /*indexTo*/){}
+	virtual void OnCursorPositionChanged(int /*line*/, int /*index*/){}
+	virtual void OnMousePress(int /*line*/, int /*index*/){}
+	virtual void OnMouseRelease(int /*line*/, int /*index*/){}
 	virtual void OnReturnPressed(){}
 
 	ibgWidgetTextEditorSubject *mSubject;
@@ -119,7 +145,7 @@ public:
 
 protected:
 
-	virtual void OnSelectionChanged(int paraFrom, int indexFrom, int paraTo, int indexTo);
+	virtual void OnSelectionChanged(int lineFrom, int indexFrom, int lineTo, int indexTo);
 
 	bool mBlockSelection;
 };
@@ -144,10 +170,10 @@ public:
 protected:
 
 	virtual void UpdateWidgetBody();
-	virtual void Select(int paraFrom, int paraTo);
+	virtual void Select(int lineFrom, int lineTo);
 
-	virtual void OnSelectionChanged(int paraFrom, int indexFrom, int paraTo, int indexTo);
-	virtual void OnCursorPositionChanged(int para, int index);
+	virtual void OnSelectionChanged(int lineFrom, int indexFrom, int lineTo, int indexTo);
+	virtual void OnCursorPositionChanged(int line, int index);
 
 	int mSelectedRange[2];
 	int mNumItems;
@@ -204,8 +230,8 @@ protected:
 	virtual void OnLinkFollowed(const char *tag);
 	virtual void OnNullHelpBuffer();
 	virtual void ModifyText(const char *tag, iString &text);
-	//virtual void OnMousePress(int para, int index);
-	//virtual void OnMouseRelease(int para, int index);
+	//virtual void OnMousePress(int line, int index);
+	//virtual void OnMouseRelease(int line, int index);
 
 	int mCurrentTag;
 	iArray<iString> mVisitedTags;
