@@ -57,8 +57,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QtGui/QToolTip>
 #endif
 
-#include "iggparameter.h"
-using namespace iggParameter;
+
+using namespace iParameter;
 
 
 //
@@ -66,9 +66,9 @@ using namespace iggParameter;
 //
 iqtDialogSubject::iqtDialogSubject(iggDialog *owner, const ibgWindowSubject *base, unsigned int mode, const iImage *icon, const iString &title) : 
 #ifdef IQT_3
-	QDialog((mode&_DialogUnattached)?0:iDynamicCast<iqtWindowHelper,ibgWindowHelper>(INFO,base->GetHelper())->GetWidget(),"",false,iqtHelper::GetFlags(iqtHelper::_Dialog,mode)), 
+	QDialog((mode&DialogFlag::Unattached)?0:iDynamicCast<iqtWindowHelper,ibgWindowHelper>(INFO,base->GetHelper())->GetWidget(),"",false,iqtHelper::GetFlags(WindowType::Dialog,mode)), 
 #else
-	QDialog((mode&_DialogUnattached)?0:iDynamicCast<iqtWindowHelper,ibgWindowHelper>(INFO,base->GetHelper())->GetWidget(),iqtHelper::GetFlags(iqtHelper::_Dialog,mode)), 
+	QDialog((mode&DialogFlag::Unattached)?0:iDynamicCast<iqtWindowHelper,ibgWindowHelper>(INFO,base->GetHelper())->GetWidget(),iqtHelper::GetFlags(WindowType::Dialog,mode)), 
 #endif
 	ibgDialogSubject(owner,base,mode,icon,title)
 {
@@ -77,13 +77,13 @@ iqtDialogSubject::iqtDialogSubject(iggDialog *owner, const ibgWindowSubject *bas
 	mMode = mode;
 	QGridLayout *layout = iqtHelper::NewLayout(this,1);
 
-	if((mode & _DialogBlocking) == 0) this->setSizeGripEnabled(true); else
+	if((mode & DialogFlag::Blocking) == 0) this->setSizeGripEnabled(true); else
 	{
 #ifndef IQT_3
 		 this->setAttribute(Qt::WA_ShowModal); 
 #endif
 	}
-	if((mode & _DialogNoTitleBar) != 0)
+	if((mode & DialogFlag::NoTitleBar) != 0)
 	{
 		this->setFocusPolicy(QFocus::NoFocus);
 		iqtHelper::SetBackground(this,0);
@@ -100,7 +100,7 @@ void iqtDialogSubject::Show(bool s)
 {
 	if(s)
 	{
-		if(mMode & _DialogWithEventLoop)
+		if(mMode & DialogFlag::WithEventLoop)
 		{
 			this->exec();
 		}
@@ -123,7 +123,7 @@ void iqtDialogSubject::SetFrame(ibgFrameSubject *frame0)
 		iqtHelper::SetParent(frame,this);
 		iDynamicCast<QGridLayout,QLayout>(INFO,this->layout())->addWidget(frame,0,0);
 	}
-	if((mMode & _DialogNoTitleBar) != 0)
+	if((mMode & DialogFlag::NoTitleBar) != 0)
 	{
 #ifdef IQT_3
 		frame->setFrameShape(QFrame::Box);
