@@ -53,8 +53,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QtGui/QTabBar>
 #endif
 
-#include "iggparameter.h"
-using namespace iggParameter;
+
+using namespace iParameter;
 
 
 //
@@ -73,7 +73,7 @@ iqtFrameSubject::~iqtFrameSubject()
 //
 //  FrameBook class
 //
-iqtFrameBookSubject::iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback, bool tabsOnTop) : QTabWidget(iqtHelper::Convert(owner->GetParent())), ibgFrameBookSubject(owner,withFeedback,tabsOnTop)
+iqtFrameBookSubject::iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback) : QTabWidget(iqtHelper::Convert(owner->GetParent())), ibgFrameBookSubject(owner,withFeedback)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -85,23 +85,6 @@ iqtFrameBookSubject::iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback,
 #endif
 #endif
 
-	if(tabsOnTop)
-	{
-#ifdef IQT_3
-		this->setTabPosition(QTabWidget::Top);
-#else
-		this->setTabPosition(QTabWidget::North);
-#endif
-	}
-	else
-	{
-#ifdef IQT_3
-		this->setTabPosition(QTabWidget::Bottom);
-#else
-		this->setTabPosition(QTabWidget::South);
-#endif
-	}
-
 	if(withFeedback)
 	{
 #ifdef IQT_3
@@ -179,7 +162,7 @@ void iqtFrameBookSubject::SetTabMode(int n, int m, const iString &title, const i
 {
 	switch(m)
 	{
-	case _BookImageOnly:
+	case BookTab::ImageOnly:
 		{
 			if(image != 0)
 			{
@@ -192,7 +175,7 @@ void iqtFrameBookSubject::SetTabMode(int n, int m, const iString &title, const i
 			}
 			break;
 		}
-	case _BookTitleOnly:
+	case BookTab::TitleOnly:
 		{
 #ifdef IQT_3
 			this->changeTab(this->page(n),QIconSet(),iqtHelper::ConvertWithModifiers(this,title));
@@ -202,7 +185,7 @@ void iqtFrameBookSubject::SetTabMode(int n, int m, const iString &title, const i
 #endif
 			break;
 		}
-	case _BookTitleAndImage:
+	case BookTab::TitleAndImage:
 		{
 			if(image != 0)
 			{
@@ -230,7 +213,7 @@ void iqtFrameBookSubject::SetTabMode(int n, int m, const iString &title, const i
 
 int iqtFrameBookSubject::GetTabMode()
 {
-	if(this->count() == 0) return _BookTitleAndImage;
+	if(this->count() == 0) return BookTab::TitleAndImage;
 	
 #ifdef IQT_3
 	bool t = !this->tabLabel(this->page(0)).isEmpty();
@@ -240,7 +223,7 @@ int iqtFrameBookSubject::GetTabMode()
 	bool i = !this->tabIcon(0).isNull();
 #endif
 
-	if(t && i) return _BookTitleAndImage; else if(i) return _BookImageOnly; else return _BookTitleOnly;
+	if(t && i) return BookTab::TitleAndImage; else if(i) return BookTab::ImageOnly; else return BookTab::TitleOnly;
 }
 
 
@@ -260,6 +243,23 @@ void iqtFrameBookSubject::ChangeIcon(int n, const iImage &image)
 }
 
 
+void iqtFrameBookSubject::SetOrientation(int v)
+{
+#ifdef IQT_3
+	v = v % 2;
+#else
+	v = v % 4;
+#endif
+	this->setTabPosition(TabPosition(v));
+}
+
+
+int iqtFrameBookSubject::GetOrientation()
+{
+	return this->tabPosition();
+}
+
+
 //
 //  FrameFlip class
 //
