@@ -84,10 +84,12 @@ public:
 	virtual void SetTabMode(int n, int m, const iString &title, const iImage *image);
 	virtual int GetTabMode();
 	virtual void ChangeIcon(int n, const iImage &image);
+	virtual void SetOrientation(int v);
+	virtual int GetOrientation();
 
 protected:
 
-	iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback, bool tabsOnTop);
+	iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback);
 
 
 	iqtCallbackHelper *mCallbackHelper;
