@@ -40,6 +40,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "istring.h"
 #include "isystem.h"
 
+#include "iggdialog.h"
 #include "iggframe.h"
 
 #include "ibgwindowhelper.h"
@@ -70,20 +71,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QtGui/QWidget>
 #endif
 
-#include "iggparameter.h"
-using namespace iggParameter;
+
+using namespace iParameter;
 
 
 //
 //  Widget flags
 //
-Qt::WFlags iqtHelper::GetFlags(Window window, int mode)
+Qt::WFlags iqtHelper::GetFlags(int window, int mode)
 {
 	Qt::WFlags f = 0;
 
 	switch(window)
 	{
-	case _MainWindow:
+	case WindowType::Main:
 		{
 #ifdef IQT_3
 			f |= Qt::WType_TopLevel;
@@ -93,7 +94,7 @@ Qt::WFlags iqtHelper::GetFlags(Window window, int mode)
 #endif
 			break;
 		}
-	case _VisualizationWindow:
+	case WindowType::Render:
 		{
 #ifdef IQT_3
 			f |= (Qt::WType_TopLevel | Qt::WResizeNoErase | Qt::WRepaintNoErase);
@@ -102,7 +103,7 @@ Qt::WFlags iqtHelper::GetFlags(Window window, int mode)
 #endif
 			break;
 		}
-	case _VisualizationWindowWithoutBorder:
+	case WindowType::BorderlessRender:
 		{
 #ifdef IQT_3
 			f |= (Qt::WType_TopLevel | Qt::WResizeNoErase | Qt::WRepaintNoErase | Qt::WStyle_Customize | Qt::WStyle_NoBorder);
@@ -111,7 +112,7 @@ Qt::WFlags iqtHelper::GetFlags(Window window, int mode)
 #endif
 			break;
 		}
-	case _Extension:
+	case WindowType::Extension:
 		{
 #ifdef IQT_3
 			f |= Qt::WType_TopLevel;
@@ -120,14 +121,14 @@ Qt::WFlags iqtHelper::GetFlags(Window window, int mode)
 #endif
 			break;
 		}
-	case _Dialog:
+	case WindowType::Dialog:
 		{
 #ifdef IQT_3
 			f |= (Qt::WStyle_Customize | Qt::WType_Dialog | Qt::WStyle_Dialog);
 #else
 			f |= Qt::Dialog;
 #endif
-			if((mode&_DialogNoTitleBar) == 0)
+			if((mode&DialogFlag::NoTitleBar) == 0)
 			{
 #ifdef IQT_3
 				f |= (Qt::WStyle_Title | Qt::WStyle_SysMenu | Qt::WStyle_NormalBorder);
@@ -141,7 +142,7 @@ Qt::WFlags iqtHelper::GetFlags(Window window, int mode)
 				f |= (Qt::FramelessWindowHint);
 #endif
 			}
-			if(mode & _DialogBlocking)
+			if(mode & DialogFlag::Blocking)
 			{
 #ifdef IQT_3
 				f |= Qt::WShowModal;
@@ -485,18 +486,18 @@ QIcon iqtHelper::ConvertToIcon(const iImage &src)
 
 int iqtHelper::Convert(int state)
 {
-	int b = _MouseNoButton;
+	int b = MouseButton::NoButton;
 
-	if(state & Qt::LeftButton) b |= _MouseLeftButton;
-	if(state & Qt::MidButton) b |= _MouseMiddleButton;
-	if(state & Qt::RightButton) b |= _MouseRightButton;
+	if(state & Qt::LeftButton) b |= MouseButton::LeftButton;
+	if(state & Qt::MidButton) b |= MouseButton::MiddleButton;
+	if(state & Qt::RightButton) b |= MouseButton::RightButton;
 
 #ifdef IQT_3
-	if(state & Qt::ControlButton) b |= _MouseControlKey;
-	if(state & Qt::ShiftButton) b |= _MouseShiftKey;
+	if(state & Qt::ControlButton) b |= MouseButton::ControlKey;
+	if(state & Qt::ShiftButton) b |= MouseButton::ShiftKey;
 #else
-	if(state & Qt::CTRL) b |= _MouseControlKey;
-	if(state & Qt::SHIFT) b |= _MouseShiftKey;
+	if(state & Qt::CTRL) b |= MouseButton::ControlKey;
+	if(state & Qt::SHIFT) b |= MouseButton::ShiftKey;
 #endif
 	return b;
 }
