@@ -82,6 +82,9 @@ protected:
 	virtual bool event(QEvent *e);
 	virtual void moveEvent(QMoveEvent *e);
 	virtual void closeEvent(QCloseEvent *e);
+	virtual void resizeEvent(QResizeEvent *e); 
+	virtual void keyPressEvent(QKeyEvent *e); 
+	virtual void keyReleaseEvent(QKeyEvent *e); 
 //	virtual void focusInEvent(QFocusEvent *e);
 //	virtual void focusOutEvent(QFocusEvent *e);
 
@@ -91,6 +94,7 @@ private:
 
 	QWidget *mMainFrame;
 	QWorkspace *mDockingWorkspace;
+	bool mIsMoveAll;
 
 	iqtMainWindowSubject(const iqtMainWindowSubject&); // Not implemented.
 	void operator=(const iqtMainWindowSubject&);  // Not implemented.
