@@ -66,6 +66,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 //
 //  helper class
 //
@@ -236,9 +239,9 @@ void iqtMenu::AddSeparator()
 //
 iqtMenuWindowSubject::iqtMenuWindowSubject(iggMenuWindow *owner, const iImage *icon, const iString &title) : 
 #ifdef IQT_3
-	QMainWindow(0,0,iqtHelper::GetFlags(iqtHelper::_MainWindow)), 
+	QMainWindow(0,0,iqtHelper::GetFlags(WindowType::Main)), 
 #else
-	QMainWindow(0,iqtHelper::GetFlags(iqtHelper::_MainWindow)), 
+	QMainWindow(0,iqtHelper::GetFlags(WindowType::Main)), 
 #endif
 	ibgMenuWindowSubject(owner,icon,title)
 {
