@@ -71,11 +71,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget* parent) : 
 #ifdef IQT_3
-	QGLWidget(parent,0,0,parent?Qt::WFlags(0):iqtHelper::GetFlags(iqtHelper::_VisualizationWindow)), 
+	QGLWidget(parent,0,0,parent?Qt::WFlags(0):iqtHelper::GetFlags(WindowType::Render)), 
 #else
-	QGLWidget(parent,0,parent?Qt::WFlags(0):iqtHelper::GetFlags(iqtHelper::_VisualizationWindow)), 
+	QGLWidget(parent,0,parent?Qt::WFlags(0):iqtHelper::GetFlags(WindowType::Render)), 
 #endif
 	ibgRenderWindowSubject(owner)
 {
@@ -120,7 +123,7 @@ void iqtRenderWindowSubject::AttachToParent(QWidget *parent, bool border)
 {
 	if(parent == 0)
 	{
-		iqtHelper::SetParent(this,parent,iqtHelper::GetFlags(border ? iqtHelper::_VisualizationWindow : iqtHelper::_VisualizationWindowWithoutBorder));
+		iqtHelper::SetParent(this,parent,iqtHelper::GetFlags(border ? WindowType::Render : WindowType::BorderlessRender));
 #ifndef IQT_3
 		this->setFormat(this->format()); // is this Qt 4 bug?
 #endif
@@ -190,7 +193,17 @@ void iqtRenderWindowSubject::MakeCurrent()
 }
 
 
-void* iqtRenderWindowSubject::GetGenericWindowId() const
+void* iqtRenderWindowSubject::GetDisplayId() const
+{
+#if defined(Q_WS_X11)
+	return (void *)this->x11Display();
+#else
+	return 0;
+#endif
+}
+
+
+void* iqtRenderWindowSubject::GetWindowId() const
 {
 	return (void *)this->winId();
 }
@@ -291,6 +304,7 @@ void iqtRenderWindowSubject::initializeGL()
 	//  I don't think we need this - it crashes X-server over the remote connection
 	//
 	//mOwner->OpenGLInit();
+	mWindowHelper->RestoreDecoration();
 }
 
 
@@ -366,12 +380,20 @@ void iqtRenderWindowSubject::OnTimer()
 }
 
 
-bool iqtRenderWindowSubject::IsCurrent()
+bool iqtRenderWindowSubject::IsCurrent() const
 {
 	return this->context() == QGLContext::currentContext();
 }
 
 
+void iqtRenderWindowSubject::RequestStereo(bool s)
+{
+	QGLFormat f = this->format();
+	f.setStereo(s);
+	this->setFormat(f);
+}
+
+
 bool iqtRenderWindowSubject::event(QEvent *e)
 {
 	//
