@@ -74,13 +74,16 @@ protected:
 	virtual void SetFullScreen(bool);
 	virtual void MakeCurrent();
 
-	virtual void* GetGenericWindowId() const;
+	virtual void* GetDisplayId() const;
+	virtual void* GetWindowId() const;
 	virtual void SetWindowName(const iString &s);
 
 	virtual void RenderIntoMemory(iImage &image);
 	virtual bool IsReadyForDumpingImage();
 
-	virtual bool IsCurrent();
+	virtual bool IsCurrent() const;
+
+	virtual void RequestStereo(bool s);
 
 	//
 	//  RenderWindowInteractor methods
