@@ -34,9 +34,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
-#include "ishell.h"
 #include "istring.h"
 
+#include "iggshell.h"
+
 #include "iqt.h"
 
 #include <vtkIOStream.h>
@@ -44,6 +45,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifdef IQT_3
 #include <qapplication.h>
 #include <qmessagebox.h>
+#include <qgl.h>
 #else
 #include <QtGui/QApplication>
 #include <QtGui/QDesktopWidget>
@@ -51,6 +53,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifdef Q_WS_X11
 #include <QtGui/QX11Info>
 #endif
+#include <QtOpenGL/QGLFormat>
 #endif
 
 
