@@ -63,7 +63,8 @@ protected:
 	virtual bool CanRecognize8BitDisplay(bool check = false) const;
 	virtual bool CanDockWindows() const;
 	virtual bool CanChangeFontSize() const;
-	virtual bool IsWindowManagerModern() const;
+
+	virtual bool CheckCondition(int flag) const;
 };
 
 #endif  // IQTSHELLSUBJECT_H
