@@ -57,15 +57,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace Qt;
 #endif
 
-#include "iggparameter.h"
-using namespace iggParameter;
-
 //
 //  Templates
 //
 #include "iarraytemplate.h"
 
 
+using namespace iParameter;
+
+
 //
 //  WidgetDisplayAreaSubject class
 //
@@ -239,13 +239,13 @@ int iqtWidgetDrawAreaSubject::Height() const
 }
 
 
-void iqtWidgetDrawAreaSubject::Begin(Mode m, bool clear)
+void iqtWidgetDrawAreaSubject::Begin(int m, bool clear)
 {
 	switch(m)
 	{
-	case _Background:
+	case DrawMode::Background:
 		{
-			mCurrentMode = _Background;
+			mCurrentMode = DrawMode::Background;
 			if(this->contentsRect().size() != mBackgroundPixmap->size()) *mBackgroundPixmap = QPixmap(this->contentsRect().size());
 			mPainter->begin(mBackgroundPixmap);
 #ifdef IQT_3
@@ -257,9 +257,9 @@ void iqtWidgetDrawAreaSubject::Begin(Mode m, bool clear)
 #endif
 			break;
 		}
-	case _Foreground:
+	case DrawMode::Foreground:
 		{
-			mCurrentMode = _Foreground;
+			mCurrentMode = DrawMode::Foreground;
 			if(clear)
 			{
 				if(mForegroundPixmap->size() != mBackgroundPixmap->size()) *mForegroundPixmap = QPixmap(mBackgroundPixmap->size());
@@ -291,8 +291,8 @@ void iqtWidgetDrawAreaSubject::End()
 {
 	switch(mCurrentMode)
 	{
-	case _Background:
-	case _Foreground:
+	case DrawMode::Background:
+	case DrawMode::Foreground:
 		{
 			mPainter->end();
 			break;
