@@ -42,18 +42,17 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifdef IQT_3
 #include <qframe.h>
 #include <qlabel.h>
+#include <qpixmap.h>
 #else
 #include <QtGui/QFrame>
 #include <QtGui/QLabel>
+#include <QtGui/QPixmap>
 #endif
 #include "ibgwidgetareasubject.h"
 
-#include <qpixmap.h>
-
 class iqtCallbackHelper;
 
 class QPainter;
-class QPixmap;
 class QTimer;
 
 
@@ -125,7 +124,7 @@ public:
 
 	virtual void SetMinimumSize(int w, int h);
 	
-	virtual void Begin(Mode m, bool clear);
+	virtual void Begin(int m, bool clear);
 	virtual void End();
 	virtual void Frame(); // show the image
 
