@@ -61,8 +61,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #endif
 
 
-#include "iggparameter.h"
-using namespace iggParameter;
+using namespace iParameter;
 
 
 iqtWidgetButtonSubject::iqtWidgetButtonSubject(iggWidget *owner, int type, const iString &text, int slot) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetButtonSubject(owner,type,text,slot)
@@ -78,30 +77,30 @@ iqtWidgetButtonSubject::iqtWidgetButtonSubject(iggWidget *owner, int type, const
 	mType = type;
 	switch(mType)
 	{
-	case _ButtonTypePushButton:
-	case _ButtonTypeSwitchButton:
+	case ButtonType::PushButton:
+	case ButtonType::SwitchButton:
 		{
 			mButton = new QPushButton(this);
 #ifdef IQT_3
-			iDynamicCast<QPushButton,QAbstractButton>(INFO,mButton)->setToggleButton(mType==_ButtonTypeSwitchButton);
+			iDynamicCast<QPushButton,QAbstractButton>(INFO,mButton)->setToggleButton(mType==ButtonType::SwitchButton);
 #else
-			iDynamicCast<QPushButton,QAbstractButton>(INFO,mButton)->setCheckable(mType==_ButtonTypeSwitchButton);
+			iDynamicCast<QPushButton,QAbstractButton>(INFO,mButton)->setCheckable(mType==ButtonType::SwitchButton);
 #endif
 			break;
 		}
-	case _ButtonTypeToolButton:
-	case _ButtonTypeToggleButton:
+	case ButtonType::ToolButton:
+	case ButtonType::ToggleButton:
 		{
 			mButton = new QToolButton(this);
 #ifdef IQT_3
-			iDynamicCast<QToolButton,QAbstractButton>(INFO,mButton)->setToggleButton(mType==_ButtonTypeToggleButton);
+			iDynamicCast<QToolButton,QAbstractButton>(INFO,mButton)->setToggleButton(mType==ButtonType::ToggleButton);
 #else
-			iDynamicCast<QToolButton,QAbstractButton>(INFO,mButton)->setCheckable(mType==_ButtonTypeToggleButton);
+			iDynamicCast<QToolButton,QAbstractButton>(INFO,mButton)->setCheckable(mType==ButtonType::ToggleButton);
 #endif
 			mButton->setMinimumSize(25,25);
 			break;
 		}
-	case _ButtonTypeCheckBox:
+	case ButtonType::CheckBox:
 		{
 			mButton = new QCheckBox(this);
 			break;
@@ -155,14 +154,14 @@ void iqtWidgetButtonSubject::SetFlat(bool s)
 {
 	switch(mType)
 	{
-	case _ButtonTypePushButton:
-	case _ButtonTypeSwitchButton:
+	case ButtonType::PushButton:
+	case ButtonType::SwitchButton:
 		{
 			iDynamicCast<QPushButton,QAbstractButton>(INFO,mButton)->setFlat(s);
 			break;
 		}
-	case _ButtonTypeToolButton:
-	case _ButtonTypeToggleButton:
+	case ButtonType::ToolButton:
+	case ButtonType::ToggleButton:
 		{
 			iDynamicCast<QToolButton,QAbstractButton>(INFO,mButton)->setAutoRaise(s);
 			break;
@@ -181,14 +180,14 @@ bool iqtWidgetButtonSubject::IsDown() const
 {
 	switch(mType)
 	{
-	case _ButtonTypePushButton:
-	case _ButtonTypeToolButton:
+	case ButtonType::PushButton:
+	case ButtonType::ToolButton:
 		{
 			return false;
 		}
-	case _ButtonTypeSwitchButton:
-	case _ButtonTypeToggleButton:
-	case _ButtonTypeCheckBox:
+	case ButtonType::SwitchButton:
+	case ButtonType::ToggleButton:
+	case ButtonType::CheckBox:
 		{
 #ifdef IQT_3
 			return mButton->isOn();
@@ -210,12 +209,12 @@ void iqtWidgetButtonSubject::SetDown(bool s)
 	mButton->blockSignals(true);
 	switch(mType)
 	{
-	case _ButtonTypePushButton:
-	case _ButtonTypeToolButton:
+	case ButtonType::PushButton:
+	case ButtonType::ToolButton:
 		{
 			break;
 		}
-	case _ButtonTypeSwitchButton:
+	case ButtonType::SwitchButton:
 		{
 #ifdef IQT_3
 			iDynamicCast<QPushButton,QAbstractButton>(INFO,mButton)->setOn(s);
@@ -224,7 +223,7 @@ void iqtWidgetButtonSubject::SetDown(bool s)
 #endif
 			break;
 		}
-	case _ButtonTypeToggleButton:
+	case ButtonType::ToggleButton:
 		{
 #ifdef IQT_3
 			iDynamicCast<QToolButton,QAbstractButton>(INFO,mButton)->setOn(s);
@@ -233,7 +232,7 @@ void iqtWidgetButtonSubject::SetDown(bool s)
 #endif
 			break;
 		}
-	case _ButtonTypeCheckBox:
+	case ButtonType::CheckBox:
 		{
 			iDynamicCast<QCheckBox,QAbstractButton>(INFO,mButton)->setChecked(s);
 			break;
