@@ -289,7 +289,7 @@ void iqtWidgetEntrySubject::SetValue(int v, double dv)
 }
 
 
-void iqtWidgetEntrySubject::SetValue(int v, unsigned long lv)
+void iqtWidgetEntrySubject::SetValue(int v, vtkIdType lv)
 {
 	this->SetDoubleValue(v,double(lv),false);
 	
