@@ -42,9 +42,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
-#include "iggparameter.h"
-using namespace iggParameter;
-
 #ifdef IQT_3
 #include <qapplication.h>
 #include <qcursor.h>
@@ -57,6 +54,9 @@ using namespace iggParameter;
 #endif
 
 
+using namespace iParameter;
+
+
 //
 // Constructs a browser
 //
