@@ -58,6 +58,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QtGui/QLabel>
 #include <QtGui/QRadioButton>
 #include <QtGui/QSpinBox>
+#include <QtGui/QStandardItem>
+#include <QtGui/QStandardItemModel>
 #endif
 
 
@@ -238,7 +240,7 @@ void iqtWidgetComboBoxSubject::SetValue(int v)
 {
 	mBox->blockSignals(true);
 #ifdef IQT_3
-	mBox->setCurrentItem(v);
+	if(v < mBox->count()) mBox->setCurrentItem(v);
 #else
 	mBox->setCurrentIndex(v);
 #endif
@@ -325,11 +327,30 @@ void iqtWidgetComboBoxSubject::SetItem(const iString &text, int index, bool vis)
 			QString s = iqtHelper::Convert(text);
 #ifdef IQT_3
 			if(!s.isEmpty() && s!=mBox->text(index)) mBox->changeItem(s,index);
+			mBox->listBox()->item(index)->setSelectable(true);
 #else
 			if(!s.isEmpty() && s!=mBox->itemText(index)) mBox->setItemText(index,s);
+			QStandardItemModel *m = dynamic_cast<QStandardItemModel*>(mBox->model());
+			if(m != 0)
+			{
+				m->item(index)->setSelectable(true);
+				m->item(index)->setForeground(Qt::black);
+			}
+#endif
+		}
+		else
+		{
+#ifdef IQT_3
+			mBox->listBox()->item(index)->setSelectable(false);
+#else
+			QStandardItemModel *m = dynamic_cast<QStandardItemModel*>(mBox->model());
+			if(m != 0)
+			{
+				m->item(index)->setSelectable(false);
+				m->item(index)->setForeground(Qt::gray);
+			}
 #endif
 		}
-		else mBox->removeItem(index);
 	}
 	else
 	{
