@@ -33,6 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iqtwidgettexteditorsubject.h"
 
 
+#include "iarray.h"
 #include "ierror.h"
 #include "istring.h"
 
@@ -43,61 +44,74 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iqthelper.h"
 #include "iqtwidgethelper.h"
 
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
-#else
-#include <QtGui/QMouseEvent>
-#endif
-
-#include "iggparameter.h"
-using namespace iggParameter;
-
-
-#ifndef I_NO_SYNTAX_HIGHLIGHTING
-
-//
-//  Syntax highlighting class
-//
-
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
-
-#include <private/qrichtext_p.h>
-
-#else
-
-namespace Qt
-{
-	const int AlignAuto = 0;
-};
-#include <Qt3Support/private/q3richtext_p.h>
-#include <Qt3Support/Q3IntDict>
-
-#define QTextPreProcessor Q3TextPreProcessor
-#define QTextDocument Q3TextDocument
-#define QTextParagraph Q3TextParagraph
-#define QTextFormat Q3TextFormat
-#define QIntDict Q3IntDict
-
-#endif
-
-#ifndef QT_VERSION
-#error "QT_VERSION is not defined."
-!TERMINATE!
-#endif
-
-#if (QT_VERSION > 0x030004)
-#define QTextParag QTextParagraph
-#endif
-
-#include "iarray.h"
 #include "iarraytemplate.h"
 
 
-class iqtSyntaxHighlighter : public QTextPreProcessor
+using namespace iParameter;
+
+
+#ifdef IQT_3
+//
+//  Temporary fix: people complained that syntax highliting code does not
+//  compile under Qt4.
+//
+#include <private/qrichtext_p.h>
+
+#if (QT_VERSION < 0x030005)
+#define QTextParagraph QTextParag
+#endif
+
+#else
+
+#include <QtGui/QMouseEvent>
+#include <QtGui/QTextBlock>
+
+#define QTextPreProcessor QObject
+
+//
+// Helper class
+//
+class iqtWidgetTextEditorSubject::Location
 {
 
 public:
 
-	iqtSyntaxHighlighter() : QTextPreProcessor(), mLastFormat(0), mLastFormatId(-1)
+	Location(const QTextEdit *editor, int pos = -1)
+	{
+		this->Define(editor,editor->textCursor(),pos);
+	}
+
+	Location(const QTextEdit *editor, const QTextCursor &c, int pos = -1)
+	{
+		this->Define(editor,c,pos);
+	}
+
+	inline int Line() const { return mLine; }
+	inline int Index() const { return mIndex; }
+
+private:
+
+	void Define(const QTextEdit *editor, const QTextCursor &c, int pos)
+	{
+		if(pos < 0) pos = c.position(); 
+		QTextBlock b = editor->document()->findBlock(pos);
+		mLine = b.blockNumber();
+		mIndex = pos - b.position();
+	}
+
+	int mLine, mIndex;
+
+};
+
+#endif
+
+
+class iqtWidgetTextEditorSubject::SyntaxHighlighter : public QTextPreProcessor
+{
+
+public:
+
+	SyntaxHighlighter() : QTextPreProcessor(), mLastFormat(0), mLastFormatId(-1)
 	{
 		mActive = false;
 
@@ -106,30 +120,35 @@ public:
 
 		mDefaultFont = QFont("courier",10,QFont::Normal);
 
+#ifdef IQT_3
 		this->AddFormat(0,new QTextFormat(mDefaultFont,Qt::black));
 		this->AddFormat(1,new QTextFormat(mDefaultFont,Qt::darkGreen));
 		this->AddFormat(2,new QTextFormat(mDefaultFont,Qt::darkRed));
+#endif
 
 		mFirstFormat = 3;
 	}
 
-	virtual ~iqtSyntaxHighlighter()
+	virtual ~SyntaxHighlighter()
 	{
 		while(mKeywords.Size() > 0) delete mKeywords.RemoveLast();
 	}
 
 	void SetPointSize(int s)
 	{
+#ifdef IQT_3
 		unsigned int i;
 		for(i=0; i<mFormats.count(); i++)
 		{
 			this->format(i)->setPointSize(s);
 			this->format(i)->setBold((s > 13));
 		}
+#endif
 		mDefaultFont = QFont(mDefaultFont.family(),s,(s>13)?QFont::Bold:QFont::Normal);
 	}
 
-	void process(QTextDocument*, QTextParag *string, int, bool)
+#ifdef IQT_3
+	void process(QTextDocument*, QTextParagraph *string, int, bool)
 	{
 		int i, j, len, index, index2, indexMax = -1;
 		static QString line;
@@ -145,11 +164,7 @@ public:
 		//
 		if(mHighlightComments)
 		{
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
 			indexMax = line.find(mCommentString,0);
-#else
-			indexMax = line.indexOf(mCommentString,0);
-#endif
 			if(indexMax == -1) 
 			{
 				indexMax = line.length(); 
@@ -173,11 +188,7 @@ public:
 			{
 				len = list[i].length();
 				index = 0;
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
 				while((index=line.find(list[i],index))!=-1 && index<indexMax && (index==0 || alphabeth.find(line.at(index-1),0)==-1) && alphabeth.find(line.at(index+len),0)==-1)
-#else
-				while((index=line.indexOf(list[i],index))!=-1 && index<indexMax && (index==0 || alphabeth.indexOf(line.at(index-1),0)==-1) && alphabeth.indexOf(line.at(index+len),0)==-1)
-#endif
 				{
 					string->setFormat(index,len,this->format(mFirstFormat+j),false);
 					index += len;
@@ -191,15 +202,9 @@ public:
 		if(mHighlightStrings)
 		{
 			index2 = -1;
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
 			while((index=line.find('"',index2+1)) != -1)
 			{
 				index2 = line.find('"',index+1);
-#else
-			while((index=line.indexOf('"',index2+1)) != -1)
-			{
-				index2 = line.indexOf('"',index+1);
-#endif
 				if(index2 == -1) index2 = indexMax - 1; 
 				string->setFormat(index,index2-index+1,this->format(2),false);
 			}
@@ -215,6 +220,7 @@ public:
 		mLastFormatId = id;
 		return mLastFormat;
 	}
+#endif
 
 	void Activate(bool s)
 	{
@@ -231,7 +237,9 @@ public:
 
 	void AddCategory(const QColor &c)
 	{
+#ifdef IQT_3
 		this->AddFormat(mFirstFormat+mKeywords.Size(),new QTextFormat(mDefaultFont,c));
+#endif
 		mKeywords.Add(new QStringList);
 	}
 
@@ -241,7 +249,9 @@ public:
 		if(mHighlightComments)
 		{
 			mCommentString = s;
+#ifdef IQT_3
 			this->format(1)->setColor(c);
+#endif
 		}
 	}
 
@@ -250,21 +260,26 @@ public:
 		mHighlightStrings = true;
 		if(mHighlightStrings)
 		{
+#ifdef IQT_3
 			this->format(2)->setColor(c);
+#endif
 		}
 	}
 
 private:
 
+#ifdef IQT_3
 	void AddFormat(int id, QTextFormat *f)
 	{
 		mFormats.insert(id,f);
 	}
 
-	QTextFormat *mLastFormat;
-	int mLastFormatId;
 	QIntDict<QTextFormat> mFormats;
+#endif
 
+	QTextFormat *mLastFormat;
+
+	int mLastFormatId;
 	iArray<QStringList*> mKeywords;
 	QString mCommentString;
 	bool mActive, mHighlightComments, mHighlightStrings;
@@ -272,13 +287,6 @@ private:
 	int mFirstFormat;
 };
 
-#endif
-
-//
-//  I use Qt3 support for now, since QTextEdit changed so much.
-//
-#define IQT_3SUPPORT
-
 
 //
 // Constructs an editor and connects a syntax highlighter
@@ -297,9 +305,9 @@ iqtWidgetTextEditorSubject::iqtWidgetTextEditorSubject(iggWidgetTextEditor *owne
 	f.setFamily("courier");
 	f.setFixedPitch(true);
 	iqtHelper::SetFont(this,f);
-	if(mode & _TextEditorWrapping)
+	if(mode & TextEditorFlag::Wrapping)
 	{
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
+#ifdef IQT_3
 		this->setWordWrap(QTextEdit::WidgetWidth);
 #else
 		this->setLineWrapMode(QTextEdit::WidgetWidth);
@@ -307,55 +315,53 @@ iqtWidgetTextEditorSubject::iqtWidgetTextEditorSubject(iggWidgetTextEditor *owne
 	}
 	else
 	{
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
+#ifdef IQT_3
 		this->setWordWrap(QTextEdit::NoWrap);
 #else
 		this->setLineWrapMode(QTextEdit::NoWrap);
 #endif
 	}
-	this->setReadOnly(mode & _TextEditorReadOnly);
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
-	if(mode & _TextEditorWithHTML) this->setTextFormat(Qt::RichText); else this->setTextFormat(Qt::PlainText);
+	this->setReadOnly(mode & TextEditorFlag::ReadOnly);
+#ifdef IQT_3
+	if(mode & TextEditorFlag::WithHTML) this->setTextFormat(Qt::RichText); else this->setTextFormat(Qt::PlainText);
 #endif
 
-#ifndef I_NO_SYNTAX_HIGHLIGHTING
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
-	mSyntaxHighlighter = new iqtSyntaxHighlighter; IERROR_ASSERT(mSyntaxHighlighter);
+	mSyntaxHighlighter = new SyntaxHighlighter; IERROR_ASSERT(mSyntaxHighlighter);
+#ifdef IQT_3
 	this->document()->setPreProcessor(mSyntaxHighlighter);
-#else
-	mSyntaxHighlighter = 0;
-#endif
-#else
-	mSyntaxHighlighter = 0;
 #endif
 
 	if(!connect(this,SIGNAL(textChanged()),this,SLOT(OnTextChanged()))) IERROR_LOW("Missed connection.");
 	if(!connect(this,SIGNAL(selectionChanged()),this,SLOT(OnSelectionChanged()))) IERROR_LOW("Missed connection.");
-	if(!connect(this,SIGNAL(cursorPositionChanged(int,int)),this,SLOT(OnCursorPositionChanged(int,int)))) IERROR_LOW("Missed connection.");
+#ifdef IQT_3
 	if(!connect(this,SIGNAL(returnPressed()),this,SLOT(OnReturnPressed()))) IERROR_LOW("Missed connection.");
+	if(!connect(this,SIGNAL(cursorPositionChanged(int,int)),this,SLOT(OnCursorPositionChanged(int,int)))) IERROR_LOW("Missed connection.");
+#else
+	if(!connect(this,SIGNAL(returnPressed2()),this,SLOT(OnReturnPressed()))) IERROR_LOW("Missed connection.");
+	if(!connect(this,SIGNAL(cursorPositionChanged()),this,SLOT(OnCursorPositionChanged()))) IERROR_LOW("Missed connection.");
+#endif
 }
 
 
 iqtWidgetTextEditorSubject::~iqtWidgetTextEditorSubject()
 {
-#ifndef I_NO_SYNTAX_HIGHLIGHTING
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
+#ifdef IQT_3
 	this->document()->setPreProcessor(0);
+#endif
+
 	delete mSyntaxHighlighter;
-#endif
-#endif
 }
 
 
 bool iqtWidgetTextEditorSubject::SupportsHTML() const
 {
-	return (mMode & _TextEditorWithHTML);
+	return (mMode & TextEditorFlag::WithHTML);
 }
 	
 
 bool iqtWidgetTextEditorSubject::TextModified() const
 {
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
+#ifdef IQT_3
 	return this->isModified();
 #else
 	return this->document()->isModified();
@@ -383,7 +389,7 @@ void iqtWidgetTextEditorSubject::Clear()
 void iqtWidgetTextEditorSubject::SetModified(bool s)
 {
 	this->blockSignals(true);
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
+#ifdef IQT_3
 	this->setModified(s);
 #else
 	this->document()->setModified(s);
@@ -395,7 +401,7 @@ void iqtWidgetTextEditorSubject::SetModified(bool s)
 void iqtWidgetTextEditorSubject::SetText(const iString &text)
 {
 	this->blockSignals(true);
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
+#ifdef IQT_3
 	this->setText(iqtHelper::Convert(text));
 #else
 	if(this->SupportsHTML()) this->setHtml(iqtHelper::Convert(text)); else this->setPlainText(iqtHelper::Convert(text));
@@ -406,7 +412,7 @@ void iqtWidgetTextEditorSubject::SetText(const iString &text)
 
 iString iqtWidgetTextEditorSubject::GetText() const
 {
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
+#ifdef IQT_3
 	return iqtHelper::Convert(this->text());
 #else
 	if(this->SupportsHTML()) return iqtHelper::Convert(this->toHtml()); else return iqtHelper::Convert(this->toPlainText());
@@ -422,7 +428,7 @@ void iqtWidgetTextEditorSubject::AppendText(const iString &text, bool scroll)
 	//
 	// if(this->GetText().IsEmpty()) this->SetText(text); else
 	this->append(iqtHelper::Convert(text));
-#if defined(IQT_3) || defined(IQT_3SUPPORT)
+#ifdef IQT_3
 	if(scroll) this->scrollToBottom();
 #endif
 	this->blockSignals(false);
@@ -436,9 +442,13 @@ int iqtWidgetTextEditorSubject::GetNumberOfLines() const
 	//
 	//  Fix a bug that returns 1 for empty text
 	//
+#ifdef IQT_3
 	int n = this->paragraphs();
+#else
+	int n = this->document()->blockCount();
+#endif
 	if(n > 1) return n;
-	if(this->text().isEmpty())
+	if(this->GetText().IsEmpty())
 	{
 		return 0;
 	}
@@ -451,10 +461,17 @@ int iqtWidgetTextEditorSubject::GetNumberOfLines() const
 
 void iqtWidgetTextEditorSubject::RemoveLine(int n)
 {
-	if(n>=0 && n<this->paragraphs())
+	if(n>=0 && n<this->GetNumberOfLines())
 	{
 		this->blockSignals(true);
+#ifdef IQT_3
 		this->removeParagraph(n);
+#else
+		QTextCursor c(this->document());
+		c.setPosition(this->document()->findBlockByNumber(n).position());
+		c.select(QTextCursor::BlockUnderCursor);
+		c.removeSelectedText();
+#endif
 		this->blockSignals(false);
 	}
 }
@@ -464,7 +481,15 @@ iString iqtWidgetTextEditorSubject::GetLine(int n) const
 {
 	static iString none;
 
-	if(n>=0 && n<this->paragraphs()) return iqtHelper::Convert(this->text(n)); else return none;
+	if(n>=0 && n<this->GetNumberOfLines())
+	{
+#ifdef IQT_3
+		return iqtHelper::Convert(this->text(n));
+#else
+		return iqtHelper::Convert(this->document()->findBlockByNumber(n).text());
+#endif
+	}
+	else return none;
 }
 
 
@@ -475,11 +500,13 @@ void iqtWidgetTextEditorSubject::SetPointSize(int s)
 {
 	if(!this->SupportsHTML())
 	{
-#ifndef I_NO_SYNTAX_HIGHLIGHTING
 		mSyntaxHighlighter->SetPointSize(s);
-#endif
 		this->blockSignals(true);
+#ifdef IQT_3
 		this->setPointSize(s);
+#else
+		this->setFontPointSize(s);
+#endif
 		this->blockSignals(false);
 	}
 }
@@ -490,7 +517,11 @@ void iqtWidgetTextEditorSubject::SetTextColor(const iColor &color)
 	if(!this->SupportsHTML())
 	{
 		this->blockSignals(true);
+#ifdef IQT_3
 		this->setColor(iqtHelper::Convert(color));
+#else
+		this->setTextColor(iqtHelper::Convert(color));
+#endif
 		this->blockSignals(false);
 	}
 }
@@ -501,7 +532,11 @@ void iqtWidgetTextEditorSubject::SetBoldText(bool s)
 	if(!this->SupportsHTML())
 	{
 		this->blockSignals(true);
+#ifdef IQT_3
 		this->setBold(s);
+#else
+		this->setFontWeight(QFont::Bold);
+#endif
 		this->blockSignals(false);
 	}
 }
@@ -510,7 +545,15 @@ void iqtWidgetTextEditorSubject::SetBoldText(bool s)
 void iqtWidgetTextEditorSubject::SetLineColor(int line, const iColor &color)
 {
 	this->blockSignals(true);
+#ifdef IQT_3
 	this->setParagraphBackgroundColor(line,iqtHelper::Convert(color));
+#else
+	QTextCursor c(this->document());
+	c.setPosition(this->document()->findBlockByNumber(line).position());
+	QTextBlockFormat f = c.blockFormat();
+	f.setBackground(QBrush(iqtHelper::Convert(color)));
+	c.setBlockFormat(f);
+#endif
 	this->blockSignals(false);
 }
 
@@ -518,35 +561,70 @@ void iqtWidgetTextEditorSubject::SetLineColor(int line, const iColor &color)
 void iqtWidgetTextEditorSubject::UnSetLineColor(int line)
 {
 	this->blockSignals(true);
+#ifdef IQT_3
 	this->clearParagraphBackground(line);
+#else
+	QTextCursor c(this->document());
+	c.setPosition(this->document()->findBlockByNumber(line).position());
+	QTextBlockFormat f = c.blockFormat();
+	f.clearBackground();
+	c.setBlockFormat(f);
+#endif
 	this->blockSignals(false);
 }
 
 
 iColor iqtWidgetTextEditorSubject::GetLineColor(int line) const
 {
+#ifdef IQT_3
 	return iqtHelper::Convert(this->paragraphBackgroundColor(line));
+#else
+	QTextCursor c(this->document());
+	c.setPosition(this->document()->findBlockByNumber(line).position());
+	return iqtHelper::Convert(c.blockFormat().background().color());
+#endif
 }
 
 
 //
 //  Selection
 //
-void iqtWidgetTextEditorSubject::Select(int paraFrom, int indexFrom, int paraTo, int indexTo, bool leftJustified, int selNum)
+void iqtWidgetTextEditorSubject::Select(int lineFrom, int indexFrom, int lineTo, int indexTo, bool leftJustified, int selNum)
 {
 	this->blockSignals(true);
-	if(paraFrom>paraTo || (paraFrom==paraTo && indexFrom>=indexTo))
+	if(lineFrom>lineTo || (lineFrom==lineTo && indexFrom>=indexTo))
 	{
+#ifdef IQT_3
 		this->removeSelection(selNum);
+#else
+		QTextCursor c(this->textCursor());
+		c.clearSelection();
+		this->setTextCursor(c);
+#endif
 	}
 	else
 	{
-		this->setSelection(paraFrom,indexFrom,paraTo,indexTo,selNum);
+#ifdef IQT_3
+		this->setSelection(lineFrom,indexFrom,lineTo,indexTo,selNum);
 		if(leftJustified)
 		{
-			this->setCursorPosition(paraTo,0);
+			this->setCursorPosition(lineTo,0);
 			this->ensureCursorVisible(); 
 		}
+#else
+		QTextCursor c(this->textCursor());
+		c.setPosition(this->document()->findBlockByNumber(lineFrom).position()+indexFrom);
+		c.setPosition(this->document()->findBlockByNumber(lineTo).position()+indexTo,QTextCursor::KeepAnchor);
+		if(leftJustified)
+		{
+//			c.setPosition(this->document()->findBlockByNumber(lineTo).position());
+		}
+		this->setTextCursor(c);
+		if(leftJustified)
+		{
+			this->ensureCursorVisible(); 
+		}
+#endif
 	}
 	this->blockSignals(false);
 }
@@ -560,17 +638,26 @@ void iqtWidgetTextEditorSubject::OnTextChanged()
 
 void iqtWidgetTextEditorSubject::OnSelectionChanged()
 {
-	int paraFrom, indexFrom, paraTo, indexTo;
+	int lineFrom, indexFrom, lineTo, indexTo;
 
-	this->getSelection(&paraFrom,&indexFrom,&paraTo,&indexTo,0);
-	if(paraFrom < 0) paraFrom = 0;
-	this->OnSelectionChangedBody(paraFrom,indexFrom,paraTo,indexTo);
+	this->GetSelection(lineFrom,indexFrom,lineTo,indexTo);
+
+	if(lineFrom < 0) lineFrom = 0;
+	this->OnSelectionChangedBody(lineFrom,indexFrom,lineTo,indexTo);
 }
 
 
-void iqtWidgetTextEditorSubject::OnCursorPositionChanged(int para, int index)
+void iqtWidgetTextEditorSubject::OnCursorPositionChanged()
 {
-	this->OnCursorPositionChangedBody(para,index);
+	int line, index;
+	this->GetCursorPosition(line,index);
+	this->OnCursorPositionChangedBody(line,index);
+}
+
+
+void iqtWidgetTextEditorSubject::OnCursorPositionChanged(int line, int index)
+{
+	this->OnCursorPositionChangedBody(line,index);
 }
 
 
@@ -580,9 +667,15 @@ void iqtWidgetTextEditorSubject::OnReturnPressed()
 }
 
 
-void iqtWidgetTextEditorSubject::GetCursorPosition(int &para, int &index)
+void iqtWidgetTextEditorSubject::GetCursorPosition(int &line, int &index)
 {
-	this->getCursorPosition(&para,&index);
+#ifdef IQT_3
+	this->getCursorPosition(&line,&index);
+#else
+	Location loc(this);
+	line = loc.Line();
+	index = loc.Index();
+#endif
 }
 
 
@@ -590,11 +683,11 @@ bool iqtWidgetTextEditorSubject::HasEditingFunction(int type) const
 {
 	switch(type)
 	{
-	case _TextEditorFunctionUndo:
-	case _TextEditorFunctionRedo:
-	case _TextEditorFunctionCut:
-	case _TextEditorFunctionCopy:
-	case _TextEditorFunctionPaste:
+	case TextEditorFunction::Undo:
+	case TextEditorFunction::Redo:
+	case TextEditorFunction::Cut:
+	case TextEditorFunction::Copy:
+	case TextEditorFunction::Paste:
 		{
 			return true;
 		}
@@ -610,27 +703,27 @@ void iqtWidgetTextEditorSubject::UseEditingFunction(int type)
 {
 	switch(type)
 	{
-	case _TextEditorFunctionUndo:
+	case TextEditorFunction::Undo:
 		{
 			this->undo();
 			break;
 		}
-	case _TextEditorFunctionRedo:
+	case TextEditorFunction::Redo:
 		{
 			this->redo();
 			break;
 		}
-	case _TextEditorFunctionCut:
+	case TextEditorFunction::Cut:
 		{
 			this->cut();
 			break;
 		}
-	case _TextEditorFunctionCopy:
+	case TextEditorFunction::Copy:
 		{
 			this->copy();
 			break;
 		}
-	case _TextEditorFunctionPaste:
+	case TextEditorFunction::Paste:
 		{
 			this->paste();
 			break;
@@ -645,9 +738,33 @@ void iqtWidgetTextEditorSubject::UseEditingFunction(int type)
 //
 //  Search & find
 //
-bool iqtWidgetTextEditorSubject::Find(const iString &text, bool cs, bool wo, bool forward, int &para, int &index)
+bool iqtWidgetTextEditorSubject::Find(const iString &text, bool cs, bool wo, bool forward, int &line, int &index)
 {
-	return this->find(iqtHelper::Convert(text),cs,wo,forward,&para,&index);
+#ifdef IQT_3
+	return this->find(iqtHelper::Convert(text),cs,wo,forward,&line,&index);
+#else
+	QTextCursor prev(this->document());
+	if(line>=0 && index>=0)
+	{
+		prev.setPosition(this->document()->findBlockByNumber(line).position()+index);
+	}
+	else
+	{
+		prev.setPosition(0);
+	}
+	QTextCursor next = this->document()->find(iqtHelper::Convert(text),prev.position(),QTextDocument::FindFlags((cs?QTextDocument::FindCaseSensitively:0)|(wo?QTextDocument::FindWholeWords:0)|(forward?QTextDocument::FindBackward:0)));
+	if(next.isNull())
+	{
+		return false;
+	}
+	else
+	{
+		Location loc(this,next);
+		line = loc.Line();
+		index = loc.Index();
+		return true;
+	}
+#endif
 }
 
 
@@ -656,41 +773,31 @@ bool iqtWidgetTextEditorSubject::Find(const iString &text, bool cs, bool wo, boo
 //
 void iqtWidgetTextEditorSubject::HighlightSyntax(bool s)
 {
-#ifndef I_NO_SYNTAX_HIGHLIGHTING
 	mSyntaxHighlighter->Activate(s);
-#endif
 }
 
 
 void iqtWidgetTextEditorSubject::AddKeyword(const iString &word, int category)
 {
-#ifndef I_NO_SYNTAX_HIGHLIGHTING
 	mSyntaxHighlighter->AddKeyword(iqtHelper::Convert(word),category);
-#endif
 }
 
 
 void iqtWidgetTextEditorSubject::AddCategory(const iColor &color)
 {
-#ifndef I_NO_SYNTAX_HIGHLIGHTING
 	mSyntaxHighlighter->AddCategory(iqtHelper::Convert(color));
-#endif
 }
 
 
 void iqtWidgetTextEditorSubject::HighlightComments(const iString &comment, const iColor &color)
 {
-#ifndef I_NO_SYNTAX_HIGHLIGHTING
 	mSyntaxHighlighter->SetHighlightComments(iqtHelper::Convert(comment),iqtHelper::Convert(color));
-#endif
 }
 
 
 void iqtWidgetTextEditorSubject::HighlightStrings(const iColor &color)
 {
-#ifndef I_NO_SYNTAX_HIGHLIGHTING
 	mSyntaxHighlighter->SetHighlightStrings(iqtHelper::Convert(color));
-#endif
 }
 
 
@@ -706,15 +813,30 @@ void iqtWidgetTextEditorSubject::enterEvent(QEvent * )
 }
 
 
+#ifdef IQT_3
 void iqtWidgetTextEditorSubject::contentsMouseDoubleClickEvent(QMouseEvent *e)
+#else
+void iqtWidgetTextEditorSubject::mouseDoubleClickEvent(QMouseEvent *e)
+#endif
 {
 	if(this->isReadOnly() && e->button()==Qt::LeftButton)
 	{
 		e->accept();
+#ifdef IQT_3
 		this->removeSelection();
 		emit returnPressed();
+#else
+		QTextCursor c(this->textCursor());
+		c.clearSelection();
+		this->setTextCursor(c);
+		emit returnPressed2();
+#endif
 	}
+#ifdef IQT_3
 	else QTextEdit::contentsMouseDoubleClickEvent(e);
+#else
+	else QTextEdit::mouseDoubleClickEvent(e);
+#endif
 }
 
 
@@ -728,7 +850,11 @@ void iqtWidgetTextEditorSubject::keyPressEvent(QKeyEvent *e)
 		case Qt::Key_Enter:
 		case Qt::Key_Space:
 			{
+#ifdef IQT_3
 				if(this->isReadOnly()) emit returnPressed();
+#else
+				if(this->isReadOnly()) emit returnPressed2();
+#endif
 				break;
 			}
 		}
@@ -739,8 +865,8 @@ void iqtWidgetTextEditorSubject::keyPressEvent(QKeyEvent *e)
 		if(e->modifiers() & Qt::CTRL)
 #endif
 		{
-			int para, index;
-			this->getCursorPosition(&para,&index);
+			int line, index;
+			this->GetCursorPosition(line,index);
 			//
 			//  Add cursor moving if Cntr button is pressed
 			//
@@ -748,48 +874,48 @@ void iqtWidgetTextEditorSubject::keyPressEvent(QKeyEvent *e)
 			{
 			case Qt::Key_Up:
 				{
-					para--;
-					this->setCursorPosition(para,index);
+					line--;
+					this->SetCursorPosition(line,index);
 					this->ensureCursorVisible();
 					e->accept();
 					return;
 				}
 			case Qt::Key_Down:
 				{
-					para++;
-					this->setCursorPosition(para,index);
+					line++;
+					this->SetCursorPosition(line,index);
 					this->ensureCursorVisible();
 					e->accept();
 					return;
 				}
 			case Qt::Key_PageUp:
 				{
-					para -= 10;
-					this->setCursorPosition(para,index);
+					line -= 10;
+					this->SetCursorPosition(line,index);
 					this->ensureCursorVisible();
 					e->accept();
 					return;
 				}
 			case Qt::Key_PageDown:
 				{
-					para += 10;
-					this->setCursorPosition(para,index);
+					line += 10;
+					this->SetCursorPosition(line,index);
 					this->ensureCursorVisible();
 					e->accept();
 					return;
 				}
 			case Qt::Key_Home:
 				{
-					para = 0;
-					this->setCursorPosition(para,index);
+					line = 0;
+					this->SetCursorPosition(line,index);
 					this->ensureCursorVisible();
 					e->accept();
 					return;
 				}
 			case Qt::Key_End:
 				{
-					para = this->paragraphs() - 1;
-					this->setCursorPosition(para,index);
+					line = this->GetNumberOfLines() - 1;
+					this->SetCursorPosition(line,index);
 					this->ensureCursorVisible();
 					e->accept();
 					return;
@@ -803,8 +929,8 @@ void iqtWidgetTextEditorSubject::keyPressEvent(QKeyEvent *e)
 		if(e->modifiers() & Qt::SHIFT)
 #endif
 		{
-			int paraFrom, indexFrom, paraTo, indexTo;
-			this->getSelection(&paraFrom,&indexFrom,&paraTo,&indexTo,0);
+			int lineFrom, indexFrom, lineTo, indexTo;
+			this->GetSelection(lineFrom,indexFrom,lineTo,indexTo);
 
 			//
 			//  Add cursor moving if Cntr button is pressed
@@ -813,46 +939,46 @@ void iqtWidgetTextEditorSubject::keyPressEvent(QKeyEvent *e)
 			{
 			case Qt::Key_Up:
 				{
-					this->setSelection(--paraFrom,indexFrom,paraTo,indexTo);
+					this->Select(--lineFrom,indexFrom,lineTo,indexTo);
 					emit selectionChanged();
 					e->accept();
 					return;
 				}
 			case Qt::Key_Down:
 				{
-					this->setSelection(paraFrom,indexFrom,++paraTo,indexTo);
+					this->Select(lineFrom,indexFrom,++lineTo,indexTo);
 					emit selectionChanged();
 					e->accept();
 					return;
 				}
 			case Qt::Key_PageUp:
 				{
-					paraFrom -= 10;
-					this->setSelection(paraFrom,indexFrom,paraTo,indexTo);
+					lineFrom -= 10;
+					this->Select(lineFrom,indexFrom,lineTo,indexTo);
 					emit selectionChanged();
 					e->accept();
 					return;
 				}
 			case Qt::Key_PageDown:
 				{
-					paraTo += 10;
-					this->setSelection(paraFrom,indexFrom,paraTo,indexTo);
+					lineTo += 10;
+					this->Select(lineFrom,indexFrom,lineTo,indexTo);
 					emit selectionChanged();
 					e->accept();
 					return;
 				}
 			case Qt::Key_Home:
 				{
-					paraFrom = 0;
-					this->setSelection(paraFrom,indexFrom,paraTo,indexTo);
+					lineFrom = 0;
+					this->Select(lineFrom,indexFrom,lineTo,indexTo);
 					emit selectionChanged();
 					e->accept();
 					return;
 				}
 			case Qt::Key_End:
 				{
-					paraTo = this->paragraphs() - 1;
-					this->setSelection(paraFrom,indexFrom,paraTo,indexTo);
+					lineTo = this->GetNumberOfLines() - 1;
+					this->Select(lineFrom,indexFrom,lineTo,indexTo);
 					emit selectionChanged();
 					e->accept();
 					return;
@@ -865,23 +991,34 @@ void iqtWidgetTextEditorSubject::keyPressEvent(QKeyEvent *e)
 }
 
 
-void iqtWidgetTextEditorSubject::contentsMousePressEvent(QMouseEvent *e)
+//
+//  Private helpers
+//
+void iqtWidgetTextEditorSubject::GetSelection(int &lineFrom, int &indexFrom, int &lineTo, int &indexTo)
 {
-//	int para;
-//	int index = this->charAt(e->pos(),&para);
-//	this->OnMousePressBody(para,index);
+#ifdef IQT_3
+	this->getSelection(&lineFrom,&indexFrom,&lineTo,&indexTo,0);
+#else
+	Location from(this,this->textCursor(),this->textCursor().selectionStart());
+	lineFrom = from.Line();
+	indexFrom = from.Index();
 
-	QTextEdit::contentsMousePressEvent(e);
+	Location to(this,this->textCursor(),this->textCursor().selectionEnd());
+	lineTo = to.Line();
+	indexTo = to.Index();
+#endif
 }
 
 
-void iqtWidgetTextEditorSubject::contentsMouseReleaseEvent(QMouseEvent *e)
+void iqtWidgetTextEditorSubject::SetCursorPosition(int line, int index)
 {
-	QTextEdit::contentsMouseReleaseEvent(e);
-
-//	int para;
-//	int index = this->charAt(e->pos(),&para);
-//	this->OnMouseReleaseBody(para,index);
+#ifdef IQT_3
+	this->setCursorPosition(line,index);
+#else
+	QTextCursor c(this->textCursor());
+	c.setPosition(this->document()->findBlockByNumber(line).position()+index);
+	this->setTextCursor(c);
+#endif
 }
 
 #endif
