@@ -38,14 +38,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifdef IQT_3
 #include <qtextedit.h>
 #else
-#include <Qt3Support/Q3TextEdit>
-#define QTextEdit Q3TextEdit
+#include <QtGui/QTextEdit>
 #endif
 #include "ibgwidgettexteditorsubject.h"
 
 
 class iggWidgetTextEditor;
 
+class iqtLocationHelper;
 class iqtSyntaxHighlighter;
 
 class QEvent;
@@ -98,8 +98,8 @@ public:
 	//
 	//  Selection & cursor location
 	//
-	virtual void Select(int paraFrom, int indexFrom, int paraTo, int indexTo, bool leftJustified = false, int selNum = 0);
-	virtual void GetCursorPosition(int &para, int &index);
+	virtual void Select(int lineFrom, int indexFrom, int lineTo, int indexTo, bool leftJustified = false, int selNum = 0);
+	virtual void GetCursorPosition(int &line, int &index);
 
 	//
 	//  Syntax highlighting
@@ -119,30 +119,45 @@ public:
 	//
 	//  Search & find
 	//
-	virtual bool Find(const iString &text, bool cs, bool wo, bool forward, int &para, int &index);
+	virtual bool Find(const iString &text, bool cs, bool wo, bool forward, int &line, int &index);
 
 protected:
 
 	iqtWidgetTextEditorSubject(iggWidgetTextEditor *owner, unsigned int mode);
 
-	iqtSyntaxHighlighter *mSyntaxHighlighter;
-	const int mMode;
-
 	//
 	//  Qt specific
 	//
 	virtual void enterEvent(QEvent *e);
 	virtual void keyPressEvent(QKeyEvent *e);
-	virtual void contentsMousePressEvent(QMouseEvent *e);
-	virtual void contentsMouseReleaseEvent(QMouseEvent *e);
+#ifdef IQT_3
 	virtual void contentsMouseDoubleClickEvent(QMouseEvent *e);
+#else
+	virtual void mouseDoubleClickEvent(QMouseEvent *e);
+#endif
+
+signals:
+
+	void returnPressed2();
 
 public slots:
 
 	void OnTextChanged();
 	void OnSelectionChanged();
-	void OnCursorPositionChanged(int, int);
 	void OnReturnPressed();
+	void OnCursorPositionChanged();
+	void OnCursorPositionChanged(int,int);
+
+private:
+
+	void GetSelection(int &lineFrom, int &indexFrom, int &lineTo, int &indexTo);
+	void SetCursorPosition(int line, int index);
+
+	class Location;
+	class SyntaxHighlighter;
+
+	SyntaxHighlighter *mSyntaxHighlighter;
+	const int mMode;
 };
 
 #endif  //  IQTWIDGETTEXTEDITORSUBJECT_H
